function [logDat ts] = ExtractBehavior(datDir, logFile, task)

% flag active reward port (L = 1, R = 2)
rwdPort = 2;
altPort = 1;

% load RHD info
rhdFile = [datDir filesep 'info.rhd'];
rhdInfo = ReadRhdInfo(rhdFile);


%% Extract All Box File Timestamps

% get recording duration
info = dir([datDir,'/board-ADC-00.dat']);
recDur = info.bytes / (2 * rhdInfo.Fs);

% extract go cue time
fid = fopen([datDir,'/board-ADC-00.dat'], 'r');
goCue = fread(fid, 'uint16');
goCue = 3.3 - goCue * 0.000050354;
fclose(fid);
goCue = goCue > 2.5;
goCue = diff(goCue);
goCue = find(goCue == 1) / rhdInfo.Fs;
goCue(goCue < 10)= [];

% extract trial/attempt initiation (RL)
fid = fopen([datDir,'/board-ADC-01.dat'], 'r');
attemptBegin = fread(fid, 'uint16');
attemptBegin = 3.3 - attemptBegin * 0.000050354;
fclose(fid);
attemptBegin = attemptBegin > 2.5;
attemptBegin = diff(attemptBegin);
attemptBegin = find(attemptBegin == 1) / rhdInfo.Fs;
attemptBegin(attemptBegin < 10)= [];

% extract Pavlovian CS time
fid = fopen([datDir,'/board-ADC-02.dat'], 'r');
pavCS = fread(fid, 'uint16');
pavCS = 3.3 - pavCS * 0.000050354;
fclose(fid);
pavCS = pavCS > 2.5;
pavCS = diff(pavCS);
pavCS = find(pavCS == 1) / rhdInfo.Fs;
pavCS(pavCS < 10)= [];

% extract trial/attempt initiation (linear track)
fid = fopen([datDir,'/board-ADC-03.dat'], 'r');
runBegin = fread(fid, 'uint16');
runBegin = 3.3 - runBegin * 0.000050354;
fclose(fid);
runBegin = runBegin > 2.5;
runBegin = diff(runBegin);
runBegin = find(runBegin == 1) / rhdInfo.Fs;
runBegin(runBegin < 10)= [];

% extract cue light times: port 1
fid = fopen([datDir,'/board-DIN-00.dat'], 'r');
cue = fread(fid, 'uint16');
cue = 1 - cue;
fclose(fid);
cue = diff(cue);
cue_on{1} = find(cue == 1) / rhdInfo.Fs;
cue_off{1} = find(cue == -1) / rhdInfo.Fs;

% extract cue light times: port 2
fid = fopen([datDir,'/board-DIN-01.dat'], 'r');
cue = fread(fid, 'uint16');
cue = 1 - cue;
fclose(fid);
cue = diff(cue);
cue_on{2} = find(cue == 1) / rhdInfo.Fs;
cue_off{2} = find(cue == -1) / rhdInfo.Fs;

% extract cue light times: port 3
fid = fopen([datDir,'/board-DIN-02.dat'], 'r');
cue = fread(fid, 'uint16');
cue = 1 - cue;
fclose(fid);
cue = diff(cue);
cue_on{3} = find(cue == 1) / rhdInfo.Fs;
cue_off{3} = find(cue == -1) / rhdInfo.Fs;

% extract cue light times: port 4
fid = fopen([datDir,'/board-DIN-03.dat'], 'r');
cue = fread(fid, 'uint16');
cue = 1 - cue;
fclose(fid);
cue = diff(cue);
cue_on{4} = find(cue == 1) / rhdInfo.Fs;
cue_off{4} = find(cue == -1) / rhdInfo.Fs;

% extract cue light times: port 5
fid = fopen([datDir,'/board-DIN-04.dat'], 'r');
cue = fread(fid, 'uint16');
cue = 1 - cue;
fclose(fid);
cue = diff(cue);
cue_on{5} = find(cue == 1) / rhdInfo.Fs;
cue_off{5} = find(cue == -1) / rhdInfo.Fs;

% extract house light times
fid = fopen([datDir,'/board-DIN-05.dat'], 'r');
light = fread(fid, 'uint16');
light = 1 - light;
fclose(fid);
light = diff(light);
light_on = find(light == 1) / rhdInfo.Fs;
light_off = find(light == -1) / rhdInfo.Fs;

% extract reward times
fid = fopen([datDir,'/board-DIN-06.dat'], 'r');
rwd = fread(fid, 'uint16');
rwd = 1 - rwd;
fclose(fid);
rwd = diff(rwd);
rwd = find(rwd == 1) / rhdInfo.Fs;

% extract laser times (laser tagging only)
fid = fopen([datDir,'/board-DIN-07.dat'], 'r');
laser = fread(fid, 'uint16');
fclose(fid);
laser = diff(laser);
laser_on = find(laser == 1) / rhdInfo.Fs;
laser_off = find(laser == -1) / rhdInfo.Fs;

% extract laser stim times (RL)
if exist([datDir,'/board-ADC-04.dat']) == 2 & strcmp(lower(task), 'rl')
    fid = fopen([datDir,'/board-ADC-04.dat'], 'r');
    laser = fread(fid, 'uint16');
    fclose(fid);
    laser = laser * 0.000050354;
    laser(laser <= 1.65) = 0;
    laser(laser > 1.65) = max(laser);
    laser_on = find(diff(laser) > 2.) / rhdInfo.Fs;
    laser_off = find(diff(laser) < -2.5) / rhdInfo.Fs;
end

if ~isempty(laser_on) & ~isempty(laser_off) & length(laser_on) + length(laser_off) > 2
    laser_off(laser_off < laser_on(1)) = [];
    laser_on(laser_on > laser_off(end)) = [];
end

% extract nosepokes: port 1
fid = fopen([datDir,'/board-DIN-08.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
port_in{1} = find(poke == 1) / rhdInfo.Fs;
port_out{1} = find(poke == -1) / rhdInfo.Fs;

% extract nosepokes: port 2
fid = fopen([datDir,'/board-DIN-09.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
port_in{2} = find(poke == 1) / rhdInfo.Fs;
port_out{2} = find(poke == -1) / rhdInfo.Fs;

% extract nosepokes: port 3
fid = fopen([datDir,'/board-DIN-10.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
port_in{3} = find(poke == 1) / rhdInfo.Fs;
port_out{3} = find(poke == -1) / rhdInfo.Fs;

% extract nosepokes: port 4
fid = fopen([datDir,'/board-DIN-11.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
port_in{4} = find(poke == 1) / rhdInfo.Fs;
port_out{4} = find(poke == -1) / rhdInfo.Fs;

% extract nosepokes: port 5
fid = fopen([datDir,'/board-DIN-12.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
port_in{5} = find(poke == 1) / rhdInfo.Fs;
port_out{5} = find(poke == -1) / rhdInfo.Fs;

% extract reward port entry: left port
fid = fopen([datDir,'/board-DIN-14.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
rwdPort_in{1} = find(poke == 1) / rhdInfo.Fs;
rwdPort_out{1} = find(poke == -1) / rhdInfo.Fs;

% extract reward port entry: right port
fid = fopen([datDir,'/board-DIN-13.dat'], 'r');
poke = fread(fid, 'uint16');
poke = 1 - poke;
fclose(fid);
poke = diff(poke);
rwdPort_in{2} = find(poke == 1) / rhdInfo.Fs;
rwdPort_out{2} = find(poke == -1) / rhdInfo.Fs;


%% Load Log File Data and Check Correspondence with Box File Timestamps

switch lower(task)
    
    case 'laser'
        
        % load data from behavior log
        logDat = ReadBehavLog(logFile, task);
        
        % check laser pulse data against log info
        nBlocks = length(logDat);
        nPulsesBox = length(laser_on);
        nPulsesLog = sum(arrayfun(@(x) x.count, logDat));
        logIPI = unique([30 60 arrayfun(@(l) 1/l.frequency, logDat)]);
        if nPulsesBox ~= nPulsesLog
            ipi = diff(laser_on);
            ipi = round(10*ipi)/10;
            % startIdx = find(~ismember(ipi, logIPI)) + 1;
            % start new code
            startIdx = find(ismember(ipi, logIPI));
            startIdx = startIdx(1);
            % end new code
            laser_on = laser_on(startIdx:end);
            laser_off = laser_off(startIdx:end);
            ipi = ipi(startIdx:end);
            nPulsesBox = length(laser_on);
            if nPulsesBox == nPulsesLog + 1
                disp('WARNING: logged laser pulses do not match recorded laser pulses')
                return
            end
        end
        %ipi = diff(laser_on); % inter-pulse interval
        %ibi = floor(max(ipi)); % inter-block interval
        for n = 1:nBlocks
            % blkIPI = 1 / logDat(n).frequency;
            idx = sum(arrayfun(@(x) x.count, logDat(1:n-1))) + (1:logDat(n).count);
            ts(n).onset = laser_on(idx);
            dur = laser_off(idx) - laser_on(idx);
            if any(abs(1000 * dur - logDat(n).duration) > 0.1)
                disp(['logged laser pulses do not match recorded laser pulses on block ' num2str(n)])
                return
            end
            ts(n).duration = dur;
            
        end
    
    case 'rl' % ** add laser to this! **
        
        % load data from behavior log
        logDat = ReadBehavLog(logFile, task);
        centerPort = logDat.attemptData.centerPort;
        
        % check attempt start times against log
        nAttempts = length(attemptBegin);
        attemptIntervalBox = diff(attemptBegin);
        attemptIntervalLog = diff(logDat.attemptData.time);
        dt = abs(attemptIntervalLog - attemptIntervalBox(1));
        firstAttempt = find(dt < 0.01);
        firstAttempt = firstAttempt(1);
        nAttempts = min(nAttempts, length(logDat.attemptData.time) - firstAttempt + 1);

        % organize box ts data by attempt
        cueDelay = arrayfun(@(i) min(abs(cue_on{centerPort(i)}-attemptBegin(i))), 1:nAttempts);
        cueDelay = arrayfun(@(i) min(abs(cue_on{3}-attemptBegin(i))), 1:nAttempts);
        earlyStart = find(cueDelay > 0.021 | cueDelay < 0.019)';
        cuedStarts = setdiff(1:nAttempts, earlyStart)';
        cueIdx = arrayfun(@(i) find(cue_on{centerPort(i)}-attemptBegin(i) > 0.019 & cue_on{centerPort(i)}-attemptBegin(i) < 0.021), cuedStarts);
        cueOn = nan(nAttempts, 1);
        cueOn(cuedStarts) = arrayfun(@(i) cue_on{centerPort(cuedStarts(i))}(cueIdx(i))-attemptBegin(cuedStarts(i)), 1:length(cuedStarts));
        attemptBegin = [attemptBegin; recDur];
        for i = 1:nAttempts
            t1 = attemptBegin(i);
            t2 = attemptBegin(i+1);
            attempt(i).begin = t1;
            attempt(i).cueOn = cueOn(i);
            attempt(i).goCue = goCue(goCue > t1 & goCue < t2) - t1;
            attempt(i).rwdTime = rwd(rwd > t1 & rwd < t2) - t1;
            attempt(i).houseLightOn = light_on(light_on > t1 & light_on < t2) - t1;
            attempt(i).houseLightOff = light_off(light_off > t1 & light_off <= t2 + 0.2) - t1;
            attempt(i).laserOn = laser_on(laser_on > t1 & laser_on < t2) - t1;
            attempt(i).laserOff = laser_off(laser_off > t1 & laser_off < t2) - t1;
            attempt(i).port_in = cellfun(@(p) p(p > t1 & p < t2) - t1, port_in, 'UniformOutput', false);
            attempt(i).port_out = cellfun(@(p) p(p > t1 + 0.02 & p < t2) - t1, port_out, 'UniformOutput', false); % hack!
            attempt(i).rwdPort_in = rwdPort_in{rwdPort}(rwdPort_in{rwdPort} > t1 & rwdPort_in{rwdPort} < t2) - t1;
            attempt(i).rwdPort_out = rwdPort_out{rwdPort}(rwdPort_out{rwdPort} > t1 & rwdPort_out{rwdPort} < t2) - t1;
            attempt(i).altRwdPort_in = rwdPort_in{altPort}(rwdPort_in{altPort} > t1 & rwdPort_in{altPort} < t2) - t1;
            attempt(i).altRwdPort_out = rwdPort_out{altPort}(rwdPort_out{altPort} > t1 & rwdPort_out{altPort} < t2) - t1;
        end
        logDat.attemptData.wrongStart = setdiff(logDat.attemptData.wrongStart, earlyStart);
        logDat.attemptData.earlyStart = earlyStart;
        ts.attempt = attempt;
        
        
        % log box ts data for valid trials
        ts.attemptNumber = logDat.attemptData.validTrial - firstAttempt + 1;
        if any(ts.attemptNumber < 1)
            disp('** WARNING: early valid trial, some log data will be wrong **')
            nDel = length(find(ts.attemptNumber < 1));
            ts.attemptNumber(1:nDel) = [];
            logDat.TrialNumber = logDat.TrialNumber(1:end-nDel); 
            logDat.nBlockTrials(1) = logDat.nBlockTrials(1) - nDel;
            logDat.blockNum(1:nDel) = [];
            % logDat.blockTrial;
            logDat.centerPort(1:nDel) = [];
            logDat.R_choice(1:nDel) = [];
            logDat.L_choice(1:nDel) = [];
            logDat.outcome(1:nDel) = [];
            logDat.block_probabilities(1:nDel) = [];
            logDat.ReactionTime(1:nDel) = [];
            logDat.MovementTime(1:nDel) = [];
            logDat.CNIlatency(1:nDel) = [];
        end
        
        % hack to catch and fix a rare error
        del = find(arrayfun(@(i) isempty(attempt(i).goCue), ts.attemptNumber)); 
        ts.attemptNumber(del) = [];
        logDat.TrialNumber(del) = [];
        logDat.R_choice(del) = [];
        logDat.L_choice(del) = [];
        logDat.blockNum(del) = [];
        logDat.centerPort(del) = [];
        logDat.outcome(del) = [];
        logDat.ReactionTime(del) = [];
        logDat.MovementTime(del) = [];
        logDat.CNIlatency(del) = [];
        
        ts.trialbegin = arrayfun(@(i) attempt(i).begin, ts.attemptNumber);
        ts.go = arrayfun(@(i) attempt(i).goCue(1), ts.attemptNumber) + ts.trialbegin;
        ts.choice = blanks(length(logDat.TrialNumber));
        ts.choice(logDat.R_choice) = 'R';
        ts.choice(logDat.L_choice) = 'L';
        
        ts.outcome = logDat.outcome;
        
        ts.Center_NI = arrayfun(@(i) attempt(i).port_in{centerPort(i)}(1), ts.attemptNumber) + ts.trialbegin;
        ts.Center_NO = arrayfun(@(i) attempt(i).port_out{centerPort(i)}(1), ts.attemptNumber) + ts.trialbegin;
        sidePort = centerPort;
        Ridx = ts.attemptNumber(arrayfun(@(x) strcmp(x, 'R'), ts.choice));
        sidePort(Ridx) = sidePort(Ridx) + 1;
        Lidx = ts.attemptNumber(arrayfun(@(x) strcmp(x, 'L'), ts.choice));
        sidePort(Lidx) = sidePort(Lidx) - 1;
        ts.Side_NI = arrayfun(@(i) attempt(i).port_in{sidePort(i)}(1), ts.attemptNumber) + ts.trialbegin;
        ts.Side_NO = arrayfun(@(i) attempt(i).port_out{sidePort(i)}(1), ts.attemptNumber) + ts.trialbegin;
        ts.firstFoodPoke = nan(length(ts.attemptNumber), 1);
        ts.firstFoodPokeOut = nan(length(ts.attemptNumber), 1);
        for i = 1:length(ts.attemptNumber)
            rwdPokeIn = attempt(ts.attemptNumber(i)).rwdPort_in + ts.trialbegin(i);
            rwdPokeOut = attempt(ts.attemptNumber(i)).rwdPort_out + ts.trialbegin(i);
            if i < length(ts.attemptNumber) % also consider rwd pokes occurring before CNI of next trial
                tmp = attempt(ts.attemptNumber(i+1)).rwdPort_in + ts.trialbegin(i+1);
                rwdPokeIn = [rwdPokeIn; tmp(tmp < ts.Center_NI(i+1))];
                tmp = attempt(ts.attemptNumber(i+1)).rwdPort_out + ts.trialbegin(i+1);
                rwdPokeOut = [rwdPokeOut; tmp(tmp < ts.Center_NI(i+1))];
            end
            rwdPokeIn = rwdPokeIn(rwdPokeIn > ts.Side_NO(i)); % only consider rwd pokes that happen after SNO of current trial
            if ~isempty(rwdPokeIn)
                ts.firstFoodPoke(i) = rwdPokeIn(1);
                rwdPokeOut = rwdPokeOut(rwdPokeOut > rwdPokeIn(1));
                if ~isempty(rwdPokeOut)
                    ts.firstFoodPokeOut(i) = rwdPokeOut(1);
                end
            end
        end
        
    case 'pav'
        
        % load data from behavior log
        logDat = ReadBehavLog(logFile, task);
        nTr = length(logDat.time);
        ts.csTime = pavCS(1:nTr);
        ts.rwdTime = nan(nTr, 1);
        if length(find(logDat.outcome)) <= length(rwd)
            tRwd = ts.csTime + (logDat.toneDur + logDat.rewForeperiod) / 1000;
            rwdTr = find(logDat.outcome)';
            for k = rwdTr
                rwdIdx = find(abs(tRwd(k) - rwd) < 0.2);     
                ts.rwdTime(k) = rwd(rwdIdx);
            end
        else
            disp('error reading reward times')
            return
        end
        if any(isnan(ts.rwdTime(logDat.outcome)))
            disp('error reading reward times')
            return
        end
        ts.foodPokeLatency = nan(nTr, 1);
        ts.rwdPokeIn = cell(nTr, 1);
        ts.rwdPokeOut = cell(nTr, 1);
        rwdPokeIn = rwdPort_in{rwdPort};
        rwdPokeOut = rwdPort_out{rwdPort};
        if ~isempty(rwdPokeIn) & ~isempty(rwdPokeOut)
            rwdPokeIn(rwdPokeIn > rwdPokeOut(end)) = [];
            rwdPokeOut(rwdPokeOut < rwdPokeIn(1)) = []; 
        end
        % for each trial, log rwd pokes between CS onset of current trial and CS onset of next trial
        for k = 1:nTr
            t1 = ts.csTime(k);
            if k < nTr
                t2 = ts.csTime(k+1);
            else
                t2 = t1 + 15;
            end
            if ~isempty(rwdPokeIn) & ~isempty(rwdPokeOut)
                ts.rwdPokeIn{k} = rwdPokeIn(rwdPokeIn > t1 & rwdPokeIn <= t2);
                ts.rwdPokeOut{k} = rwdPokeOut(rwdPokeOut > t1 & rwdPokeOut <= t2);
            end
            if length(ts.rwdPokeIn{k}) > 0
                ts.foodPokeLatency(k) = ts.rwdPokeIn{k}(1) - ts.csTime(k);
                if length(ts.rwdPokeOut{k}) > 0 && ts.rwdPokeIn{k}(1) > ts.rwdPokeOut{k}(1)
                    ts.foodPokeLatency(k) = 0;
                end
            elseif length(ts.rwdPokeOut{k}) > 0
                ts.foodPokeLatency(k) = 0;
            end
        end

        
    case 'track'
        
    case 'laser'
        
end