% NOTE: there is no Fig. 1 ver. 6
% Changes: log-scale plots for B and D
% Waveforms for example cells
% Box-and-arrows diagram for Fig. 1A
% Changes/removal of tagging panel
% Avg rate/CV bars for D (labeled rate-CV plot)


%% Load Unit Data
 
datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)

fpColor = [1 0.5 0];
rpColor = [0.7 0 0];

% see earlier versions of GPe-RPE Fig 1 to for raw data load



%% Figure 1a: Drive Schematics

%% Figure 1b (Example Units at Wake-SWS Transition)

% summary of cell type and spike amplitude by recording session
sesList = unique(uSes);

sesDat = [];
for s = 1:length(sesList)
    
    unitList = find(strcmp(uSes, sesList{s}));
    
    sesFP = intersect(fp, unitList);
    sesSP = intersect(sp, unitList);
    sesAK = intersect(ak, unitList);
    sesRP = intersect(rp, unitList);
    
    if all(cellfun(@(u) ~isempty(u), {sesFP, sesSP, sesAK, sesRP}))
        clear x
        x.ses = sesList{s};
        x.unit = unitList;
        x.fp = sesFP;
        x.sp = sesSP;
        x.ak = sesAK;
        x.rp = sesRP; 
        x.ampl = []; x.chan = []; x.rel = []; x.relChan = [];
        trodeList = unique(uTrode(strcmp(uSes, sesList{s})));
        for t = 1:length(trodeList)
            uLoc = find(strcmp(uTrode(unitList), trodeList{t}));
            uTmp = unitList(uLoc);
            ampl = [];
            for u = uTmp
                ampl = [ampl; max(abs(unit(u).meanWaveform))];
            end
            rel = ampl;
            if size(ampl,1) > 1
                for c = 1:size(ampl,2)
                    tmp = sort(ampl(:,c), 'descend');
                    rel(:,c) = rel(:,c) / tmp(2);
                end
            else
                rel = 10 * rel / max(rel);
            end
            [a c] = max(ampl,[],2);
            x.ampl = [x.ampl a'];
            x.chan = [x.chan c'];
            [a c] = max(rel,[],2);
            x.rel = [x.rel a'];
            x.relChan = [x.relChan c'];
        end
        sesDat = [sesDat x];
    end
    
end

% find sessions with large spikes of every cell type
minAmpl = 0.08;
minRel = 3;
match = [];
for s = 1:length(sesDat)
    clear x
    x.ses = sesDat(s).ses;
    [~, i] = ismember(sesDat(s).fp, sesDat(s).unit);
    tmp = sesDat(s).ampl(i)>minAmpl  & sesDat(s).rel(i)>minRel;
    x.fp = sesDat(s).fp(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    x.fpAmpl = sesDat(s).ampl(i);
    x.fpAmpl = x.fpAmpl(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    [~, i] = ismember(sesDat(s).sp, sesDat(s).unit);
    tmp = sesDat(s).ampl(i)>minAmpl  & sesDat(s).rel(i)>minRel;
    x.sp = sesDat(s).sp(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    x.spAmpl = sesDat(s).ampl(i);
    x.spAmpl = x.spAmpl(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    [~, i] = ismember(sesDat(s).ak, sesDat(s).unit);
    tmp = sesDat(s).ampl(i)>minAmpl  & sesDat(s).rel(i)>minRel;
    x.ak = sesDat(s).ak(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    x.akAmpl = sesDat(s).ampl(i);
    x.akAmpl = x.akAmpl(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    [~, i] = ismember(sesDat(s).rp, sesDat(s).unit);
    tmp = sesDat(s).ampl(i)>minAmpl  & sesDat(s).rel(i)>minRel;
    x.rp = sesDat(s).rp(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    x.rpAmpl = sesDat(s).ampl(i);
    x.rpAmpl = x.rpAmpl(sesDat(s).chan(i) == sesDat(s).relChan(i) & tmp);
    
    if all(cellfun(@(u) ~isempty(u), {x.fp, x.sp, x.ak, x.rp}))
        [~, tmp] = ismember(x.fp, sesDat(s).unit);
        x.fpChan = sesDat(s).chan(tmp);
        [~, tmp] = ismember(x.sp, sesDat(s).unit);
        x.spChan = sesDat(s).chan(tmp);
        [~, tmp] = ismember(x.ak, sesDat(s).unit);
        x.akChan = sesDat(s).chan(tmp);
        [~, tmp] = ismember(x.rp, sesDat(s).unit);
        x.rpChan = sesDat(s).chan(tmp);
        match = [match x];
    end
end
length(match)

for i = 1:length(match)
    rat = unique(uRat(strcmp(uSes, match(i).ses)));
    str = [rat{1} ', ' match(i).ses '\nFP: '];
    for j = 1:length(match(i).fp)
        u = match(i).fp(j);
        ampl = max(abs(unit(u).meanWaveform(:,match(i).fpChan(j))));
        wR = unit(u).wakeRate; sR = unit(u).swsRate;
        str = [str sprintf('(%d) %d/%d, %.1f mV', j, round(wR), round(sR), ampl)];
        if j < length(match(i).fp)
            str = [str ';  '];
        else
            str = [str '\n'];
        end
    end
    str = [str 'SP: '];
    for j = 1:length(match(i).sp)
        u = match(i).sp(j);
        ampl = max(abs(unit(u).meanWaveform(:,match(i).spChan(j))));
        wR = unit(u).wakeRate; sR = unit(u).swsRate;
        str = [str sprintf('(%d) %d/%d, %.1f mV', j, round(wR), round(sR), ampl)];
        if j < length(match(i).sp)
            str = [str ';  '];
        else
            str = [str '\n'];
        end
    end
    str = [str 'AK: '];
    for j = 1:length(match(i).ak)
        u = match(i).ak(j);
        ampl = max(abs(unit(u).meanWaveform(:,match(i).akChan(j))));
        wR = unit(u).wakeRate; sR = unit(u).swsRate;
        str = [str sprintf('(%d) %d/%d, %.1f mV', j, round(wR), round(sR), ampl)];
        if j < length(match(i).ak)
            str = [str ';  '];
        else
            str = [str '\n'];
        end
    end
    str = [str 'RP: '];
    for j = 1:length(match(i).rp)
        u = match(i).rp(j);
        ampl = max(abs(unit(u).meanWaveform(:,match(i).rpChan(j))));
        wR = unit(u).wakeRate; sR = unit(u).swsRate;
        str = [str sprintf('(%d) %d/%d, %.1f mV', j, round(wR), round(sR), ampl)];
        if j < length(match(i).rp)
            str = [str ';  '];
        else
            str = [str '\n'];
        end
    end
    fprintf(['\n' str '\n'])
end

% check sessions
i = 1;
session = match(i).ses
idx = find(strcmp(session, uSes));
rat = uRat{idx(1)};

% load sleep log data
clear sleepLog
datDir = [datRoot rat filesep session filesep];
load([datDir 'sleepLog.mat']);
[wake, sws] = WakeTimes(sleepLog, unit(match(i).fp(1)));

datRoot2 = '/Volumes/Backup Plus/';
datRoot3 = '/Volumes/LaCie 1/Farries recordings/';

dDir = [datRoot rat filesep session filesep]

winSize = 2;
i=1;

% choose sleep segment
swsStart = 10356;

swsWin = [swsStart swsStart+winSize];
tIdx = find(unit(match(i).fp(1)).taskStart < swsWin(1));
swsTask = unit(match(i).fp(1)).taskList{tIdx(end)};
swsWin = swsWin - unit(match(i).fp(1)).taskStart(tIdx(end));

% choose wake segment
wakeStart = 10685; %10705

wakeWin = [wakeStart wakeStart+winSize];
tIdx = find(unit(match(i).fp(1)).taskStart < wakeWin(1));
tIdx = tIdx(end);
wakeTask = unit(match(i).fp(1)).taskList{tIdx};
wakeWin = wakeWin - unit(match(i).fp(1)).taskStart(tIdx(end));

% load fast proto data
match(i).fp; % 1067
fpIdx = match(i).fp(1);
fpChan = match(i).fpChan(1);
fpAmpl = match(i).fpAmpl(1);
trode = uTrode{fpIdx};
trodeFile = [dDir 'filtered' filesep wakeTask filesep trode '.hsd'];
fpWakeDat = PlotTrodeData(trodeFile, wakeWin, 'returnData', true, 'makePlot', false);
spkWinWake = wakeWin + unit(fpIdx).taskStart(tIdx);
fpWakeSpk = unit(fpIdx).spkTimes(unit(fpIdx).spkTimes > spkWinWake(1) & unit(fpIdx).spkTimes <= spkWinWake(2));
trodeFile = [dDir 'filtered' filesep swsTask filesep trode '.hsd'];
fpSwsDat = PlotTrodeData(trodeFile, swsWin, 'returnData', true, 'makePlot', false);
spkWinSws = swsWin + unit(fpIdx).taskStart(tIdx);
fpSwsSpk = unit(fpIdx).spkTimes(unit(fpIdx).spkTimes > spkWinSws(1) & unit(fpIdx).spkTimes <= spkWinSws(2));
fpWakeDat = fpWakeDat(fpChan,:);
fpSwsDat = fpSwsDat(fpChan,:);

% load slow proto data
match(i).sp;
spIdx = match(i).sp(1);     % 1085
spChan = match(i).spChan(1);
spAmpl = match(i).spAmpl(1);
trode = uTrode{spIdx};
trodeFile = [dDir 'filtered' filesep wakeTask filesep trode '.hsd'];
spWakeDat = PlotTrodeData(trodeFile, wakeWin, 'returnData', true, 'makePlot', false);
spWakeSpk = unit(spIdx).spkTimes(unit(spIdx).spkTimes > spkWinWake(1) & unit(spIdx).spkTimes <= spkWinWake(2));
trodeFile = [dDir 'filtered' filesep swsTask filesep trode '.hsd'];
spSwsDat = PlotTrodeData(trodeFile, swsWin, 'returnData', true, 'makePlot', false);
spSwsSpk = unit(spIdx).spkTimes(unit(spIdx).spkTimes > spkWinSws(1) & unit(spIdx).spkTimes <= spkWinSws(2));
spWakeDat = -spWakeDat(spChan,:);
spSwsDat = -spSwsDat(spChan,:);

% load arky data
match(i).ak;
akIdx = match(i).ak(3);     % 1096
akChan = match(i).akChan(3);
akAmpl = match(i).akAmpl(3);
trode = uTrode{akIdx};
trodeFile = [dDir 'filtered' filesep wakeTask filesep trode '.hsd'];
akWakeDat = PlotTrodeData(trodeFile, wakeWin, 'returnData', true, 'makePlot', false);
akWakeSpk = unit(akIdx).spkTimes(unit(akIdx).spkTimes > spkWinWake(1) & unit(akIdx).spkTimes <= spkWinWake(2));
trodeFile = [dDir 'filtered' filesep swsTask filesep trode '.hsd'];
akSwsDat = PlotTrodeData(trodeFile, swsWin, 'returnData', true, 'makePlot', false);
akSwsSpk = unit(akIdx).spkTimes(unit(akIdx).spkTimes > spkWinSws(1) & unit(akIdx).spkTimes <= spkWinSws(2));
akWakeDat = akWakeDat(akChan,:);
akSwsDat = akSwsDat(match(i).akChan(3),:);

% load RPE data
match(i).rp;
rpIdx = match(1).rp(1);     % 1093
rpChan = match(i).rpChan(1);
rpAmpl = match(i).rpAmpl(1);
trode = uTrode{rpIdx};
trodeFile = [dDir 'filtered' filesep wakeTask filesep trode '.hsd'];
rpWakeDat = PlotTrodeData(trodeFile, wakeWin, 'returnData', true, 'makePlot', false);
rpWakeSpk = unit(rpIdx).spkTimes(unit(rpIdx).spkTimes > spkWinWake(1) & unit(rpIdx).spkTimes <= spkWinWake(2));
trodeFile = [dDir 'filtered' filesep swsTask filesep trode '.hsd'];
rpSwsDat = PlotTrodeData(trodeFile, swsWin, 'returnData', true, 'makePlot', false);
rpSwsSpk = unit(rpIdx).spkTimes(unit(rpIdx).spkTimes > spkWinSws(1) & unit(rpIdx).spkTimes <= spkWinSws(2));
rpWakeDat = rpWakeDat(rpChan,:);
rpSwsDat = rpSwsDat(rpChan,:);

% load ECoG data
trodeFile = [dDir 'LFP' filesep wakeTask filesep 'ECoG1.hsdf'];
egWakeDat = PlotTrodeData(trodeFile, wakeWin, 'returnData', true, 'makePlot', false);
trodeFile = [dDir 'LFP' filesep swsTask filesep 'ECoG1.hsdf'];
egSwsDat = PlotTrodeData(trodeFile, swsWin, 'returnData', true, 'makePlot', false);

% plot traces
fpRange = range([fpWakeDat fpSwsDat]);
spRange = range([spWakeDat spSwsDat]);
akRange = range([akWakeDat akSwsDat]);
rpRange = range([rpWakeDat rpSwsDat]);
deltaY = 1.25*max([fpRange, spRange, akRange, rpRange]);
tEg = (1:length(egWakeDat))*(1000/500);
t = (1:length(fpWakeDat))*(1000/30000);
deltaT = 1.1*range(t);
figure('Position', [1 90 1440 700])
subplot('Position', [0.01 0.01 0.75 0.98])
hold on
plot(tEg, 0.5*egWakeDat+deltaY*4, 'k')
plot(tEg+deltaT, 0.5*egSwsDat+deltaY*4, 'k')
plot(t, 1.7*fpWakeDat+deltaY*3, 'k')
tickX = (fpWakeSpk - wakeWin(1) - unit(fpIdx).taskStart(tIdx))*1000;
tickY = ones(size(fpWakeSpk))*1.7*max([fpWakeDat fpSwsDat])+deltaY*3 + 0.02;
scatter(tickX, tickY, 50, fpColor, '|')
%s = scatter(tickX, tickY, 20, 0.75*fpColor, 'filled', 'v')
plot(t+deltaT, 1.7*fpSwsDat+deltaY*3, 'k')
tickX = (fpSwsSpk - swsWin(1) - unit(fpIdx).taskStart(tIdx))*1000 ;
tickY = ones(size(fpSwsSpk))*tickY(1);
scatter(tickX+deltaT, tickY, 50, fpColor, '|')
plot(t, spWakeDat+deltaY*2, 'k')
tickX = (spWakeSpk - wakeWin(1) - unit(spIdx).taskStart(tIdx))*1000;
tickY = ones(size(spWakeSpk))*1*max([spWakeDat spSwsDat])+deltaY*2 + 0.02;
scatter(tickX, tickY, 50, 'b', '|')
plot(t+deltaT, spSwsDat+deltaY*2, 'k')
tickX = (spSwsSpk - swsWin(1) - unit(spIdx).taskStart(tIdx))*1000;
tickY = ones(size(spSwsSpk))*1*max([spWakeDat spSwsDat])+deltaY*2 + 0.02;
scatter(tickX+deltaT, tickY, 50, 'b', '|')
plot(t, akWakeDat+deltaY, 'k')
tickX = (akWakeSpk - wakeWin(1) - unit(akIdx).taskStart(tIdx))*1000;
tickY = ones(size(akWakeSpk))*1*max([akWakeDat akSwsDat])+deltaY + 0.02;
scatter(tickX, tickY, 50, 'c', '|')
plot(t+deltaT, akSwsDat+deltaY, 'k')
tickX = (akSwsSpk - swsWin(1) - unit(akIdx).taskStart(tIdx))*1000;
tickY = ones(size(akSwsSpk))*1*max([akWakeDat akSwsDat])+deltaY + 0.02;
scatter(tickX+deltaT, tickY, 50, 'c', '|')
plot(t, 1.9*rpWakeDat, 'k')
tickX = (rpWakeSpk - wakeWin(1) - unit(rpIdx).taskStart(tIdx))*1000;
tickY = ones(size(rpWakeSpk))*1.9*max([rpWakeDat rpSwsDat]) + 0.02;
scatter(tickX, tickY, 50, rpColor, '|')
plot(t+deltaT, 1.9*rpSwsDat, 'k')
tickX = (rpSwsSpk - swsWin(1) - unit(rpIdx).taskStart(tIdx))*1000;
tickY = ones(size(rpSwsSpk))*1.9*max([rpWakeDat rpSwsDat]) + 0.02;
scatter(tickX+deltaT, tickY, 50, rpColor, '|')
xlim([0 1000*winSize+deltaT])
ylim([-0.15 1.95])
plot([1000 1200], [1.75 1.75], 'k', 'linewidth', 3) % time scale bar (250 ms)
plot([2100 2100], [1.65 1.8], 'k', 'linewidth', 3) % voltage scale bar (0.1 mV)
set(gca, 'YTick', [])
set(gca, 'XTick', [])
set(gca, 'Visible', 'off')
ylim([-0.15 2.03])

% rate and CV bar graphs
fpWakeIsi = []; spWakeIsi = []; akWakeIsi = []; rpWakeIsi = [];
for i = 1:size(wake,1)
    
    spk = unit(fpIdx).spkTimes(unit(fpIdx).spkTimes>wake(i,1) & unit(fpIdx).spkTimes<=wake(i,2));
    if length(spk) > 1
        fpWakeIsi = [fpWakeIsi diff(spk)];
    end
    
    spk = unit(spIdx).spkTimes(unit(spIdx).spkTimes>wake(i,1) & unit(spIdx).spkTimes<=wake(i,2));
    if length(spk) > 1
        spWakeIsi = [spWakeIsi diff(spk)];
    end
    
    spk = unit(akIdx).spkTimes(unit(akIdx).spkTimes>wake(i,1) & unit(akIdx).spkTimes<=wake(i,2));
    if length(spk) > 1
        akWakeIsi = [akWakeIsi diff(spk)];
    end
    
    spk = unit(rpIdx).spkTimes(unit(rpIdx).spkTimes>wake(i,1) & unit(rpIdx).spkTimes<=wake(i,2));
    if length(spk) > 1
        rpWakeIsi = [rpWakeIsi diff(spk)];
    end
    
end
fpWakeCv = std(fpWakeIsi) / mean(fpWakeIsi);
spWakeCv = std(spWakeIsi) / mean(spWakeIsi);
akWakeCv = std(akWakeIsi) / mean(akWakeIsi);
rpWakeCv = std(rpWakeIsi) / mean(rpWakeIsi);

subplot('Position', [0.78 0.69 0.1 0.16])
hold on
b = bar([unit(fpIdx).wakeRate unit(fpIdx).swsRate]); 
b.FaceColor = fpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 28])

subplot('Position', [0.89 0.69 0.1 0.16])
hold on
b = bar([fpWakeCv unit(fpIdx).swsCv]); 
b.FaceColor = fpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 2])

subplot('Position', [0.78 0.47 0.1 0.16])
hold on
b = bar([unit(spIdx).wakeRate unit(spIdx).swsRate]); 
b.FaceColor = 'b'; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 28])

subplot('Position', [0.89 0.47 0.1 0.16])
hold on
b = bar([spWakeCv unit(spIdx).swsCv]); 
b.FaceColor = 'b'; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 2])

subplot('Position', [0.78 0.24 0.1 0.16])
hold on
b = bar([unit(akIdx).wakeRate unit(akIdx).swsRate]); 
b.FaceColor = 'c'; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 28])

subplot('Position', [0.89 0.24 0.1 0.16])
hold on
b = bar([akWakeCv unit(akIdx).swsCv]); 
b.FaceColor = 'c'; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 2])

subplot('Position', [0.78 0.02 0.1 0.16])
hold on
b = bar([unit(rpIdx).wakeRate unit(rpIdx).swsRate]); 
b.FaceColor = rpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 28])

subplot('Position', [0.89 0.02 0.1 0.16])
hold on
b = bar([rpWakeCv unit(rpIdx).swsCv]); 
b.FaceColor = rpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]);
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 2])


%% Window Search

tWake = [];
tSws = [];
fpWake = [];
spWake = [];
rpWake = [];
akWake = [];
fpSws = [];
spSws = [];
rpSws = [];
akSws = [];

fpSpk = unit(match(1).fp(1)).spkTimes;
spSpk = unit(match(1).sp(1)).spkTimes;
rpSpk = unit(match(1).rp(1)).spkTimes;
akSpk = unit(match(1).ak(3)).spkTimes;

for i = 1:length(wake)
    dur = range(wake(i,:));
    for t = wake(i,1):winSize:(wake(i,2)-winSize)
        tWake = [tWake t];
        fpWake = [fpWake length(fpSpk(fpSpk>=t & fpSpk <t+winSize))/winSize];
        spWake = [spWake length(spSpk(spSpk>=t & spSpk <t+winSize))/winSize];
        rpWake = [rpWake length(rpSpk(rpSpk>=t & rpSpk <t+winSize))/winSize];
        akWake = [akWake length(akSpk(akSpk>=t & akSpk <t+winSize))/winSize];   
    end
end

for i = 1:length(sws)
    dur = range(sws(i,:));
    for t = sws(i,1):winSize:(sws(i,2)-winSize)
        tSws = [tSws t];
        fpSws = [fpSws length(fpSpk(fpSpk>=t & fpSpk <t+winSize))/winSize];
        spSws = [spSws length(spSpk(spSpk>=t & spSpk <t+winSize))/winSize];
        rpSws = [rpSws length(rpSpk(rpSpk>=t & rpSpk <t+winSize))/winSize];
        akSws = [akSws length(akSpk(akSpk>=t & akSpk <t+winSize))/winSize];
    end
end

figure
plot(spWake)
hold on
scatter(1:length(spWake), spWake)

figure
plot(spSws)
hold on
scatter(1:length(spSws), spSws)


%% Load Full ISI Stats

ratList = unique(uRat);

% loop through rats
swsRate = nan(size(unit));
swsMean = nan(size(unit));
swsSd = nan(size(unit));
swsSkew = nan(size(unit));
swsKurt = nan(size(unit));
swsNumIsi = zeros(size(unit));
swsDur = zeros(size(unit));
wakeMean = nan(size(unit));
wakeSd = nan(size(unit));
wakeSkew = nan(size(unit));
wakeKurt = nan(size(unit));
swsCv = nan(size(unit));
swsCv2 = nan(size(unit));
wakeRate = nan(size(unit));
wakeCv = nan(size(unit));
wakeCv2 = nan(size(unit));
wakeNumIsi = zeros(size(unit));
wakeDur = zeros(size(unit));
rat = cellfun(@(r) str2num(r(3:end)), uRat);
for r = 1:length(ratList)
    
    disp(['rat ' ratList{r}])
    
    uIdx = find(strcmp(ratList{r}, uRat));
    sesList = unique(uSes(uIdx));
    
    % loop through recording sessions
    for iSes = 1:length(sesList)
        
        disp(['   session ' num2str(iSes)])
    
        % load sleep log data
        clear sleepLog
        datDir = [datRoot ratList{r} filesep sesList{iSes} filesep];
        load([datDir 'sleepLog.mat']);
        
        % identify GPe cells recorded in this session, get behavior data
        uIdx = find(strcmp(sesList{iSes}, uSes));
            
        % identify periods of disengaged wakefulness, log SWS times across tasks
        [wake, sws] = WakeTimes(sleepLog, unit(uIdx(1)));
        wakeDur(uIdx) = sum(arrayfun(@(i) diff(wake(i,:)), 1:size(wake,1)));
        swsDur(uIdx) = sum(arrayfun(@(i) diff(sws(i,:)), 1:size(sws,1)));
          
        % extract rate-regularity parameters
        for u = uIdx
            wakeIsi = [];
            for k = 1:size(wake, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > wake(k,1) & unit(u).spkTimes <= wake(k,2));
                wakeIsi = [wakeIsi diff(spk)];
            end
            swsIsi = [];
            for k = 1:size(sws, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > sws(k,1) & unit(u).spkTimes <= sws(k,2));
                swsIsi = [swsIsi diff(spk)];
            end
            wakeNumIsi(u) = length(wakeIsi);
            wakeMean(u) = mean(wakeIsi);
            wakeRate(u) = 1 / wakeMean(u);
            wakeSd(u) = std(wakeIsi);
            wakeCv(u) = wakeSd(u) / wakeMean(u);
            wakeCv2(u) = sqrt(2) * mean(abs(wakeIsi(2:end) - wakeIsi(1:end-1)) ./ (wakeIsi(2:end) + wakeIsi(1:end-1)));
            wakeSkew(u) = skewness(wakeIsi);
            wakeKurt(u) = kurtosis(wakeIsi);
            swsNumIsi(u) = length(swsIsi);
            swsMean(u) = mean(swsIsi);
            swsRate(u) = 1 / swsMean(u);
            swsSd(u) = std(swsIsi);
            swsCv(u) = swsSd(u) / swsMean(u);
            swsCv2(u) = sqrt(2) * mean(abs(swsIsi(2:end) - swsIsi(1:end-1)) ./ (swsIsi(2:end) + swsIsi(1:end-1)));
            swsSkew(u) = skewness(swsIsi);
            swsKurt(u) = kurtosis(swsIsi);
        end
    end
end

% log transform
w1 = -log10(wakeMean); % negative sign converts log(mean ISI) to log(mean rate)
w2 = log10(wakeSd);
w3 = log10(wakeSkew);

s1 = -log10(swsMean); % negative sign converts log(mean ISI) to log(mean rate)
s2 = log10(swsSd);
s3 = log10(swsSkew);



%% Figure 1c (ISI Stats, Log-Log plot, Unlabeled)

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(s2, s1, 60,'k')
xlim([-2.3 0.71])
ylim([-0.7 2])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];
%ax.XTickLabels = {'0.01', '0.1', '1', '10', '100'};
%ax.YTickLabels = {'0.01', '0.1', '1', '10', '100'};
scatter(s2(rp), s1(rp), 60, rpColor, 'filled')
scatter(s2(spIdx), s1(spIdx), 100, 'b', 'filled')
scatter(s2(fpIdx), s1(fpIdx), 100,fpColor, 'filled')
scatter(s2(akIdx), s1(akIdx), 100, 'c', 'filled')

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1, s1, 60,'k')
xlim([-0.6 2.1])
ylim([-0.7 2])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];
%ax.XTickLabels = {'0.01', '0.1', '1', '10', '100'};
%ax.YTickLabels = {'0.01', '0.1', '1', '10', '100'};
scatter(w1(rpIdx), s1(rpIdx), 100, rpColor, 'filled')
scatter(w1(spIdx), s1(spIdx), 100, 'b', 'filled')
scatter(w1(fpIdx), s1(fpIdx), 100, fpColor, 'filled')
scatter(w1(akIdx), s1(akIdx), 100, 'c', 'filled')

% in Adobe Illustrator, scale (resize) to 15%, make axis thickness 0.3



%% Figure 1d/e (ISI Stats, Log-Log plot, Cell Types Labels)

tg = find(arrayfun(@(u) u.tagged, unit));
nonTg = find(arrayfun(@(u) ~u.tagged, unit));
fpNT = intersect(nonTg, fp);
spNT = intersect(nonTg, sp);
arNT = intersect(nonTg, ak);
rpNT = intersect(nonTg, rp);
ucNT = intersect(nonTg, union(out, ip));

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1(ucNT), s1(ucNT), 60,'k')
scatter(w1(fpNT), s1(fpNT), 60, fpColor, 'filled')
scatter(w1(arNT), s1(arNT), 60, 'c', 'filled')
scatter(w1(spNT), s1(spNT), 60, 'b', 'filled')
scatter(w1(rpNT), s1(rpNT), 60, rpColor, 'filled')
scatter(w1(tg), s1(tg), 240, 'p', 'filled', 'MarkerFaceColor', 'y', 'MarkerEdgeColor', 'k', 'lineWidth', 1)
xlim([-0.6 2.1])
ylim([-0.7 2])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];
%ax.XTickLabels = {'0.01', '0.1', '1', '10', '100'};
%ax.YTickLabels = {'0.01', '0.1', '1', '10', '100'};

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(s2(ucNT), s1(ucNT), 60,'k')
scatter(s2(fpNT), s1(fpNT), 60, fpColor, 'filled')
scatter(s2(arNT), s1(arNT), 60, 'c', 'filled')
scatter(s2(spNT), s1(spNT), 60, 'b', 'filled')
scatter(s2(rpNT), s1(rpNT), 60, rpColor, 'filled')
scatter(s2(tg), s1(tg), 240, 'p', 'filled', 'MarkerFaceColor', 'y', 'MarkerEdgeColor', 'k', 'lineWidth', 1)
xlim([-2.3 0.71])
ylim([-0.7 2])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];

% bar graph of mean and SD rate/CV by cell type
figure('Position', [1 100 1440 400])
m = 0.005; g1 = 0.005; g2 = 0.02; w = (1 - 2*m - 6*g1 - g2) / 8;
l = m + (0:3)*(w+g1);
l = [l l(4)+g1+w+g2 + (0:3)*(w+g1)];

subplot('Position', [l(1) 0.01 w 0.98])
hold on
avg = [mean(wakeRate(fp)) mean(swsRate(fp))];
err = [std(wakeRate(fp)) std(swsRate(fp))];
b = bar(avg); 
b.FaceColor = fpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = fpColor; e.LineStyle = 'none'; e.LineWidth = 2;
ylim([0 80])
ax = gca; ax.YTick = [20 40 60 80]; ax.XTick = []; ax.YTickLabels = [];

subplot('Position', [l(2) 0.01 w 0.98])
hold on
avg = [mean(wakeRate(sp)) mean(swsRate(sp))];
err = [std(wakeRate(sp)) std(swsRate(sp))];
b = bar(avg); 
b.FaceColor = 'b'; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = 'b'; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 80])

subplot('Position', [l(3) 0.01 w 0.98])
hold on
avg = [mean(wakeRate(ak)) mean(swsRate(ak))];
err = [std(wakeRate(ak)) std(swsRate(ak))];
b = bar(avg); 
b.FaceColor = 'c'; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = 'c'; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 80])

subplot('Position', [l(4) 0.01 w 0.98])
hold on
avg = [mean(wakeRate(rp)) mean(swsRate(rp))];
err = [std(wakeRate(rp)) std(swsRate(rp))];
b = bar(avg); 
b.FaceColor = rpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = rpColor; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 80])


subplot('Position', [l(5) 0.01 w 0.98])
hold on
avg = [mean(wakeCv(fp)) mean(swsCv(fp))];
err = [std(wakeCv(fp)) std(swsCv(fp))];
b = bar(avg); 
b.FaceColor = fpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = fpColor; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = [1 2 3]; ax.XTick = []; ax.YTickLabels = [];
ylim([0 3])

subplot('Position', [l(6) 0.01 w 0.98])
hold on
avg = [mean(wakeCv(sp)) mean(swsCv(sp))];
err = [std(wakeCv(sp)) std(swsCv(sp))];
b = bar(avg); 
b.FaceColor = 'b'; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = 'b'; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 3])

subplot('Position', [l(7) 0.01 w 0.98])
hold on
avg = [mean(wakeCv(ak)) mean(swsCv(ak))];
err = [std(wakeCv(ak)) std(swsCv(ak))];
b = bar(avg); 
b.FaceColor = 'c'; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = 'c'; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 3])

subplot('Position', [l(8) 0.01 w 0.98])
hold on
avg = [mean(wakeCv(rp)) mean(swsCv(rp))];
err = [std(wakeCv(rp)) std(swsCv(rp))];
b = bar(avg); 
b.FaceColor = rpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = rpColor; e.LineStyle = 'none'; e.LineWidth = 2;
ax = gca; ax.YTick = []; ax.XTick = [];
ylim([0 3])

% in Adobe Illustrator, scale (resize) to 15%, make axis thickness 0.3



%% Figure 1d: Opto-Tagging

% unit name 'IM1153 2019-05-04 II-t09 1'
% 1 mW, 0.5 ms, block 2 bout 1

u = find(strcmp('IM1153 2019-05-04 II-t09 1', uName)) % 983
sesDir = [datRoot uRat{u} '/' uSes{u} '/'];
    
% load laser data
load([sesDir 'laserDat.mat'])
lName = arrayfun(@(l) l.name, laserResponse, 'UniformOutput', false);
idx = find(strcmp(lName, uName{u}));
lR = laserResponse(idx);

preWin = -20;
postWin = 20;
binWidth = 0.5;

blk = 2;    % choose laser power (block)
bout = 1;   % choose pulse duration (bout)
tag = TagCheck(lR.block{blk}(bout));
taskName = lR.block{blk}(1).taskName;
taskIdx = find(cellfun(@(t) strcmp(t, taskName), unit(u).taskList));
t1 = unit(u).taskStart(taskIdx);
t2 = unit(u).taskEnd(taskIdx);
spk = unit(u).spkTimes;
spk = unique(spk(spk > t1 & spk < t2) - t1);
laserOn = randsample(lR(1).block{blk}(bout).pulseOnset', 200);
trNum = length(laserOn);
tickWidth = 2;
tickY = [-2 2];
s = [];
figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
lzT = preWin+0.25:0.5:postWin-0.25;
lzH = zeros(1,length(lzT));
lzH(40) = length(laserOn);
h = bar(lzT, lzH, 1, 'r');
h.EdgeColor = 'none';
h.FaceAlpha = 0.5;
hold on
for p = laserOn
    sp = 1000*(spk(spk >= p+preWin/1000 & spk <= p+postWin/1000) - p);
    for s = sp
        line([s s], trNum + 0.5 + tickY, 'color', 'k', 'LineWidth', tickWidth);
    end
    trNum = trNum - 1;
end
xlim([preWin postWin])
ylim([0 length(laserOn)])
ax = gca;
ax.YTick = [];
ax.XTick = [-10 0 10 20 30];
ax.XTickLabels = [];
ax.Box = 'off';

% load trace data
% nTraces = 20;
% win = [-0.005 0.015];
% t = (0:diff(win)*30000 - 1)/30000 + win(1);
% trIdx = [31 59 61 68 82 87 102 130 223 225 291 336 389 400 405 406 420 473 479 486];
% trIdx = randsample(length(lR.block{blk}(bout).pulseOnset), nTraces);
% tStim = lR.block{blk}(bout).pulseOnset(trIdx);
% traces = zeros(nTraces, diff(win)*30000);
% for i = 1:nTraces
%     dat = PlotTrodeData(trodeFile, win + tStim(i), 'returnData', true, 'makePlot', false);
%     traces(i,:) = dat(chan,:);
% end

% figure('Position', [440 378 720 620])
% subplot('Position', [0.01 0.01 0.98 0.49])
% lzT = -2.5:5:12.5;
% lzH = zeros(1,4);
% lzH(2) = 900;
% h = bar(lzT, lzH, 1, 'r');
% h.EdgeColor = 'none';
% h.FaceAlpha = 0.5;
% hold on
% bar(bE(2:end) - diff(bE)/2, psth, 1, 'k')
% yR = [0 900];
% xlim([-5 15])
% ax = gca;
% ax.Box = 'off';
% ax.Visible = 'off';
% plot([10 10], [450 650], 'k', 'linewidth', 5)
% plot([-5 -2], [400 400], 'k', 'linewidth', 5)
% subplot('Position', [0.01 0.5 0.98 0.49])
% lzH(2) = 0.6;
% h = bar(lzT, lzH, 1, 'r');
% h.EdgeColor = 'none';
% h.FaceAlpha = 0.5;
% hold on
% for i = 1:nTraces
%     plot(t*1000,traces(i,:)+0.2, 'k')
% end
% xlim([-5 15]);
% ylim([0 0.6])
% ax = gca;
% ax.Box = 'off';
% ax.Visible = 'off';
% plot([9 9], [0.5 0.6], 'k', 'linewidth', 5)

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
l = tag.latency;
nl = tag.nullLat;
plot(sort(nl), (1:length(nl))/length(nl), 'b', 'linewidth', 2)
plot(sort(l), (1:length(l))/length(l), 'r', 'linewidth', 2)
ax = gca;
ax.YTick = 0.25:0.25:0.75;
xlim([0 20])
ax.XTick = 5:5:20;
ax.Box = 'on';



