% NOTE: There is no Fig. 7 ver. 6

%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];



%% Pavlovian Behavior

% identfiy sessions with Pavlovian behavior
uPav = find(arrayfun(@(u) any(strcmp('pav', lower(u.taskList))), unit));
pavSes = unique(uSes(uPav));

% remove sessions in which the reward port was non-functional
rwdPort = true(1, length(pavSes));
for s = 1:length(pavSes)
    uIdx= find(strcmp(pavSes{s}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    rwdPort(s) = ~all(cellfun(@(r) isempty(r), ts.rwdPokeIn));
end
pavSes = pavSes(rwdPort);

% collect Pavlovian behavioral data
pavDat = [];
rwdTime = [];
dt = 0.005;
win = [-0.5 4.5];
times = win(1):dt:win(2);
nSamp = length(times);
for s = 1:length(pavSes)
    clear x
    uIdx = find(strcmp(pavSes{s}, uSes));
    u = uIdx(1);
    x.rat = uRat{u};
    x.date = uSes{u};
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    logPav = unit(u).behav_log{pavIdx};
    
    % collect trial rwd port pokes together into 1 list for whole session
    nTr = length(ts.csTime);
    pokeIn = [];
    pokeOut = [];
    for k = 1:nTr
        pokeIn = [pokeIn ts.rwdPokeIn{k}'];
        pokeOut = [pokeOut ts.rwdPokeOut{k}'];
    end
    
    % create rwd port occupancy trajectory for entire session
    clear ocpTraj
    ocpTraj.times = 0:dt:ceil(ts.csTime(end) + 16);
    ocpTraj.rate = zeros(size(ocpTraj.times));
    for i = 1:length(pokeIn)
        [~,~,bin1] = histcounts(pokeIn(i), ocpTraj.times);
        [~,~,bin2] = histcounts(pokeOut(i), ocpTraj.times);
        ocpTraj.rate(bin1:bin2) = 1;
    end
    ocpTraj = TrajSplit(ocpTraj, ts, win);
    x.csTime = ts.csTime;
    x.outcome = logPav.outcome;
    x.probRwd = logPav.toneFreq;
    x.probRwd(x.probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for i = 1:size(logPav.cueRwdTable, 1)
        x.probRwd(x.probRwd == logPav.cueRwdTable(i,1)) = logPav.cueRwdTable(i,2);
    end
    x.firstRwdPoke = nan(1,nTr);
    x.rwdPokeIn = cell(1,nTr);
    x.rwdPokeOut = cell(1,nTr);
    x.portOcp = zeros(nTr, nSamp);
    for k = 1:nTr
        if k > 1
            x.rwdPokeIn{k} = [ts.rwdPokeIn{k-1}; ts.rwdPokeIn{k}] - ts.csTime(k);
            x.rwdPokeOut{k} = [ts.rwdPokeOut{k-1}; ts.rwdPokeOut{k}] - ts.csTime(k);
        else
            x.rwdPokeIn{k} = ts.rwdPokeIn{k} - ts.csTime(k);
            x.rwdPokeOut{k} = ts.rwdPokeOut{k} - ts.csTime(k);
        end
        if ~isempty(ts.rwdPokeIn{k}) 
            x.firstRwdPoke(k) = x.rwdPokeIn{k}(1);
        end
        
        % reward port occupancy
        x.portOcp(k,:) = ocpTraj(k).rate;
        
    end
    x.t = times;
    pavDat = [pavDat x];
    rT = ts.rwdTime' - ts.csTime';
    rwdTime = [rwdTime rT(~isnan(rT))];
end
rwdTime = mean(rwdTime);

% average reward port occupancy
tPoke = pavDat(1).t;
p0 = zeros(length(pavDat), length(tPoke));
p25 = zeros(length(pavDat), length(tPoke));
p75 = zeros(length(pavDat), length(tPoke));
p25r = zeros(length(pavDat), length(tPoke));
p75r = zeros(length(pavDat), length(tPoke));
p25nr = zeros(length(pavDat), length(tPoke));
p75nr = zeros(length(pavDat), length(tPoke));
unpred = zeros(length(pavDat), length(tPoke));
for s = 1:length(pavDat)
    nTr = length(pavDat(s).csTime);
    sel0 = pavDat(s).probRwd == 0;
    sel25 = pavDat(s).probRwd == 25;
    sel75 = pavDat(s).probRwd == 75;
    selUnp = pavDat(s).probRwd == 100;
    p0(s,:) = mean(pavDat(s).portOcp(sel0,:));
    unpred(s,:) = mean(pavDat(s).portOcp(selUnp,:));
    p25(s,:) = mean(pavDat(s).portOcp(sel25,:));
    p25r(s,:) = mean(pavDat(s).portOcp(sel25 & pavDat(s).outcome,:));
    p25nr(s,:) = mean(pavDat(s).portOcp(sel25 & ~pavDat(s).outcome,:));
    p75(s,:) = mean(pavDat(s).portOcp(sel75,:));
    p75r(s,:) = mean(pavDat(s).portOcp(sel75 & pavDat(s).outcome,:));
    p75nr(s,:) = mean(pavDat(s).portOcp(sel75 & ~pavDat(s).outcome,:));
end

figure
plot(tPoke, p25(1,:))

rwdBin = find(tPoke > rwdTime);
rwdBin = rwdBin(1)
figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
plot(tPoke(1:rwdBin), mean(p25(:, 1:rwdBin)), 'color', [0.3 0.3 0.3], 'lineWidth', 2)
plot(tPoke(1:rwdBin), mean(p75(:, 1:rwdBin)), 'color', [0.7 0.7 0.7], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p25r(:, rwdBin+1:end)), 'color', [0.6 0 0], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p75r(:, rwdBin+1:end)), 'color', [1 0.4 0.4], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p25nr(:, rwdBin+1:end)), 'color', [0 0 0.6], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p75nr(:, rwdBin+1:end)), 'color', [0.4 0.4 1], 'lineWidth', 2)
plot(tPoke, mean(p0), 'b', 'lineWidth', 2)
plot(tPoke, mean(unpred), 'r', 'lineWidth', 2)

tPre = tPoke(1:rwdBin);
tPost = tPoke(rwdBin+1:end);
p25M = smoothdata(mean(p25), 'gaussian', 10);
p25L = p25M - smoothdata(std(p25)/sqrt(size(p25,1)), 'gaussian', 10);
p25H = p25M + smoothdata(std(p25)/sqrt(size(p25,1)), 'gaussian', 10);
p75M = smoothdata(mean(p75), 'gaussian', 10);
p75L = p75M - smoothdata(std(p75)/sqrt(size(p25,1)), 'gaussian', 10);
p75H = p75M + smoothdata(std(p75)/sqrt(size(p25,1)), 'gaussian', 10);
p25RM = smoothdata(mean(p25r), 'gaussian', 10);
p25RL = p25RM - smoothdata(std(p25r)/sqrt(size(p25r,1)), 'gaussian', 10);
p25RH = p25RM + smoothdata(std(p25r)/sqrt(size(p25r,1)), 'gaussian', 10);
p25NM = smoothdata(mean(p25nr), 'gaussian', 10);
p25NL = p25NM - smoothdata(std(p25nr)/sqrt(size(p25nr,1)), 'gaussian', 10);
p25NH = p25NM + smoothdata(std(p25nr)/sqrt(size(p25nr,1)), 'gaussian', 10);
p75RM = smoothdata(mean(p75r), 'gaussian', 10);
p75RL = p75RM - smoothdata(std(p75r)/sqrt(size(p75r,1)), 'gaussian', 10);
p75RH = p75RM + smoothdata(std(p75r)/sqrt(size(p75r,1)), 'gaussian', 10);
p75NM = smoothdata(mean(p75nr), 'gaussian', 10);
p75NL = p75NM - smoothdata(std(p75nr)/sqrt(size(p75nr,1)), 'gaussian', 10);
p75NH = p75NM + smoothdata(std(p75nr)/sqrt(size(p75nr,1)), 'gaussian', 10);
p0M = smoothdata(mean(p0), 'gaussian', 10);
p0L = p0M - smoothdata(std(p0)/sqrt(size(p0,1)), 'gaussian', 10);
p0H = p0M + smoothdata(std(p0)/sqrt(size(p0,1)), 'gaussian', 10);
unM = smoothdata(mean(unpred), 'gaussian', 10);
unL = unM - smoothdata(std(unpred)/sqrt(size(unpred,1)), 'gaussian', 10);
unH = unM + smoothdata(std(unpred)/sqrt(size(unpred,1)), 'gaussian', 10);

% CS and US
figure('Position', [10 100 695 125])
subplot('Position', [0.005 0.585 0.994 0.99])
hold on
pip = 0:0.15:2.4;
for p = 1:length(pip)
    plot([pip(p) pip(p)], [0.6 1], 'k')
end
plot([rwdTime rwdTime], [0.1 0.5], 'r')
xlim(win)
ylim([0 1])
ax = gca;
ax.Visible = 'off';   

figure('Position', [10 100 695 450])
subplot('Position', [0.005 0.005 0.994 0.99])
hold on
shade(tPre, p75H(1:rwdBin),tPre, p75L(1:rwdBin),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.7 0.7 0.7], 'FillAlpha', 0.25)
plot(tPre, p75M(1:rwdBin), 'color', [0.7 0.7 0.7], 'lineWidth', 2)
shade(tPre, p25H(1:rwdBin),tPre, p25L(1:rwdBin),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.3 0.3 0.3], 'FillAlpha', 0.25)
plot(tPre, p25M(1:rwdBin), 'color', [0.3 0.3 0.3], 'lineWidth', 2)
shade(tPost, p25NH(rwdBin+1:end),tPost, p25NL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0 0 0.6], 'FillAlpha', 0.25)
plot(tPost, p25NM(rwdBin+1:end), 'color', [0 0 0.6], 'lineWidth', 2)
shade(tPost, p25RH(rwdBin+1:end),tPost, p25RL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.6 0 0], 'FillAlpha', 0.25)
plot(tPost, p25RM(rwdBin+1:end), 'color', [0.6 0 0], 'lineWidth', 2)
shade(tPost, p75NH(rwdBin+1:end),tPost, p75NL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.4 0.4 1], 'FillAlpha', 0.25)
plot(tPost, p75NM(rwdBin+1:end), 'color', [0.4 0.4 1], 'lineWidth', 2)
shade(tPost, p75RH(rwdBin+1:end),tPost, p75RL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [1 0.4 0.4], 'FillAlpha', 0.25)
plot(tPost, p75RM(rwdBin+1:end), 'color', [1 0.4 0.4], 'lineWidth', 2)
yR = [0 0.8];
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;

figure('Position', [10 100 695 450])
subplot('Position', [0.005 0.005 0.994 0.99])
hold on
shade(tPoke, p0H,tPoke, p0L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tPoke, p0M, 'color', 'b', 'lineWidth', 2)
shade(tPoke, unH,tPoke, unL,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(tPoke, unM, 'color', 'r', 'lineWidth', 2)
yR = [0 0.8];
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;



%% Pavlovian Behavior -- DA

% identify DA cells with matching Pavlovian data (25%-75% prob[rwd])
pav50DA = false(1, length(unitDA));
pav25DA = false(1, length(unitDA));
pavAllDA = false(1, length(unitDA));
for u = 1:length(unitDA)
    [~, pavIdx] = ismember('Pav', unitDA(u).taskList);
    lg = unitDA(u).behav_log{pavIdx};
    pavAllDA(u) = ~isempty(lg);
    if pavAllDA(u)
        pav25DA(u) = ~isempty(lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1));
        pav50DA(u) = ~isempty(lg.cueRwdTable(lg.cueRwdTable(:,2) == 50, 1));
    end
end
pav25DA = find(pav25DA);
pavAllDA = find(pavAllDA);

% remove sessions in which the reward port was non-functional
rwdPort = true(1, length(pavSes));
for s = 1:length(pavSes)
    uIdx= find(strcmp(pavSes{s}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    rwdPort(s) = ~all(cellfun(@(r) isempty(r), ts.rwdPokeIn));
end
pavSes = pavSes(rwdPort);

% collect Pavlovian behavioral data
pavDatDA = [];
rwdTimeDA = [];
dt = 0.005;
win = [-0.5 4.5];
times = win(1):dt:win(2);
nSamp = length(times);
for i = 1:length(pav25DA)
    u = pav25DA(i);
    clear x
    x.rat = unitDA(u).name(1:6);
    x.date = unitDA(u).name(7:12);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    ts = unitDA(u).behav_ts{pavIdx};
    logPav = unitDA(u).behav_log{pavIdx};
    
    % collect trial rwd port pokes together into 1 list for whole session
    nTr = length(ts.csTime);
    pokeIn = [];
    pokeOut = [];
    for k = 1:nTr
        pokeIn = [pokeIn ts.rwdPokeIn{k}'];
        pokeOut = [pokeOut ts.rwdPokeOut{k}'];
    end
    
    % create rwd port occupancy trajectory for entire session
    clear ocpTraj
    ocpTraj.times = 0:dt:ceil(ts.csTime(end) + 16);
    ocpTraj.rate = zeros(size(ocpTraj.times));
    for i = 1:length(pokeIn)
        [~,~,bin1] = histcounts(pokeIn(i), ocpTraj.times);
        [~,~,bin2] = histcounts(pokeOut(i), ocpTraj.times);
        ocpTraj.rate(bin1:bin2) = 1;
    end
    ocpTraj = TrajSplit(ocpTraj, ts, win);
    x.csTime = ts.csTime;
    x.outcome = logPav.outcome;
    x.probRwd = logPav.toneFreq;
    x.probRwd(x.probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for i = 1:size(logPav.cueRwdTable, 1)
        x.probRwd(x.probRwd == logPav.cueRwdTable(i,1)) = logPav.cueRwdTable(i,2);
    end
    x.firstRwdPoke = nan(1,nTr);
    x.rwdPokeIn = cell(1,nTr);
    x.rwdPokeOut = cell(1,nTr);
    x.portOcp = zeros(nTr, nSamp);
    for k = 1:nTr
        if k > 1
            x.rwdPokeIn{k} = [ts.rwdPokeIn{k-1}; ts.rwdPokeIn{k}] - ts.csTime(k);
            x.rwdPokeOut{k} = [ts.rwdPokeOut{k-1}; ts.rwdPokeOut{k}] - ts.csTime(k);
        else
            x.rwdPokeIn{k} = ts.rwdPokeIn{k} - ts.csTime(k);
            x.rwdPokeOut{k} = ts.rwdPokeOut{k} - ts.csTime(k);
        end
        if ~isempty(ts.rwdPokeIn{k}) 
            x.firstRwdPoke(k) = x.rwdPokeIn{k}(1);
        end
        
        % reward port occupancy
        x.portOcp(k,:) = ocpTraj(k).rate;
        
    end
    x.t = times;
    pavDat = [pavDat x];
    rT = ts.rwdTime' - ts.csTime';
    rwdTime = [rwdTime rT(~isnan(rT))];
end
rwdTime = mean(rwdTime);

% average reward port occupancy
tPoke = pavDat(1).t;
p0 = zeros(length(pavDat), length(tPoke));
p25 = zeros(length(pavDat), length(tPoke));
p75 = zeros(length(pavDat), length(tPoke));
p25r = zeros(length(pavDat), length(tPoke));
p75r = zeros(length(pavDat), length(tPoke));
p25nr = zeros(length(pavDat), length(tPoke));
p75nr = zeros(length(pavDat), length(tPoke));
unpred = zeros(length(pavDat), length(tPoke));
for s = 1:length(pavDat)
    nTr = length(pavDat(s).csTime);
    sel0 = pavDat(s).probRwd == 0;
    sel25 = pavDat(s).probRwd == 25;
    sel75 = pavDat(s).probRwd == 75;
    selUnp = pavDat(s).probRwd == 100;
    p0(s,:) = mean(pavDat(s).portOcp(sel0,:));
    unpred(s,:) = mean(pavDat(s).portOcp(selUnp,:));
    p25(s,:) = mean(pavDat(s).portOcp(sel25,:));
    p25r(s,:) = mean(pavDat(s).portOcp(sel25 & pavDat(s).outcome,:));
    p25nr(s,:) = mean(pavDat(s).portOcp(sel25 & ~pavDat(s).outcome,:));
    p75(s,:) = mean(pavDat(s).portOcp(sel75,:));
    p75r(s,:) = mean(pavDat(s).portOcp(sel75 & pavDat(s).outcome,:));
    p75nr(s,:) = mean(pavDat(s).portOcp(sel75 & ~pavDat(s).outcome,:));
end

figure
plot(tPoke, p25(1,:))

rwdBin = find(tPoke > rwdTime);
rwdBin = rwdBin(1)
figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
plot(tPoke(1:rwdBin), mean(p25(:, 1:rwdBin)), 'color', [0.3 0.3 0.3], 'lineWidth', 2)
plot(tPoke(1:rwdBin), mean(p75(:, 1:rwdBin)), 'color', [0.7 0.7 0.7], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p25r(:, rwdBin+1:end)), 'color', [0.6 0 0], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p75r(:, rwdBin+1:end)), 'color', [1 0.4 0.4], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p25nr(:, rwdBin+1:end)), 'color', [0 0 0.6], 'lineWidth', 2)
plot(tPoke(rwdBin+1:end), mean(p75nr(:, rwdBin+1:end)), 'color', [0.4 0.4 1], 'lineWidth', 2)
plot(tPoke, mean(p0), 'b', 'lineWidth', 2)
plot(tPoke, mean(unpred), 'r', 'lineWidth', 2)

tPre = tPoke(1:rwdBin);
tPost = tPoke(rwdBin+1:end);
p25M = smoothdata(mean(p25), 'gaussian', 10);
p25L = p25M - smoothdata(std(p25)/sqrt(size(p25,1)), 'gaussian', 10);
p25H = p25M + smoothdata(std(p25)/sqrt(size(p25,1)), 'gaussian', 10);
p75M = smoothdata(mean(p75), 'gaussian', 10);
p75L = p75M - smoothdata(std(p75)/sqrt(size(p25,1)), 'gaussian', 10);
p75H = p75M + smoothdata(std(p75)/sqrt(size(p25,1)), 'gaussian', 10);
p25RM = smoothdata(mean(p25r), 'gaussian', 10);
p25RL = p25RM - smoothdata(std(p25r)/sqrt(size(p25r,1)), 'gaussian', 10);
p25RH = p25RM + smoothdata(std(p25r)/sqrt(size(p25r,1)), 'gaussian', 10);
p25NM = smoothdata(mean(p25nr), 'gaussian', 10);
p25NL = p25NM - smoothdata(std(p25nr)/sqrt(size(p25nr,1)), 'gaussian', 10);
p25NH = p25NM + smoothdata(std(p25nr)/sqrt(size(p25nr,1)), 'gaussian', 10);
p75RM = smoothdata(mean(p75r), 'gaussian', 10);
p75RL = p75RM - smoothdata(std(p75r)/sqrt(size(p75r,1)), 'gaussian', 10);
p75RH = p75RM + smoothdata(std(p75r)/sqrt(size(p75r,1)), 'gaussian', 10);
p75NM = smoothdata(mean(p75nr), 'gaussian', 10);
p75NL = p75NM - smoothdata(std(p75nr)/sqrt(size(p75nr,1)), 'gaussian', 10);
p75NH = p75NM + smoothdata(std(p75nr)/sqrt(size(p75nr,1)), 'gaussian', 10);
p0M = smoothdata(mean(p0), 'gaussian', 10);
p0L = p0M - smoothdata(std(p0)/sqrt(size(p0,1)), 'gaussian', 10);
p0H = p0M + smoothdata(std(p0)/sqrt(size(p0,1)), 'gaussian', 10);
unM = smoothdata(mean(unpred), 'gaussian', 10);
unL = unM - smoothdata(std(unpred)/sqrt(size(unpred,1)), 'gaussian', 10);
unH = unM + smoothdata(std(unpred)/sqrt(size(unpred,1)), 'gaussian', 10);

% CS and US
figure('Position', [10 100 695 125])
subplot('Position', [0.005 0.585 0.994 0.99])
hold on
pip = 0:0.15:2.4;
for p = 1:length(pip)
    plot([pip(p) pip(p)], [0.6 1], 'k')
end
plot([rwdTime rwdTime], [0.1 0.5], 'r')
xlim(win)
ylim([0 1])
ax = gca;
ax.Visible = 'off';   

figure('Position', [10 100 695 450])
subplot('Position', [0.005 0.005 0.994 0.99])
hold on
shade(tPre, p75H(1:rwdBin),tPre, p75L(1:rwdBin),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.7 0.7 0.7], 'FillAlpha', 0.25)
plot(tPre, p75M(1:rwdBin), 'color', [0.7 0.7 0.7], 'lineWidth', 2)
shade(tPre, p25H(1:rwdBin),tPre, p25L(1:rwdBin),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.3 0.3 0.3], 'FillAlpha', 0.25)
plot(tPre, p25M(1:rwdBin), 'color', [0.3 0.3 0.3], 'lineWidth', 2)
shade(tPost, p25NH(rwdBin+1:end),tPost, p25NL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0 0 0.6], 'FillAlpha', 0.25)
plot(tPost, p25NM(rwdBin+1:end), 'color', [0 0 0.6], 'lineWidth', 2)
shade(tPost, p25RH(rwdBin+1:end),tPost, p25RL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.6 0 0], 'FillAlpha', 0.25)
plot(tPost, p25RM(rwdBin+1:end), 'color', [0.6 0 0], 'lineWidth', 2)
shade(tPost, p75NH(rwdBin+1:end),tPost, p75NL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.4 0.4 1], 'FillAlpha', 0.25)
plot(tPost, p75NM(rwdBin+1:end), 'color', [0.4 0.4 1], 'lineWidth', 2)
shade(tPost, p75RH(rwdBin+1:end),tPost, p75RL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [1 0.4 0.4], 'FillAlpha', 0.25)
plot(tPost, p75RM(rwdBin+1:end), 'color', [1 0.4 0.4], 'lineWidth', 2)
yR = [0 0.8];
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;

figure('Position', [10 100 695 450])
subplot('Position', [0.005 0.005 0.994 0.99])
hold on
shade(tPoke, p0H,tPoke, p0L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tPoke, p0M, 'color', 'b', 'lineWidth', 2)
shade(tPoke, unH,tPoke, unL,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(tPoke, unM, 'color', 'r', 'lineWidth', 2)
yR = [0 0.8];
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;



%% Figure 2b: Fraction Encoding Value (p[rwd])

load([datRoot 'pavLR4.mat']) % load LR if already computed
rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);

% Multiply slopes by 100 to convert from 0-100 p[rwd] to 0-1 p[rwd]
sRR = 100*sRR; sRRr = 100*sRRr; sRRn = 100*sRRn;

[lia,rpPav] = ismember(rp, uPav2);
rpPav = rpPav(lia);
[lia,fpPav] = ismember(fp, uPav2);
fpPav = fpPav(lia);
[lia,spPav] = ismember(sp, uPav2);
spPav = spPav(lia);
[lia,akPav] = ismember(ak, uPav2);
akPav = akPav(lia);

smWd = 10; % smoothing window for frac encoding and regr slope

% frac encoding trace data
fRfp = smoothdata(FracSignificant2(pRR(fpPav,:), 0.05), 'gaussian', smWd);
fRsp = smoothdata(FracSignificant2(pRR(spPav,:), 0.05), 'gaussian', smWd);
fRak = smoothdata(FracSignificant2(pRR(akPav,:), 0.05), 'gaussian', smWd);
fRrp = smoothdata(FracSignificant2(pRR(rpPav,:), 0.05), 'gaussian', smWd);

fRfpR = smoothdata(FracSignificant2(pRRr(fpPav,:), 0.05), 'gaussian', smWd);
fRspR = smoothdata(FracSignificant2(pRRr(spPav,:), 0.05), 'gaussian', smWd);
fRakR = smoothdata(FracSignificant2(pRRr(akPav,:), 0.05), 'gaussian', smWd);
fRrpR = smoothdata(FracSignificant2(pRRr(rpPav,:), 0.05), 'gaussian', smWd);

fRfpN = smoothdata(FracSignificant2(pRRn(fpPav,:), 0.05), 'gaussian', smWd);
fRspN = smoothdata(FracSignificant2(pRRn(spPav,:), 0.05), 'gaussian', smWd);
fRakN = smoothdata(FracSignificant2(pRRn(akPav,:), 0.05), 'gaussian', smWd);
fRrpN = smoothdata(FracSignificant2(pRRn(rpPav,:), 0.05), 'gaussian', smWd);

% regression slope trace data
mRfp = smoothdata(mean(sRR(fpPav,:)), 'gaussian', smWd);
mRsp = smoothdata(mean(sRR(spPav,:)), 'gaussian', smWd);
mRak = smoothdata(mean(sRR(akPav,:)), 'gaussian', smWd);
mRrp = smoothdata(mean(sRR(rpPav,:)), 'gaussian', smWd);

mRfpR = smoothdata(mean(sRRr(fpPav,:)), 'gaussian', smWd);
mRspR = smoothdata(mean(sRRr(spPav,:)), 'gaussian', smWd);
mRakR = smoothdata(mean(sRRr(akPav,:)), 'gaussian', smWd);
mRrpR = smoothdata(mean(sRRr(rpPav,:)), 'gaussian', smWd);

mRfpN = smoothdata(mean(sRRn(fpPav,:)), 'gaussian', smWd);
mRspN = smoothdata(mean(sRRn(spPav,:)), 'gaussian', smWd);
mRakN = smoothdata(mean(sRRn(akPav,:)), 'gaussian', smWd);
mRrpN = smoothdata(mean(sRRn(rpPav,:)), 'gaussian', smWd);

% includes unpredicted rwd as p[rwd] = 0
sMrp = smoothdata(mean(sRR(rpPav,:)), 'gaussian', smWd);
sLrp = sMrp - smoothdata(std(sRR(rpPav,:))/sqrt(length(rpPav)), 'gaussian', smWd);
sHrp = sMrp + smoothdata(std(sRR(rpPav,:))/sqrt(length(rpPav)), 'gaussian', smWd);
sMfp = smoothdata(mean(sRR(fpPav,:)), 'gaussian', smWd);
sLfp = sMfp - smoothdata(std(sRR(fpPav,:))/sqrt(length(fpPav)), 'gaussian', smWd);
sHfp = sMfp + smoothdata(std(sRR(fpPav,:))/sqrt(length(fpPav)), 'gaussian', smWd);
sMsp = smoothdata(mean(sRR(spPav,:)), 'gaussian', smWd);
sLsp = sMsp - smoothdata(std(sRR(spPav,:))/sqrt(length(spPav)), 'gaussian', smWd);
sHsp = sMsp + smoothdata(std(sRR(spPav,:))/sqrt(length(spPav)), 'gaussian', smWd);
sMak = smoothdata(mean(sRR(akPav,:)), 'gaussian', smWd);
sLak = sMak - smoothdata(std(sRR(akPav,:))/sqrt(length(akPav)), 'gaussian', smWd);
sHak = sMak + smoothdata(std(sRR(akPav,:))/sqrt(length(akPav)), 'gaussian', smWd);

sMRrp = smoothdata(mean(sRRr(rpPav,:)), 'gaussian', smWd);
sLRrp = sMRrp - smoothdata(std(sRRr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', smWd);
sHRrp = sMRrp + smoothdata(std(sRRr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', smWd);
sMRfp = smoothdata(mean(sRRr(fpPav,:)), 'gaussian', smWd);
sLRfp = sMRfp - smoothdata(std(sRRr(fpPav,:))/sqrt(length(fpPav)), 'gaussian', smWd);
sHRfp = sMRfp + smoothdata(std(sRRr(fpPav,:))/sqrt(length(fpPav)), 'gaussian', smWd);
sMRsp = smoothdata(mean(sRRr(spPav,:)), 'gaussian', smWd);
sLRsp = sMRsp - smoothdata(std(sRRr(spPav,:))/sqrt(length(spPav)), 'gaussian', smWd);
sHRsp = sMRsp + smoothdata(std(sRRr(spPav,:))/sqrt(length(spPav)), 'gaussian', smWd);
sMRak = smoothdata(mean(sRRr(akPav,:)), 'gaussian', smWd);
sLRak = sMRak - smoothdata(std(sRRr(akPav,:))/sqrt(length(akPav)), 'gaussian', smWd);
sHRak = sMRak + smoothdata(std(sRRr(akPav,:))/sqrt(length(akPav)), 'gaussian', smWd);

sMNrp = smoothdata(mean(sRRn(rpPav,:)), 'gaussian', smWd);
sLNrp = sMNrp - smoothdata(std(sRRn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', smWd);
sHNrp = sMNrp + smoothdata(std(sRRn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', smWd);
sMNfp = smoothdata(mean(sRRn(fpPav,:)), 'gaussian', smWd);
sLNfp = sMNfp - smoothdata(std(sRRn(fpPav,:))/sqrt(length(fpPav)), 'gaussian', smWd);
sHNfp = sMNfp + smoothdata(std(sRRn(fpPav,:))/sqrt(length(fpPav)), 'gaussian', smWd);
sMNsp = smoothdata(mean(sRRn(spPav,:)), 'gaussian', smWd);
sLNsp = sMNsp - smoothdata(std(sRRn(spPav,:))/sqrt(length(spPav)), 'gaussian', smWd);
sHNsp = sMNsp + smoothdata(std(sRRn(spPav,:))/sqrt(length(spPav)), 'gaussian', smWd);
sMNak = smoothdata(mean(sRRn(akPav,:)), 'gaussian', smWd);
sLNak = sMNak - smoothdata(std(sRRn(akPav,:))/sqrt(length(akPav)), 'gaussian', smWd);
sHNak = sMNak + smoothdata(std(sRRn(akPav,:))/sqrt(length(akPav)), 'gaussian', smWd);

% fraction encoding panel
figure('Position', [1 85 1440 550])
w1 = 0.7620; g = 0.01; w2 = 0.98 - w1 - g
subplot('Position', [0.01 0.01 w1 0.98])
hold on
plot(t1, fRsp, 'b', 'linewidth', 3)
plot(t1, fRak, 'c', 'linewidth', 3)
plot(t1, fRfp, 'color', fpColor, 'linewidth', 3)
plot(t1, fRrp, 'color', rpColor, 'linewidth', 3)

plot(t2, fRspR, 'b', 'linewidth', 3)
plot(t2, fRakR, 'c', 'linewidth', 3)
plot(t2, fRfpR, 'color', fpColor, 'linewidth', 3)
plot(t2, fRrpR, 'color', rpColor, 'linewidth', 3)
yR = [0 0.65]; yT = [0.2 0.4 0.6];
plot([0 0], yR, '--k', 'linewidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2)
plot(win, [0.1 0.1], '--k', 'linewidth', 2)
ylim(yR)
xlim(win)
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';

subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
plot(t2, fRspN, 'b', 'linewidth', 3)
plot(t2, fRakN, 'c', 'linewidth', 3)
plot(t2, fRfpN, 'color', fpColor, 'linewidth', 3)
plot(t2, fRrpN, 'color', rpColor, 'linewidth', 3)
plot([rwdTime 4.5], [0.1 0.1], '--k', 'linewidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;

% regression slope panel
figure('Position', [1 378 1440 550])
subplot('Position', [0.01 0.01 w1 0.98])
hold on
shade(t1, sHsp, t1, sLsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t1, sMsp, 'color', 'b', 'lineWidth', 2)
shade(t1, sHak, t1, sLak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t1, sMak, 'color', 'c', 'lineWidth', 2)
shade(t1, sHfp, t1, sLfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t1, sMfp, 'color', fpColor, 'lineWidth', 2)
shade(t1, sHrp, t1, sLrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t1, sMrp, 'color', rpColor, 'lineWidth', 2)

shade(t2, sHRsp, t2, sLRsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t2, sMRsp, 'color', 'b', 'lineWidth', 2)
shade(t2, sHRak, t2, sLRak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t2, sMRak, 'color', 'c', 'lineWidth', 2)
shade(t2, sHRfp, t2, sLRfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t2, sMRfp, 'color', fpColor, 'lineWidth', 2)
shade(t2, sHRrp, t2, sLRrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMRrp, 'color', rpColor, 'lineWidth', 2)
plot(win, [0 0], '--k', 'lineWidth', 2)
yR = [-2 2];
plot([0 0], yR, '--k', 'lineWidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'lineWidth', 2)
plot([rwdTime 4.5], [0 0], '--k', 'lineWidth', 2)
ylim(yR)
yT = -1.6:0.8:1.6;
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';

subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
shade(t2, sHNsp, t2, sLNsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t2, sMNsp, 'color', 'b', 'lineWidth', 2)
shade(t2, sHNak, t2, sLNak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t2, sMNak, 'color', 'c', 'lineWidth', 2)
shade(t2, sHNfp, t2, sLNfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t2, sMNfp, 'color', fpColor, 'lineWidth', 2)
shade(t2, sHNrp, t2, sLNrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMNrp, 'color', rpColor, 'lineWidth', 2)
plot([rwdTime 4.5], [0 0], '--k', 'lineWidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;



%% Figure 2d--RPE Example Cell (Pav)

best = [337 425];
candidate = [368 337 425];

winPav = [-0.5 4.5];
sesList = unique(uSes);
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

u = 337;
uTrajPav = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
dt = uTrajPav(1).times(2) - uTrajPav(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
pavIdx = find(strcmp(lower(unit(u).taskList), 'pav'));
lg = unit(u).behav_log{pavIdx};
ts = unit(u).behav_ts{pavIdx};

cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

rwdTime = nanmean(ts.rwdTime - ts.csTime);
traj = TrajSplit(uTrajPav, ts, winPav);

% average rate: prob 0 cue
tr0 = find(lg.toneFreq == cue0);
r = zeros(length(tr0), nPtsPav);
for k = 1:length(tr0)
    r(k,:) = traj(tr0(k)).rate;
end
p0 = mean(r); 

% average rate: unpredicted reward
tr100 = find(lg.toneFreq == 0);
r = zeros(length(tr100), nPtsPav);
for k = 1:length(tr100)
    r(k,:) = traj(tr100(k)).rate;
end
p100 = mean(r);

% average rate: prob 25 cue
tr25 = find(lg.toneFreq == cue25);
tr25r = intersect(tr25, find(lg.outcome));
r = zeros(length(tr25r), nPtsPav);
for k = 1:length(tr25r)
    r(k,:) = traj(tr25r(k)).rate;
end
p25r = mean(r);
tr25nr = intersect(tr25, find(~lg.outcome));
r = zeros(length(tr25nr), nPtsPav);
for k = 1:length(tr25nr)
    r(k,:) = traj(tr25nr(k)).rate;
end
p25nr = mean(r);
r = zeros(length(tr25), nPtsPav);
for k = 1:length(tr25)
    r(k,:) = traj(tr25(k)).rate;
end
p25 = mean(r);

% average rate: prob 75 cue
tr75 = find(lg.toneFreq == cue75);
tr75r = intersect(tr75, find(lg.outcome));
r = zeros(length(tr75r), nPtsPav);
for k = 1:length(tr75r)
    r(k,:) = traj(tr75r(k)).rate;
end
p75r = mean(r);
tr75nr = intersect(tr75, find(~lg.outcome));
r = zeros(length(tr75nr), nPtsPav);
for k = 1:length(tr75nr)
    r(k,:) = traj(tr75nr(k)).rate;
end
p75nr = mean(r);
r = zeros(length(tr75), nPtsPav);
for k = 1:length(tr75)
    r(k,:) = traj(tr75(k)).rate;
end
p75 = mean(r);

maxRate = max([p0 p100 p25r p25nr p75r p75nr]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];
yticks = [30 60 90];

tkW = 2;
tkH = 3;

% Pav example, 25% and 75% pRwd rate plot
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', [0.3 0.3 0.3], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;

% Pav example, 0% and 100% rate plot
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav, p0, 'color', 'b', 'linewidth', 3)
plot(timesPav, p100, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;

% CS and US
figure('Position', [10 100 695 125])
subplot('Position', [0.005 0 0.994 1])
hold on
pip = 0:0.15:2.4;
for p = 1:length(pip)
    plot([pip(p) pip(p)], [0.6 1], 'k')
end
plot([rwdTime rwdTime], [0.1 0.5], 'r')
xlim([timesPav(1) timesPav(end)])
ylim([0 1])
ax = gca;
ax.Visible = 'off';   

% Pav example, 25% and 75% pRwd raster
f = figure('Position', [10 100 695 240])
subplot('Position', [0.005 0.005 0.994 0.995])
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};
RasterPlot(unit(u), 1, winPav, 'trials', {tr75r, tr25r, tr75nr, tr25nr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH,...
    'colors', cList, 'task', 'Pav')
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
plot([rwdTime rwdTime], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';

% Pav example, 0% and 100% raster
f = figure('Position', [10 100 695 240])
subplot('Position', [0.005 0.005 0.994 0.995])       
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};
RasterPlot(unit(u), 1, winPav, 'trials', {tr100, tr0}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH,...
    'colors', {'r', 'b'}, 'task', 'Pav')
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
plot([rwdTime rwdTime], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';



%% Figure 2e (top row)--Average Response (DA cells, Pav)

winPav = [-0.5 4.5];

% load DA cell data
load([datRoot 'unitDa.mat'])
keep = false(1, length(unitDA));
for u = 1:length(unitDA)
    lg = unitDA(u).behav_log{pavIdx};
    keep(u) = ~isempty(lg);
    if keep(u)
        keep(u) = ~isempty(lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1));
    end
end
unitDA = unitDA(keep);


% generate smoothed rate trajectories
sigma = 0.02;
dt = sigma / 10;
for u = 1:length(unitDA)
    uTrajDA(u) = UnitTraj(unitDA(u), sigma, dt, 'Pav');
    uTrajDA(u).name = unitDA(u).name;
end

dt = uTrajDA(1).times(2) - uTrajDA(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
p0 = zeros(length(unitDA), nPtsPav);
p100 = zeros(length(unitDA), nPtsPav);
p25 = zeros(length(unitDA), nPtsPav);
p75 = zeros(length(unitDA), nPtsPav);
p25r = zeros(length(unitDA), nPtsPav);
p75r = zeros(length(unitDA), nPtsPav);
p25nr = zeros(length(unitDA), nPtsPav);
p75nr = zeros(length(unitDA), nPtsPav);
rwdTime = zeros(1, length(unitDA));

for u = 1:length(unitDA)
    
    ts = unitDA(u).behav_ts{pavIdx};
    lg = unitDA(u).behav_log{pavIdx};
    traj = TrajSplit(uTrajDA(u), ts, winPav);
    cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
    cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
    cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

    rwdTime(u) = nanmean(ts.rwdTime - ts.csTime);
    
    % average rate: prob 0 cue
    tr0 = find(lg.toneFreq == cue0);
    r = zeros(length(tr0), nPtsPav);
    for k = 1:length(tr0)
        r(k,:) = traj(tr0(k)).rate;
    end
    p0(u,:) = mean(r);
    
    % average rate: unpredicted reward
    tr100 = find(lg.toneFreq == 0);
    r = zeros(length(tr100), nPtsPav);
    for k = 1:length(tr100)
        r(k,:) = traj(tr100(k)).rate;
    end
    p100(u,:) = mean(r);

    % average rate: prob 25 cue
    tr25 = find(lg.toneFreq == cue25);
    tr25r = intersect(tr25, find(lg.outcome));
    r = zeros(length(tr25r), nPtsPav);
    for k = 1:length(tr25r)
        r(k,:) = traj(tr25r(k)).rate;
    end
    p25r(u,:) = mean(r);
    tr25nr = intersect(tr25, find(~lg.outcome));
    r = zeros(length(tr25nr), nPtsPav);
    for k = 1:length(tr25nr)
        r(k,:) = traj(tr25nr(k)).rate;
    end
    p25nr(u,:) = mean(r);
    r = zeros(length(tr25), nPtsPav);
    for k = 1:length(tr25)
        r(k,:) = traj(tr25(k)).rate;
    end
    p25(u,:) = mean(r);
    
    % average rate: prob 75 cue
    tr75 = find(lg.toneFreq == cue75);
    tr75r = intersect(tr75, find(lg.outcome));
    r = zeros(length(tr75r), nPtsPav);
    for k = 1:length(tr75r)
        r(k,:) = traj(tr75r(k)).rate;
    end
    p75r(u,:) = mean(r);
    tr75nr = intersect(tr75, find(~lg.outcome));
    r = zeros(length(tr75nr), nPtsPav);
    for k = 1:length(tr75nr)
        r(k,:) = traj(tr75nr(k)).rate;
    end
    p75nr(u,:) = mean(r);
    r = zeros(length(tr75), nPtsPav);
    for k = 1:length(tr75)
        r(k,:) = traj(tr75(k)).rate;
    end
    p75(u,:) = mean(r);
    
end

rwdTime = mean(rwdTime);
p0 = mean(p0);
p100 = mean(p100);
p25 = mean(p25);
p75 = mean(p75);
p25r = mean(p25r);
p75r = mean(p75r);
p25nr = mean(p25nr);
p75nr = mean(p75nr);

maxRate = max([p25 p75 p25r p25nr p75r p75nr p0 p100]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate]
yticks = [15 30 45];

% Pav 25% and 75% pRwd rate plot (average over cells)
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', [0.3 0.3 0.3], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;

% Pav example, 0% and 100% rate plot
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
hold on
plot(timesPav, p0, 'color', 'b', 'linewidth', 3)
plot(timesPav, p100, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;




%% Figure 2e--Average Response By Cell Type (Pav)

winPav = [-0.5 4.5];
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

% repeat for each cell type
uIdx = intersect(sp, uPav);
unitTmp = unit(uIdx);
uTrajPav = LoadUnitTraj(unitTmp, 'Pav', datRoot, 'sigma', 20);
del = find(arrayfun(@(u) isempty(u.rate), uTrajPav));
uTrajPav(del) = [];
unitTmp(del) = [];
uIdx(del) = [];

dt = uTrajPav(1).times(2) - uTrajPav(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
p0 = zeros(length(uIdx), nPtsPav);
p100 = zeros(length(uIdx), nPtsPav);
p25 = zeros(length(uIdx), nPtsPav);
p75 = zeros(length(uIdx), nPtsPav);
p25r = zeros(length(uIdx), nPtsPav);
p75r = zeros(length(uIdx), nPtsPav);
p25nr = zeros(length(uIdx), nPtsPav);
p75nr = zeros(length(uIdx), nPtsPav);
rwdTime = zeros(1, length(uIdx));

for u = 1:length(unitTmp)
    
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitTmp(u).taskList));
    ts = unitTmp(u).behav_ts{pavIdx};
    lg = unitTmp(u).behav_log{pavIdx};
    traj = TrajSplit(uTrajPav(u), ts, winPav);
    cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
    cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
    cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

    rwdTime(u) = nanmean(ts.rwdTime - ts.csTime);
    
    % average rate: prob 0 cue
    tr0 = find(lg.toneFreq == cue0);
    r = zeros(length(tr0), nPtsPav);
    for k = 1:length(tr0)
        r(k,:) = traj(tr0(k)).rate;
    end
    p0(u,:) = mean(r);
    
    % average rate: unpredicted reward
    tr100 = find(lg.toneFreq == 0);
    r = zeros(length(tr100), nPtsPav);
    for k = 1:length(tr100)
        r(k,:) = traj(tr100(k)).rate;
    end
    p100(u,:) = mean(r);

    % average rate: prob 25 cue
    tr25 = find(lg.toneFreq == cue25);
    tr25r = intersect(tr25, find(lg.outcome));
    r = zeros(length(tr25r), nPtsPav);
    for k = 1:length(tr25r)
        r(k,:) = traj(tr25r(k)).rate;
    end
    p25r(u,:) = mean(r);
    tr25nr = intersect(tr25, find(~lg.outcome));
    r = zeros(length(tr25nr), nPtsPav);
    for k = 1:length(tr25nr)
        r(k,:) = traj(tr25nr(k)).rate;
    end
    p25nr(u,:) = mean(r);
    r = zeros(length(tr25), nPtsPav);
    for k = 1:length(tr25)
        r(k,:) = traj(tr25(k)).rate;
    end
    p25(u,:) = mean(r);
    
    % average rate: prob 75 cue
    tr75 = find(lg.toneFreq == cue75);
    tr75r = intersect(tr75, find(lg.outcome));
    r = zeros(length(tr75r), nPtsPav);
    for k = 1:length(tr75r)
        r(k,:) = traj(tr75r(k)).rate;
    end
    p75r(u,:) = mean(r);
    tr75nr = intersect(tr75, find(~lg.outcome));
    r = zeros(length(tr75nr), nPtsPav);
    for k = 1:length(tr75nr)
        r(k,:) = traj(tr75nr(k)).rate;
    end
    p75nr(u,:) = mean(r);
    r = zeros(length(tr75), nPtsPav);
    for k = 1:length(tr75)
        r(k,:) = traj(tr75(k)).rate;
    end
    p75(u,:) = mean(r);
    
end

rwdTime = mean(rwdTime);
p0 = mean(p0);
p100 = mean(p100);
p25 = mean(p25);
p75 = mean(p75);
p25r = mean(p25r);
p75r = mean(p75r);
p25nr = mean(p25nr);
p75nr = mean(p75nr);

maxRate = max([p25 p75 p25r p25nr p75r p75nr p0 p100]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate]
yticks = [10 20 30];

% Pav 25% and 75% pRwd rate plot (average over cells)
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', [0.3 0.3 0.3], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;

% Pav 0% and 100% rate plot (average over cells)
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
hold on
plot(timesPav, p0, 'color', 'b', 'linewidth', 3)
plot(timesPav, p100, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;





%% Figure 2b--Average Response (Pav)

winPav = [-0.5 3.5];
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

% repeat for each cell type
uIdx = arky;
unitTmp = unit(uIdx);
uTrajPav = LoadUnitTraj(unitTmp, 'Pav', datRoot, 'sigma', 20);
del = find(arrayfun(@(u) isempty(u.rate), uTrajPav));
uTrajPav(del) = [];
unitTmp(del) = [];
uIdx(del) = [];

dt = uTrajPav(1).times(2) - uTrajPav(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
p0 = zeros(length(uIdx), nPtsPav);
p100 = zeros(length(uIdx), nPtsPav);
p25 = zeros(length(uIdx), nPtsPav);
p75 = zeros(length(uIdx), nPtsPav);
p25r = zeros(length(uIdx), nPtsPav);
p75r = zeros(length(uIdx), nPtsPav);
p25nr = zeros(length(uIdx), nPtsPav);
p75nr = zeros(length(uIdx), nPtsPav);
rwdTime = zeros(1, length(uIdx));

for u = 1:length(unitTmp)
    
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitTmp(u).taskList));
    ts = unitTmp(u).behav_ts{pavIdx};
    lg = unitTmp(u).behav_log{pavIdx};
    traj = TrajSplit(uTrajPav(u), ts, winPav);
    cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
    cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
    cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

    rwdTime(u) = nanmean(ts.rwdTime - ts.csTime);
    
    % average rate: prob 0 cue
    tr0 = find(lg.toneFreq == cue0);
    r = zeros(length(tr0), nPtsPav);
    for k = 1:length(tr0)
        r(k,:) = traj(tr0(k)).rate;
    end
    p0(u,:) = mean(r);
    
    % average rate: unpredicted reward
    tr100 = find(lg.toneFreq == 0);
    r = zeros(length(tr100), nPtsPav);
    for k = 1:length(tr100)
        r(k,:) = traj(tr100(k)).rate;
    end
    p100(u,:) = mean(r);

    % average rate: prob 25 cue
    tr25 = find(lg.toneFreq == cue25);
    tr25r = intersect(tr25, find(lg.outcome));
    r = zeros(length(tr25r), nPtsPav);
    for k = 1:length(tr25r)
        r(k,:) = traj(tr25r(k)).rate;
    end
    p25r(u,:) = mean(r);
    tr25nr = intersect(tr25, find(~lg.outcome));
    r = zeros(length(tr25nr), nPtsPav);
    for k = 1:length(tr25nr)
        r(k,:) = traj(tr25nr(k)).rate;
    end
    p25nr(u,:) = mean(r);
    r = zeros(length(tr25), nPtsPav);
    for k = 1:length(tr25)
        r(k,:) = traj(tr25(k)).rate;
    end
    p25(u,:) = mean(r);
    
    % average rate: prob 75 cue
    tr75 = find(lg.toneFreq == cue75);
    tr75r = intersect(tr75, find(lg.outcome));
    r = zeros(length(tr75r), nPtsPav);
    for k = 1:length(tr75r)
        r(k,:) = traj(tr75r(k)).rate;
    end
    p75r(u,:) = mean(r);
    tr75nr = intersect(tr75, find(~lg.outcome));
    r = zeros(length(tr75nr), nPtsPav);
    for k = 1:length(tr75nr)
        r(k,:) = traj(tr75nr(k)).rate;
    end
    p75nr(u,:) = mean(r);
    r = zeros(length(tr75), nPtsPav);
    for k = 1:length(tr75)
        r(k,:) = traj(tr75(k)).rate;
    end
    p75(u,:) = mean(r);
    
end

rwdTime = mean(rwdTime);
p0 = mean(p0);
p100 = mean(p100);
p25 = mean(p25);
p75 = mean(p75);
p25r = mean(p25r);
p75r = mean(p75r);
p25nr = mean(p25nr);
p75nr = mean(p75nr);

maxRate = max([p25 p75 p25r p25nr p75r p75nr p0 p100]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate]
yticks = [10 20 30];

% Pav 25% and 75% pRwd rate plot (average over cells)
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', [0.3 0.3 0.3], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:3])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;

% Pav 0% and 100% rate plot (average over cells)
figure('Position', [10 100 695 188])
subplot('Position', [0.005 0.005 0.994 0.995])
hold on
plot(timesPav, p0, 'color', 'b', 'linewidth', 3)
plot(timesPav, p100, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5:0.5:3])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;





%% Figure 2d--Average Response (by cell type)

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 2;
sesList = unique(uSes);

% go through each cell type here
uIdx = arky;
unitTmp = unit(uIdx);
uTrajRL = LoadUnitTraj(unitTmp, 'RL', datRoot, 'sigma', 20);

dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
siLo = zeros(length(uIdx), nPtsRL);
siMed = zeros(length(uIdx), nPtsRL);
siHi = zeros(length(uIdx), nPtsRL);
loRwd = zeros(length(uIdx), nPtsRL);
medRwd = zeros(length(uIdx), nPtsRL);
hiRwd = zeros(length(uIdx), nPtsRL);
loNoRwd = zeros(length(uIdx), nPtsRL);
medNoRwd = zeros(length(uIdx), nPtsRL);
hiNoRwd = zeros(length(uIdx), nPtsRL);
ltShortLat = zeros(length(uIdx), nPtsRL);
ltLongLat = zeros(length(uIdx), nPtsRL);
ciShortLat = zeros(length(uIdx), nPtsRL);
ciLongLat = zeros(length(uIdx), nPtsRL);
goLo = zeros(length(uIdx), nPtsRL);
goMed = zeros(length(uIdx), nPtsRL);
goHi = zeros(length(uIdx), nPtsRL);
fpRwd = zeros(length(uIdx), nPtsRL);
fpNoRwd = zeros(length(uIdx), nPtsRL);

for u = 1:length(unitTmp)
    
    t1 = unitTmp(u).taskStart(rlIdx);
    t2 = unitTmp(u).taskEnd(rlIdx);
    ts = unitTmp(u).behav_ts{rlIdx};
    
    % average rate: light on
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 1);
    [lat rt] = BehaviorTimes(unitTmp(u).behav_ts{rlIdx});
    sL = find(lat < latCrit);
    lL = find(lat >= latCrit);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ltShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ltLongLat(u,:) = mean(r);
    
    % average rate: center in
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 2);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ciShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ciLongLat(u,:) = mean(r);
    
    % average rate: go cue
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 3);
    s = uSes(uIdx(u));
    [~, s] = ismember(s{1}, sesList);
    rr = rwdRate{s}(11:end);
    loTr = find(rr <= quantile(rr, lo(2))) + 10;
    medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
    hiTr = find(rr >= quantile(rr, hi(1))) + 10;
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    goLo(u,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    goMed(u,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    goHi(u,:) = mean(r);
    
    % average rate: side in
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 5);
    rwd = TrialFilter(unitTmp(u).behav_ts{rlIdx}, 'x1', unitTmp(u).side);
    noRwd = TrialFilter(unitTmp(u).behav_ts{rlIdx}, 'x0', unitTmp(u).side);
    
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    siLo(u,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    siMed(u,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    siHi(u,:) = mean(r);
    
    sel = intersect(loTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loRwd(u,:) = mean(r);
    sel = intersect(loTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loNoRwd(u,:) = mean(r);
    sel = intersect(medTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medRwd(u,:) = mean(r);
    sel = intersect(medTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medNoRwd(u,:) = mean(r);
    
    sel = intersect(hiTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiRwd(u,:) = mean(r);
    sel = intersect(hiTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiNoRwd(u,:) = mean(r);
    
    % average rate: food port
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 6);
    fp = find(~isnan(ts.firstFoodPoke));
    sel = intersect(rwd, fp);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpRwd(u,:) = mean(r);
    else
        fpRwd(u,:) = nan(1, nPtsRL);
    end
    sel = intersect(noRwd, fp);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpNoRwd(u,:) = mean(r);
    else
        fpNoRwd(u,:) = nan(1, nPtsRL);
    end
    
end

ltSh = mean(ltShortLat);
ltLo = mean(ltLongLat);
ciSh = mean(ciShortLat);
ciLo = mean(ciLongLat);
goL = mean(goLo);
goM = mean(goMed);
goH = mean(goHi);
siL = mean(siLo);
siM = mean(siMed);
siH = mean(siHi);
siLR = nanmean(loRwd);
siMR = mean(medRwd);
siHR = mean(hiRwd);
siLN = mean(loNoRwd);
siMN = mean(medNoRwd);
siHN = mean(hiNoRwd);
goodCells = find(~isnan(fpRwd(:,1)));
fpR = mean(fpRwd(goodCells,:));
goodCells = find(~isnan(fpNoRwd(:,1)));
fpN = mean(fpNoRwd(goodCells,:));

maxRate = max([ltSh ltLo ciSh ciLo goL goM goH siLR siMR siHR siLN siMN siHN fpR fpN]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];
yticks = [15 30];

f = figure('Position', [10 100 1400 188])
subplot('Position', [0.005 0.005 0.194 0.995])
cList = {[0.1 1 0.1], [0 0.4 0]};
hold on
plot(timesRL, ltSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ltLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.204 0.005 0.194 0.995])
hold on
plot(timesRL, ciSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ciLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.403 0.005 0.194 0.995])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.602 0.005 0.194 0.995])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
pt = find(timesRL == 0) + 1;
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.801 0.005 0.194 0.995])
hold on
plot(timesRL, fpN, 'color', 'b', 'linewidth', 3)
plot(timesRL, fpR, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')




%% Figure 2b--Average Response (DA cells)

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 2;

% load DA cell data
load([datRoot 'unitDa.mat'])

% calculate DA cell reward rate
tau = 90;
rwdRateDA = cell(1, length(unitDA));
rlIdxDA = nan(1, length(unitDA));
pavIdxDA = nan(1, length(unitDA));
for u = 1:length(unitDA)
    rlIdxDA(u) = find(cellfun(@(t) strcmp(lower(t), 'rl'), unitDA(u).taskList));
    pavIdxDA(u) = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    tsRL = unitDA(u).behav_ts{rlIdxDA(u)};
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRateDA{u} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRateDA{u}(k) = rwdRateDA{u}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRateDA{u}(k) = rwdRateDA{u}(k) + tsRL.outcome(k);
    end      
end 

% generate smoothed rate trajectories
sigma = 0.02;
dt = sigma / 10;
for u = 1:length(unitDA)
    uTrajDA(u) = UnitTraj(unitDA(u), sigma, dt, 'RL');
    uTrajDA(u).name = unitDA(u).name;
end

timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
loRwd = zeros(length(unitDA), nPtsRL);
medRwd = zeros(length(unitDA), nPtsRL);
hiRwd = zeros(length(unitDA), nPtsRL);
loNoRwd = zeros(length(unitDA), nPtsRL);
medNoRwd = zeros(length(unitDA), nPtsRL);
hiNoRwd = zeros(length(unitDA), nPtsRL);
ltShortLat = zeros(length(unitDA), nPtsRL);
ltLongLat = zeros(length(unitDA), nPtsRL);
ciShortLat = zeros(length(unitDA), nPtsRL);
ciLongLat = zeros(length(unitDA), nPtsRL);
goLo = zeros(length(unitDA), nPtsRL);
goMed = zeros(length(unitDA), nPtsRL);
goHi = zeros(length(unitDA), nPtsRL);
siLo = zeros(length(unitDA), nPtsRL);
siMed = zeros(length(unitDA), nPtsRL);
siHi = zeros(length(unitDA), nPtsRL);
fpRwd = zeros(length(unitDA), nPtsRL);
fpNoRwd = zeros(length(unitDA), nPtsRL);

for u = 1:length(unitDA)
    
    t1 = unitDA(u).taskStart(rlIdxDA(u));
    t2 = unitDA(u).taskEnd(rlIdxDA(u));
    ts = unitDA(u).behav_ts{rlIdxDA(u)};
    
    % average rate: light on
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 1);
    [lat rt] = BehaviorTimes(ts);
    sL = find(lat < latCrit);
    lL = find(lat >= latCrit);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ltShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ltLongLat(u,:) = mean(r);
    
    % average rate: center in
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 2);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ciShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ciLongLat(u,:) = mean(r);
    
    % average rate: go cue
    traj = TrajSplit(uTrajDA(u),  ts, winRL, 'event', 3);
    rr = rwdRateDA{u}(11:end);
    loTr = find(rr <= quantile(rr, lo(2))) + 10;
    medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
    hiTr = find(rr >= quantile(rr, hi(1))) + 10;
    
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    goLo(u,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    goMed(u,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    goHi(u,:) = mean(r);
    
    % average rate: side in
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 5);
    rwd = TrialFilter(ts, 'x1', unitDA(u).side);
    noRwd = TrialFilter(ts, 'x0', unitDA(u).side);
    
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    siLo(u,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    siMed(u,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    siHi(u,:) = mean(r);
    
    sel = intersect(loTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loRwd(u,:) = mean(r);
    sel = intersect(loTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loNoRwd(u,:) = mean(r);
    sel = intersect(medTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medRwd(u,:) = mean(r);
    sel = intersect(medTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medNoRwd(u,:) = mean(r);
    
    sel = intersect(hiTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiRwd(u,:) = mean(r);
    sel = intersect(hiTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiNoRwd(u,:) = mean(r);
    
    % average rate: food port
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 6);
    fp = find(~isnan(ts.firstFoodPoke));
    sel = intersect(rwd, fp);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpRwd(u,:) = mean(r);
    else
        fpRwd(u,:) = nan(1, nPtsRL);
    end
    sel = intersect(noRwd, fp);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpNoRwd(u,:) = mean(r);
    else
        fpNoRwd(u,:) = nan(1, nPtsRL);
    end
    
end

ltSh = mean(ltShortLat);
ltLo = mean(ltLongLat);
ciSh = mean(ciShortLat);
ciLo = mean(ciLongLat);
goL = mean(goLo);
goM = mean(goMed);
goH = mean(goHi);
siLR = mean(loRwd);
siMR = mean(medRwd);
siHR = mean(hiRwd);
siLN = mean(loNoRwd);
siMN = mean(medNoRwd);
siHN = mean(hiNoRwd);
siL = mean(siLo);
siM = mean(siMed);
siH = mean(siHi);
goodCells = find(~isnan(fpRwd(:,1)));
fpR = mean(fpRwd(goodCells,:));
goodCells = find(~isnan(fpNoRwd(:,1)));
fpN = mean(fpNoRwd(goodCells,:));

maxRate = max([ltSh ltLo ciSh ciLo goRate siLR siMR siHR siLN siMN siHN fpR fpN]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];
yticks = [0 15 30];

f = figure('Position', [10 100 1400 188])
subplot('Position', [0.005 0.005 0.194 0.995])
cList = {[0.1 1 0.1], [0 0.4 0]};
hold on
plot(timesRL, ltSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ltLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.204 0.005 0.194 0.995])
hold on
plot(timesRL, ciSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ciLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.403 0.005 0.194 0.995])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.602 0.005 0.194 0.995])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
pt = find(timesRL == 0) + 1;
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.801 0.005 0.194 0.995])
hold on
plot(timesRL, fpN, 'color', 'b', 'linewidth', 3)
plot(timesRL, fpR, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')





%% Response Summary By Cell Type (RL, with plots)

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 0.25;
rtCrit = 0.5;
sesList = unique(uSes);

% bin specs for response detection
bW = 0.05;
bB = 0.1;
bE = 0:bW:0.25;

uIdx = gpeRpe;
typeLabel = 'GPe-RPE';
unitTmp = unit(uIdx);
uTrajRL = LoadUnitTraj(unitTmp, 'RL', datRoot, 'sigma', 20);

dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
loRwd = zeros(length(uIdx), nPtsRL);
medRwd = zeros(length(uIdx), nPtsRL);
hiRwd = zeros(length(uIdx), nPtsRL);
loNoRwd = zeros(length(uIdx), nPtsRL);
medNoRwd = zeros(length(uIdx), nPtsRL);
hiNoRwd = zeros(length(uIdx), nPtsRL);
ltShortLat = zeros(length(uIdx), nPtsRL);
ltLongLat = zeros(length(uIdx), nPtsRL);
ciShortLat = zeros(length(uIdx), nPtsRL);
ciLongLat = zeros(length(uIdx), nPtsRL);
goShortRt = zeros(length(uIdx), nPtsRL);
goLongRt = zeros(length(uIdx), nPtsRL);
fpRwd = zeros(length(uIdx), nPtsRL);
fpNoRwd = zeros(length(uIdx), nPtsRL);

ltShortResponse = false(1, length(uIdx));
ltLongResponse = false(1, length(uIdx));
ciResponse = false(1, length(uIdx));
goResponse = false(1, length(uIdx));
siRwdResponse = false(1, length(uIdx));
siNoRwdResponse = false(1, length(uIdx));

for u = 1:length(unitTmp)
    
    t1 = unitTmp(u).taskStart(rlIdx);
    t2 = unitTmp(u).taskEnd(rlIdx);
    ts = unitTmp(u).behav_ts{rlIdx};
    spk = unitTmp(u).spkTimes(unitTmp(u).spkTimes>t1 & unitTmp(u).spkTimes<t2) - t1;
    
    % average rate: light on
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 1);
    [lat rt] = BehaviorTimes(unitTmp(u).behav_ts{rlIdx});
    sL = find(lat < quantile(lat, latCrit));
    lL = find(lat >= quantile(lat, latCrit));
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ltShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ltLongLat(u,:) = mean(r);
    
    % significant response: light on
    eTime = ts.trialbegin;
    baseLn = mean(arrayfun(@(t0) length(spk(spk >= t0-bB & spk < t0)), eTime)) / bB;
    s = [];
    for t0 = eTime(sL)'
        s = [s spk(spk > t0+bE(1) & spk <t0+bE(end)) - t0];
    end
    rate = histcounts(s, bE) ./ (diff(bE) * length(sL));
    p = ones(size(rate));
    p(rate <= baseLn) = poisscdf(rate(rate <= baseLn), baseLn);
    p(rate > baseLn) = 1 - poisscdf(rate(rate > baseLn), baseLn);
    ltShortResponse(u) = ~isempty(HolmBonferroni(p));
    s = [];
    for t0 = eTime(lL)'
        s = [s spk(spk > t0+bE(1) & spk <t0+bE(end)) - t0];
    end
    rate = histcounts(s, bE) ./ (diff(bE) * length(lL));
    p = ones(size(rate));
    p(rate <= baseLn) = poisscdf(rate(rate <= baseLn), baseLn);
    p(rate > baseLn) = 1 - poisscdf(rate(rate > baseLn), baseLn);
    ltLongResponse(u) = ~isempty(HolmBonferroni(p));
    
    % average rate: center in
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 2);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ciShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ciLongLat(u,:) = mean(r);
    
    % significant response: center in
    eTime = ts.Center_NI;
    baseLn = mean(arrayfun(@(t0) length(spk(spk >= t0-bB & spk < t0)), eTime)) / bB;
    s = [];
    for t0 = eTime'
        s = [s spk(spk > t0+bE(1) & spk <t0+bE(end)) - t0];
    end
    rate = histcounts(s, bE) ./ (diff(bE) * length(eTime));
    p = ones(size(rate));
    p(rate <= baseLn) = poisscdf(rate(rate <= baseLn), baseLn);
    p(rate > baseLn) = 1 - poisscdf(rate(rate > baseLn), baseLn);
    ciResponse(u) = ~isempty(HolmBonferroni(p));
    
    % average rate: go cue
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 3);
    sRt = find(rt < quantile(rt, rtCrit));
    lRt = find(rt >= quantile(rt, rtCrit));
    r = zeros(length(sRt), nPtsRL);
    for k = 1:length(sRt)
        r(k,:) = traj(sRt(k)).rate;
    end
    goShortRt(u,:) = mean(r);    
    r = zeros(length(lRt), nPtsRL);
    for k = 1:length(lRt)
        r(k,:) = traj(lRt(k)).rate;
    end
    goLongRt(u,:) = mean(r);
    
    % significant response: go cue
    eTime = ts.go;
    baseLn = mean(arrayfun(@(t0) length(spk(spk >= t0-bB & spk < t0)), eTime)) / bB;
    s = [];
    for t0 = eTime'
        s = [s spk(spk > t0+bE(1) & spk <t0+bE(end)) - t0];
    end
    rate = histcounts(s, bE) ./ (diff(bE) * length(eTime));
    p = ones(size(rate));
    p(rate <= baseLn) = poisscdf(rate(rate <= baseLn), baseLn);
    p(rate > baseLn) = 1 - poisscdf(rate(rate > baseLn), baseLn);
    goResponse(u) = ~isempty(HolmBonferroni(p));
    
    % average rate: side in
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 5);
    s = uSes(uIdx(u));
    [~, s] = ismember(s{1}, sesList);
    rr = rwdRate{s}(11:end);
    loTr = find(rr <= quantile(rr, lo(2))) + 10;
    medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
    hiTr = find(rr >= quantile(rr, hi(1))) + 10;
    rwd = TrialFilter(unitTmp(u).behav_ts{rlIdx}, 'x1', unitTmp(u).side);
    noRwd = TrialFilter(unitTmp(u).behav_ts{rlIdx}, 'x0', unitTmp(u).side);
    
    sel = intersect(loTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loRwd(u,:) = mean(r);
    sel = intersect(loTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loNoRwd(u,:) = mean(r);
    sel = intersect(medTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medRwd(u,:) = mean(r);
    sel = intersect(medTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medNoRwd(u,:) = mean(r);
    
    sel = intersect(hiTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiRwd(u,:) = mean(r);
    sel = intersect(hiTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiNoRwd(u,:) = mean(r);
    
    % significant response: side in
    eTime = ts.Side_NI;
    baseLn = mean(arrayfun(@(t0) length(spk(spk >= t0-bB & spk < t0)), eTime)) / bB;
    s = [];
    for t0 = eTime(rwd)'
        s = [s spk(spk > t0+bE(1) & spk <t0+bE(end)) - t0];
    end
    rate = histcounts(s, bE) ./ (diff(bE) * length(rwd));
    p = ones(size(rate));
    p(rate <= baseLn) = poisscdf(rate(rate <= baseLn), baseLn);
    p(rate > baseLn) = 1 - poisscdf(rate(rate > baseLn), baseLn);
    siRwdResponse(u) = ~isempty(HolmBonferroni(p));
    s = [];
    for t0 = eTime(noRwd)'
        s = [s spk(spk > t0+bE(1) & spk <t0+bE(end)) - t0];
    end
    rate = histcounts(s, bE) ./ (diff(bE) * length(noRwd));
    p = ones(size(rate));
    p(rate <= baseLn) = poisscdf(rate(rate <= baseLn), baseLn);
    p(rate > baseLn) = 1 - poisscdf(rate(rate > baseLn), baseLn);
    siNoRwdResponse(u) = ~isempty(HolmBonferroni(p));
    
    % average rate: food port
    traj = TrajSplit(uTrajRL(u),  unitTmp(u).behav_ts{rlIdx}, winRL, 'event', 6);
    fp = find(~isnan(ts.firstFoodPoke));
    sel = intersect(rwd, fp);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpRwd(u,:) = mean(r);
    else
        fpRwd(u,:) = nan(1, nPtsRL);
    end
    sel = intersect(noRwd, fp);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpNoRwd(u,:) = mean(r);
    else
        fpNoRwd(u,:) = nan(1, nPtsRL);
    end
    
    % display results for unit u
    maxRate = max([max(ltShortLat(u,:)) max(ltLongLat(u,:)) max(ciShortLat(u,:)) max(ciLongLat(u,:))...
         max(goShortRt(u,:)) max(goLongRt(u,:)) max(loRwd(u,:)) max(medRwd(u,:)) max(hiRwd(u,:))...
          max(loNoRwd(u,:)) max(medNoRwd(u,:)) max(hiNoRwd(u,:))]);
    maxRate = 10*ceil(1.1*maxRate(1)/10);
    yR = [0 maxRate];
    figure('NumberTitle', 'off', 'Name', [num2str(u) ') ' unit(uIdx(u)).name ' (' typeLabel ')'], 'Position', [10 100 1400 330])
    subplot('Position', [0.02 0.05 0.19 0.92])
    hold on
    plot(timesRL, ltLongLat(u,:), 'linewidth', 2, 'color', 'b')
    plot(timesRL, ltShortLat(u,:), 'linewidth', 2, 'color', 'r')
    plot([0 0], yR, 'k', 'linewidth', 1)
    ylim(yR);
    set(gca, 'Box', 'on')
    set(gca, 'XTick', [-0.5 0 0.5])
    if ltShortResponse(u)
        text(-0.9,0.95*yR(2), '*short latency', 'color', 'red', 'FontWeight', 'bold')
    end
    if ltLongResponse(u)
        text(-0.9,0.9*yR(2), '*long latency', 'color', 'blue', 'FontWeight', 'bold')
    end
    
    subplot('Position', [0.215 0.05 0.19 0.92])
    hold on
    plot(timesRL, ciLongLat(u,:), 'linewidth', 2, 'color', 'b')
    plot(timesRL, ciShortLat(u,:), 'linewidth', 2, 'color', 'r')
    plot([0 0], yR, 'k', 'linewidth', 1)
    ylim(yR);
    set(gca, 'Box', 'on')
    set(gca, 'XTick', [-0.5 0 0.5])
    set(gca, 'YTickLabels', [])
    if ciResponse(u)
        text(-0.9,0.95*yR(2), '*center in', 'color', 'k', 'FontWeight', 'bold')
    end
    
    subplot('Position', [0.41 0.05 0.19 0.92])
    hold on
    plot(timesRL, goLongRt(u,:), 'linewidth', 2, 'color', 'b')
    plot(timesRL, goShortRt(u,:), 'linewidth', 2, 'color', 'r')
    plot([0 0], yR, 'k', 'linewidth', 1)
    ylim(yR);
    set(gca, 'Box', 'on')
    set(gca, 'XTick', [-0.5 0 0.5])
    set(gca, 'YTickLabels', [])
    if goResponse(u)
        text(-0.9,0.95*yR(2), '*go', 'color', 'k', 'FontWeight', 'bold')
    end

    subplot('Position', [0.605 0.05 0.19 0.92])
    hold on
    plot(timesRL, loNoRwd(u,:), 'linewidth', 2, 'color', [0 0 0.6])
    plot(timesRL, medNoRwd(u,:), 'linewidth', 2, 'color', [0 0 1])
    plot(timesRL, hiNoRwd(u,:), 'linewidth', 2, 'color', [0.4 0.4 1])
    plot(timesRL, loRwd(u,:), 'linewidth', 2, 'color', [0.6 0 0])
    plot(timesRL, medRwd(u,:), 'linewidth', 2, 'color', [1 0 0])
    plot(timesRL, hiRwd(u,:), 'linewidth', 2, 'color', [1 0.4 0.4])
    plot([0 0], yR, 'k', 'linewidth', 1)
    ylim(yR);
    set(gca, 'Box', 'on')
    set(gca, 'XTick', [-0.5 0 0.5])
    set(gca, 'YTickLabels', [])
    if siRwdResponse(u)
        text(-0.9,0.95*yR(2), '*reward', 'color', 'r', 'FontWeight', 'bold')
    end
    if siNoRwdResponse(u)
        text(-0.9,0.9*yR(2), '*omission', 'color', 'b', 'FontWeight', 'bold')
    end
    
    subplot('Position', [0.8 0.05 0.19 0.92])
    hold on
    plot(timesRL, fpRwd(u,:), 'linewidth', 2, 'color', 'r')
    plot(timesRL, fpNoRwd(u,:), 'linewidth', 2, 'color', 'b')
    plot([0 0], yR, 'k', 'linewidth', 1)
    ylim(yR);
    set(gca, 'Box', 'on')
    set(gca, 'XTick', [-0.5 0 0.5])
    set(gca, 'YTickLabels', [])
    
end

% display avergage response among units in class
ltSh = mean(ltShortLat);
ltLo = mean(ltLongLat);
ciSh = mean(ciShortLat);
ciLo = mean(ciLongLat);
goSh = mean(goShortRt);
goLo = mean(goLongRt);
siLR = mean(loRwd);
siMR = mean(medRwd);
siHR = mean(hiRwd);
siLN = mean(loNoRwd);
siMN = mean(medNoRwd);
siHN = mean(hiNoRwd);

maxRate = max([max(ltSh) max(ltLo) max(ciSh) max(ciLo) max(goSh) max(goLo) max(siLR)]);
maxRate = max([maxRate max(siMR) max(siHR) max(siLN) max(siMN) max(siHN)]);
maxRate = 10*ceil(1.1*maxRate(1)/10);
yR = [0 maxRate];
figure('NumberTitle', 'off', 'Name', typeLabel, 'Position', [100 100 1260 330])
subplot('Position', [0.03 0.05 0.23 0.92])
hold on
plot(timesRL, ltLo, 'linewidth', 2, 'color', 'b')
plot(timesRL, ltSh, 'linewidth', 2, 'color', 'r')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
pct = round(100*length(find(ltShortResponse))/length(uIdx));
str = ['short latency: ' num2str(pct) '%'];
text(-0.9,0.95*yR(2), str, 'color', 'r')
pct = round(100*length(find(ltLongResponse))/length(uIdx));
str = ['long latency: ' num2str(pct) '%'];
text(-0.9,0.9*yR(2), str, 'color', 'b')

subplot('Position', [0.27 0.05 0.23 0.92])
hold on
plot(timesRL, ciLo, 'linewidth', 2, 'color', 'b')
plot(timesRL, ciSh, 'linewidth', 2, 'color', 'r')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
pct = round(100*length(find(ciResponse))/length(uIdx));
str = ['center in: ' num2str(pct) '%'];
text(-0.9,0.95*yR(2), str, 'color', 'k')

subplot('Position', [0.51 0.05 0.23 0.92])
hold on
plot(timesRL, goLo, 'linewidth', 2, 'color', 'b')
plot(timesRL, goSh, 'linewidth', 2, 'color', 'r')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
pct = round(100*length(find(goResponse))/length(uIdx));
str = ['go cue: ' num2str(pct) '%'];
text(-0.9,0.95*yR(2), str, 'color', 'k')

subplot('Position', [0.75 0.05 0.23 0.92])
hold on
plot(timesRL, siLN, 'linewidth', 2, 'color', [0 0 0.6])
plot(timesRL, siMN, 'linewidth', 2, 'color', [0 0 1])
plot(timesRL, siHN, 'linewidth', 2, 'color', [0.4 0.4 1])
plot(timesRL, siLR, 'linewidth', 2, 'color', [0.6 0 0])
plot(timesRL, siMR, 'linewidth', 2, 'color', [1 0 0])
plot(timesRL, siHR, 'linewidth', 2, 'color', [1 0.4 0.4])
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
pct = round(100*length(find(siRwdResponse))/length(uIdx));
str = ['reward: ' num2str(pct) '%'];
text(-0.9,0.95*yR(2), str, 'color', 'r')
pct = round(100*length(find(siNoRwdResponse))/length(uIdx));
str = ['no reward: ' num2str(pct) '%'];
text(-0.9,0.9*yR(2), str, 'color', 'b')




%% View Single Trials

winRL = [-1 1];

% 1 GPe-RPE
uIdx = gpeRpe;
unitTmp = unit(uIdx);
uTrajRL = LoadUnitTraj(unitTmp, 'RL', datRoot, 'sigma', 50);
dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
nPtsRL = round(diff(winRL)/dt) + 1;

u = 31;
tsRL = unit(uIdx(u)).behav_ts{rlIdx};
nTr = length(tsRL.trialbegin);

lt = TrajSplit(uTrajRL(u),  tsRL, winRL, 'event', 1);
ci = TrajSplit(uTrajRL(u),  tsRL, winRL, 'event', 2);
go = TrajSplit(uTrajRL(u),  tsRL, winRL, 'event', 3);
si = TrajSplit(uTrajRL(u),  tsRL, winRL, 'event', 5);

k = 1;
maxRate = max([lt(k).rate ci(k).rate go(k).rate si(k).rate]);
maxRate = 10*ceil(maxRate/10);
yR = [0 maxRate];
figure('NumberTitle', 'off', 'Name', [num2str(u) ') ' unit(uIdx(u)).name ', trial ' num2str(k)], 'Position', [100 100 1260 330])
subplot('Position', [0.03 0.05 0.23 0.92])
hold on
plot(lt(k).times, lt(k).rate, 'linewidth', 2, 'color', 'b')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])

subplot('Position', [0.27 0.05 0.23 0.92])
hold on
plot(ci(k).times, ci(k).rate, 'linewidth', 2, 'color', 'b')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])

subplot('Position', [0.51 0.05 0.23 0.92])
hold on
plot(go(k).times, go(k).rate, 'linewidth', 2, 'color', 'b')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])

subplot('Position', [0.75 0.05 0.23 0.92])
hold on
plot(si(k).times, si(k).rate, 'linewidth', 2, 'color', 'b')
plot([0 0], yR, 'k', 'linewidth', 1)
ylim(yR);
set(gca, 'Box', 'on')
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])






%% Pavlovian RPE Plot (CS)

uIdx = gpeRpe;
unitTmp = unit(uIdx);
uTraj = LoadUnitTraj(unitTmp, 'Pav', datRoot);
del = find(arrayfun(@(u) isempty(u.rate), uTraj));
uTraj(del) = [];
unitTmp(del) = [];

win = [-1 4];
dt = uTraj(1).times(2) - uTraj(1).times(1);
nPtsPav = round(diff(win)/dt) + 1;

p0noRwd = zeros(length(unitTmp), nPtsPav);
p25noRwd = zeros(length(unitTmp), nPtsPav);
p25rwd = zeros(length(unitTmp), nPtsPav);
p75noRwd = zeros(length(unitTmp), nPtsPav);
p75rwd = zeros(length(unitTmp), nPtsPav);
rwd100 = zeros(length(unitTmp), nPtsPav);

for u = 1:length(unitTmp)
      
    pavTs = unitTmp(u).behav_ts{pavIdx};
    pavLog = unitTmp(u).behav_log{pavIdx};
    cue0 = pavLog.cueRwdTable(pavLog.cueRwdTable(:,2) == 0, 1);
    cue25 = pavLog.cueRwdTable(pavLog.cueRwdTable(:,2) == 25, 1);
    cue75 = pavLog.cueRwdTable(pavLog.cueRwdTable(:,2) == 75, 1);
    tr0 = find(pavLog.toneFreq == cue0);
    tr25r = find(pavLog.toneFreq == cue25 & pavLog.outcome);
    tr25nr = find(pavLog.toneFreq == cue25 & ~pavLog.outcome);
    tr75r = find(pavLog.toneFreq == cue75 & pavLog.outcome);
    tr75nr = find(pavLog.toneFreq == cue75 & ~pavLog.outcome);
    tr100 = find(pavLog.toneFreq == 0);
    traj = TrajSplit(uTraj(u), pavTs, win);
    r = zeros(length(tr0), nPtsPav);
    for k = 1:length(tr0)
        r(k,:) = traj(tr0(k)).rate;
    end
    p0noRwd(u,:) = mean(r);

    r = zeros(length(tr25r), nPtsPav);
    for k = 1:length(tr25r)
        r(k,:) = traj(tr25r(k)).rate;
    end
    p25rwd(u,:) = mean(r);
    
    r = zeros(length(tr25nr), nPtsPav);
    for k = 1:length(tr25nr)
        r(k,:) = traj(tr25nr(k)).rate;
    end
    p25noRwd(u,:) = mean(r);


    r = zeros(length(tr75r), nPtsPav);
    for k = 1:length(tr75r)
        r(k,:) = traj(tr75r(k)).rate;
    end
    p75rwd(u,:) = mean(r);
    
    r = zeros(length(tr75nr), nPtsPav);
    for k = 1:length(tr75nr)
        r(k,:) = traj(tr75nr(k)).rate;
    end
    p75noRwd(u,:) = mean(r);

    r = zeros(length(tr100), nPtsPav);
    for k = 1:length(tr100)
        r(k,:) = traj(tr100(k)).rate;
    end
    rwd100(u,:) = mean(r);
    
end

figure('Position', [440 378 560 620])
subplot('Position', [0.01 0.01 0.48 0.98])
plot(traj(1).times, mean(p0noRwd), 'linewidth', 2, 'color', 'b')
hold on
plot(traj(1).times, mean(rwd100), 'linewidth', 2, 'color', 'r')
plot([0 0], [0 48], 'k', 'linewidth', 1)
xlim([-0.1 0.5])
ylim([0 50])
ax = gca;
ax.Box = 'off';
ax.XTick = [0 0.2 0.4];
ax.YTick = [0 25 50];
ax.XTickLabels=[];
ax.YTickLabels=[];

subplot('Position', [0.5 0.01 0.48 0.98])
plot(traj(1).times, mean(p0noRwd), 'linewidth', 2, 'color', 'b')
hold on
plot(traj(1).times, mean(rwd100), 'linewidth', 2, 'color', 'r')
plot([3 3], [0 48], 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [3 3.2 3.4];
ax.YTick = [0 25 50];
ax.XTickLabels=[];
ax.YTickLabels=[];
ax.YAxis.Visible = 'off';
xlim([2.9 3.5])
ylim([0 50])

figure('Position', [440 378 560 620])
subplot('Position', [0.01 0.01 0.48 0.98])
hold on
plot(traj(1).times, mean(p25noRwd), 'linewidth', 2, 'color', [0 0 0.7])
plot(traj(1).times, mean(p75noRwd), 'linewidth', 2, 'color', [0.1 0.1 1])
plot(traj(1).times, mean(p25rwd), 'linewidth', 2, 'color', [0.7 0 0])
plot(traj(1).times, mean(p75rwd), 'linewidth', 2, 'color', [1 0.1 0.1])
plot([0 0], [0 48], 'k', 'linewidth', 1)
xlim([-0.1 0.5])
ylim([0 50])
ax = gca;
ax.Box = 'off';
ax.XTick = [0 0.2 0.4];
ax.YTick = [0 25 50];
ax.XTickLabels=[];
ax.YTickLabels=[];

subplot('Position', [0.5 0.01 0.48 0.98])
hold on
plot(traj(1).times, mean(p25noRwd), 'linewidth', 2, 'color', [0 0 0.7])
plot(traj(1).times, mean(p75noRwd), 'linewidth', 2, 'color', [0.1 0.1 1])
plot(traj(1).times, mean(p25rwd), 'linewidth', 2, 'color', [0.7 0 0])
plot(traj(1).times, mean(p75rwd), 'linewidth', 2, 'color', [1 0.1 0.1])
plot([3 3], [0 48], 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [3 3.2 3.4];
ax.YTick = [0 25 50];
ax.XTickLabels=[];
ax.YTickLabels=[];
ax.YAxis.Visible = 'off';
xlim([2.9 3.5])
ylim([0 50])

figure
hold on
plot(traj(1).times, mean(p25noRwd), 'linewidth', 2, 'color', [0 0 0.7])
plot(traj(1).times, mean(p75noRwd), 'linewidth', 2, 'color', [0.1 0.1 1])
plot(traj(1).times, mean(p25rwd), 'linewidth', 2, 'color', [0.7 0 0])
plot(traj(1).times, mean(p75rwd), 'linewidth', 2, 'color', [1 0.1 0.1])
ylim([0 60])

for u = 1:length(unitTmp)

    figure('NumberTitle', 'off', 'Name', [num2str(u) ') ' unitTmp(u).name])
    hold on
    plot(traj(1).times, p0noRwd(u,:), 'linewidth', 2, 'color', 'b')
    plot(traj(1).times, rwd100(u,:), 'linewidth', 2, 'color', 'r')
    
    figure('NumberTitle', 'off', 'Name', [num2str(u) ') ' unitTmp(u).name])
    hold on
    plot(traj(1).times, p25noRwd(u,:), 'linewidth', 2, 'color', [0 0 0.7])
    plot(traj(1).times, p75noRwd(u,:), 'linewidth', 2, 'color', [0.1 0.1 1])
    plot(traj(1).times, p25rwd(u,:), 'linewidth', 2, 'color', [0.7 0 0])
    plot(traj(1).times, p75rwd(u,:), 'linewidth', 2, 'color', [1 0.1 0.1])

end


