%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];

% Load RL behavior logs (unitLog)
% load([datRoot 'unit logs.mat'])


%% Compute Reward Rate for Each Session (corr)

sesList = unique(uSes);
rwdTau = 1:length(sesList);
rwdCorr = 1:length(sesList);
slope1 = 1:length(sesList);
pVal1 = 1:length(sesList);
rSq1 = 1:length(sesList);
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    tau = 1:2000;
    c = zeros(size(tau));
    for i = 1:length(tau)
        r = zeros(1, nTr);
        for k = 1:nTr
            if k > 1
                r(k) = r(k-1)*exp(-(t(k) - t(k-1))/tau(i));
            end
            r(k) = r(k) + tsRL.outcome(k);
            
        end
        c(i) = corr(logLat, r');
    end
    iTau = find(c == min(c));
    rwdTau(s) = tau(iTau(1));
    rwdCorr(s) = c(iTau(1));
    
    r = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            r(k) = r(k-1)*exp(-(t(k) - t(k-1))/tau(i));
        end
        r(k) = r(k) + tsRL.outcome(k);
    end
    lm = fitlm(r', logLat);
    slope1(s) = lm.Coefficients.Estimate(2);
    pVal1(s) = lm.Coefficients.pValue(2);
    rSq1(s) = lm.Rsquared.Ordinary;
end 


%% Compute Reward Rate for Each Session (fitlm)

sesList = unique(uSes);
rwdTau = 1:length(sesList);
slope2 = 1:length(sesList);
pVal2 = 1:length(sesList);
rSq2 = 1:length(sesList);
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    tau = 1:500;
    p = zeros(size(tau));
    for i = 1:length(tau)
        r = zeros(1, nTr);
        for k = 1:nTr
            if k > 1
                r(k) = r(k-1)*exp(-(t(k) - t(k-1))/tau(i));
            end
            r(k) = r(k) + tsRL.outcome(k);      
        end
        lm = fitlm(r', logLat);
        p(i) = lm.Coefficients.pValue(2);
    end
    iTau = find(p == min(p));
    rwdTau(s) = tau(iTau(1));
    
    r = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            r(k) = r(k-1)*exp(-(t(k) - t(k-1))/rwdTau(s));
        end
        r(k) = r(k) + tsRL.outcome(k);
    end
    lm = fitlm(r', logLat);
    slope2(s) = lm.Coefficients.Estimate(2);
    pVal2(s) = lm.Coefficients.pValue(2);
    rSq2(s) = lm.Rsquared.Ordinary;
end 


%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89; % median time constant, calculated elsewhere
rwdRate = cell(1, length(sesList));
slope3 = 1:length(sesList);
pVal3 = 1:length(sesList);
rSq3 = 1:length(sesList);
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end
    lm = fitlm(rwdRate{s}', logLat);
    slope3(s) = lm.Coefficients.Estimate(2);
    pVal3(s) = lm.Coefficients.pValue(2);
    rSq3(s) = lm.Rsquared.Ordinary;
end 


%% Figure 3b: Example RL Session

s = 45;
smooth = 20;
pad = 10;

uIdx = find(strcmp(sesList{s}, uSes));
u = uIdx(1);
rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
tsRL = unit(u).behav_ts{rlIdx};
logFile = dir([datRoot uRat{u} '/' sesList{s} '/*RL.log']);
logFile = logFile(1).name;
logRL = ReadBehavLog([datRoot uRat{u} '/' sesList{s} '/' logFile], 'RL');
nBlocks = length(logRL.nBlockTrials) - 1;
blkStart = [1 1+arrayfun(@(b) sum(logRL.nBlockTrials(1:b)), 1:nBlocks)];
blkBoundaries = blkStart(2:end-1) - 0.5;
nTr = blkStart(end) - 1;
lat = BehaviorTimes(tsRL)';
lat = [lat(pad:-1:1) lat(1:nTr) lat(nTr:-1:nTr-pad+1)];
logLat = smoothdata(log10(lat), 'gaussian', smooth);
logLat = logLat(pad+1:nTr+pad);

c = tsRL.choice == 'R';
c = [c(pad:-1:1) c(1:nTr) c(nTr:-1:nTr-pad+1)];
pRt = smoothdata(c, 'gaussian', smooth);
pRt = pRt(pad+1:nTr+pad);

c = tsRL.choice == 'L';
c = [c(pad:-1:1) c(1:nTr) c(nTr:-1:nTr-pad+1)];
pLt = smoothdata(c, 'gaussian', smooth);
pLt = pLt(pad+1:nTr+pad);

% prob[choice]
f = figure('Position', [10 100 1415 300])
subplot('Position', [0.005 0.005 0.99 0.99])
hold on
colororder({'k', 'k'})
for k = 1:nTr
    if tsRL.choice(k) == 'L';
        line([k k], [1.14 1.08 - 0.06*tsRL.outcome(k)], 'color', 'b', 'LineWidth', 2);
    else
        line([k k], [1.14 1.08 - 0.06*tsRL.outcome(k)], 'color', 'r', 'LineWidth', 2);
    end
end
plot(1:nTr, pRt, 'r', 'linewidth', 3)
plot(1:nTr, pLt, 'b', 'linewidth', 3)
for b = 1:nBlocks-1
    plot(blkBoundaries(b)*[1 1], [0 1.3], '--k', 'linewidth', 1)
end
blockProb = zeros(nBlocks,2);
for b = 1:nBlocks
    x = blkStart(b) + logRL.nBlockTrials(b)/2;
    blockProb(b,:) = 100*logRL.block_probabilities(blkStart(b),:);
end
ylim([0 1.3])
xlim([1 nTr])
ax = gca;
ax.Box = 'on';
ax.YTick = 0.25:0.25:1;
ax.XTick = [50:50:350];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.TickLength = ax.TickLength / 2;

% latency/reward rate
f = figure('Position', [10 100 1415 300])
subplot('Position', [0.005 0.005 0.99 0.99])
hold on
yyaxis left
rR = smoothdata(rwdRate{s}, 'gaussian', 10);
plot(rR(1:nTr), 'k', 'linewidth', 3)
ylim([0 7.5])
ax = gca;
ax.YTick = [3 6];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.TickLength = ax.TickLength / 2;
ax.Box = 'on';
yyaxis right
plot(logLat, 'c', 'linewidth', 3)
yR = [-0.7 1.1];
ylim(yR)
xlim([1 nTr])
for b = 1:nBlocks-1
    plot(blkBoundaries(b)*[1 1], yR, '--k', 'linewidth', 1)
end
ax = gca;
ax.YDir = 'reverse'
ax.YTick = log10([0.5 2 8]);
ax.YTickLabels = [];
ax.TickLength = ax.TickLength / 2;



%% Figure 3c: RL Behavior

minTr = 35; % minimum trials per block for inclusion in analysis
p10_10 = []; p10_50 = []; p10_90 = []; p50_50 = []; p50_90 = []; p90_90 = [];
logLat = cell(1,5);
rR = cell(1,5);
ratList = unique(uRat);

for s = 1:length(sesList)
    disp(s)
    uIdx = find(strcmp(sesList{s}, uSes));
    u = uIdx(1);
    ratIdx = find(strcmp(ratList, uRat{u}));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    tsRL = unit(u).behav_ts{rlIdx};
    logFile = dir([datRoot uRat{u} '/' sesList{s} '/*RL.log']);
    logFile = logFile(1).name;
    logRL = ReadBehavLog([datRoot uRat{u} '/' sesList{s} '/' logFile], 'RL');
    lat = BehaviorTimes(tsRL)';
    logLat{ratIdx} = [logLat{ratIdx} log10(lat(11:end))];
    rR{ratIdx} = [rR{ratIdx} rwdRate{s}(11:end)];
    nBlocks = length(logRL.nBlockTrials(logRL.nBlockTrials >= minTr));
    blkStart = [1 1+arrayfun(@(b) sum(logRL.nBlockTrials(1:b)), 1:nBlocks)];
    for b = 1:nBlocks
        pR = logRL.block_probabilities(blkStart(b),:);
        hiChoice =  pR(1) > pR(2);
        if pR(1) == pR(2)
            hiChoice = rand > 0.5;
        end
        choice = tsRL.choice(blkStart(b):blkStart(b)+minTr-1) == 'L';
        if ~hiChoice
            choice = ~choice;
        end
        pR = sort(pR);
        if all(pR == [0.1 0.1])
            p10_10 = [p10_10; choice];
        elseif all(pR == [0.1 0.5])
            p10_50 = [p10_50; choice];
        elseif all(pR == [0.1 0.9])
            p10_90 = [p10_90; choice];
        elseif all(pR == [0.5 0.5])
            p50_50 = [p50_50; choice];
        elseif all(pR == [0.5 0.9])
            p50_90 = [p50_90; choice];
        elseif all(pR == [0.9 0.9])
                p90_90 = [p90_90; choice];
        end
    end
end

% version 1
pDelta0 = [p10_10; p50_50; p90_90];
pDelta40 = [p10_50; p50_90];
pDelta80 = p10_90;
pD0M = smoothdata(mean(pDelta0), 'gaussian', 10);
pD0L = pD0M - smoothdata(std(pDelta0)/sqrt(size(pDelta0,1)), 'gaussian', 10);
pD0H = pD0M + smoothdata(std(pDelta0)/sqrt(size(pDelta0,1)), 'gaussian', 10);
pD40M = smoothdata(mean(pDelta40), 'gaussian', 10);
pD40L = pD40M - smoothdata(std(pDelta40)/sqrt(size(pDelta40,1)), 'gaussian', 10);
pD40H = pD40M + smoothdata(std(pDelta40)/sqrt(size(pDelta40,1)), 'gaussian', 10);
pD80M = smoothdata(mean(pDelta80), 'gaussian', 10);
pD80L = pD80M - smoothdata(std(pDelta80)/sqrt(size(pDelta80,1)), 'gaussian', 10);
pD80H = pD80M + smoothdata(std(pDelta80)/sqrt(size(pDelta80,1)), 'gaussian', 10);

% choice panel, version 1 (delta prob)
figure('Position', [440 378 650 560])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
shade(1:35, pD0H,1:35, pD0L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(1:35, pD0M, 'color', 'b', 'lineWidth', 2)

shade(1:35, pD40H,1:35, pD40L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.5 0 1], 'FillAlpha', 0.25)
plot(1:35, pD40M, 'color', [0.5 0 1], 'lineWidth', 2)

shade(1:35, pD80H,1:35, pD80L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(1:35, pD80M, 'color', 'r', 'lineWidth', 2)
plot([1 35], [0.5 0.5], '--k', 'linewidth', 1)
xlim([1 35])
ylim([0.45 0.95])
ax = gca;
ax.Box = 'on';
ax.XTick = 10:10:30;
ax.YTick = 0.5:0.1:0.9;
ax,XTickLabels = [];
ax.YTickLabels = [];

% version 2
p1010M = smoothdata(mean(p10_10), 'gaussian', 10);
p1010L = p1010M - smoothdata(std(p10_10)/sqrt(size(p10_10,1)), 'gaussian', 10);
p1010H = p1010M + smoothdata(std(p10_10)/sqrt(size(p10_10,1)), 'gaussian', 10);

p1050M = smoothdata(mean(p10_50), 'gaussian', 10);
p1050L = p1050M - smoothdata(std(p10_50)/sqrt(size(p10_50,1)), 'gaussian', 10);
p1050H = p1050M + smoothdata(std(p10_50)/sqrt(size(p10_50,1)), 'gaussian', 10);

p1090M = smoothdata(mean(p10_90), 'gaussian', 10);
p1090L = p1090M - smoothdata(std(p10_90)/sqrt(size(p10_90,1)), 'gaussian', 10);
p1090H = p1090M + smoothdata(std(p10_90)/sqrt(size(p10_90,1)), 'gaussian', 10);

p5090M = smoothdata(mean(p50_90), 'gaussian', 10);
p5090L = p5090M - smoothdata(std(p50_90)/sqrt(size(p50_90,1)), 'gaussian', 10);
p5090H = p5090M + smoothdata(std(p50_90)/sqrt(size(p50_90,1)), 'gaussian', 10);

p5050M = smoothdata(mean(p50_50), 'gaussian', 10);
p5050L = p5050M - smoothdata(std(p50_50)/sqrt(size(p50_50,1)), 'gaussian', 10);
p5050H = p5050M + smoothdata(std(p50_50)/sqrt(size(p50_50,1)), 'gaussian', 10);

p9090M = smoothdata(mean(p90_90), 'gaussian', 10);
p9090L = p9090M - smoothdata(std(p90_90)/sqrt(size(p90_90,1)), 'gaussian', 10);
p9090H = p9090M + smoothdata(std(p90_90)/sqrt(size(p90_90,1)), 'gaussian', 10);

% choice panel, version 2 (high rwd choice grouped together)
figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
shade(1:35, p1010H,1:35, p1010L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(1:35, p1010M, 'color', 'b', 'lineWidth', 2)

shade(1:35, p5050H,1:35, p5050L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.5 0 1], 'FillAlpha', 0.25)
plot(1:35, p5050M, 'color', [0.5 0 1], 'lineWidth', 2)

shade(1:35, p9090H,1:35, p9090L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(1:35, p9090M, 'color', 'r', 'lineWidth', 2)

shade(1:35, p1050H,1:35, p1050L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.5 0 1], 'FillAlpha', 0.25)
plot(1:35, p1050M, 'color', [0.5 0 1], 'lineWidth', 2)

shade(1:35, p5090H,1:35, p5090L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(1:35, p5090M, 'color', 'r', 'lineWidth', 2)

shade(1:35, p1090H,1:35, p1090L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(1:35, p1090M, 'color', 'r', 'lineWidth', 2)
plot([1 35], [0.5 0.5], '--k', 'linewidth', 1)
xlim([1 35])
ylim([0.4 1])

l = cell2mat(logLat);
r = cell2mat(rR);
bE = 0:0.1:8; binN = 1:length(bE)-1;
[~,~,bin] = histcounts(r, bE);
lM = arrayfun(@(b) mean(l(bin==b)), binN);
lsem = arrayfun(@(b) std(l(bin==b))/sqrt(length(l(bin==b))), binN);
lM = smoothdata(lM, 'gaussian', 10);
lsem = smoothdata(lsem, 'gaussian', 10);
lL = lM - lsem;
lH = lM + lsem;
rb = arrayfun(@(b) mean(r(bin==b)), binN);
figure('Position', [440 378 650 560])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
shade(rb, lH, rb, lL,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'k', 'FillAlpha', 0.25)
plot(rb, lM, 'color', 'k', 'lineWidth', 2)
ax = gca;
ax.YTick = log10(2:2:8);
ax.XTick = 2:2:6;
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

figure('Position', [440 378 325 224])
h = histogram(l, -2:0.05:4);
h.LineStyle = 'none';
h.FaceColor = 'k';
ax = gca;
ax.YTick = [];
ax.XTick = -1:3;
ax.XTickLabels = [];
xlim([-1.6 2.5])

figure('Position', [10 100 1400 300])
lM = 0.025; g = 0.005; w = 0.19;
subplot('Position', [lM 0.15 w 0.75])
cSize = 1;
scatter(rR{1}, logLat{1}, cSize, 'k', 'filled')
ax = gca;
ax.Box = 'on';
ax.XTick = 1:8
ax.YTick = [-4:2:8];
xlim([0 8.5])
ylim([-4 8])
xlabel('reward rate')
ylabel('log latency')
title(ratList{1})
subplot('Position', [lM+w+g 0.15 w 0.75])
scatter(rR{2}, logLat{2}, cSize, 'k', 'filled')
ax = gca;
ax.Box = 'on';
ax.XTick = 1:8
ax.YTick = [-4:2:8];
ax.YTickLabels = [];
xlim([0 8.5])
ylim([-4 8])
xlabel('reward rate')
title(ratList{2})
subplot('Position', [lM+2*(w+g) 0.15 w 0.75])
scatter(rR{3}, logLat{3}, cSize, 'k', 'filled')
ax = gca;
ax.Box = 'on';
ax.XTick = 1:8
ax.YTick = [-4:2:8];
ax.YTickLabels = [];
xlim([0 8.5])
ylim([-4 8])
xlabel('reward rate')
title(ratList{3})
subplot('Position', [lM+3*(w+g) 0.15 w 0.75])
scatter(rR{4}, logLat{4}, cSize, 'k', 'filled')
ax = gca;
ax.Box = 'on';
ax.XTick = 1:8
ax.YTick = [-4:2:8];
ax.YTickLabels = [];
xlim([0 8.5])
ylim([-4 8])
xlabel('reward rate')
title(ratList{4})
subplot('Position', [lM+4*(w+g) 0.15 w 0.75])
scatter(rR{5}, logLat{5}, cSize, 'k', 'filled')
ax = gca;
ax.Box = 'on';
ax.XTick = 1:8
ax.YTick = [-4:2:8];
ax.YTickLabels = [];
xlim([0 8.5])
ylim([-4 8])
xlabel('reward rate')
title(ratList{5})

figure('Position', [10 100 1400 300])
bE = -3:0.1:5;
lM = 0.025; g = 0.005; w = 0.19;
subplot('Position', [lM 0.15 w 0.75])
histogram(logLat{1}(rR{1} > 2), bE)
ax = gca;
ax.YTick = [];
title(ratList{1})
xlabel('log latency')

subplot('Position', [lM+w+g 0.15 w 0.75])
histogram(logLat{2}(rR{2} > 2), bE)
ax = gca;
ax.YTick = [];
title(ratList{2})
xlabel('log latency')

subplot('Position', [lM+2*(w+g) 0.15 w 0.75])
histogram(logLat{3}(rR{3} > 2), bE)
ax = gca;
ax.YTick = [];
title(ratList{3})
xlabel('log latency')

subplot('Position', [lM+3*(w+g) 0.15 w 0.75])
histogram(logLat{4}(rR{4} > 2), bE)
ax = gca;
ax.YTick = [];
title(ratList{4})
xlabel('log latency')

subplot('Position', [lM+4*(w+g) 0.15 w 0.75])
histogram(logLat{5}(rR{5} > 2), bE)
ax = gca;
ax.YTick = [];
title(ratList{5})
xlabel('log latency')



%% Compute Plottable Output from Linear Regression

load([datRoot 'rlLR7.mat']) % load LR if already computed

% variables for rlLR3 stored in cell arrays: 1=LO, 2=CI, 3=GO, 4=pre-SI (all trials together)
% 1=post-SI, 2=FP (broken into separate rewarded and unrewarded cases)

smWd = 10;

fracLOrp = smoothdata(FracSignificant2(pR{1}(rp,:), 0.05), 'gaussian', smWd);
fracLOfp = smoothdata(FracSignificant2(pR{1}(fp,:), 0.05), 'gaussian', smWd);
fracLOip = smoothdata(FracSignificant2(pR{1}(ip,:), 0.05), 'gaussian', smWd);
fracLOsp = smoothdata(FracSignificant2(pR{1}(sp,:), 0.05), 'gaussian', smWd);
fracLOak = smoothdata(FracSignificant2(pR{1}(ak,:), 0.05), 'gaussian', smWd);

fracCIrp = smoothdata(FracSignificant2(pR{2}(rp,:), 0.05), 'gaussian', smWd);
fracCIfp = smoothdata(FracSignificant2(pR{2}(fp,:), 0.05), 'gaussian', smWd);
fracCIip = smoothdata(FracSignificant2(pR{2}(ip,:), 0.05), 'gaussian', smWd);
fracCIsp = smoothdata(FracSignificant2(pR{2}(sp,:), 0.05), 'gaussian', smWd);
fracCIak = smoothdata(FracSignificant2(pR{2}(ak,:), 0.05), 'gaussian', smWd);

fracGOrp = smoothdata(FracSignificant2(pR{3}(rp,:), 0.05), 'gaussian', smWd);
fracGOfp = smoothdata(FracSignificant2(pR{3}(fp,:), 0.05), 'gaussian', smWd);
fracGOip = smoothdata(FracSignificant2(pR{3}(ip,:), 0.05), 'gaussian', smWd);
fracGOsp = smoothdata(FracSignificant2(pR{3}(sp,:), 0.05), 'gaussian', smWd);
fracGOak = smoothdata(FracSignificant2(pR{3}(ak,:), 0.05), 'gaussian', smWd);

fracSIprp = smoothdata(FracSignificant2(pR{5}(rp,:), 0.05), 'gaussian', smWd);
fracSIpfp = smoothdata(FracSignificant2(pR{5}(fp,:), 0.05), 'gaussian', smWd);
fracSIpip = smoothdata(FracSignificant2(pR{5}(ip,:), 0.05), 'gaussian', smWd);
fracSIpsp = smoothdata(FracSignificant2(pR{5}(sp,:), 0.05), 'gaussian', smWd);
fracSIpak = smoothdata(FracSignificant2(pR{5}(ak,:), 0.05), 'gaussian', smWd);

fracSIrrp = smoothdata(FracSignificant2(pRr{1}(rp,:), 0.05), 'gaussian', smWd);
fracSIrfp = smoothdata(FracSignificant2(pRr{1}(fp,:), 0.05), 'gaussian', smWd);
fracSIrip = smoothdata(FracSignificant2(pRr{1}(ip,:), 0.05), 'gaussian', smWd);
fracSIrsp = smoothdata(FracSignificant2(pRr{1}(sp,:), 0.05), 'gaussian', smWd);
fracSIrak = smoothdata(FracSignificant2(pRr{1}(ak,:), 0.05), 'gaussian', smWd);

fracSInrp = smoothdata(FracSignificant2(pRn{1}(rp,:), 0.05), 'gaussian', smWd);
fracSInfp = smoothdata(FracSignificant2(pRn{1}(fp,:), 0.05), 'gaussian', smWd);
fracSInip = smoothdata(FracSignificant2(pRn{1}(ip,:), 0.05), 'gaussian', smWd);
fracSInsp = smoothdata(FracSignificant2(pRn{1}(sp,:), 0.05), 'gaussian', smWd);
fracSInak = smoothdata(FracSignificant2(pRn{1}(ak,:), 0.05), 'gaussian', smWd);

fracFPrrp = smoothdata(FracSignificant2(pRr{2}(rp,:), 0.05), 'gaussian', smWd);
fracFPrfp = smoothdata(FracSignificant2(pRr{2}(fp,:), 0.05), 'gaussian', smWd);
fracFPrip = smoothdata(FracSignificant2(pRr{2}(ip,:), 0.05), 'gaussian', smWd);
fracFPrsp = smoothdata(FracSignificant2(pRr{2}(sp,:), 0.05), 'gaussian', smWd);
fracFPrak = smoothdata(FracSignificant2(pRr{2}(ak,:), 0.05), 'gaussian', smWd);

sLO_Mrp = smoothdata(mean(sR{1}(rp,:)), 'gaussian', smWd);
sLO_Lrp = sLO_Mrp - smoothdata(std(sR{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Hrp = sLO_Mrp + smoothdata(std(sR{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Mfp = smoothdata(mean(sR{1}(fp,:)), 'gaussian', smWd);
sLO_Lfp = sLO_Mfp - smoothdata(std(sR{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sLO_Hfp = sLO_Mfp + smoothdata(std(sR{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sLO_Mip = smoothdata(mean(sR{1}(ip,:)), 'gaussian', smWd);
sLO_Lip = sLO_Mip - smoothdata(std(sR{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sLO_Hip = sLO_Mip + smoothdata(std(sR{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sLO_Msp = smoothdata(mean(sR{1}(sp,:)), 'gaussian', smWd);
sLO_Lsp = sLO_Msp - smoothdata(std(sR{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sLO_Hsp = sLO_Msp + smoothdata(std(sR{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sLO_Mak = smoothdata(mean(sR{1}(ak,:)), 'gaussian', smWd);
sLO_Lak = sLO_Mak - smoothdata(std(sR{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sLO_Hak = sLO_Mak + smoothdata(std(sR{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sCI_Mrp = smoothdata(mean(sR{2}(rp,:)), 'gaussian', smWd);
sCI_Lrp = sCI_Mrp - smoothdata(std(sR{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Hrp = sCI_Mrp + smoothdata(std(sR{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Mfp = smoothdata(mean(sR{2}(fp,:)), 'gaussian', smWd);
sCI_Lfp = sCI_Mfp - smoothdata(std(sR{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sCI_Hfp = sCI_Mfp + smoothdata(std(sR{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sCI_Mip = smoothdata(mean(sR{2}(ip,:)), 'gaussian', smWd);
sCI_Lip = sCI_Mip - smoothdata(std(sR{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sCI_Hip = sCI_Mip + smoothdata(std(sR{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sCI_Msp = smoothdata(mean(sR{2}(sp,:)), 'gaussian', smWd);
sCI_Lsp = sCI_Msp - smoothdata(std(sR{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sCI_Hsp = sCI_Msp + smoothdata(std(sR{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sCI_Mak = smoothdata(mean(sR{2}(ak,:)), 'gaussian', smWd);
sCI_Lak = sCI_Mak - smoothdata(std(sR{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sCI_Hak = sCI_Mak + smoothdata(std(sR{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sGO_Mrp = smoothdata(mean(sR{3}(rp,:)), 'gaussian', smWd);
sGO_Lrp = sGO_Mrp - smoothdata(std(sR{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Hrp = sGO_Mrp + smoothdata(std(sR{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Mfp = smoothdata(mean(sR{3}(fp,:)), 'gaussian', smWd);
sGO_Lfp = sGO_Mfp - smoothdata(std(sR{3}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sGO_Hfp = sGO_Mfp + smoothdata(std(sR{3}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sGO_Mip = smoothdata(mean(sR{3}(ip,:)), 'gaussian', smWd);
sGO_Lip = sGO_Mip - smoothdata(std(sR{3}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sGO_Hip = sGO_Mip + smoothdata(std(sR{3}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sGO_Msp = smoothdata(mean(sR{3}(sp,:)), 'gaussian', smWd);
sGO_Lsp = sGO_Msp - smoothdata(std(sR{3}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sGO_Hsp = sGO_Msp + smoothdata(std(sR{3}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sGO_Mak = smoothdata(mean(sR{3}(ak,:)), 'gaussian', smWd);
sGO_Lak = sGO_Mak - smoothdata(std(sR{3}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sGO_Hak = sGO_Mak + smoothdata(std(sR{3}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIp_Mrp = smoothdata(mean(sR{4}(rp,:)), 'gaussian', smWd);
sSIp_Lrp = sSIp_Mrp - smoothdata(std(sR{4}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Hrp = sSIp_Mrp + smoothdata(std(sR{4}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Mfp = smoothdata(mean(sR{4}(fp,:)), 'gaussian', smWd);
sSIp_Lfp = sSIp_Mfp - smoothdata(std(sR{4}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIp_Hfp = sSIp_Mfp + smoothdata(std(sR{4}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIp_Mip = smoothdata(mean(sR{4}(ip,:)), 'gaussian', smWd);
sSIp_Lip = sSIp_Mip - smoothdata(std(sR{4}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIp_Hip = sSIp_Mip + smoothdata(std(sR{4}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIp_Msp = smoothdata(mean(sR{4}(sp,:)), 'gaussian', smWd);
sSIp_Lsp = sSIp_Msp - smoothdata(std(sR{4}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIp_Hsp = sSIp_Msp + smoothdata(std(sR{4}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIp_Mak = smoothdata(mean(sR{4}(ak,:)), 'gaussian', smWd);
sSIp_Lak = sSIp_Mak - smoothdata(std(sR{4}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIp_Hak = sSIp_Mak + smoothdata(std(sR{4}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIr_Mrp = smoothdata(mean(sRr{1}(rp,:)), 'gaussian', smWd);
sSIr_Lrp = sSIr_Mrp - smoothdata(std(sRr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Hrp = sSIr_Mrp + smoothdata(std(sRr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Mfp = smoothdata(mean(sRr{1}(fp,:)), 'gaussian', smWd);
sSIr_Lfp = sSIr_Mfp - smoothdata(std(sRr{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIr_Hfp = sSIr_Mfp + smoothdata(std(sRr{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIr_Mip = smoothdata(mean(sRr{1}(ip,:)), 'gaussian', smWd);
sSIr_Lip = sSIr_Mip - smoothdata(std(sRr{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIr_Hip = sSIr_Mip + smoothdata(std(sRr{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIr_Msp = smoothdata(mean(sRr{1}(sp,:)), 'gaussian', smWd);
sSIr_Lsp = sSIr_Msp - smoothdata(std(sRr{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIr_Hsp = sSIr_Msp + smoothdata(std(sRr{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIr_Mak = smoothdata(mean(sRr{1}(ak,:)), 'gaussian', smWd);
sSIr_Lak = sSIr_Mak - smoothdata(std(sRr{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIr_Hak = sSIr_Mak + smoothdata(std(sRr{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIn_Mrp = smoothdata(mean(sRn{1}(rp,:)), 'gaussian', smWd);
sSIn_Lrp = sSIn_Mrp - smoothdata(std(sRn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Hrp = sSIn_Mrp + smoothdata(std(sRn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Mfp = smoothdata(mean(sRn{1}(fp,:)), 'gaussian', smWd);
sSIn_Lfp = sSIn_Mfp - smoothdata(std(sRn{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIn_Hfp = sSIn_Mfp + smoothdata(std(sRn{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIn_Mip = smoothdata(mean(sRn{1}(ip,:)), 'gaussian', smWd);
sSIn_Lip = sSIn_Mip - smoothdata(std(sRn{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIn_Hip = sSIn_Mip + smoothdata(std(sRn{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIn_Msp = smoothdata(mean(sRn{1}(sp,:)), 'gaussian', smWd);
sSIn_Lsp = sSIn_Msp - smoothdata(std(sRn{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIn_Hsp = sSIn_Msp + smoothdata(std(sRn{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIn_Mak = smoothdata(mean(sRn{1}(ak,:)), 'gaussian', smWd);
sSIn_Lak = sSIn_Mak - smoothdata(std(sRn{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIn_Hak = sSIn_Mak + smoothdata(std(sRn{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sFPr_Mrp = smoothdata(nanmean(sRr{2}(rp,:)), 'gaussian', smWd);
sFPr_Lrp = sFPr_Mrp - smoothdata(nanstd(sRr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Hrp = sFPr_Mrp + smoothdata(nanstd(sRr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Mfp = smoothdata(nanmean(sRr{2}(fp,:)), 'gaussian', smWd);
sFPr_Lfp = sFPr_Mfp - smoothdata(nanstd(sRr{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sFPr_Hfp = sFPr_Mfp + smoothdata(nanstd(sRr{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sFPr_Mip = smoothdata(nanmean(sRr{2}(ip,:)), 'gaussian', smWd);
sFPr_Lip = sFPr_Mip - smoothdata(nanstd(sRr{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sFPr_Hip = sFPr_Mip + smoothdata(nanstd(sRr{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sFPr_Msp = smoothdata(nanmean(sRr{2}(sp,:)), 'gaussian', smWd);
sFPr_Lsp = sFPr_Msp - smoothdata(nanstd(sRr{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sFPr_Hsp = sFPr_Msp + smoothdata(nanstd(sRr{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sFPr_Mak = smoothdata(nanmean(sRr{2}(ak,:)), 'gaussian', smWd);
sFPr_Lak = sFPr_Mak - smoothdata(nanstd(sRr{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sFPr_Hak = sFPr_Mak + smoothdata(nanstd(sRr{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);



%% Figure 3d: Fraction Encoding Value (reward rate)

dtLR = 0.005;
winLO = [-1 1];
winCI = [-1 1];
winGO = [-1 1];
winSIpre = [-1 1];
winSIpost = [0 1];
winFP = [-1 1];
tFP = tLO;

plotDur = [range(winLO) range(winCI) range(winGO) winSIpost(2)-winSIpre(1) range(winSIpost) range(winFP)];
plotFrac = plotDur / sum(plotDur);
m = 0.0025; g = 0.005; plotSpace = (1-3*m-4*g);
w = plotFrac * plotSpace; wg = w + [g g g m g m];
l = m + [0 arrayfun(@(i) sum(wg(1:i)), 1:5)];
 
b = 0.005; h = 0.99
f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
plot(tLO, fracLOak, 'c', 'linewidth', 3)
plot(tLO, fracLOsp, 'b', 'linewidth', 3)
plot(tLO, fracLOfp, 'color', fpColor, 'linewidth', 3)
plot(tLO, fracLOrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
yR = [0 0.65];
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winLO)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
plot(tCI, fracCIak, 'c', 'linewidth', 3)
plot(tCI, fracCIsp, 'b', 'linewidth', 3)
plot(tCI, fracCIfp, 'color', fpColor, 'linewidth', 3)
plot(tCI, fracCIrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winCI)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
plot(tGO, fracGOak, 'c', 'linewidth', 3)
plot(tGO, fracGOsp, 'b', 'linewidth', 3)
plot(tGO, fracGOfp, 'color', fpColor, 'linewidth', 3)
plot(tGO, fracGOrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winGO)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
plot(tSIpre, fracSIpak, 'c', 'linewidth', 3)
plot(tSIpre, fracSIpsp, 'b', 'linewidth', 3)
plot(tSIpre, fracSIpfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpre, fracSIprp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSIrak, 'c', 'linewidth', 3)
plot(tSIpost, fracSIrsp, 'b', 'linewidth', 3)
plot(tSIpost, fracSIrfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpost, fracSIrrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim([winSIpre(1) winSIpost(2)])
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
plot(tSIpost, fracSInak, 'c', 'linewidth', 3)
plot(tSIpost, fracSInsp, 'b', 'linewidth', 3)
plot(tSIpost, fracSInfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpost, fracSInrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
xlim(winSIpost)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
plot(tFP, fracFPrak, 'c', 'linewidth', 3)
plot(tFP, fracFPrsp, 'b', 'linewidth', 3)
plot(tFP, fracFPrfp, 'color', fpColor, 'linewidth', 3)
plot(tFP, fracFPrrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winFP)
ylim(yR)
ax = gca;
ax.YTick = [-0.4:0.2:0.4];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Figure 3e: Regression Slope

f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
shade(tLO, sLO_Hak, tLO, sLO_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tLO, sLO_Mak, 'color', 'c', 'lineWidth', 2)
shade(tLO, sLO_Hsp, tLO, sLO_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tLO, sLO_Msp, 'color', 'b', 'lineWidth', 2)
shade(tLO, sLO_Hfp, tLO, sLO_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tLO, sLO_Hrp, tLO, sLO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
yR = [-0.21 0.03];
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
shade(tCI, sCI_Hak, tCI, sCI_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tCI, sCI_Mak, 'color', 'c', 'lineWidth', 2)
shade(tCI, sCI_Hsp, tCI, sCI_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tCI, sCI_Msp, 'color', 'b', 'lineWidth', 2)
shade(tCI, sCI_Hfp, tCI, sCI_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tCI, sCI_Hrp, tCI, sCI_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
shade(tGO, sGO_Hak, tGO, sGO_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tGO, sGO_Mak, 'color', 'c', 'lineWidth', 2)
shade(tGO, sGO_Hsp, tGO, sGO_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tGO, sGO_Msp, 'color', 'b', 'lineWidth', 2)
shade(tGO, sGO_Hfp, tGO, sGO_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tGO, sGO_Hrp, tGO, sGO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
shade(tSIpre, sSIp_Hak(1:201), tSIpre, sSIp_Lak(1:201),'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mak(1:201), 'color', 'c', 'lineWidth', 2)
shade(tSIpre, sSIp_Hsp(1:201), tSIpre, sSIp_Lsp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Msp(1:201), 'color', 'b', 'lineWidth', 2)
shade(tSIpre, sSIp_Hfp(1:201), tSIpre, sSIp_Lfp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mfp(1:201), 'color', fpColor, 'lineWidth', 2)
shade(tSIpre, sSIp_Hrp(1:201), tSIpre, sSIp_Lrp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mrp(1:201), 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hak, tSIpost, sSIr_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mak, 'color', 'c', 'lineWidth', 2)
shade(tSIpost, sSIr_Hsp, tSIpost, sSIr_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Msp, 'color', 'b', 'lineWidth', 2)
shade(tSIpost, sSIr_Hfp, tSIpost, sSIr_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hrp, tSIpost, sSIr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
shade(tSIpost, sSIn_Hak, tSIpost, sSIn_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mak, 'color', 'c', 'lineWidth', 2)
shade(tSIpost, sSIn_Hsp, tSIpost, sSIn_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Msp, 'color', 'b', 'lineWidth', 2)
shade(tSIpost, sSIn_Hfp, tSIpost, sSIn_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tSIpost, sSIn_Hrp, tSIpost, sSIn_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([0 1], [0 0], '--k', 'linewidth', 2)
ylim(yR)
xlim([0 1])
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
shade(tFP, sFPr_Hak, tFP, sFPr_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tFP, sFPr_Mak, 'color', 'c', 'lineWidth', 2)
shade(tFP, sFPr_Hsp, tFP, sFPr_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tFP, sFPr_Msp, 'color', 'b', 'lineWidth', 2)
shade(tFP, sFPr_Hfp, tFP, sFPr_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tFP, sFPr_Hrp, tFP, sFPr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Figure 3f--RPE Example Cell

best = [337 425];
candidate = [368 337 425];
u = 337; % choice

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 1;
sesList = unique(uSes);
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

uTrajRL = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
ts = unit(u).behav_ts{rlIdx};

% average rate: light on
lat = BehaviorTimes(ts);
sL = find(lat < latCrit);
lL = find(lat >= latCrit);
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 1);
r = zeros(length(sL), nPtsRL);
for k = 1:length(sL)
    r(k,:) = traj(sL(k)).rate;
end
ltShortLat = mean(r); 
r = zeros(length(lL), nPtsRL);
for k = 1:length(lL)
    r(k,:) = traj(lL(k)).rate;
end
ltLongLat = mean(r);

% average rate: center in
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 2);
r = zeros(length(sL), nPtsRL);
for k = 1:length(sL)
    r(k,:) = traj(sL(k)).rate;
end
ciShortLat = mean(r); 
r = zeros(length(lL), nPtsRL);
for k = 1:length(lL)
    r(k,:) = traj(lL(k)).rate;
end
ciLongLat = mean(r);

% average rate: go
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 3);
s = find(strcmp(uSes{u}, sesList));
rr = rwdRate{s}(11:end);
loTr = find(rr <= quantile(rr, lo(2))) + 10;
medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
hiTr = find(rr >= quantile(rr, hi(1))) + 10;
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
goL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
goM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
goH = mean(r);

% average rate: side in
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 5);
rwd = TrialFilter(ts, 'x1', unit(u).side);
noRwd = TrialFilter(ts, 'x0', unit(u).side);

r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
siL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
siM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
siH = mean(r);

sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLR = mean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMR = mean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHR = mean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLN = mean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMN = mean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHN = mean(r);

% average rate: food port
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 6);
s = find(strcmp(uSes{u}, sesList));
valid = find(~isnan(ts.firstFoodPoke));
sel = intersect(valid, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpR = mean(r);
sel = intersect(valid, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpN = mean(r);

maxRate = max([ltLongLat ltShortLat ciLongLat ciShortLat goL goM goH siLR siMR siHR siLN siMN siHN]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];

tkW = 2;
tkH = 4;

f = figure('Position', [1 100 1440 300])
subplot('Position', [0.005 0.005 0.194 0.99])
cList = {[0.1 1 0.1], [0 0.4 0]};
[~, oS] = sort(lat(sL));
[~, oL] = sort(lat(lL));
odr = {oS, oL};
RasterPlot(unit(u), 1, [-1 1], 'trials', {sL, lL}, 'order', odr, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [0.204 0.005 0.194 0.99])
RasterPlot(unit(u), 2, [-1 1], 'trials', {sL, lL}, 'order', odr, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [0.403 0.005 0.194 0.99])
RasterPlot(unit(u), 3, [-1 1], 'trials', {loTr, medTr, hiTr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors',...
    {[0.1 0.1 0.1], [0.4 0.4 0.4], [0.7 0.7 0.7]})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [0.602 0.005 0.194 0.99])
cList = {[0.4 0 0], [1 0 0], [1 0.6 0.6], [0 0 0.4], [0 0 1], [0.6 0.6 1]};
trList = {intersect(loTr, rwd), intersect(medTr, rwd), intersect(hiTr, rwd), ...
    intersect(loTr, noRwd), intersect(medTr, noRwd), intersect(hiTr, noRwd)};
RasterPlot(unit(u), 5, [-1 1], 'trials', trList, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off'
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [0.801 0.005 0.194 0.99])
RasterPlot(unit(u), 7, [-1 1], 'trials', {rwd, noRwd}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', {'r', 'b'})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off'
ax.XTick = [];
ax.YAxis.Visible = 'off';

yR = [0 60];
figure('Position', [1 100 1440 300])
subplot('Position', [0.005 0.005 0.194 0.99])
hold on
cList = {[0.1 1 0.1], [0 0.4 0]};
plot(timesRL, ltShortLat, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ltLongLat, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0 25 50])
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.204 0.005 0.194 0.99])
hold on
plot(timesRL, ciShortLat, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ciLongLat, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0 25 50])
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.403 0.005 0.194 0.99])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0 25 50])
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.602 0.005 0.194 0.99])
hold on
pt = find(timesRL == 0) + 1;
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0 25 50])
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.801 0.005 0.194 0.99])
hold on
plot(timesRL, fpN, 'color', 'b', 'linewidth', 3)
plot(timesRL, fpR, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0 25 50])
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')



%% Figure 3g--Average Response (by cell type)

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 1;
sesList = unique(uSes);

% go through each cell type here
uIdx = ak;

dt = 0.002; % assumes sigma = 20 ms for loaded trajectories
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
siLo = zeros(length(uIdx), nPtsRL);
siMed = zeros(length(uIdx), nPtsRL);
siHi = zeros(length(uIdx), nPtsRL);
loRwd = zeros(length(uIdx), nPtsRL);
medRwd = zeros(length(uIdx), nPtsRL);
hiRwd = zeros(length(uIdx), nPtsRL);
loNoRwd = zeros(length(uIdx), nPtsRL);
medNoRwd = zeros(length(uIdx), nPtsRL);
hiNoRwd = zeros(length(uIdx), nPtsRL);
ltShortLat = zeros(length(uIdx), nPtsRL);
ltLongLat = zeros(length(uIdx), nPtsRL);
ciShortLat = zeros(length(uIdx), nPtsRL);
ciLongLat = zeros(length(uIdx), nPtsRL);
goLo = zeros(length(uIdx), nPtsRL);
goMed = zeros(length(uIdx), nPtsRL);
goHi = zeros(length(uIdx), nPtsRL);
fpRwd = zeros(length(uIdx), nPtsRL);
fpNoRwd = zeros(length(uIdx), nPtsRL);

for i = 1:length(uIdx)
    
    u = uIdx(i);
    uTrajRL = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    t1 = unit(u).taskStart(rlIdx);
    tSIpost = unit(u).taskEnd(rlIdx);
    ts = unit(u).behav_ts{rlIdx};
    
    % average rate: light on
    traj = TrajSplit(uTrajRL,  unit(u).behav_ts{rlIdx}, winRL, 'event', 1);
    [lat rt] = BehaviorTimes(unit(u).behav_ts{rlIdx});
    sL = find(lat < latCrit);
    lL = find(lat >= latCrit);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ltShortLat(i,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ltLongLat(i,:) = mean(r);
    
    % average rate: center in
    traj = TrajSplit(uTrajRL,  unit(u).behav_ts{rlIdx}, winRL, 'event', 2);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ciShortLat(i,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ciLongLat(i,:) = mean(r);
    
    % average rate: go cue
    traj = TrajSplit(uTrajRL,  unit(u).behav_ts{rlIdx}, winRL, 'event', 3);
    s = uSes(u);
    [~, s] = ismember(s{1}, sesList);
    rr = rwdRate{s}(11:end);
    loTr = find(rr <= quantile(rr, lo(2))) + 10;
    medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
    hiTr = find(rr >= quantile(rr, hi(1))) + 10;
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    goLo(i,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    goMed(i,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    goHi(i,:) = mean(r);
    
    % average rate: side in
    traj = TrajSplit(uTrajRL,  unit(u).behav_ts{rlIdx}, winRL, 'event', 5);
    rwd = TrialFilter(unit(u).behav_ts{rlIdx}, 'x1', unit(u).side);
    noRwd = TrialFilter(unit(u).behav_ts{rlIdx}, 'x0', unit(u).side);
    
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    siLo(i,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    siMed(i,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    siHi(i,:) = mean(r);
    
    sel = intersect(loTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loRwd(i,:) = mean(r);
    sel = intersect(loTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loNoRwd(i,:) = mean(r);
    sel = intersect(medTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medRwd(i,:) = mean(r);
    sel = intersect(medTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medNoRwd(i,:) = mean(r);
    
    sel = intersect(hiTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiRwd(i,:) = mean(r);
    sel = intersect(hiTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiNoRwd(i,:) = mean(r);
    
    % average rate: food port
    traj = TrajSplit(uTrajRL,  unit(u).behav_ts{rlIdx}, winRL, 'event', 6);
    poke1 = find(~isnan(ts.firstFoodPoke));
    sel = intersect(rwd, poke1);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpRwd(i,:) = mean(r);
    else
        fpRwd(i,:) = nan(1, nPtsRL);
    end
    sel = intersect(noRwd, poke1);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpNoRwd(i,:) = mean(r);
    else
        fpNoRwd(i,:) = nan(1, nPtsRL);
    end
    
end

ltSh = mean(ltShortLat);
ltLo = mean(ltLongLat);
ciSh = mean(ciShortLat);
ciLo = mean(ciLongLat);
goL = mean(goLo);
goM = mean(goMed);
goH = mean(goHi);
siL = mean(siLo);
siM = mean(siMed);
siH = mean(siHi);
siLR = nanmean(loRwd);
siMR = mean(medRwd);
siHR = mean(hiRwd);
siLN = mean(loNoRwd);
siMN = mean(medNoRwd);
siHN = mean(hiNoRwd);
goodCells = find(~isnan(fpRwd(:,1)));
fpR = mean(fpRwd(goodCells,:));
goodCells = find(~isnan(fpNoRwd(:,1)));
fpN = mean(fpNoRwd(goodCells,:));

maxRate = max([ltSh ltLo ciSh ciLo goL goM goH siLR siMR siHR siLN siMN siHN fpR fpN]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];
yticks = [15 30];

f = figure('Position', [10 100 1400 188])
subplot('Position', [0.005 0.005 0.194 0.99])
cList = {[0.1 1 0.1], [0 0.4 0]};
hold on
plot(timesRL, ltSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ltLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.204 0.005 0.194 0.99])
hold on
plot(timesRL, ciSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ciLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.403 0.005 0.194 0.99])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.602 0.005 0.194 0.99])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
pt = find(timesRL == 0) + 1;
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.801 0.005 0.194 0.99])
hold on
plot(timesRL, fpN, 'color', 'b', 'linewidth', 3)
plot(timesRL, fpR, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')




%% Figure 3g--Average Response (DA cells)

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 1;

% load DA cell data
load([datRoot 'unitDa.mat'])

% calculate DA cell reward rate
tau = 89;
rwdRateDA = cell(1, length(unitDA));
rlIdxDA = nan(1, length(unitDA));
pavIdxDA = nan(1, length(unitDA));
for u = 1:length(unitDA)
    rlIdxDA(u) = find(cellfun(@(t) strcmp(lower(t), 'rl'), unitDA(u).taskList));
    pavIdxDA(u) = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    tsRL = unitDA(u).behav_ts{rlIdxDA(u)};
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRateDA{u} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRateDA{u}(k) = rwdRateDA{u}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRateDA{u}(k) = rwdRateDA{u}(k) + tsRL.outcome(k);
    end      
end 

% generate smoothed rate trajectories
sigma = 0.02;
dt = sigma / 10;
for u = 1:length(unitDA)
    uTrajDA(u) = UnitTraj(unitDA(u), sigma, dt, 'RL');
    uTrajDA(u).name = unitDA(u).name;
end

timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
loRwd = zeros(length(unitDA), nPtsRL);
medRwd = zeros(length(unitDA), nPtsRL);
hiRwd = zeros(length(unitDA), nPtsRL);
loNoRwd = zeros(length(unitDA), nPtsRL);
medNoRwd = zeros(length(unitDA), nPtsRL);
hiNoRwd = zeros(length(unitDA), nPtsRL);
ltShortLat = zeros(length(unitDA), nPtsRL);
ltLongLat = zeros(length(unitDA), nPtsRL);
ciShortLat = zeros(length(unitDA), nPtsRL);
ciLongLat = zeros(length(unitDA), nPtsRL);
goLo = zeros(length(unitDA), nPtsRL);
goMed = zeros(length(unitDA), nPtsRL);
goHi = zeros(length(unitDA), nPtsRL);
siLo = zeros(length(unitDA), nPtsRL);
siMed = zeros(length(unitDA), nPtsRL);
siHi = zeros(length(unitDA), nPtsRL);
fpRwd = zeros(length(unitDA), nPtsRL);
fpNoRwd = zeros(length(unitDA), nPtsRL);

for u = 1:length(unitDA)
    
    t1 = unitDA(u).taskStart(rlIdxDA(u));
    t2 = unitDA(u).taskEnd(rlIdxDA(u));
    ts = unitDA(u).behav_ts{rlIdxDA(u)};
    
    % average rate: light on
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 1);
    [lat rt] = BehaviorTimes(ts);
    sL = find(lat < latCrit);
    lL = find(lat >= latCrit);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ltShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ltLongLat(u,:) = mean(r);
    
    % average rate: center in
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 2);
    r = zeros(length(sL), nPtsRL);
    for k = 1:length(sL)
        r(k,:) = traj(sL(k)).rate;
    end
    ciShortLat(u,:) = mean(r);    
    r = zeros(length(lL), nPtsRL);
    for k = 1:length(lL)
        r(k,:) = traj(lL(k)).rate;
    end
    ciLongLat(u,:) = mean(r);
    
    % average rate: go cue
    traj = TrajSplit(uTrajDA(u),  ts, winRL, 'event', 3);
    rr = rwdRateDA{u}(11:end);
    loTr = find(rr <= quantile(rr, lo(2))) + 10;
    medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
    hiTr = find(rr >= quantile(rr, hi(1))) + 10;
    
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    goLo(u,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    goMed(u,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    goHi(u,:) = mean(r);
    
    % average rate: side in
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 5);
    rwd = TrialFilter(ts, 'x1', unitDA(u).side);
    noRwd = TrialFilter(ts, 'x0', unitDA(u).side);
    
    r = zeros(length(loTr), nPtsRL);
    for k = 1:length(loTr)
        r(k,:) = traj(loTr(k)).rate;
    end
    siLo(u,:) = mean(r);
    r = zeros(length(medTr), nPtsRL);
    for k = 1:length(medTr)
        r(k,:) = traj(medTr(k)).rate;
    end
    siMed(u,:) = mean(r);
    r = zeros(length(hiTr), nPtsRL);
    for k = 1:length(hiTr)
        r(k,:) = traj(hiTr(k)).rate;
    end
    siHi(u,:) = mean(r);
    
    sel = intersect(loTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loRwd(u,:) = mean(r);
    sel = intersect(loTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    loNoRwd(u,:) = mean(r);
    sel = intersect(medTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medRwd(u,:) = mean(r);
    sel = intersect(medTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    medNoRwd(u,:) = mean(r);
    
    sel = intersect(hiTr, rwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiRwd(u,:) = mean(r);
    sel = intersect(hiTr, noRwd);
    r = zeros(length(sel), nPtsRL);
    for k = 1:length(sel)
        r(k,:) = traj(sel(k)).rate;
    end
    hiNoRwd(u,:) = mean(r);
    
    % average rate: food port
    traj = TrajSplit(uTrajDA(u), ts, winRL, 'event', 6);
    poke1 = find(~isnan(ts.firstFoodPoke));
    sel = intersect(rwd, poke1);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpRwd(u,:) = mean(r);
    else
        fpRwd(u,:) = nan(1, nPtsRL);
    end
    sel = intersect(noRwd, poke1);
    if ~isempty(sel)
        r = zeros(length(sel), nPtsRL);
        for k = 1:length(sel)
            r(k,:) = traj(sel(k)).rate;
        end
        fpNoRwd(u,:) = mean(r);
    else
        fpNoRwd(u,:) = nan(1, nPtsRL);
    end
    
end

ltSh = mean(ltShortLat);
ltLo = mean(ltLongLat);
ciSh = mean(ciShortLat);
ciLo = mean(ciLongLat);
goL = mean(goLo);
goM = mean(goMed);
goH = mean(goHi);
siLR = mean(loRwd);
siMR = mean(medRwd);
siHR = mean(hiRwd);
siLN = mean(loNoRwd);
siMN = mean(medNoRwd);
siHN = mean(hiNoRwd);
siL = mean(siLo);
siM = mean(siMed);
siH = mean(siHi);
goodCells = find(~isnan(fpRwd(:,1)));
fpR = mean(fpRwd(goodCells,:));
goodCells = find(~isnan(fpNoRwd(:,1)));
fpN = mean(fpNoRwd(goodCells,:));

maxRate = max([ltSh ltLo ciSh ciLo goL goM goH siLR siMR siHR siLN siMN siHN fpR fpN]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];
yticks = [15 30];

f = figure('Position', [10 100 1400 188])
subplot('Position', [0.005 0.005 0.194 0.99])
cList = {[0.1 1 0.1], [0 0.4 0]};
hold on
plot(timesRL, ltSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ltLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.204 0.005 0.194 0.99])
hold on
plot(timesRL, ciSh, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ciLo, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.403 0.005 0.194 0.99])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.602 0.005 0.194 0.99])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
pt = find(timesRL == 0) + 1;
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [0.801 0.005 0.194 0.99])
hold on
plot(timesRL, fpN, 'color', 'b', 'linewidth', 3)
plot(timesRL, fpR, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yticks)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')





