%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)

rpColor = [0.7 0 0];



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end      
end 


%% Load DA Cell Data

% load DA cell data
load([datRoot 'unitDa.mat'])

% calculate DA cell reward rate
tau = 89;
rwdRateDA = cell(1, length(unitDA));
rlIdxDA = nan(1, length(unitDA));
pavIdxDA = nan(1, length(unitDA));
for u = 1:length(unitDA)
    rlIdxDA(u) = find(cellfun(@(t) strcmp(lower(t), 'rl'), unitDA(u).taskList));
    pavIdxDA(u) = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    tsRL = unitDA(u).behav_ts{rlIdxDA(u)};
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRateDA{u} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRateDA{u}(k) = rwdRateDA{u}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRateDA{u}(k) = rwdRateDA{u}(k) + tsRL.outcome(k);
    end      
end 



%% Parameters for Response Assessment and Peak Measurement

latCrit = 1;
sigma = 20;

% specs for response detection
pR.bslnWin = [-0.1 0];        % baseline window
pR.responseWin = [0 0.3];     % response window
pR.binWidth = 0.05;           % response bin width
pR.responsePolarity = 0;      % response polarity

% specs for response detection after GO cue (narrower window)
pG.bslnWin = [-0.1 0];        % baseline window
pG.responseWin = [0 0.1]; % response window
pG.binWidth = 0.05;           % response bin width
pG.responsePolarity = 0;      % response polarity

nBins = length([pR.responseWin(1):pR.binWidth:pR.responseWin(2)]) - 1;
nGoBins = length([pG.responseWin(1):pG.binWidth:pG.responseWin(2)]) - 1;
win = [pR.bslnWin(1) pR.responseWin(2)];
winGo = [pG.bslnWin(1) pG.responseWin(2)];



%% Assess Responsivness, Measure Peak Response (RL, GPe)

uIdx = rp;
typeLabel = 'slow pacemaker';
unitTmp = unit(uIdx);
uTraj = LoadUnitTraj(unitTmp, 'RL', datRoot, 'sigma', sigma);

ltPval = ones(length(uIdx), nBins);
ltBsln = zeros(length(uIdx), 1);
ltRate = zeros(length(uIdx), nBins);
goPval = ones(length(uIdx), nGoBins);
goBsln = zeros(length(uIdx), 1);
goRate = zeros(length(uIdx), nGoBins);
siRwdPval = ones(length(uIdx), nBins);
siRwdBsln = zeros(length(uIdx), 1);
siRwdRate = zeros(length(uIdx), nBins);
siNoRwdPval = ones(length(uIdx), nBins);
siNoRwdBsln = zeros(length(uIdx), 1);
siNoRwdRate = zeros(length(uIdx), nBins);

ltPk = cell(1, length(uIdx));
ltPkt = zeros(1, length(uIdx));
goPk = cell(1, length(uIdx));
goPkt = zeros(1, length(uIdx));
siRwdPk = cell(1, length(uIdx));
siRwdPkt = zeros(1, length(uIdx));
siNoRwdPk = cell(1, length(uIdx));
siNoRwdPkt = zeros(1, length(uIdx));

pol = 0;
for u = 1:length(unitTmp)
    
    [~, rlIdx] = ismember('RL', unitTmp(u).taskList);
    t1 = unitTmp(u).taskStart(rlIdx);
    t2 = unitTmp(u).taskEnd(rlIdx);
    ts = unitTmp(u).behav_ts{rlIdx};
    spk = unitTmp(u).spkTimes(unitTmp(u).spkTimes>t1 & unitTmp(u).spkTimes<t2) - t1;
    
    % light on (short CNI latency)
    lat = BehaviorTimes(ts);
    sL = find(lat < latCrit);
    eTime = ts.trialbegin;
    [ltPval(u,:) ltRate(u,:) ltBsln(u)] = ResponseAssess(spk, eTime(sL), pR);
    [ltPk{u} ltPkt(u)] = PeakResponse(uTraj(u), eTime(sL), win, pol);
        
    % go
    eTime = ts.go;
    [goPval(u,:) goRate(u,:) goBsln(u)] = ResponseAssess(spk, eTime, pG);
    [goPk{u} goPkt(u)] = PeakResponse(uTraj(u), eTime, winGo, pol);
    
    % side in: rewarded
    rwd = TrialFilter(ts, 'x1', 'R');
    eTime = ts.Side_NI;
    [siRwdPval(u,:) siRwdRate(u,:) siRwdBsln(u)] = ResponseAssess(spk, eTime(rwd), pR);
    [siRwdPk{u} siRwdPkt(u)] = PeakResponse(uTraj(u), eTime(rwd), win, pol);
    
    % side in: unrewarded
    noRwd = TrialFilter(ts, 'x0', 'R');
    [siNoRwdPval(u,:) siNoRwdRate(u,:) siNoRwdBsln(u)] = ResponseAssess(spk, eTime(noRwd), pR);
    [siNoRwdPk{u} siNoRwdPkt(u)] = PeakResponse(uTraj(u), eTime(noRwd), win, pol);
    
end



%% Assess Responsivness, Measure Peak Response (RL, VTA-DA)

% generate smoothed rate trajectories
sesList = unique(uSes);
sigmaDA = sigma/1000;
dt = sigmaDA / 10;
for u = 1:length(unitDA)
    uTrajDA(u) = UnitTraj(unitDA(u), sigmaDA, dt, 'RL');
    uTrajDA(u).name = unitDA(u).name;
end

ltPvalDA = ones(length(unitDA), nBins);
ltRateDA = ones(length(unitDA), nBins);
ltBslnDA = ones(length(unitDA), 1);
goPvalDA = ones(length(unitDA), nGoBins);
goRateDA = ones(length(unitDA), nGoBins);
goBslnDA = ones(length(unitDA), 1);
siRwdPvalDA = ones(length(unitDA), nBins);
siRwdRateDA = ones(length(unitDA), nBins);
siRwdBslnDA = ones(length(unitDA), 1);
siNoRwdPvalDA = ones(length(unitDA), nBins);
siNoRwdRateDA = ones(length(unitDA), nBins);
siNoRwdBslnDA = ones(length(unitDA), 1);
ltPkDA = cell(1, length(unitDA));
ltPktDA = zeros(1, length(unitDA));
goPkDA = cell(1, length(unitDA));
goPktDA = zeros(1, length(unitDA));
siRwdPkDA = cell(1, length(unitDA));
siRwdPktDA = zeros(1, length(unitDA));
siNoRwdPkDA = cell(1, length(unitDA));
siNoRwdPktDA = zeros(1, length(unitDA));

pol = 0;
for u = 1:length(unitDA)
    
    [~, rlIdx] = ismember('RL', unitDA(u).taskList); 
    t1 = unitDA(u).taskStart(rlIdx);
    t2 = unitDA(u).taskEnd(rlIdx);
    ts = unitDA(u).behav_ts{rlIdx};
    spk = unitDA(u).spkTimes(unitDA(u).spkTimes>t1 & unitDA(u).spkTimes<t2) - t1;
    
    % light on (short CNI latency)
    lat = BehaviorTimes(ts);
    sL = find(lat < latCrit);
    eTime = ts.trialbegin;
    [ltPvalDA(u,:) ltRateDA(u,:) ltBslnDA(u)] = ResponseAssess(spk, eTime(sL), pR);
    [ltPkDA{u} ltPktDA(u)] = PeakResponse(uTrajDA(u), eTime(sL), win, pol);
    
    % go
    eTime = ts.go;
    [goPvalDA(u,:) goRateDA(u,:) goBslnDA(u)] = ResponseAssess(spk, eTime, pG);
    [goPkDA{u} goPktDA(u)] = PeakResponse(uTrajDA(u), eTime, winGo, pol);
    
    % side in: rewarded
    rwd = TrialFilter(ts, 'x1', 'R');
    eTime = ts.Side_NI;
    [siRwdPvalDA(u,:) siRwdRateDA(u,:) siRwdBslnDA(u)] = ResponseAssess(spk, eTime(rwd), pR);
    [siRwdPkDA{u} siRwdPktDA(u)] = PeakResponse(uTrajDA(u), eTime(rwd), win, pol);
    
    % side in: unrewarded
    noRwd = TrialFilter(ts, 'x0', 'R');
    [siNoRwdPvalDA(u,:) siNoRwdRateDA(u,:) siNoRwdBslnDA(u)] = ResponseAssess(spk, eTime(noRwd), pR);
    [siNoRwdPkDA{u} siNoRwdPktDA(u)] = PeakResponse(uTrajDA(u), eTime(noRwd), win, pol);
    
end



%% Assess Responsivness, Measure Peak Response (Pav, GPe)

uIdx = rp;
typeLabel = 'slow pacemaker';
unitTmp = unit(uIdx);
uTraj = LoadUnitTraj(unitTmp, 'Pav', datRoot, 'sigma', sigma);

cs0Pval = nan(length(uIdx), nBins);
cs0Rate = ones(length(uIdx), nBins);
cs0Bsln = ones(length(uIdx), 1);
cs25Pval = nan(length(uIdx), nBins);
cs25Rate = ones(length(uIdx), nBins);
cs25Bsln = ones(length(uIdx), 1);
cs75Pval = nan(length(uIdx), nBins);
cs75Rate = ones(length(uIdx), nBins);
cs75Bsln = ones(length(uIdx), 1);
csAllPval = nan(length(uIdx), nBins);
csAllRate = ones(length(uIdx), nBins);
csAllBsln = ones(length(uIdx), 1);
us0Pval = nan(length(uIdx), nBins);
us0Rate = ones(length(uIdx), nBins);
us0Bsln = ones(length(uIdx), 1);
us25rPval = nan(length(uIdx), nBins);
us25rRate = ones(length(uIdx), nBins);
us25rBsln = ones(length(uIdx), 1);
us25nrPval = nan(length(uIdx), nBins);
us25nrRate = ones(length(uIdx), nBins);
us25nrBsln = ones(length(uIdx), 1);
us75rPval = nan(length(uIdx), nBins);
us75rRate = ones(length(uIdx), nBins);
us75rBsln = ones(length(uIdx), 1);
us75nrPval = nan(length(uIdx), nBins);
us75nrRate = ones(length(uIdx), nBins);
us75nrBsln = ones(length(uIdx), 1);
us100Pval = nan(length(uIdx), nBins);
us100Rate = ones(length(uIdx), nBins);
us100Bsln = ones(length(uIdx), 1);
usAllPval = nan(length(uIdx), nBins);
usAllRate = ones(length(uIdx), nBins);
usAllBsln = ones(length(uIdx), 1);
cs0Pk = cell(1, length(uIdx));
cs0Pkt = nan(1, length(uIdx));
cs25Pk = cell(1, length(uIdx));
cs25Pkt = nan(1, length(uIdx));
cs75Pk = cell(1, length(uIdx));
cs75Pkt = nan(1, length(uIdx));
csAllPk = cell(1, length(uIdx));
csAllPkt = nan(1, length(uIdx));
us0Pk = cell(1, length(uIdx));
us0Pkt = nan(1, length(uIdx));
us25rPk = cell(1, length(uIdx));
us25rPkt = nan(1, length(uIdx));
us25nrPk = cell(1, length(uIdx));
us25nrPkt = nan(1, length(uIdx));
us75rPk = cell(1, length(uIdx));
us75rPkt = nan(1, length(uIdx));
us75nrPk = cell(1, length(uIdx));
us75nrPkt = nan(1, length(uIdx));
us100Pk = cell(1, length(uIdx));
us100Pkt = nan(1, length(uIdx));
usAllPk = cell(1, length(uIdx));
usAllPkt = nan(1, length(uIdx));

for u = 1:length(unitTmp)
    
    [~, pavIdx] = ismember('Pav', unitTmp(u).taskList);
    if pavIdx ~= 0
        ts = unitTmp(u).behav_ts{pavIdx};
    else
        continue
    end
    lg = unitTmp(u).behav_log{pavIdx};
    cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
    cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
    cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);
    tr0 = find(lg.toneFreq == cue0);
    tr25 = find(lg.toneFreq == cue25);
    tr75 = find(lg.toneFreq == cue75);
    tr100 = find(lg.toneFreq == 0);
    rwd = find(lg.outcome);
    noRwd = find(~lg.outcome);
    t1 = unitTmp(u).taskStart(pavIdx);
    t2 = unitTmp(u).taskEnd(pavIdx);
    spk = unitTmp(u).spkTimes(unitTmp(u).spkTimes>t1 & unitTmp(u).spkTimes<t2) - t1;

    % CS prob 0
    eTime = ts.csTime;
    [cs0Pval(u,:) cs0Rate(u,:) cs0Bsln(u)] = ResponseAssess(spk, eTime(tr0), pR);
    [cs0Pk{u} cs0Pkt(u)] = PeakResponse(uTraj(u), eTime(tr0), win, pol);
    
    % CS prob 25
    [cs25Pval(u,:) cs25Rate(u,:) cs25Bsln(u)] = ResponseAssess(spk, eTime(tr25), pR);
    [cs25Pk{u} cs25Pkt(u)] = PeakResponse(uTraj(u), eTime(tr25), win, pol);
    
    % CS prob 75
    [cs75Pval(u,:) cs75Rate(u,:) cs75Bsln(u)] = ResponseAssess(spk, eTime(tr75), pR);
    [cs75Pk{u} cs75Pkt(u)] = PeakResponse(uTraj(u), eTime(tr75), win, pol);
    
    % CS All
    tr = unique([tr0; tr25; tr75]);
    [csAllPval(u,:) csAllRate(u,:) csAllBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [csAllPk{u} csAllPkt(u)] = PeakResponse(uTraj(u), eTime(tr), win, pol);
    
    % US prob 0
    rwdTime = dt*round(nanmean(ts.rwdTime - ts.csTime)/dt);
    eTime = ts.csTime + rwdTime;
    [us0Pval(u,:) us0Rate(u,:) us0Bsln(u)] = ResponseAssess(spk, eTime(tr0), pR);
    [us0Pk{u} us0Pkt(u)] = PeakResponse(uTraj(u), eTime(tr0), win, pol);
    
    % US prob 100 (unpredicted reward)
    [us100Pval(u,:) us100Rate(u,:) us100Bsln(u)] = ResponseAssess(spk, eTime(tr100), pR);
    [us100Pk{u} us100Pkt(u)] = PeakResponse(uTraj(u), eTime(tr100), win, pol);
    
    % US prob 25 rewarded
    tr = intersect(tr25, rwd);
    [us25rPval(u,:) us25rRate(u,:) us25rBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us25rPk{u} us25rPkt(u)] = PeakResponse(uTraj(u), eTime(tr), win, pol);
    
    % US prob 25 unrewarded
    tr = intersect(tr25, noRwd);
    [us25nrPval(u,:) us25nrRate(u,:) us25nrBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us25nrPk{u} us25nrPkt(u)] = PeakResponse(uTraj(u), eTime(tr), win, pol);
    
    % US prob 75 rewarded
    tr = intersect(tr75, rwd);
    [us75rPval(u,:) us75rRate(u,:) us75rBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us75rPk{u} us75rPkt(u)] = PeakResponse(uTraj(u), eTime(tr), win, pol);
    
    % US prob 75 unrewarded
    tr = intersect(tr75, noRwd);
    [us75nrPval(u,:) us75nrRate(u,:) us75nrBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us75nrPk{u} us75nrPkt(u)] = PeakResponse(uTraj(u), eTime(tr), win, pol);
    
    % US all (rewarded only)
    [usAllPval(u,:) usAllRate(u,:) usAllBsln(u)] = ResponseAssess(spk, eTime(rwd), pR);
    [usAllPk{u} usAllPkt(u)] = PeakResponse(uTraj(u), eTime(rwd), win, pol);
    
end



%% Assess Responsivness, Measure Peak Response (Pav, DA)

% identify DA cells with matching Pavlovian data (25%-75% prob[rwd])
pav50DA = false(1, length(unitDA));
pav25DA = false(1, length(unitDA));
pavAllDA = false(1, length(unitDA));
for u = 1:length(unitDA)
    [~, pavIdx] = ismember('Pav', unitDA(u).taskList);
    lg = unitDA(u).behav_log{pavIdx};
    pavAllDA(u) = ~isempty(lg);
    if pavAllDA(u)
        pav25DA(u) = ~isempty(lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1));
        pav50DA(u) = ~isempty(lg.cueRwdTable(lg.cueRwdTable(:,2) == 50, 1));
    end
end
pav25DA = find(pav25DA);
pavAllDA = find(pavAllDA);

% generate smoothed rate trajectories
sigmaDA = sigma/1000;
dt = sigmaDA / 10;
clear uTrajDA
for u = 1:length(unitDA)
    uTrajDA(u) = UnitTraj(unitDA(u), sigmaDA, dt, 'Pav');
end

cs0PvalDA = ones(length(unitDA), nBins);
cs0RateDA = nan(length(unitDA), nBins);
cs0BslnDA = nan(length(unitDA), 1);
cs50PvalDA = nan(length(unitDA), nBins);
cs50RateDA = ones(length(unitDA), nBins);
cs50BslnDA = ones(length(unitDA), 1);
cs100PvalDA = ones(length(unitDA), nBins);
cs100RateDA = nan(length(unitDA), nBins);
cs100BslnDA = nan(length(unitDA), 1);

cs25PvalDA = ones(length(unitDA), nBins);
cs25RateDA = nan(length(unitDA), nBins);
cs25BslnDA = nan(length(unitDA), 1);
cs75PvalDA = ones(length(unitDA), nBins);
cs75RateDA = nan(length(unitDA), nBins);
cs75BslnDA = nan(length(unitDA), 1);
csAllPvalDA = ones(length(unitDA), nBins);
csAllRateDA = nan(length(unitDA), nBins);
csAllBslnDA = nan(length(unitDA), 1);
us0PvalDA = ones(length(unitDA), nBins);
us0RateDA = nan(length(unitDA), nBins);
us0BslnDA = nan(length(unitDA), 1);
us25rPvalDA = ones(length(unitDA), nBins);
us25rRateDA = nan(length(unitDA), nBins);
us25rBslnDA = nan(length(unitDA), 1);
us25nrPvalDA = ones(length(unitDA), nBins);
us25nrRateDA = nan(length(unitDA), nBins);
us25nrBslnDA = nan(length(unitDA), 1);
us75rPvalDA = ones(length(unitDA), nBins);
us75rRateDA = nan(length(unitDA), nBins);
us75rBslnDA = nan(length(unitDA), 1);
us75nrPvalDA = ones(length(unitDA), nBins);
us75nrRateDA = nan(length(unitDA), nBins);
us75nrBslnDA = nan(length(unitDA), 1);
us100PvalDA = ones(length(unitDA), nBins);
us100RateDA = nan(length(unitDA), nBins);
us100BslnDA = nan(length(unitDA), 1);
usAllPvalDA = ones(length(unitDA), nBins);
usAllRateDA = nan(length(unitDA), nBins);
usAllBslnDA = nan(length(unitDA), 1);
cs0PkDA = cell(1, length(unitDA));
cs0PktDA = nan(1, length(unitDA));
cs25PkDA = cell(1, length(unitDA));
cs25PktDA = nan(1, length(unitDA));
cs75PkDA = cell(1, length(unitDA));
cs75PktDA = nan(1, length(unitDA));
csAllPkDA = cell(1, length(unitDA));
csAllPktDA = nan(1, length(unitDA));
us0PkDA = cell(1, length(unitDA));
us0PktDA = nan(1, length(unitDA));
us25rPkDA = cell(1, length(unitDA));
us25rPktDA = nan(1, length(unitDA));
us25nrPkDA = cell(1, length(unitDA));
us25nrPktDA = nan(1, length(unitDA));
us75rPkDA = cell(1, length(unitDA));
us75rPktDA = nan(1, length(unitDA));
us75nrPkDA = cell(1, length(unitDA));
us75nrPktDA = nan(1, length(unitDA));
us100PkDA = cell(1, length(unitDA));
us100PktDA = nan(1, length(unitDA));
usAllPkDA = cell(1, length(unitDA));
usAllPktDA = nan(1, length(unitDA));

pol = 0;
for u = 1:length(unitDA)
    
    [~, pavIdx] = ismember('Pav', unitDA(u).taskList);
    if pavIdx ~= 0
        ts = unitDA(u).behav_ts{pavIdx};
    else
        continue
    end
    ts = unitDA(u).behav_ts{pavIdx};
    lg = unitDA(u).behav_log{pavIdx};
    cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
    tr0 = find(lg.toneFreq == cue0);
    trXX = find(lg.toneFreq ~= 0);
    tr100 = find(lg.toneFreq == 0);
    rwd = find(lg.outcome);
    noRwd = find(~lg.outcome);
    t1 = unitDA(u).taskStart(pavIdx);
    t2 = unitDA(u).taskEnd(pavIdx);
    spk = unitDA(u).spkTimes(unitDA(u).spkTimes>t1 & unitDA(u).spkTimes<t2) - t1;
    
    csTime = ts.csTime;
    rwdTime = dt*round(nanmean(ts.rwdTime - ts.csTime)/dt);
    usTime = csTime + rwdTime;
    
    % CS prob 0
    [cs0PvalDA(u,:) cs0RateDA(u,:) cs0BslnDA(u)] = ResponseAssess(spk, csTime(tr0), pR);
    [cs0PkDA{u} cs0PktDA(u)] = PeakResponse(uTrajDA(u), csTime(tr0), win, pol);
    
    % US prob 0
    [us0PvalDA(u,:) us0RateDA(u,:) us0BslnDA(u)] = ResponseAssess(spk, usTime(tr0), pR);
    [us0PkDA{u} us0PktDA(u)] = PeakResponse(uTrajDA(u), usTime(tr0), win, pol);
    
    % US prob 100 (unpredicted reward)
    [us100PvalDA(u,:) us100RateDA(u,:) us100BslnDA(u)] = ResponseAssess(spk, usTime(tr100), pR);
    [us100PkDA{u} us100PktDA(u)] = PeakResponse(uTrajDA(u), usTime(tr100), win, pol);
    
    if ismember(u, pav25DA)
        
        cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
        cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);
        tr25 = find(lg.toneFreq == cue25);
        tr75 = find(lg.toneFreq == cue75);
    
        % CS prob 25
        [cs25PvalDA(u,:) cs25RateDA(u,:) cs25BslnDA(u)] = ResponseAssess(spk, csTime(tr25), pR);
        [cs25PkDA{u} cs25PktDA(u)] = PeakResponse(uTrajDA(u), csTime(tr25), win, pol);
        
        % CS prob 75
        [cs75PvalDA(u,:) cs75RateDA(u,:) cs75BslnDA(u)] = ResponseAssess(spk, csTime(tr75), pR);
        [cs75PkDA{u} cs75PktDA(u)] = PeakResponse(uTrajDA(u), csTime(tr75), win, pol);
        
        % US prob 25 rewarded
        tr = intersect(tr25, rwd);
        [us25rPvalDA(u,:) us25rRateDA(u,:) us25rBslnDA(u)] = ResponseAssess(spk, usTime(tr), pR);
        [us25rPkDA{u} us25rPktDA(u)] = PeakResponse(uTrajDA(u), usTime(tr), win, pol);
    
        % US prob 25 unrewarded
        tr = intersect(tr25, noRwd);
        [us25nrPvalDA(u,:) us25nrRateDA(u,:) us25nrBslnDA(u)] = ResponseAssess(spk, usTime(tr), pR);
        [us25nrPkDA{u} us25nrPktDA(u)] = PeakResponse(uTrajDA(u), usTime(tr), win, pol);
        
        % US prob 75 rewarded
        tr = intersect(tr75, rwd);
        [us75rPvalDA(u,:) us75rRateDA(u,:) us75rBslnDA(u)] = ResponseAssess(spk, usTime(tr), pR);
        [us75rPkDA{u} us75rPktDA(u)] = PeakResponse(uTrajDA(u), usTime(tr), win, pol);
    
        % US prob 75 unrewarded
        tr = intersect(tr75, noRwd);
        [us75nrPvalDA(u,:) us75nrRateDA(u,:) us75nrBslnDA(u)] = ResponseAssess(spk, usTime(tr), pR);
        [us75nrPkDA{u} us75nrPktDA(u)] = PeakResponse(uTrajDA(u), usTime(tr), win, pol);
        
    end
    
    % CS All
    [csAllPvalDA(u,:) csAllRateDA(u,:) csAllBslnDA(u)] = ResponseAssess(spk, csTime(trXX), pR);
    [csAllPkDA{u} csAllPktDA(u)] = PeakResponse(uTrajDA(u), csTime(trXX), win, pol);
    
    % US all (rewarded only)
    [usAllPvalDA(u,:) usAllRateDA(u,:) usAllBslnDA(u)] = ResponseAssess(spk, usTime(rwd), pR);
    [usAllPkDA{u} usAllPktDA(u)] = PeakResponse(uTrajDA(u), usTime(rwd), win, pol);
       
end



%% Identify Responsive Cells

pCrit = 0.01;
uIdx = rp;

ltGP = find(arrayfun(@(u) ~isempty(HolmBonferroni(ltPval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
goGP = find(arrayfun(@(u) ~isempty(HolmBonferroni(goPval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
siRwdGP = find(arrayfun(@(u) ~isempty(HolmBonferroni(siRwdPval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
siNoRwdGP = find(arrayfun(@(u) ~isempty(HolmBonferroni(siNoRwdPval(u,:), 'criterion', pCrit)), 1:length(uIdx)));

ltDA = find(arrayfun(@(u) ~isempty(HolmBonferroni(ltPvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
goDA = find(arrayfun(@(u) ~isempty(HolmBonferroni(goPvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
siRwdDA = find(arrayfun(@(u) ~isempty(HolmBonferroni(siRwdPvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
siNoRwdDA = find(arrayfun(@(u) ~isempty(HolmBonferroni(siNoRwdPvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));

pavGP = find(~isnan(cs0Pval(:,1)));
nPavGP = length(pavGP);
nPav25DA = length(pav25DA);
nPavAllDA = length(pavAllDA);

cs0GP = find(arrayfun(@(u) ~isempty(HolmBonferroni(cs0Pval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
cs0DA = find(arrayfun(@(u) ~isempty(HolmBonferroni(cs0PvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
cs25GP = find(arrayfun(@(u) ~isempty(HolmBonferroni(cs25Pval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
cs25DA = find(arrayfun(@(u) ~isempty(HolmBonferroni(cs25PvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
cs75GP = find(arrayfun(@(u) ~isempty(HolmBonferroni(cs75Pval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
cs75DA = find(arrayfun(@(u) ~isempty(HolmBonferroni(cs75PvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
csAllGP = find(arrayfun(@(u) ~isempty(HolmBonferroni(csAllPval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
csAllDA = find(arrayfun(@(u) ~isempty(HolmBonferroni(csAllPvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));
usAllGP = find(arrayfun(@(u) ~isempty(HolmBonferroni(usAllPval(u,:), 'criterion', pCrit)), 1:length(uIdx)));
usAllDA = find(arrayfun(@(u) ~isempty(HolmBonferroni(usAllPvalDA(u,:), 'criterion', pCrit)), 1:length(unitDA)));



%% Response Comparison: GP-RPe vs VTA-DA

fracCs0GP = length(cs0GP)/nPavGP
fracCs0DA = length(cs0DA)/nPavAllDA
pCs0GP_DA = ranksum(cellfun(@(p) mean(p), cs0Pk), cellfun(@(p) mean(p), cs0PkDA)) % all responses
ranksum(cellfun(@(p) mean(p), cs0Pk(cs0GP)), cellfun(@(p) mean(p), cs0PkDA(cs0DA))) % significant responses

fracCs25GP = length(cs25GP)/nPavGP
fracCs25DA = length(cs25DA)/nPav25DA
pCs25GP_DA = ranksum(cellfun(@(p) mean(p), cs25Pk), cellfun(@(p) mean(p), cs25PkDA)) % all responses
ranksum(cellfun(@(p) mean(p), cs25Pk(cs25GP)), cellfun(@(p) mean(p), cs25PkDA(cs25DA))) % significant responses

fracCs75GP = length(cs75GP)/nPavGP
fracCs75DA = length(cs75DA)/nPav25DA
pCs75GP_DA = ranksum(cellfun(@(p) mean(p), cs75Pk), cellfun(@(p) mean(p), cs75PkDA)) % all responses
ranksum(cellfun(@(p) mean(p), cs75Pk(cs75GP)), cellfun(@(p) mean(p), cs75PkDA(cs75DA))) % significant responses

fracUsGP = length(usAllGP)/nPavGP
fracUsDA = length(usAllDA)/nPavAllDA
pUsGP_DA = ranksum(cellfun(@(p) mean(p), usAllPk), cellfun(@(p) mean(p), usAllPkDA)) % all responses
ranksum(cellfun(@(p) mean(p), usAllPk(usAllGP)), cellfun(@(p) mean(p), usAllPkDA(usAllDA))) % significant responses

fracLtGP = length(ltGP) / length(uIdx)
fracLtDA = length(ltDA) / length(unitDA)
pLtGP_DA = ranksum(cellfun(@(p) mean(p), ltPk), cellfun(@(p) mean(p), ltPkDA)) % all responses
ranksum(cellfun(@(p) mean(p), ltPk(ltGP)), cellfun(@(p) mean(p), ltPkDA(ltDA))) % significant responses

fracGoGP = length(goGP) / length(uIdx)
fracGoDA = length(goDA) / length(unitDA)
pGoGP_DA = ranksum(cellfun(@(p) mean(p), goPk), cellfun(@(p) mean(p), goPkDA)) % all responses
ranksum(cellfun(@(p) mean(p), goPk(goGP)), cellfun(@(p) mean(p), goPkDA(goDA))) % significant responses

fracRwdGP = length(siRwdGP) / length(uIdx)
fracRwdDA = length(siRwdDA) / length(unitDA)
pRwdGP_DA = ranksum(cellfun(@(p) mean(p), siRwdPk), cellfun(@(p) mean(p), siRwdPkDA)) % all responses
ranksum(cellfun(@(p) mean(p), siRwdPk(siRwdGP)), cellfun(@(p) mean(p), siRwdPk(siRwdDA))) % significant responses

fracNoRwdGP = length(siNoRwdGP) / length(uIdx)
fracNoRwdDA = length(siNoRwdDA) / length(unitDA)
pNoRwdGP_DA = ranksum(cellfun(@(p) mean(p), siNoRwdPk), cellfun(@(p) mean(p), siNoRwdPkDA)) % all responses
ranksum(cellfun(@(p) mean(p), siNoRwdPk(siNoRwdGP)), cellfun(@(p) mean(p), siNoRwdPkDA(siNoRwdDA))) % significant responses



%% Figure 4a: Plot Peak Responses

offset = 0.2;

figure('Position', [10 100 1400 300])

% Pavlovian
subplot('Position', [0.005 0.005 0.49 0.99])
hold on

sig = cs0GP;
pavGP = find(~isnan(cs0Pkt));
notSig = setdiff(pavGP, sig);
pk = cellfun(@(p) mean(p), cs0Pk);
x = ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = cs0DA;
notSig = setdiff(pav25DA, sig);
pkDA = cellfun(@(p) mean(p), cs0PkDA);
x = ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
cs0comparePval = ranksum(pk, pkDA)

sig = cs25GP;
notSig = setdiff(pavGP, sig);
pk = cellfun(@(p) mean(p), cs25Pk);
x = 2*ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)

sig = cs25DA;
notSig = setdiff(pav25DA, sig);
pkDA = cellfun(@(p) mean(p), cs25PkDA);
x = 2*ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
cs25comparePval = ranksum(pk, pkDA)

sig = cs75GP;
notSig = setdiff(pavGP, sig);
pk = cellfun(@(p) mean(p), cs75Pk);
x = 3*ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = cs75DA;
notSig = setdiff(pav25DA, sig);
pkDA = cellfun(@(p) mean(p), cs75PkDA);
x = 3*ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pkDA = pkDA(sig);
cs75comparePval = ranksum(pk, pkDA)

sig = usAllGP;
notSig = setdiff(pavGP, sig);
pk = cellfun(@(p) mean(p), usAllPk);
x = 4*ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = usAllDA;
notSig = setdiff(pavAllDA, sig);
pkDA = cellfun(@(p) mean(p), usAllPkDA);
x = 4*ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pkDA = pkDA(sig);
ranksum(pk, pkDA)
usComparePval = ranksum(pk, pkDA)

plot([0.5 4.5], [0 0], 'k', 'linewidth', 1)
xlim([0.5 4.5])
ylim
yR = [-22 95]
ylim(yR)
xT = -20:20:80;
set(gca, 'YTick', xT)
set(gca, 'XTick', [])
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')

% RL
subplot('Position', [0.505 0.005 0.49 0.99])
hold on

sig = ltGP;
notSig = setdiff(1:length(uIdx), sig);
pk = cellfun(@(p) mean(p), ltPk);
x = ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = ltDA;
notSig = setdiff(1:length(unitDA), sig);
pkDA = cellfun(@(p) mean(p), ltPkDA);
x = ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pkDA = pkDA(sig);
ltComparePval = ranksum(pk, pkDA)

sig = goGP;
notSig = setdiff(1:length(uIdx), sig);
pk = cellfun(@(p) mean(p), goPk);
x = 2*ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = goDA;
notSig = setdiff(1:length(unitDA), sig);
pkDA = cellfun(@(p) mean(p), goPkDA);
x = 2*ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pkDA = pkDA(sig);
goComparePval = ranksum(pk, pkDA)

sig = siRwdGP;
notSig = setdiff(1:length(uIdx), sig);
pk = cellfun(@(p) mean(p), siRwdPk);
x = 3*ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = siRwdDA;
notSig = setdiff(1:length(unitDA), sig);
pkDA = cellfun(@(p) mean(p), siRwdPkDA);
x = 3*ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pkDA = pkDA(sig);
ranksum(pk, pkDA)
siRwdComparePval = ranksum(pk, pkDA)

sig = siNoRwdGP;
notSig = setdiff(1:length(uIdx), sig);
pk = cellfun(@(p) mean(p), siNoRwdPk);
x = 4*ones(size(pk));
scatter(x(notSig)-offset, pk(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)-offset, pk(sig), 100, [0.7 0 0], 'filled')
plot(x(1)+[-2*offset 0], median(pk(sig))*[1 1], 'color', [0.7 0 0], 'linewidth', 3)
q25 = quantile(pk(sig), 0.25);
q75 = quantile(pk(sig), 0.75);
plot(x(1)+[-1.5*offset -0.5*offset], [q25 q25], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -0.5*offset], [q75 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-1.5*offset -1.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
plot(x(1)+[-0.5*offset -0.5*offset], [q25 q75], 'color', [0.7 0 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pk = pk(sig);

sig = siNoRwdDA;
notSig = setdiff(1:length(unitDA), sig);
pkDA = cellfun(@(p) mean(p), siNoRwdPkDA);
x = 4*ones(size(pkDA));
scatter(x(notSig)+offset, pkDA(notSig), 90, 'k', 'linewidth', 1)
scatter(x(sig)+offset, pkDA(sig), 100, [0 0.7 0], 'filled')
plot(x(1)+[+2*offset 0], median(pkDA(sig))*[1 1], 'color', [0 0.7 0], 'linewidth', 3)
q25 = quantile(pkDA(sig), 0.25);
q75 = quantile(pkDA(sig), 0.75);
plot(x(1)+[0.5*offset 1.5*offset], [q25 q25], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 1.5*offset], [q75 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[0.5*offset 0.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
plot(x(1)+[1.5*offset 1.5*offset], [q25 q75], 'color', [0 0.7 0], 'linewidth', 1)
length(sig)/(length(sig)+length(notSig))
pkDA = pkDA(sig);
siNoRwdComparePval = ranksum(pk, pkDA)

plot([0.5 4.5], [0 0], 'k', 'linewidth', 1)
xlim([0.5 4.5])
ylim
ylim(yR)
set(gca, 'YTick', xT)
set(gca, 'XTick', [])
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')





%% Figure 4b: RPE Coding (RL and Pav)

uIdx = rp;
unitTmp = unit(uIdx);
mPosRpeGP = zeros(1, length(uIdx));
pPosRpeGP = zeros(1, length(uIdx));
rPosRpeGP = zeros(1, length(uIdx));
mNegRpeGP = zeros(1, length(uIdx));
pNegRpeGP = zeros(1, length(uIdx));
rNegRpeGP = zeros(1, length(uIdx));
for u = 1:length(uIdx)
    [~, rlIdx] = ismember('RL', unitTmp(u).taskList);
    ts = unitTmp(u).behav_ts{rlIdx};
    [~, iSes] = ismember(uSes{rp(u)}, sesList);
    rr = rwdRate{iSes};
    fr = siRwdPk{u};
    rwd = TrialFilter(ts, 'x1', unitTmp(u).side);
    sel = find(rwd > 10);
    lm = fitlm(rr(rwd(sel)), fr(sel));
    mPosRpeGP(u) = lm.Coefficients.Estimate(2);
    pPosRpeGP(u) = lm.Coefficients.pValue(2);
    rPosRpeGP(u) = lm.Rsquared.Ordinary;
    
    noRwd = TrialFilter(ts, 'x0', unitTmp(u).side);
    fr = siNoRwdPk{u};
    sel = find(noRwd > 10);
    lm = fitlm(rr(noRwd(sel)), fr(sel));
    mNegRpeGP(u) = lm.Coefficients.Estimate(2);
    pNegRpeGP(u) = lm.Coefficients.pValue(2);
    rNegRpeGP(u) = lm.Rsquared.Ordinary;
    
end

mPosRpeDA = zeros(1, length(unitDA));
pPosRpeDA = zeros(1, length(unitDA));
rPosRpeDA = zeros(1, length(unitDA));
mNegRpeDA = zeros(1, length(unitDA));
pNegRpeDA = zeros(1, length(unitDA));
rNegRpeDA = zeros(1, length(unitDA));
for u = 1:length(unitDA)
    [~, rlIdx] = ismember('RL', unitDA(u).taskList);
    ts = unitDA(u).behav_ts{rlIdx};
    rr = rwdRateDA{u};
    fr = siRwdPkDA{u};
    rwd = TrialFilter(ts, 'x1', unitDA(u).side);
    sel = find(rwd > 10);
    lm = fitlm(rr(rwd(sel)), fr(sel));
    mPosRpeDA(u) = lm.Coefficients.Estimate(2);
    pPosRpeDA(u) = lm.Coefficients.pValue(2);
    rPosRpeDA(u) = lm.Rsquared.Ordinary;
    
    noRwd = TrialFilter(ts, 'x0', unitDA(u).side);
    fr = siNoRwdPkDA{u};
    sel = find(noRwd > 10);
    lm = fitlm(rr(noRwd(sel)), fr(sel));
    mNegRpeDA(u) = lm.Coefficients.Estimate(2);
    pNegRpeDA(u) = lm.Coefficients.pValue(2);
    rNegRpeDA(u) = lm.Rsquared.Ordinary;
    
end

uIdx = rp;
rpPav = [];
unitTmp = unit(uIdx);
mUsGP = [];
pUsGP = [];
rUsGP = [];
mCsGP = [];
pCsGP = [];
rCsGP = [];
for u = 1:length(uIdx)
    [pav, pavIdx] = ismember('Pav', unitTmp(u).taskList);
    if ~pav
        continue
    end
    rpPav = [rpPav u];
    fr25 = cs25Pk{u};
    fr75 = cs75Pk{u};
    probRwd = [0.25*ones(size(fr25)); 0.75*ones(size(fr75))];
    lm = fitlm(probRwd, [fr25; fr75]);
    mCsGP = [mCsGP lm.Coefficients.Estimate(2)];
    pCsGP = [pCsGP lm.Coefficients.pValue(2)];
    rCsGP = [rCsGP lm.Rsquared.Ordinary];
        
    fr25 = us25rPk{u};
    fr75 = us75rPk{u};
    probRwd = [0.25*ones(size(fr25)); 0.75*ones(size(fr75))];
    lm = fitlm(probRwd, [fr25; fr75]);
    mUsGP = [mUsGP lm.Coefficients.Estimate(2)];
    pUsGP = [pUsGP lm.Coefficients.pValue(2)];
    rUsGP = [rUsGP lm.Rsquared.Ordinary]; 
end

mUsDA = [];
pUsDA = [];
rUsDA = [];
mCsDA = [];
pCsDA = [];
rCsDA = [];
for u = pav25DA
    fr25 = cs25PkDA{u};
    fr75 = cs75PkDA{u};
    probRwd = [0.25*ones(size(fr25)); 0.75*ones(size(fr75))];
    lm = fitlm(probRwd, [fr25; fr75]);
    mCsDA = [mCsDA lm.Coefficients.Estimate(2)]
    pCsDA = [pCsDA lm.Coefficients.pValue(2)];
    rCsDA = [rCsDA lm.Rsquared.Ordinary];
        
    fr25 = us25rPkDA{u};
    fr75 = us75rPkDA{u};
    probRwd = [0.25*ones(size(fr25)); 0.75*ones(size(fr75))];
    lm = fitlm(probRwd, [fr25; fr75]);
    mUsDA = [mUsDA lm.Coefficients.Estimate(2)];
    pUsDA = [pUsDA lm.Coefficients.pValue(2)];
    rUsDA = [rUsDA lm.Rsquared.Ordinary]; 
end

% check correlation between mUs and mPosRpe
[r p] = corr(mUsDA', mPosRpeDA(pav25DA)');  % r = 0.6818, p = 0.0299
[r p] = corr(mUsGP', mPosRpeGP(rpPav)');    % r = 0.5175; p = 6.3953e-7
rpPav

pCrit = 0.05;
figure('Position', [10 100 1400 300])

% Pav CS
subplot('Position', [0.005 0.005 0.23 0.99])
hold on
sig = find(pCsGP < pCrit);
notSig = find(pCsGP >= pCrit);
scatter(rCsGP(notSig), mCsGP(notSig), 90, [0.7 0 0], 'linewidth', 1)
scatter(rCsGP(sig), mCsGP(sig), 100, [0.7 0 0], 'filled')
sigDA = find(pCsDA < pCrit);
notSigDA = find(pCsDA >= pCrit);
scatter(rCsDA(notSigDA), mCsDA(notSigDA), 90, [0 0.7 0], 'linewidth', 1)
scatter(rCsDA(sigDA), mCsDA(sigDA), 100, [0 0.7 0], 'filled')
yR = [-90 90];
xR = [0 0.8];
yT = -80:40:80;
xT = [0.2:0.2:0.6];
ylim(yR)
xlim(xR)
plot(xlim, [0 0], 'k', 'linewidth', 1)
set(gca, 'Box', 'on')
set(gca, 'YTick', yT)
set(gca, 'XTick', xT)
set(gca, 'YTickLabels', [])
fracCsGP = length(sig)/length(pCsGP)
fracCsDA = length(sigDA)/length(pCsDA)

% Pav US
subplot('Position', [0.245 0.005 0.23 0.99])
hold on
sig = find(pUsGP < pCrit);
notSig = find(pUsGP >= pCrit);
scatter(rUsGP(notSig), mUsGP(notSig), 90, [0.7 0 0], 'linewidth', 1)
scatter(rUsGP(sig), mUsGP(sig), 100, [0.7 0 0], 'filled')
sigDA = find(pUsDA < pCrit);
notSigDA = find(pUsDA >= pCrit);
scatter(rUsDA(notSigDA), mUsDA(notSigDA), 90, [0 0.7 0], 'linewidth', 1)
scatter(rUsDA(sigDA), mUsDA(sigDA), 100, [0 0.7 0], 'filled')
ylim(yR)
xlim(xR)
plot(xlim, [0 0], 'k', 'linewidth', 1)
set(gca, 'Box', 'on')
set(gca, 'YTick', yT)
set(gca, 'XTick', xT)
set(gca, 'YTickLabels', [])
fracUsGP = length(sig)/length(pUsGP)
fracUsDA = length(sigDA)/length(pUsDA)

% RL +RPE
subplot('Position', [0.525 0.005 0.23 0.99])
hold on
sig = find(pPosRpeGP < pCrit);
notSig = find(pPosRpeGP >= pCrit);
scatter(rPosRpeGP(notSig), mPosRpeGP(notSig), 90, [0.7 0 0], 'linewidth', 1)
scatter(rPosRpeGP(sig), mPosRpeGP(sig), 100, [0.7 0 0], 'filled')
sigDA = find(pPosRpeDA < pCrit);
notSigDA = find(pPosRpeDA >= pCrit);
scatter(rPosRpeDA(notSigDA), mPosRpeDA(notSigDA), 90, [0 0.7 0], 'linewidth', 1)
scatter(rPosRpeDA(sigDA), mPosRpeDA(sigDA), 100, [0 0.7 0], 'filled')
ylim
xlim
yR = [-10 3];
xR = [0 0.35];
ylim(yR);
xlim(xR);
yT = [-9 -6 -3 0 3];
xT = [0.1 0.2 0.3];
plot(xlim, [0 0], 'k', 'linewidth', 1)
set(gca, 'Box', 'on')
set(gca, 'YTick', yT)
set(gca, 'XTick', xT)
set(gca, 'YTickLabels', [])
fracPosRpeGP = length(sig)/length(pPosRpeGP)
fracPosRpeDA = length(sigDA)/length(pPosRpeDA)

% RL -RPE
subplot('Position', [0.765 0.005 0.23 0.99])
hold on
sig = find(pNegRpeGP < pCrit);
notSig = find(pNegRpeGP >= pCrit);
scatter(rNegRpeGP(notSig), mNegRpeGP(notSig), 90, [0.7 0 0], 'linewidth', 1)
scatter(rNegRpeGP(sig), mNegRpeGP(sig), 100, [0.7 0 0], 'filled')
sigDA = find(pNegRpeDA < pCrit);
notSigDA = find(pNegRpeDA >= pCrit);
scatter(rNegRpeDA(notSigDA), mNegRpeDA(notSigDA), 90, [0 0.7 0], 'linewidth', 1)
scatter(rNegRpeDA(sigDA), mNegRpeDA(sigDA), 100, [0 0.7 0], 'filled')
ylim
xlim
ylim(yR)
xlim(xR)
plot(xlim, [0 0], 'k', 'linewidth', 1)
set(gca, 'Box', 'on')
set(gca, 'YTick', yT)
set(gca, 'XTick', xT)
set(gca, 'YTickLabels', [])
fracNegRpeGP = length(sig)/length(pNegRpeGP)
fracNegRpeDA = length(sigDA)/length(pNegRpeDA)




%% Latency Measurement Parameters

pL.pCrit = 0.1;
pL.binCrit = 3;         % number of consecutive bins that must be significant to trigger latency measure
pL.bslnWin = [-0.1 0];  % baseline window
pL.binWidth = 0.002;    % response bin width
pL.dt = 0.002;          % response bin interval (latency measure resolution)
pL.minLat = 0.002;      % minimum allowable response latency
pL.maxLat = 0.25;       % maximum allowable response latency
pL.responsePolarity = 1;


%% Assess Response Polarity (Latency Measurements Restricted to Excitatory Responses)

uIdx = rp;
ltPol = zeros(1, length(uIdx));
goPol = zeros(1, length(uIdx));
siPol = zeros(1, length(uIdx));
csPol = zeros(1, length(uIdx));
usPol = zeros(1, length(uIdx));

for u = ltGP
    ltPol(u) = sign(mean(ltRate(u,:)) - ltBsln(u));   
end
for u = goGP
    goPol(u) = sign(mean(goRate(u,:)) - goBsln(u));
end
for u = siRwdGP
    siPol(u) = sign(mean(siRwdRate(u,:)) - siRwdBsln(u));
end
for u = csAllGP
    csPol(u) = sign(mean(csAllRate(u,:)) - csAllBsln(u));
end
for u = usAllGP
    usPol(u) = sign(mean(usAllRate(u,:)) - usAllBsln(u));
end

ltPolDA = zeros(1, length(unitDA));
goPolDA = zeros(1, length(unitDA));
siPolDA = zeros(1, length(unitDA));
csPolDA = zeros(1, length(unitDA));
usPolDA = zeros(1, length(unitDA));

for u = ltDA
    ltPolDA(u) = sign(mean(ltRateDA(u,:)) - ltBslnDA(u));   
end
for u = goDA
    goPolDA(u) = sign(mean(goRateDA(u,:)) - goBslnDA(u));
end
for u = siRwdDA
    siPolDA(u) = sign(mean(siRwdRateDA(u,:)) - siRwdBslnDA(u));
end
for u = csAllDA
    csPolDA(u) = sign(mean(csAllRateDA(u,:)) - csAllBslnDA(u));
end
for u = usAllDA
    usPolDA(u) = sign(mean(usAllRateDA(u,:)) - usAllBslnDA(u));
end



%% Response Latency (GPe, RL)

latLt = nan(1, length(uIdx));
latGo = nan(1, length(uIdx));
latSi = nan(1, length(uIdx));

for u = 1:length(unitTmp)
    
    t1 = unitTmp(u).taskStart(rlIdx);
    t2 = unitTmp(u).taskEnd(rlIdx);
    ts = unitTmp(u).behav_ts{rlIdx};
    spk = unitTmp(u).spkTimes(unitTmp(u).spkTimes>t1 & unitTmp(u).spkTimes<t2) - t1;
    cniLat = BehaviorTimes(ts);
    rwd = TrialFilter(ts, 'x1', unitTmp(u).side);
    
    % light on latency
    eTime = ts.trialbegin(cniLat < latCrit);
    latLt(u) = ResponseLatency(spk, eTime, pL);
     
    % go cue latency
    eTime = ts.go;
    latGo(u) = ResponseLatency(spk, eTime, pL);
    
    % side in latency
    eTime = ts.Side_NI(rwd);
    latSi(u) = ResponseLatency(spk, eTime, pL);  
    
end


%% Response Latency (VTA-DA, RL)

latLtDA = nan(1, length(unitDA));
latGoDA = nan(1, length(unitDA));
latSiDA = nan(1, length(unitDA));

for u = 1:length(unitDA)
    
    [~, rlIdx] = ismember('RL', unitDA(u).taskList);
    t1 = unitDA(u).taskStart(rlIdx);
    t2 = unitDA(u).taskEnd(rlIdx);
    ts = unitDA(u).behav_ts{rlIdx};
    spk = unitDA(u).spkTimes(unitDA(u).spkTimes>t1 & unitDA(u).spkTimes<t2) - t1;
    cniLat = BehaviorTimes(ts);
    rwd = TrialFilter(ts, 'x1', unitDA(u).side);
    
    % light on latency
    eTime = ts.trialbegin(cniLat < latCrit);
    latLtDA(u) = ResponseLatency(spk, eTime, pL);
    
    % go cue latency
    eTime = ts.go;
    latGoDA(u) = ResponseLatency(spk, eTime, pL);
    
    % side in latency
    eTime = ts.Side_NI(rwd);
    latSiDA(u) = ResponseLatency(spk, eTime, pL);
       
end



%% Response Latency (GPe, Pav)

latCs = nan(1, length(uIdx));
latUs = nan(1, length(uIdx));

for u = 1:length(unitTmp)
    
    [pav, pavIdx] = ismember('Pav', unitTmp(u).taskList);
    if ~pav
        continue
    end
    t1 = unitTmp(u).taskStart(pavIdx);
    t2 = unitTmp(u).taskEnd(pavIdx);
    ts = unitTmp(u).behav_ts{pavIdx};
    lg = unitTmp(u).behav_log{pavIdx};
    spk = unitTmp(u).spkTimes(unitTmp(u).spkTimes>t1 & unitTmp(u).spkTimes<t2) - t1;
    us = find(lg.outcome);
    cs = find(lg.toneFreq ~= 0);
    
    % CS latency
    eTime = ts.csTime(cs);
    latCs(u) = ResponseLatency(spk, eTime, pL);
    
    % US latency
    eTime = ts.rwdTime(us);
    latUs(u) = ResponseLatency(spk, eTime, pL);
    
end


%% Response Latency (VTA-DA, Pav)

latCsDA = nan(1, length(pavAllDA));
latUsDA = nan(1, length(pavAllDA));

for u = 1:length(pavAllDA)
    
    [pav, pavIdx] = ismember('Pav', unitDA(pavAllDA(u)).taskList);
    t1 = unitDA(pavAllDA(u)).taskStart(pavIdx);
    t2 = unitDA(pavAllDA(u)).taskEnd(pavIdx);
    ts = unitDA(pavAllDA(u)).behav_ts{pavIdx};
    lg = unitDA(pavAllDA(u)).behav_log{pavIdx};
    spk = unitDA(pavAllDA(u)).spkTimes(unitDA(pavAllDA(u)).spkTimes>t1 & unitDA(pavAllDA(u)).spkTimes<t2) - t1;
    us = find(lg.outcome);
    cs = find(lg.toneFreq ~= 0);
    
    % CS latency
    eTime = ts.csTime(cs);
    latCsDA(u) = ResponseLatency(spk, eTime, pL);
    
    % US latency
    eTime = ts.rwdTime(us);
    latUsDA(u) = ResponseLatency(spk, eTime, pL);
    
end


%% Figure 4c: Response Latencies

str = ['p=' num2str(pL.pCrit) ', n=' num2str(pL.binCrit) ', w=' num2str(round(pL.binWidth*1000)) ' ms'];
figure('Position', [10 100 1400 300], 'NumberTitle', 'off', 'name', str)

subplot('Position', [0.005 0.005 0.19 0.99])
hold on
goodLat = find(~isnan(latCs));
excite = find(csPol > 0);
latGP = latCs(intersect(goodLat, excite));
goodLat = find(~isnan(latCsDA));
excite = find(csPolDA > 0);
latDA = latCsDA(intersect(goodLat, excite));
stairs(1000*[min(latGP) sort(latGP)], (0:length(latGP)) / length(latGP), 'color', [0.7 0 0], 'linewidth', 2)
stairs(1000*[min(latDA) sort(latDA)], (0:length(latDA)) / length(latDA), 'color', [0 0.7 0], 'linewidth', 2)
xlim([0 150])
set(gca, 'Box', 'on')
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'YTickLabels', [])
set(gca, 'XTick', [0 50 100 150])
set(gca, 'XTickLabels', [])
pLatCs = ranksum(latGP, latDA) % NS, p = 0.9733
[mean(latGP) mean(latDA)]
%  0.0677      0.0671
[median(latGP) median(latDA)]
%   0.0640        0.0700

subplot('Position', [0.202 0.005 0.19 0.99])
hold on
goodLat = find(~isnan(latUs));
excite = find(usPol > 0);
latGP = latUs(intersect(goodLat, excite));
goodLat = find(~isnan(latUsDA));
excite = find(usPolDA > 0);
latDA = latUsDA(intersect(goodLat, excite));
stairs(1000*[min(latGP) sort(latGP)], (0:length(latGP)) / length(latGP), 'color', [0.7 0 0], 'linewidth', 2)
stairs(1000*[min(latDA) sort(latDA)], (0:length(latDA)) / length(latDA), 'color', [0 0.7 0], 'linewidth', 2)
xlim([0 150])
set(gca, 'Box', 'on')
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'YTickLabels', [])
set(gca, 'XTick', [0 50 100 150])
set(gca, 'XTickLabels', [])
pLatUs = ranksum(latGP, latDA) % NS, p = 0.0619
[mean(latGP) mean(latDA)]
%  0.0667      0.0599
[median(latGP) median(latDA)]
%   0.0640        0.0600

subplot('Position', [0.411 0.005 0.19 0.99])
hold on
goodLat = find(~isnan(latLt));
excite = find(ltPol > 0);
latGP = latLt(intersect(goodLat, excite));
length(latGP)/length(ltGP)
goodLat = find(~isnan(latLtDA));
excite = find(ltPolDA > 0);
latDA = latLtDA(intersect(goodLat, excite));
length(latDA)/length(ltDA)
stairs(1000*[min(latGP) sort(latGP)], (0:length(latGP)) / length(latGP), 'color', [0.7 0 0], 'linewidth', 2)
stairs(1000*[min(latDA) sort(latDA)], (0:length(latDA)) / length(latDA), 'color', [0 0.7 0], 'linewidth', 2)
set(gca, 'Box', 'on')
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'YTickLabels', [])
set(gca, 'XTick', [0 100 200])
set(gca, 'XTickLabels', [])
xlim([0 250])
pLatLt = ranksum(latGP, latDA) % sig, p = 0.0194
[mean(latGP) mean(latDA)]
%  0.1442      0.1196
[std(latGP) std(latDA)]
%  0.0543      0.0316
[median(latGP) median(latDA)]
%   0.1560        0.1200

subplot('Position', [0.608 0.005 0.19 0.99])
hold on
goodLat = find(~isnan(latGo));
excite = find(goPol > 0);
latGP = latGo(intersect(goodLat, excite));
length(latGP)/length(goGP)
goodLat = find(~isnan(latGoDA));
excite = find(goPolDA > 0);
latDA = latGoDA(intersect(goodLat, excite));
length(latDA)/length(goDA)
stairs(1000*[min(latGP) sort(latGP)], (0:length(latGP)) / length(latGP), 'color', [0.7 0 0], 'linewidth', 2)
stairs(1000*[min(latDA) sort(latDA)], (0:length(latDA)) / length(latDA), 'color', [0 0.7 0], 'linewidth', 2)
xlim([0 150])
set(gca, 'Box', 'on')
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'YTickLabels', [])
set(gca, 'XTick', [0 50 100 150])
set(gca, 'XTickLabels', [])
pLatGo = ranksum(latGP, latDA) % sig, p = 0.0068
[mean(latGP) mean(latDA)]
%  0.0440      0.0559
[std(latGP) std(latDA)]
%  0.0169      0.0192
[median(latGP) median(latDA)]
%   0.0430        0.0520

subplot('Position', [0.805 0.005 0.19 0.99])
hold on
goodLat = find(~isnan(latSi));
excite = find(siPol > 0);
latGP = latSi(intersect(goodLat, excite));
goodLat = find(~isnan(latSiDA));
excite = find(siPolDA > 0);
latDA = latSiDA(intersect(goodLat, excite));
stairs(1000*[min(latGP) sort(latGP)], (0:length(latGP)) / length(latGP), 'color', [0.7 0 0], 'linewidth', 2)
stairs(1000*[min(latDA) sort(latDA)], (0:length(latDA)) / length(latDA), 'color', [0 0.7 0], 'linewidth', 2)
xlim([0 250])
set(gca, 'Box', 'on')
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'YTickLabels', [])
set(gca, 'XTick', [0 100 200])
set(gca, 'XTickLabels', [])
pLatSi = ranksum(latGP, latDA)

% stats for paper text
% CS--  GP: 67.7 ms,    DA: 67.1 ms,    p = 0.973
% US--  GP: 66.7 ms,    DA: 59.9 ms,    p = 0.062
% LT--  GP: 144.2 ms,   DA: 119.6 ms,   p = 0.019   *
% GO--  GP: 44.0 ms,    DA: 55.9 ms,    p = 0.007   *
% SI--  GP: 84.6 ms,    DA: 77.4 ms,    p = 0.15


%% Figure 4d

pavGP = find(~isnan(cs0Pkt));

% Pavlovian peak data
pkCs0_GP = cellfun(@(p) mean(p), cs0Pk);
pkCs0_GP_sig = cs0GP;
pkCs0_GP_notSig = setdiff(pavGP, cs0GP);
pkCs0_DA = cellfun(@(p) mean(p), cs0PkDA);
pkCs0_DA_sig = cs0DA;
pkCs0_DA_notSig = setdiff(1:length(unitDA), cs0DA);
pkCs25_GP = cellfun(@(p) mean(p), cs25Pk);
pkCs25_GP_sig = cs25GP;
pkCs25_GP_notSig = setdiff(pavGP, cs25GP);
pkCs25_DA = cellfun(@(p) mean(p), cs25PkDA);
pkCs25_DA_sig = cs25DA;
pkCs25_DA_notSig = setdiff(pav25DA, cs25DA);
pkCs75_GP = cellfun(@(p) mean(p), cs75Pk);
pkCs75_GP_sig = cs75GP;
pkCs75_GP_notSig = setdiff(pavGP, cs75GP);
pkCs75_DA = cellfun(@(p) mean(p), cs75PkDA);
pkCs75_DA_sig = cs75DA;
pkCs75_DA_notSig = setdiff(pav25DA, cs75DA);
pkCsAll_GP = cellfun(@(p) mean(p), csAllPk);
pkCsAll_GP_sig = csAllGP;
pkCsAll_GP_notSig = setdiff(pavGP, csAllGP);
pkCsAll_DA = cellfun(@(p) mean(p), csAllPkDA);
pkCsAll_DA_sig = csAllDA;
pkCsAll_DA_notSig = setdiff(1:length(unitDA), csAllDA);
pkUs_GP = cellfun(@(p) mean(p), usAllPk);
pkUs_GP_sig = usAllGP;
pkUs_GP_notSig = setdiff(pavGP, usAllGP);
pkUs_DA = cellfun(@(p) mean(p), usAllPkDA);
pkUs_DA_sig = usAllDA;
pkUs_DA_notSig = setdiff(1:length(unitDA), usAllDA);

% RL peak data
pkLt_GP = cellfun(@(p) mean(p), ltPk);
pkLt_GP_sig = ltGP;
pkLt_GP_notSig = setdiff(1:length(rp), ltGP);
pkLt_DA = cellfun(@(p) mean(p), ltPkDA);
pkLt_DA_sig = ltDA;
pkLt_DA_notSig = setdiff(1:length(unitDA), ltDA);
pkGo_GP = cellfun(@(p) mean(p), goPk);
pkGo_GP_sig = goGP;
pkGo_GP_notSig = setdiff(1:length(rp), goGP);
pkGo_DA = cellfun(@(p) mean(p), goPkDA);
pkGo_DA_sig = goDA;
pkGo_DA_notSig = setdiff(1:length(unitDA), goDA);
pkSi_GP = cellfun(@(p) mean(p), siRwdPk);
pkSi_GP_sig = siRwdGP;
pkSi_GP_notSig = setdiff(1:length(rp), siRwdGP);
pkSi_DA = cellfun(@(p) mean(p), siRwdPkDA);
pkSi_DA_sig = siRwdDA;
pkSi_DA_notSig = setdiff(1:length(unitDA), siRwdDA);

% Pavlovian RPE slopes
mCs_GP = nan(1, length(rp));
mCs_GP(pavGP) = mCsGP;
mCs_GP_sig = pavGP(find(pCsGP < 0.05));
mCs_GP_notSig = pavGP(find(pCsGP >= 0.05));
mCs_DA = nan(1, length(unitDA));
mCs_DA(pav25DA) = mCsDA;
mCs_DA_sig = pav25DA(find(pCsDA < 0.05));
mCs_DA_notSig = pav25DA(find(pCsDA >= 0.05));
mUs_GP = nan(1, length(rp));
mUs_GP(pavGP) = mUsGP;
mUs_GP_sig = pavGP(find(pUsGP < 0.05));
mUs_GP_notSig = pavGP(find(pUsGP >= 0.05));
mUs_DA = nan(1, length(unitDA));
mUs_DA(pav25DA) = mUsDA;
mUs_DA_sig = pav25DA(find(pUsDA < 0.05));
mUs_DA_notSig = pav25DA(find(pUsDA >= 0.05));

% RL RPE slopes
mSi_GP = mPosRpeGP;
mSi_GP_sig = find(pPosRpeGP < 0.05);
mSi_GP_notSig = find(pPosRpeGP >= 0.05);
mSi_DA = mPosRpeDA;
mSi_DA_sig = find(pPosRpeDA < 0.05);
mSi_DA_notSig = find(pPosRpeDA >= 0.05);

% Pav
Cs0_GP = intersect(pkCs0_GP_sig, find(pkCs0_GP > 0)); nCs0_GP = setdiff(pavGP, Cs0_GP);
Cs25_GP = intersect(pkCs25_GP_sig, find(pkCs25_GP > 0)); nCs25_GP = setdiff(pavGP, Cs25_GP);
Cs75_GP = intersect(pkCs75_GP_sig, find(pkCs75_GP > 0)); nCs75_GP = setdiff(pavGP, Cs75_GP);
Cs2575_GP = union(Cs25_GP, Cs75_GP); nCs2575_GP = setdiff(pavGP, Cs2575_GP);
Cs_GP = intersect(pkCsAll_GP_sig, find(pkCsAll_GP > 0)); nCs_GP = setdiff(pavGP, Cs_GP);
Us_GP = intersect(pkUs_GP_sig, find(pkUs_GP > 0)); nUs_GP = setdiff(pavGP, Us_GP);

Cs0_DA = intersect(pkCs0_DA_sig, find(pkCs0_DA > 0)); nCs0_DA = setdiff(1:length(unitDA), Cs0_DA);
Cs25_DA = intersect(pkCs25_DA_sig, find(pkCs25_DA > 0)); nCs25_DA = setdiff(pav25DA, Cs25_DA);
Cs75_DA = intersect(pkCs75_DA_sig, find(pkCs75_DA > 0)); nCs75_DA = setdiff(pav25DA, Cs75_DA);
Cs2575_DA = union(Cs25_DA, Cs75_DA); nCs2575_DA = setdiff(pav25DA, Cs2575_DA);
Cs_DA = intersect(pkCsAll_DA_sig, find(pkCsAll_DA > 0)); nCs_DA = setdiff(1:length(unitDA), Cs_DA);
Us_DA = intersect(pkUs_DA_sig, find(pkUs_DA > 0)); nUs_DA = setdiff(1:length(unitDA), Us_DA);

nr_Pav_GP = intersect(nCs_GP, nUs_GP);
CsOnly_GP = intersect(Cs_GP, nUs_GP);
Cs0Only_GP = intersect(Cs0_GP, intersect(nUs_GP, nCs2575_GP));
Cs25Only_GP = intersect(Cs25_GP, intersect(nUs_GP, intersect(nCs0_GP, nCs75_GP)));
Cs75Only_GP = intersect(Cs75_GP, intersect(nUs_GP, intersect(nCs0_GP, nCs25_GP)));
Cs2575Only_GP = intersect(Cs2575_GP, intersect(nCs0_GP, nUs_GP));
UsOnly_GP = intersect(Us_GP, nCs_GP);
all_Pav_GP = intersect(Cs_GP, Us_GP);

nr_Pav_DA = intersect(nCs_DA, nUs_DA);
CsOnly_DA = intersect(Cs_DA, nUs_DA);
Cs0Only_DA = intersect(Cs0_DA, intersect(nUs_DA, nCs2575_DA));
Cs25Only_DA = intersect(Cs25_DA, intersect(nUs_DA, intersect(nCs0_DA, nCs75_DA)));
Cs75Only_DA = intersect(Cs75_DA, intersect(nUs_DA, intersect(nCs0_DA, nCs25_DA)));
Cs2575Only_DA = intersect(Cs2575_DA, intersect(nCs0_DA, nUs_DA));
UsOnly_DA = intersect(Us_DA, nCs_DA);
all_Pav_DA = intersect(Cs_DA, Us_DA);

% proportion coding Pav elements (CS, US)
Pav_GP_0 = length(nr_Pav_GP) / length(pavGP)
Pav_GP_Cs = length(CsOnly_GP) / length(pavGP)
Pav_GP_Us = length(UsOnly_GP) / length(pavGP)
Pav_GP_2 = length(all_Pav_GP) / length(pavGP)
% Pav_GP_1 = length([CsOnly_GP UsOnly_GP]) / length(pavGP)

Pav_DA_0 = length(nr_Pav_DA) / length(unitDA)
Pav_DA_Cs = length(CsOnly_DA) / length(unitDA)
Pav_DA_Us = length(UsOnly_DA) / length(unitDA)
Pav_DA_2 = length(all_Pav_DA) / length(unitDA)
% Pav_DA_1 = length([CsOnly_DA UsOnly_DA])/length(unitDA)

% RL 
Lt_GP = intersect(pkLt_GP_sig, find(pkLt_GP > 0)); nLt_GP = setdiff(1:length(rp), Lt_GP);
Go_GP = intersect(pkGo_GP_sig, find(pkGo_GP > 0)); nGo_GP = setdiff(1:length(rp), Go_GP);
Si_GP = intersect(pkSi_GP_sig, find(pkSi_GP > 0)); nSi_GP = setdiff(1:length(rp), Si_GP);

nr_RL_GP = intersect(intersect(nLt_GP,nGo_GP), nSi_GP);
LtOnly_GP = intersect(Lt_GP, intersect(nGo_GP, nSi_GP));
GoOnly_GP = intersect(Go_GP, intersect(nLt_GP, nSi_GP));
SiOnly_GP = intersect(Si_GP, intersect(nGo_GP, nLt_GP));
LtGo_GP = intersect(intersect(Lt_GP, Go_GP), nSi_GP);
LtSi_GP = intersect(intersect(Lt_GP, Si_GP), nGo_GP);
SiGo_GP = intersect(intersect(Si_GP, Go_GP), nLt_GP);
all_RL_GP = intersect(intersect(Lt_GP, Go_GP), Si_GP);

Lt_DA = intersect(pkLt_DA_sig, find(pkLt_DA > 0)); nLt_DA = setdiff(1:length(unitDA), Lt_DA);
Go_DA = intersect(pkGo_DA_sig, find(pkGo_DA > 0)); nGo_DA = setdiff(1:length(unitDA), Go_DA);
Si_DA = intersect(pkSi_DA_sig, find(pkSi_DA > 0)); nSi_DA = setdiff(1:length(unitDA), Si_DA);

nr_RL_DA = intersect(intersect(nLt_DA, nGo_DA), nSi_DA);
LtOnly_DA = intersect(Lt_DA, intersect(nGo_DA, nSi_DA));
GoOnly_DA = intersect(Go_DA, intersect(nLt_DA, nSi_DA));
SiOnly_DA = intersect(Si_DA, intersect(nGo_DA, nLt_DA));
LtGo_DA = intersect(intersect(Lt_DA, Go_DA), nSi_DA);
LtSi_DA = intersect(intersect(Lt_DA, Si_DA), nGo_DA);
SiGo_DA = intersect(intersect(Si_DA, Go_DA), nLt_DA);
all_RL_DA = intersect(intersect(Lt_DA, Go_DA), Si_DA);

% proportion coding RL elements (LO, GO, SI-rwd)
RL_GP_0 = length(nr_RL_GP)/length(rp)
RL_GP_1 = length([LtOnly_GP GoOnly_GP SiOnly_GP])/length(rp)
RL_GP_2 = length([LtGo_GP LtSi_GP SiGo_GP]) / length(rp)
RL_GP_3 = length(all_RL_GP) / length(rp)
RL_DA_0 = length(nr_RL_DA)/length(unitDA)
RL_DA_1 = length([LtOnly_DA GoOnly_DA SiOnly_DA])/length(unitDA)
RL_DA_2 = length([LtGo_DA LtSi_DA SiGo_DA]) / length(unitDA)
RL_DA_3 = length(all_RL_DA) / length(unitDA)

% RPE coding across CS, US, and SI
RpeSi_GP = intersect(find(mSi_GP < 0), mSi_GP_sig); nRpeSi_GP = setdiff(pavGP, RpeSi_GP);
RpeCs_GP = intersect(find(mCs_GP > 0), mCs_GP_sig); nRpeCs_GP = setdiff(pavGP, RpeCs_GP);
RpeUs_GP = intersect(find(mUs_GP < 0), mUs_GP_sig); nRpeUs_GP = setdiff(pavGP, RpeUs_GP);
RpeSi_DA = intersect(find(mSi_DA < 0), mSi_DA_sig); nRpeSi_DA = setdiff(1:length(unitDA), RpeSi_DA);
RpeCs_DA = intersect(find(mCs_DA > 0), mCs_DA_sig); nRpeCs_DA = setdiff(pav25DA, RpeCs_DA);
RpeUs_DA = intersect(find(mUs_DA < 0), mUs_DA_sig); nRpeUs_DA = setdiff(pav25DA, RpeUs_DA);

rpeCsOnly_GP = intersect(RpeCs_GP, nRpeUs_GP);
rpeUsOnly_GP = intersect(RpeUs_GP, nRpeCs_GP);
rpeCsUs_GP = intersect(RpeUs_GP, RpeCs_GP);
rpeNil_GP = intersect(nRpeUs_GP, nRpeCs_GP);
rpeCsOnly_DA = intersect(RpeCs_DA, nRpeUs_DA);
rpeUsOnly_DA = intersect(RpeUs_DA, nRpeCs_DA);
rpeCsUs_DA = intersect(RpeUs_DA, RpeCs_DA);
rpeNil_DA = intersect(nRpeUs_DA, nRpeCs_DA);

P_rpeCs_GP = length(rpeCsOnly_GP) / length(pavGP)
P_rpeUs_GP = length(rpeUsOnly_GP) / length(pavGP)
P_rpeCsUs_GP = length(rpeCsUs_GP) / length(pavGP)
P_rpeNil_GP = length(rpeNil_GP) / length(pavGP)
P_rpeCs_DA = length(rpeCsOnly_DA) / length(pav25DA)
P_rpeUs_DA = length(rpeUsOnly_DA) / length(pav25DA)
P_rpeCsUs_DA = length(rpeCsUs_DA) / length(pav25DA)
P_rpeNil_DA = length(rpeNil_DA) / length(pav25DA)

R_rpeUs_GP = length(intersect(RpeUs_GP, nRpeSi_GP)) / length(pavGP)
R_rpeSi_GP = length(intersect(RpeSi_GP, nRpeUs_GP)) / length(pavGP)
R_rpeUsSi_GP = length(intersect(RpeSi_GP, RpeUs_GP)) / length(pavGP)
R_rpeNil_GP = length(intersect(nRpeSi_GP, nRpeUs_GP)) / length(pavGP)
R_rpeUs_DA = length(intersect(RpeUs_DA, nRpeSi_DA)) / length(pav25DA)
R_rpeSi_DA = length(intersect(RpeSi_DA, nRpeUs_DA)) / length(pav25DA)
R_rpeUsSi_DA = length(intersect(RpeSi_DA, RpeUs_DA)) / length(pav25DA)
R_rpeNil_DA = length(intersect(nRpeSi_DA, nRpeUs_DA)) / length(pav25DA)


rpeSiOnly_GP = intersect(RpeSi_GP, union(nRpeCs_GP, nRpeUs_GP))
rpeCsOnly_GP = intersect(RpeCs_GP, union(nRpeSi_GP, nRpeUs_GP))
rpeUsOnly_GP = intersect(RpeUs_GP, union(nRpeCs_GP, nRpeSi_GP))

rpeSiUs_GP = intersect(RpeSi_GP, RpeUs_GP)
rpeCsUs_GP = intersect(RpeCs_GP, RpeUs_GP)



rpeSiOnly_DA = intersect(RpeSi_DA, union(nRpeCs_DA, nRpeUs_DA))
rpeCsOnly_DA = intersect(RpeCs_DA, union(nRpeSi_DA, nRpeUs_DA))
rpeUsOnly_DA = intersect(RpeUs_DA, union(nRpeCs_DA, nRpeSi_DA))

rpeSiUs_DA = intersect(RpeSi_DA, RpeUs_DA)
rpeCsUs_DA = intersect(RpeCs_DA, RpeUs_DA)




% make figure
f = figure('Position', [10 500 1400 300])
subplot('Position', [0.005 0.005 0.24 0.99])
y = [Pav_GP_Us Pav_GP_2 Pav_GP_Cs Pav_GP_0; Pav_DA_Us Pav_DA_2 Pav_DA_Cs Pav_DA_0];
bar(y, 'stacked');
ax = gca; ax.Box = 'on';
ax.YTick = []; ax.XTick = [];
xlim([-1 4]); ylim([0 1.25])
hold on
plot (xlim, [1 1], 'k', 'linewidth', 1)

subplot('Position', [0.255 0.005 0.24 0.99])
set(gca, 'Box', 'on')
y = [P_rpeUs_GP P_rpeCsUs_GP P_rpeCs_GP P_rpeNil_GP; P_rpeUs_DA P_rpeCsUs_DA P_rpeCs_DA P_rpeNil_DA];
bar(y, 'stacked');
ax = gca; ax.Box = 'on';
ax.YTick = []; ax.XTick = [];
xlim([-1 4]); ylim([0 1.25])
hold on
plot (xlim, [1 1], 'k', 'linewidth', 1)

subplot('Position', [0.505 0.005 0.24 0.99])
set(gca, 'Box', 'on')
y = [R_rpeUs_GP R_rpeUsSi_GP R_rpeSi_GP R_rpeNil_GP; R_rpeUs_DA R_rpeUsSi_DA R_rpeSi_DA R_rpeNil_DA];
bar(y, 'stacked');
ax = gca; ax.Box = 'on';
ax.YTick = []; ax.XTick = [];
xlim([-1 4]); ylim([0 1.25])
hold on
plot (xlim, [1 1], 'k', 'linewidth', 1)

subplot('Position', [0.755 0.005 0.24 0.99])
set(gca, 'Box', 'on')
y = [RL_GP_3 RL_GP_2 RL_GP_1 RL_GP_0; RL_DA_3 RL_DA_2 RL_DA_1 RL_DA_0];
bar(y, 'stacked')
ax = gca; ax.Box = 'on';
ax.YTick = []; ax.XTick = [];
xlim([-1 4]); ylim([0 1.25])
hold on
plot (xlim, [1 1], 'k', 'linewidth', 1)

intersect(rpeSi_GP, nSi_GP)
mSi_GP = mPosRpeGP;
mSi_GP_sig = find(pPosRpeGP < 0.05);
mSi_GP_notSig = find(pPosRpeGP >= 0.05);


scatter(rNegRpeGP(notSig), mNegRpeGP(notSig), 90, [0.7 0 0], 'linewidth', 1)
scatter(rNegRpeGP(sig), mNegRpeGP(sig), 100, [0.7 0 0], 'filled')

figure
ns = intersect(pkGo_GP_notSig, pkSi_GP_notSig);
scatter(pkGo_GP(ns), pkSi_GP(ns), 90, rpColor, 'linewidth', 1)
hold on
sel = union(intersect(pkGo_GP_sig, pkSi_GP_notSig),intersect(pkGo_GP_notSig, pkSi_GP_sig));
scatter(pkGo_GP(sel), pkSi_GP(sel), 90, [1 0.2 0.2], 'filled')
sel = intersect(pkGo_GP_sig, pkSi_GP_sig);
scatter(pkGo_GP(sel), pkSi_GP(sel), 100, rpColor, 'filled')

scatter(pkGo_DA, pkSi_DA, 100, [0 0.7 0], 'filled')
xlabel('peak GO response (Hz)')
ylabel('peak SI-rwd response (Hz)')
plot(xlim, [0 0], 'k')
plot([0 0], ylim, 'k')