%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end      
end 

 

%% Load Pavlovian and RL LR

load([datRoot 'pavLR4.mat'])
load([datRoot 'rlLR7.mat'])

% RL times
winRL = [-1 1];
winPre = [winRL(1) 0];
winPost = [0 winRL(2)];
dtLR = 0.005;
tFP = tLO;

% Pav times
rwdTime = 3.1356;
winPav = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [winPav(1) rT];
winLR2 = [rT+dtLR winPav(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
pt0 = find(abs(t1) == min(abs(t1)));

% significance criteria
pCrit = 0.05;
durCrit = 0.05;



%% Analysis of Value Coding (Pavlovian)

% pavSes = unique(uSes(uPav2));

% time windows (in seconds)
postCsWin = rwdTime;
csPt = min([round(postCsWin / dtLR) + pt0, size(pRR,2)]);
postUsWin = 1;
usPt = round(postUsWin / dtLR);

pavPreDur = nan(1, length(uPav2)); % fraction of time before US sig. coding value
pavPreSlp = nan(1, length(uPav2)); % significant coding slope before US
pavPreMag = nan(1, length(uPav2)); % significant coding slope magnitude before US
pavPreCon = nan(1, length(uPav2)); % significant coding consistency before US

pavDur = nan(1, length(uPav2)); % fraction of time coding value (before and after US)
pavSlp = nan(1, length(uPav2)); % significant coding slope (before and after US)
pavMag = nan(1, length(uPav2)); % significant coding slope magnitude (before and after US)
pavCon = nan(1, length(uPav2)); % significant coding consistency (before and after US)

pavPostDurR = nan(1, length(uPav2)); % frac. of time after US sig. coding value (rewarded)
pavPostSlpR = nan(1, length(uPav2)); % significant coding slope after US (rewarded)
pavPostMagR = nan(1, length(uPav2)); % sig. coding slope magnitude after US (rewarded)
pavPostConR = nan(1, length(uPav2)); % significant coding consistency after US (rewarded)

pavPostDurN = nan(1, length(uPav2)); % frac. of time after US sig. coding value  (unrewarded)
pavPostSlpN = nan(1, length(uPav2)); % significant coding slope after US (unrewarded)
pavPostMagN = nan(1, length(uPav2)); % sig. coding slope magnitude after US (unrewarded)
pavPostConN = nan(1, length(uPav2)); % significant coding consistency after US (unrewarded)

for u = 1:length(uPav2)
    
    if isnan(pRR(u,1))
        disp(u)
        continue
    end
    
    % pre US
    sigPre = pRR(u,pt0:csPt) < pCrit;
    slpPre = sRR(u,pt0:csPt);
    pavPreDur(u) = length(find(sigPre)) / length(sigPre);
    pavPreSlp(u) = mean(slpPre(sigPre));
    pavPreMag(u) = mean(abs(slpPre(sigPre)));
    pavPreCon(u) = abs(mean(slpPre(sigPre))) / mean(abs(slpPre(sigPre)));
    
    % post US (rewarded)
    sigPostR = pRRr(u,1:usPt) < pCrit;
    slpPostR = sRRr(u,1:usPt);
    pavPostDurR(u) = length(find(sigPostR)) / length(sigPostR);
    pavPostSlpR(u) = mean(slpPostR(sigPostR));
    pavPostMagR(u) = mean(abs(slpPostR(sigPostR)));
    pavPostConR(u) = abs(mean(slpPostR(sigPostR))) / mean(abs(slpPostR(sigPostR)));
    
    % post US (unrewarded)
    sigPostN = pRRn(u,1:usPt) < pCrit;
    slpPostN = sRRn(u,1:usPt);
    pavPostDurN(u) = length(find(sigPostN)) / length(sigPostN);
    pavPostSlpN(u) = mean(slpPostN(sigPostN));
    pavPostMagN(u) = mean(abs(slpPostN(sigPostN)));
    pavPostConN(u) = abs(mean(slpPostN(sigPostN))) / mean(abs(slpPostN(sigPostN)));
    
    % combined
    pavDur(u) = (length(find(sigPre)) + (length(find(sigPostR))+length(find(sigPostN)))/2 ) /...
        (length(sigPre)+length(sigPostR));
    pavSlp(u) = mean([slpPre(sigPre) slpPostR(sigPostR)/2 slpPostN(sigPostN)/2]);
    pavMag(u) = mean(abs([slpPre(sigPre) slpPostR(sigPostR)/2 slpPostN(sigPostN)/2]));
    pavCon(u) = abs(mean([slpPre(sigPre) slpPostR(sigPostR)/2 slpPostN(sigPostN)/2])) / pavMag(u);
       
end

[lia fpPav] = ismember(fp, uPav2); fpPav = fpPav(lia);
[lia spPav] = ismember(sp, uPav2); spPav = spPav(lia);
[lia akPav] = ismember(ak, uPav2); akPav = akPav(lia);
[lia rpPav] = ismember(rp, uPav2); rpPav = rpPav(lia);

% pavTotDur = (pavPreDur * rwdTime + 0.5 * (pavPostDurR+pavPostDurN) * postUsWin) / (rwdTime + postUsWin);

% assumes postUsWin = 1:
%preMag = pavPreMag; postMagR = pavPostMagR; postMagN = pavPostMagN;
%preMag(isnan(preMag)) = 0; postMagR(isnan(postMagR)) = 0; postMagN(isnan(postMagN)) = 0;
%pavMag = (preMag .* (pavPreDur*rwdTime) + 0.5*(postMagR.*pavPostDurR + postMagN.*pavPostDurN)) / (rwdTime+1);

lm = 0.01; xg = 0.01; w = (1 - lm - 3*xg)/3;
lp = [lm + (0:2) * (w+xg)];
bm = 0.01; h = 0.98;

% coding duration (total)
figure
hold on
stairs([min(pavDur(fpPav)) sort(pavDur(fpPav))], (0:length(fpPav)) / length(fpPav), 'color', fpColor, 'linewidth', 2)
stairs([min(pavDur(spPav)) sort(pavDur(spPav))], (0:length(spPav)) / length(spPav), 'color', 'b', 'linewidth', 2)
stairs([min(pavDur(akPav)) sort(pavDur(akPav))], (0:length(akPav)) / length(akPav), 'color', 'c', 'linewidth', 2)
stairs([min(pavDur(rpPav)) sort(pavDur(rpPav))], (0:length(rpPav)) / length(rpPav), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];

% slope magnitude (total)
figure
hold on
magFP = pavMag(fpPav); magFP(isnan(magFP)) = [];
magSP = pavMag(spPav); magSP(isnan(magSP)) = [];
magAK = pavMag(akPav); magAK(isnan(magAK)) = [];
magRP = pavMag(rpPav); magRP(isnan(magRP)) = [];
stairs([min(magFP) sort(magFP)], (0:length(magFP)) / length(magFP), 'color', fpColor, 'linewidth', 2)
stairs([min(magSP) sort(magSP)], (0:length(magSP)) / length(magSP), 'color', 'b', 'linewidth', 2)
stairs([min(magAK) sort(magAK)], (0:length(magAK)) / length(magAK), 'color', 'c', 'linewidth', 2)
stairs([min(magRP) sort(magRP)], (0:length(magRP)) / length(magRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 0.016])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];

% coding duration
figure('Position', [10 100 1125 350], 'Name', 'Pav coding duration')
subplot('Position', [lp(1) bm w h])
hold on
stairs([min(pavPreDur(fpPav)) sort(pavPreDur(fpPav))], (0:length(fpPav)) / length(fpPav), 'color', fpColor, 'linewidth', 2)
stairs([min(pavPreDur(spPav)) sort(pavPreDur(spPav))], (0:length(spPav)) / length(spPav), 'color', 'b', 'linewidth', 2)
stairs([min(pavPreDur(akPav)) sort(pavPreDur(akPav))], (0:length(akPav)) / length(akPav), 'color', 'c', 'linewidth', 2)
stairs([min(pavPreDur(rpPav)) sort(pavPreDur(rpPav))], (0:length(rpPav)) / length(rpPav), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [lp(2) bm w h])
hold on
stairs([min(pavPostDurR(fpPav)) sort(pavPostDurR(fpPav))], (0:length(fpPav)) / length(fpPav), 'color', fpColor, 'linewidth', 2)
stairs([min(pavPostDurR(spPav)) sort(pavPostDurR(spPav))], (0:length(spPav)) / length(spPav), 'color', 'b', 'linewidth', 2)
stairs([min(pavPostDurR(akPav)) sort(pavPostDurR(akPav))], (0:length(akPav)) / length(akPav), 'color', 'c', 'linewidth', 2)
stairs([min(pavPostDurR(rpPav)) sort(pavPostDurR(rpPav))], (0:length(rpPav)) / length(rpPav), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [lp(3) bm w h])
hold on
stairs([min(pavPostDurN(fpPav)) sort(pavPostDurN(fpPav))], (0:length(fpPav)) / length(fpPav), 'color', fpColor, 'linewidth', 2)
stairs([min(pavPostDurN(spPav)) sort(pavPostDurN(spPav))], (0:length(spPav)) / length(spPav), 'color', 'b', 'linewidth', 2)
stairs([min(pavPostDurN(akPav)) sort(pavPostDurN(akPav))], (0:length(akPav)) / length(akPav), 'color', 'c', 'linewidth', 2)
stairs([min(pavPostDurN(rpPav)) sort(pavPostDurN(rpPav))], (0:length(rpPav)) / length(rpPav), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

% slope mean
figure('Position', [10 100 1125 350], 'Name', 'Pav mean slope')
subplot('Position', [lp(1) bm w h])
hold on
slpFP = pavPreSlp(fpPav); slpFP(isnan(slpFP)) = [];
slpSP = pavPreSlp(spPav); slpSP(isnan(slpSP)) = [];
slpAK = pavPreSlp(akPav); slpAK(isnan(slpAK)) = [];
slpRP = pavPreSlp(rpPav); slpRP(isnan(slpRP)) = [];
stairs([min(slpFP) sort(slpFP)], (0:length(slpFP)) / length(slpFP), 'color', fpColor, 'linewidth', 2)
stairs([min(slpSP) sort(slpSP)], (0:length(slpSP)) / length(slpSP), 'color', 'b', 'linewidth', 2)
stairs([min(slpAK) sort(slpAK)], (0:length(slpAK)) / length(slpAK), 'color', 'c', 'linewidth', 2)
stairs([min(slpRP) sort(slpRP)], (0:length(slpRP)) / length(slpRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(2) bm w h])
hold on
sFP = pavPostSlpR(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPostSlpR(spPav); sSP(isnan(sSP)) = [];
sAK = pavPostSlpR(akPav); sAK(isnan(sAK)) = [];
sRP = pavPostSlpR(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(3) bm w h])
hold on
sFP = pavPostSlpN(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPostSlpN(spPav); sSP(isnan(sSP)) = [];
sAK = pavPostSlpN(akPav); sAK(isnan(sAK)) = [];
sRP = pavPostSlpN(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

% slope magnitude
figure('Position', [10 100 1125 350], 'Name', 'Pav mean slope magnitude')
subplot('Position', [lp(1) bm w h])
hold on
magFP = pavPreMag(fpPav); magFP(isnan(magFP)) = [];
magSP = pavPreMag(spPav); magSP(isnan(magSP)) = [];
magAK = pavPreMag(akPav); magAK(isnan(magAK)) = [];
magRP = pavPreMag(rpPav); magRP(isnan(magRP)) = [];
stairs([min(magFP) sort(magFP)], (0:length(magFP)) / length(magFP), 'color', fpColor, 'linewidth', 2)
stairs([min(magSP) sort(magSP)], (0:length(magSP)) / length(magSP), 'color', 'b', 'linewidth', 2)
stairs([min(magAK) sort(magAK)], (0:length(magAK)) / length(magAK), 'color', 'c', 'linewidth', 2)
stairs([min(magRP) sort(magRP)], (0:length(magRP)) / length(magRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(2) bm w h])
hold on
sFP = pavPostMagR(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPostMagR(spPav); sSP(isnan(sSP)) = [];
sAK = pavPostMagR(akPav); sAK(isnan(sAK)) = [];
sRP = pavPostMagR(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(3) bm w h])
hold on
sFP = pavPostMagN(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPostMagN(spPav); sSP(isnan(sSP)) = [];
sAK = pavPostMagN(akPav); sAK(isnan(sAK)) = [];
sRP = pavPostMagN(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

% coding consistency
figure('Position', [10 100 1125 350], 'Name', 'Pav coding consistency')
subplot('Position', [lp(1) bm w h])
hold on
sFP = pavPreCon(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPreCon(spPav); sSP(isnan(sSP)) = [];
sAK = pavPreCon(akPav); sAK(isnan(sAK)) = [];
sRP = pavPreCon(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(2) bm w h])
hold on
sFP = pavPostConR(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPostConR(spPav); sSP(isnan(sSP)) = [];
sAK = pavPostConR(akPav); sAK(isnan(sAK)) = [];
sRP = pavPostConR(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(3) bm w h])
hold on
sFP = pavPostConN(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPostConN(spPav); sSP(isnan(sSP)) = [];
sAK = pavPostConN(akPav); sAK(isnan(sAK)) = [];
sRP = pavPostConN(rpPav); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];



%% Analysis of Value Coding (RL)

% RL epochs: pre-LO, pre-CI, hold (500 ms post-CI, 500 ms pre-GO), 
% choice (250 ms post-GO, 100-250 ms pre-SI), post-SI

% variables for rlLR3 stored in cell arrays: 1=LO, 2=CI, 3=GO, 4=pre-SI (all trials together)
% 1=post-SI, 2=FP (broken into separate rewarded and unrewarded cases)

win = [-1 1];
winPre = [win(1) 0];
winPost = [0 win(2)];
dtLR = 0.005;
tLR = win(1):dtLR:win(2);
pt0 = find(abs(tLR) == min(abs(tLR))); 
tPre = win(1):dtLR:0;
tPost = 0:dtLR:win(2);

% significance criteria
pCrit = 0.05;

% time windows (in seconds)
postCiWin = 0.5; postCiPt = find(abs(tLR-postCiWin) == min(abs(tLR-postCiWin)));
preGoWin = 0.5; preGoPt = find(abs(tLR+preGoWin) == min(abs(tLR+preGoWin)));
postGoWin = 0.1; postGoPt = find(abs(tLR-postGoWin) == min(abs(tLR-postGoWin)));
preSiWin = 0.2; preSiPt = find(abs(tLR+preSiWin) == min(abs(tLR+preSiWin)));

rlPreDur = nan(1, length(unit)); % significant coding duration before US
rlPreSlp = nan(1, length(unit)); % significant coding slope before US
rlPreMag = nan(1, length(unit)); % magnitude of sig. coding slope before US
rlPreMagMax = nan(1, length(unit)); % max magnitude of sig. coding slope before US
rlPreCon = nan(1, length(unit)); % significant coding consistency before US

rlDur = nan(1, length(unit)); % significant coding duration (all)
rlSlp = nan(1, length(unit)); % significant coding slope (all)
rlMag = nan(1, length(unit)); % magnitude of sig. coding slope (all)
rlCon = nan(1, length(unit)); % significant coding consistency (all)

rlPostDurR = nan(1, length(unit)); % significant coding duration after US (rewarded)
rlPostSlpR = nan(1, length(unit)); % significant coding slope after US (rewarded)
rlPostMagR = nan(1, length(unit)); % magnitude of sig. coding slope after US (rewarded)
rlPostConR = nan(1, length(unit)); % significant coding consistency after US (rewarded)

rlPostDurN = nan(1, length(unit)); % significant coding duration after US (unrewarded)
rlPostSlpN = nan(1, length(unit)); % significant coding slope after US (unrewarded)
rlPostMagN = nan(1, length(unit)); % magnitude of sig. coding slope after US (unrewarded)
rlPostConN = nan(1, length(unit)); % significant coding consistency after US (unrewarded)

for u = 1:length(unit)
    
    if isnan(pR{2}(u,1))
        continue
    end
    
    % pre outcome
    sig1 = pR{2}(u,pt0+1:postCiPt) < pCrit;  % post CI sig
    slp1 = sR{2}(u,pt0+1:postCiPt);          % post CI slp
    sig2 = pR{3}(u,preGoPt:pt0) < pCrit;     % pre GO sig
    slp2 = sR{3}(u,preGoPt:pt0);             % pre GO slp
    sig3 = pR{3}(u,pt0+1:postGoPt) < pCrit;  % post GO sig
    slp3 = sR{3}(u,pt0+1:postGoPt);          % post GO slp
    sig4 = pR{5}(u,preSiPt:pt0) < pCrit;     % pre SI sig
    slp4 = sR{5}(u,preSiPt:pt0);             % pre SI slp
    sig = [sig1 sig2 sig3 sig4];
    slp = [slp1 slp2 slp3 slp4];
    rlPreDur(u) = length(find(sig)) / length(sig);
    rlPreSlp(u) = mean(slp(sig));
    rlPreMag(u) = mean(abs(slp(sig)));
    maxSlp = max(abs(slp(sig)));
    if ~isempty(maxSlp)
        rlPreMagMax(u) = maxSlp;
    end
    rlPreCon(u) = abs(mean(slp(sig))) / mean(abs(slp(sig)));
    
    % post outcome (rewarded)
    sigR = pRr{1}(u,:) < pCrit;
    slpR = sRr{1}(u,:);
    rlPostDurR(u) = length(find(sigR)) / length(sigR);
    rlPostSlpR(u) = mean(slpR(sigR));
    rlPostMagR(u) = mean(abs(slpR(sigR)));
    rlPostConR(u) = abs(mean(slpR(sigR))) / mean(abs(slpR(sigR)));
    
    % post outcome (unrewarded)
    sigN = pRn{1}(u,:) < pCrit;
    slpN = sRn{1}(u,:);
    rlPostDurN(u) = length(find(sigN)) / length(sigN);
    rlPostSlpN(u) = mean(slpN(sigN));
    rlPostMagN(u) = mean(abs(slpN(sigN)));
    rlPostConN(u) = abs(mean(slpN(sigN))) / mean(abs(slpN(sigN)));
    
    % pre- and postoutcome combned
    rlDur(u) = (length(find(sig)) + length(find([sigR sigN]))/2 ) / (length(sig) + length([sigR sigN])/2);
    rlSlp(u) = mean([slp(sig) slpR(sigR)/2 slpN(sigN)/2]);
    rlMag(u) = mean(abs([slp(sig) slpR(sigR)/2 slpN(sigN)/2]));
    rlCon(u) = abs(mean([slp(sig) slpR(sigR)/2 slpN(sigN)/2])) / rlPreMag(u);
    
end

preWin = postCiWin + preGoWin + postGoWin + preSiWin;
rlTotDur = (rlPreDur * preWin + 0.5 * (rlPostDurR+rlPostDurN))/ (preWin + 1);

preMag = rlPreMag; postMagR = rlPostMagR; postMagN = rlPostMagN;
preMag(isnan(preMag)) = 0; postMagR(isnan(postMagR)) = 0; postMagN(isnan(postMagN)) = 0;
rlMag = (preMag .* (rlPreDur*preWin) + 0.5*(postMagR.*rlPostDurR + postMagN.*rlPostDurN)) / (preWin+1);

% coding duration (total)
figure
hold on
stairs([min(rlDur(fp)) sort(rlDur(fp))], (0:length(fp)) / length(fp), 'color', fpColor, 'linewidth', 2)
stairs([min(rlDur(sp)) sort(rlDur(sp))], (0:length(sp)) / length(sp), 'color', 'b', 'linewidth', 2)
stairs([min(rlDur(ak)) sort(rlDur(ak))], (0:length(ak)) / length(ak), 'color', 'c', 'linewidth', 2)
stairs([min(rlDur(rp)) sort(rlDur(rp))], (0:length(rp)) / length(rp), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

% slope magnitude (total)
figure
hold on
sFP = rlMag(fp); sFP(isnan(sFP)) = [];
sSP = rlMag(sp); sSP(isnan(sSP)) = [];
sAK = rlMag(ak); sAK(isnan(sAK)) = [];
sRP = rlMag(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

% coding duration
figure('Position', [10 100 1125 350], 'Name', 'RL coding duration')
subplot('Position', [lp(1) bm w h])
hold on
stairs([min(rlPreDur(fp)) sort(rlPreDur(fp))], (0:length(fp)) / length(fp), 'color', fpColor, 'linewidth', 2)
stairs([min(rlPreDur(sp)) sort(rlPreDur(sp))], (0:length(sp)) / length(sp), 'color', 'b', 'linewidth', 2)
stairs([min(rlPreDur(ak)) sort(rlPreDur(ak))], (0:length(ak)) / length(ak), 'color', 'c', 'linewidth', 2)
stairs([min(rlPreDur(rp)) sort(rlPreDur(rp))], (0:length(rp)) / length(rp), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [lp(2) bm w h])
hold on
stairs([min(rlPostDurR(fp)) sort(rlPostDurR(fp))], (0:length(fp)) / length(fp), 'color', fpColor, 'linewidth', 2)
stairs([min(rlPostDurR(sp)) sort(rlPostDurR(sp))], (0:length(sp)) / length(sp), 'color', 'b', 'linewidth', 2)
stairs([min(rlPostDurR(ak)) sort(rlPostDurR(ak))], (0:length(ak)) / length(ak), 'color', 'c', 'linewidth', 2)
stairs([min(rlPostDurR(rp)) sort(rlPostDurR(rp))], (0:length(rp)) / length(rp), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [lp(3) bm w h])
hold on
stairs([min(rlPostDurN(fp)) sort(rlPostDurN(fp))], (0:length(fp)) / length(fp), 'color', fpColor, 'linewidth', 2)
stairs([min(rlPostDurN(sp)) sort(rlPostDurN(sp))], (0:length(sp)) / length(sp), 'color', 'b', 'linewidth', 2)
stairs([min(rlPostDurN(ak)) sort(rlPostDurN(ak))], (0:length(ak)) / length(ak), 'color', 'c', 'linewidth', 2)
stairs([min(rlPostDurN(rp)) sort(rlPostDurN(rp))], (0:length(rp)) / length(rp), 'color', rpColor, 'linewidth', 2)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';

% slope mean
figure('Position', [10 100 1125 350], 'Name', 'RL mean slope')
subplot('Position', [lp(1) bm w h])
hold on
sFP = rlPreSlp(fp); sFP(isnan(sFP)) = [];
sSP = rlPreSlp(sp); sSP(isnan(sSP)) = [];
sAK = rlPreSlp(ak); sAK(isnan(sAK)) = [];
sRP = rlPreSlp(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(2) bm w h])
hold on
sFP = rlPostSlpR(fp); sFP(isnan(sFP)) = [];
sSP = rlPostSlpR(sp); sSP(isnan(sSP)) = [];
sAK = rlPostSlpR(ak); sAK(isnan(sAK)) = [];
sRP = rlPostSlpR(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(3) bm w h])
hold on
sFP = rlPostSlpN(fp); sFP(isnan(sFP)) = [];
sSP = rlPostSlpN(sp); sSP(isnan(sSP)) = [];
sAK = rlPostSlpN(ak); sAK(isnan(sAK)) = [];
sRP = rlPostSlpN(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

% slope magnitude
figure('Position', [10 100 1125 350], 'Name', 'RL mean slope magnitude')
subplot('Position', [lp(1) bm w h])
hold on
sFP = rlPreMag(fp); sFP(isnan(sFP)) = [];
sSP = rlPreMag(sp); sSP(isnan(sSP)) = [];
sAK = rlPreMag(ak); sAK(isnan(sAK)) = [];
sRP = rlPreMag(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(2) bm w h])
hold on
sFP = rlPostMagR(fp); sFP(isnan(sFP)) = [];
sSP = rlPostMagR(sp); sSP(isnan(sSP)) = [];
sAK = rlPostMagR(ak); sAK(isnan(sAK)) = [];
sRP = rlPostMagR(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(3) bm w h])
hold on
sFP = rlPostMagN(fp); sFP(isnan(sFP)) = [];
sSP = rlPostMagN(sp); sSP(isnan(sSP)) = [];
sAK = rlPostMagN(ak); sAK(isnan(sAK)) = [];
sRP = rlPostMagN(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

% coding consistency
figure('Position', [10 100 1125 350], 'Name', 'RL coding consistency')
subplot('Position', [lp(1) bm w h])
hold on
sFP = rlPreCon(fp); sFP(isnan(sFP)) = [];
sSP = rlPreCon(sp); sSP(isnan(sSP)) = [];
sAK = rlPreCon(ak); sAK(isnan(sAK)) = [];
sRP = rlPreCon(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(2) bm w h])
hold on
sFP = rlPostConR(fp); sFP(isnan(sFP)) = [];
sSP = rlPostConR(sp); sSP(isnan(sSP)) = [];
sAK = rlPostConR(ak); sAK(isnan(sAK)) = [];
sRP = rlPostConR(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];

subplot('Position', [lp(3) bm w h])
hold on
sFP = rlPostConN(fp); sFP(isnan(sFP)) = [];
sSP = rlPostConN(sp); sSP(isnan(sSP)) = [];
sAK = rlPostConN(ak); sAK(isnan(sAK)) = [];
sRP = rlPostConN(rp); sRP(isnan(sRP)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 2)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 2)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 2)
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 2)
plot([0 0], [0 1], 'k', 'linewidth', 1)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
%xlim([-0.04 0.04])
ax = gca; ax.Box = 'on';
ax.XTick = [-0.02 0 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];



%% Figure 5a: Example Cell (RL panel)

sel = find(rlPreCon < nanmedian(rlPreCon) & rlPreMag > nanmedian(rlPreMag));
sel = intersect(fp, sel);
sel = intersect(sel, uPav2);
rlPreMag
rlPreDur

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 1;
sesList = unique(uSes);
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

% ak examples: 220(RPE) 520 (alt)
% ak examples (suppl): 186 809 525 644 196
% sp examples: 1278 
% sp examples (suppl): 207 229 363 1003 1279
% fp example: 404
% fp examples (suppl): 393 537 1263 325 380 [alt: 716]

u = 196;
[~, uP] = ismember(u, uPav2)

s = find(strcmp(uSes{u}, sesList));
rr = rwdRate{s}(11:end);
uTrajRL = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
ts = unit(u).behav_ts{rlIdx};
pt = find(timesRL == 0) + 1;

loTr = find(rr <= quantile(rr, lo(2))) + 10;
medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
hiTr = find(rr >= quantile(rr, hi(1))) + 10;

% light on
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 1);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
loL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
loM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
loH = mean(r);

% center in
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 2);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
ciL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
ciM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
ciH = mean(r);

% go
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 3);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
goL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
goM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
goH = mean(r);

% side in (pre)
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 5);
rwd = TrialFilter(ts, 'x1', unit(u).side);
noRwd = TrialFilter(ts, 'x0', unit(u).side);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
siL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
siM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
siH = mean(r);

% side in (post)
sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLR = mean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMR = mean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHR = mean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLN = mean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMN = mean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHN = mean(r,1);

% food port
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 6);
sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpLR = nanmean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpMR = nanmean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpHR = nanmean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpLN = nanmean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpMN = nanmean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpHN = nanmean(r);

% make figure
lm = 0.005; xg = 0.005; w = 0.194;
bm = 0.01; yg = 0.025; hb = 0.34; ht = 0.62; bt = bm+yg+hb;

nm = [unit(u).cellType ' (' num2str(u) ')'];
figure('Position', [10 100 1400 400], 'NumberTitle', 'off', 'name', nm)
maxRate = max([loL loM loH ciL ciM ciH goL goM goH siL siM siH]);
maxRate = max([maxRate siLR siMR siHR siLN siMN siHN fpLR fpMR fpHR fpLN fpMN fpHN]);
yR = [0 1.25*maxRate];
yT = [40 80];

sMin = min([sR{1}(u,:) sR{2}(u,:) sR{3}(u,:) sR{4}(u,:) sRr{1}(u,:) sRn{1}(u,:) sRr{2}(u,:) sRn{2}(u,:)]);
sMax = max([sR{1}(u,:) sR{2}(u,:) sR{3}(u,:) sR{4}(u,:) sRr{1}(u,:) sRn{1}(u,:) sRr{2}(u,:) sRn{2}(u,:)]);
ySR = [sMin sMax] *1.1;
yST = [ -0.2 0.2];

ns = [1 1 1]*0.65;
nsR = [1 0.6 0.6];
nsN = [0.6 0.6 1];

smWd = 10;

% light on
subplot('Position', [lm bt w ht])
hold on
plot(timesRL, loH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, loM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, loL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
ylim(yR)
sigPts = AnnotateSig(gcf, tLR, pR{1}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
plot([0 0], yR, '--k', 'linewidth', 2);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{1}(u,:), 'gaussian', smWd);
subplot('Position', [lm bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tLR(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% center in
subplot('Position', [lm+w+xg bt w ht])
hold on
plot(timesRL, ciH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, ciM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, ciL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
sigPts = AnnotateSig(gcf, tLR, pR{2}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{2}(u,:), 'gaussian', smWd);
subplot('Position', [lm+w+xg bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tLR(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% GO
subplot('Position', [lm+2*(w+xg) bt w ht])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
sigPts = AnnotateSig(gcf, tLR, pR{3}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{3}(u,:), 'gaussian', smWd);
subplot('Position', [lm+2*(w+xg) bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tLR(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% side in
subplot('Position', [lm+3*(w+xg) bt w ht])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
sigPts = AnnotateSig(gcf, tPre, pR{5}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
sigPtsR = AnnotateSig(gcf, tPost, pRr{1}(u,:), pCrit, durCrit, 'r', 'bardrop', 0.03, 'returnPts', true);
sigPtsN = AnnotateSig(gcf, tPost, pRn{1}(u,:), pCrit, durCrit, 'b', 'bardrop', 0.08, 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{5}(u,:), 'gaussian', smWd);
subplot('Position', [lm+3*(w+xg) bm w hb])
hold on
plot(tPre, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tPre(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
slp = smoothdata(sRn{1}(u,:), 'gaussian', smWd);
plot(tPost, slp, 'linewidth', 3, 'color', nsN)
for i = 1:length(sigPtsN)
    plot(tPost(sigPtsN{i}), slp(sigPtsN{i}), 'linewidth', 3, 'color', [0 0 0.75])
end
slp = smoothdata(sRr{1}(u,:), 'gaussian', smWd);
plot(tPost, slp, 'linewidth', 3, 'color', nsR)
for i = 1:length(sigPtsR)
    plot(tPost(sigPtsR{i}), slp(sigPtsR{i}), 'linewidth', 3, 'color', [0.75 0 0])
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% food port
subplot('Position', [lm+4*(w+xg) bt w ht])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL, fpLN, 'color', cList{6}, 'linewidth', 3)
plot(timesRL, fpMN, 'color', cList{5}, 'linewidth', 3)
plot(timesRL, fpHN, 'color', cList{4}, 'linewidth', 3)
plot(timesRL, fpLR, 'color', cList{3}, 'linewidth', 3)
plot(timesRL, fpMR, 'color', cList{2}, 'linewidth', 3)
plot(timesRL, fpHR, 'color', cList{1}, 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR);
sigPtsR = AnnotateSig(gcf, tLR, pRr{2}(u,:), pCrit, durCrit, 'r', 'bardrop', 0.03, 'returnPts', true);
sigPtsN = AnnotateSig(gcf, tLR, pRn{2}(u,:), pCrit, durCrit, 'b', 'bardrop', 0.08, 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sRn{2}(u,:), 'gaussian', smWd);
subplot('Position', [lm+4*(w+xg) bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', nsN)
for i = 1:length(sigPtsN)
    plot(tLR(sigPtsN{i}), slp(sigPtsN{i}), 'linewidth', 3, 'color', [0 0 0.75])
end
slp = smoothdata(sRr{2}(u,:), 'gaussian', smWd);
plot(tLR, slp, 'linewidth', 3, 'color', nsR)
for i = 1:length(sigPtsR)
    plot(tLR(sigPtsR{i}), slp(sigPtsR{i}), 'linewidth', 3, 'color', [0.75 0 0])
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')



%% Figure 5a: Example Cell (Pav panel)

winPav = [-0.5 4.5];
cListPav = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

uTrajPav = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
dt = uTrajPav(1).times(2) - uTrajPav(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
pavIdx = find(strcmp(lower(unit(u).taskList), 'pav'));
lg = unit(u).behav_log{pavIdx};
ts = unit(u).behav_ts{pavIdx};

cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

rwdTime = nanmean(ts.rwdTime - ts.csTime);
traj = TrajSplit(uTrajPav, ts, winPav);

% average rate: prob 25 cue
tr25 = find(lg.toneFreq == cue25);
tr25r = intersect(tr25, find(lg.outcome));
r = zeros(length(tr25r), nPtsPav);
for k = 1:length(tr25r)
    r(k,:) = traj(tr25r(k)).rate;
end
p25r = mean(r);
tr25nr = intersect(tr25, find(~lg.outcome));
r = zeros(length(tr25nr), nPtsPav);
for k = 1:length(tr25nr)
    r(k,:) = traj(tr25nr(k)).rate;
end
p25nr = mean(r);
r = zeros(length(tr25), nPtsPav);
for k = 1:length(tr25)
    r(k,:) = traj(tr25(k)).rate;
end
p25 = mean(r);

% average rate: prob 75 cue
tr75 = find(lg.toneFreq == cue75);
tr75r = intersect(tr75, find(lg.outcome));
r = zeros(length(tr75r), nPtsPav);
for k = 1:length(tr75r)
    r(k,:) = traj(tr75r(k)).rate;
end
p75r = mean(r);
tr75nr = intersect(tr75, find(~lg.outcome));
r = zeros(length(tr75nr), nPtsPav);
for k = 1:length(tr75nr)
    r(k,:) = traj(tr75nr(k)).rate;
end
p75nr = mean(r);
r = zeros(length(tr75), nPtsPav);
for k = 1:length(tr75)
    r(k,:) = traj(tr75(k)).rate;
end
p75 = mean(r);

%maxRate = max([p25 p75 p25r p25nr p75r p75nr]);
%maxRate = 5*ceil(maxRate/5);
% yR = [0 maxRate];     Use limits from RL panels
% yticks = [25 50 75];  Use ticks from RL panels

maxSlope = max([sRR(uP,:) sRRr(uP,:) sRRn(uP,:)])
minSlope = min([sRR(uP,:) sRRr(uP,:) sRRn(uP,:)])
yS = [-0.02 0.02];
ySt = [-0.01 0.01];

tkW = 2;
tkH = 3;

% Pav example, 25% and 75% pRwd rate plot
fig = figure('Position', [10 100 930 400])
subplot('Position', [lm bt 0.99 ht])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cListPav{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cListPav{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cListPav{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cListPav{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', [0.3 0.3 0.3], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;
sigPts = AnnotateSig(gcf, t1, pRR(uP,:), pCrit, durCrit, 'k', 'returnPts', true);
sigPtsR = AnnotateSig(gcf, t2, pRRr(uP,:), pCrit, durCrit, 'r', 'bardrop', 0.03, 'returnPts', true);
sigPtsN = AnnotateSig(gcf, t2, pRRn(uP,:), pCrit, durCrit, 'b', 'bardrop', 0.08, 'returnPts', true);

slp = smoothdata(sRR(uP,:), 'gaussian', smWd);
subplot('Position', [lm bm 0.99 hb])
hold on
plot(t1, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(t1(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
slp = smoothdata(sRRn(uP,:), 'gaussian', smWd);
plot(t2, slp, 'linewidth', 3, 'color', nsN)
for i = 1:length(sigPtsN)
    plot(t2(sigPtsN{i}), slp(sigPtsN{i}), 'linewidth', 3, 'color', [0 0 0.75])
end
slp = smoothdata(sRRr(uP,:), 'gaussian', smWd);
plot(t2, slp, 'linewidth', 3, 'color', nsR)
for i = 1:length(sigPtsR)
    plot(t2(sigPtsR{i}), slp(sigPtsR{i}), 'linewidth', 3, 'color', [0.75 0 0])
end
plot([0 0], yS, '--k', 'linewidth', 2);
plot([rwdTime rwdTime], yS, '--k', 'linewidth', 2);
plot([t1(1) t2(end)], [0,0], '--k', 'linewidth', 2);
ylim(yS)
set(gca, 'YTick', ySt)
set(gca, 'XTick', [-0.5:0.5:4]);
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;



%% Brief Examination of Reaction Time and Movement Time

RT = [];
MT = [];
for s = 1:length(sesList)
    [~,u] = ismember(sesList{s}, uSes);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    [~, rt, mt] = BehaviorTimes(unit(u).behav_ts{rlIdx});
    RT = [RT; rt];
    MT = [MT; mt];    
end
TT = RT + MT;

[mean(RT) median(RT) quantile(RT, 0.25)]
% 0.1821    0.1196    0.0998

[mean(MT) median(MT) quantile(MT, 0.25)]
% 0.2561    0.2320    0.2116

[mean(TT) median(TT) quantile(TT, 0.25)]
% 0.4382    0.3678    0.3246

[mean(TT) std(TT)]
% 0.4382    0.9376

[min(TT)   max(TT)    quantile(TT, 0.99)]
% 0.1861  149.6757(!)  1.2405



%% Statistics for Manuscript Text

% mean coding duration (fraction), Pavlovian combined
[mean(pavDur(fpPav)) mean(pavDur(spPav)) mean(pavDur(akPav)) mean(pavDur(rpPav))]
%     0.1836                 0.1051              0.0967             0.1025

% Pavlovian combined coding duration ANOVA, non-RP
grp = [ones(size(fpPav)) 2*ones(size(spPav)) 3*ones(size(akPav))];
kruskalwallis([pavDur(fpPav) pavDur(spPav) pavDur(akPav)], grp) % p = 5.91336e-19

% Pavlovian combined coding duration ANOVA, all cell types
grp2 = [ones(size(rpPav)) 2*ones(size(fpPav)) 3*ones(size(spPav)) 4*ones(size(akPav))];
kruskalwallis([pavDur(rpPav) pavDur(fpPav) pavDur(spPav) pavDur(akPav)], grp2) % p = 8.08365e-19

% Pavlovian combined coding duration, pairwise comparisons
[ranksum(pavDur(fpPav), pavDur(spPav)) ranksum(pavDur(fpPav), pavDur(akPav)) ranksum(pavDur(fpPav), pavDur(rpPav))]
[ranksum(pavDur(spPav), pavDur(akPav)) ranksum(pavDur(spPav), pavDur(rpPav))]
ranksum(pavDur(rpPav), pavDur(akPav))

%               fast proto   slow proto   arkypallidal   slow pacemkr
% fast proto         -       6.0702e-15    3.3148e-16     5.0423e-06
% slow proto         -            -          0.2193         0.1010
% arkypallidal       -            -             -           0.0113


% mean coding duration (fraction), RL
[mean(rlDur(fp)) mean(rlDur(sp)) mean(rlDur(ak)) mean(rlDur(rp))]
%    0.3543          0.2262          0.2083          0.1496

% RL combined coding duration ANOVA, non-RP
grp = [ones(size(fp)) 2*ones(size(sp)) 3*ones(size(ak))];
kruskalwallis([rlDur(fp) rlDur(sp) rlDur(ak)], grp) % p = 6.81185e-23

% RL combined coding duration ANOVA, all cell types
grp2 = [ones(size(rp)) 2*ones(size(fp)) 3*ones(size(sp)) 4*ones(size(ak))];
kruskalwallis([rlDur(rp) rlDur(fp) rlDur(sp) rlDur(ak)], grp2) % p = 4.51731e-29

% RL combined coding duration, pairwise comparisons
[ranksum(rlDur(fp), rlDur(sp)) ranksum(rlDur(fp), rlDur(ak)) ranksum(rlDur(fp), rlDur(rp))]
[ranksum(rlDur(sp), rlDur(ak)) ranksum(rlDur(sp), rlDur(rp))]
ranksum(rlDur(rp), rlDur(ak))

%               fast proto   slow proto   arkypallidal   slow pacemkr
% fast proto         -       2.9484e-18    6.4767e-19     1.1890e-19
% slow proto         -            -          0.4837       9.5860e-05
% arkypallidal       -            -             -           0.0011


% mean slope magnitude, Pavlovian combined
[mean(pavMag(fpPav)) mean(pavMag(spPav)) mean(pavMag(akPav)) mean(pavMag(rpPav))]
%     0.0091                 0.0083              0.0084             0.0105

% Pavlovian combined slope magnitude ANOVA, non-RP
grp = [ones(size(fpPav)) 2*ones(size(spPav)) 3*ones(size(akPav))];
kruskalwallis([pavMag(fpPav) pavMag(spPav) pavMag(akPav)], grp) % p = 1.7228e-07

% Pavlovian combined slope magnitude ANOVA, all cell types
grp2 = [ones(size(rpPav)) 2*ones(size(fpPav)) 3*ones(size(spPav)) 4*ones(size(akPav))];
kruskalwallis([pavMag(rpPav) pavMag(fpPav) pavMag(spPav) pavMag(akPav)], grp2) % p = 1.9252e-11

% Pavlovian combined slope magnitude, pairwise comparisons
[ranksum(pavMag(fpPav), pavMag(spPav)) ranksum(pavMag(fpPav), pavMag(akPav)) ranksum(pavMag(fpPav), pavMag(rpPav))]
[ranksum(pavMag(spPav), pavMag(akPav)) ranksum(pavMag(spPav), pavMag(rpPav))]
ranksum(pavMag(rpPav), pavMag(akPav))

%               fast proto   slow proto   arkypallidal   slow pacemkr
% fast proto         -       8.3398e-07    1.4151e-06       0.0125
% slow proto         -            -          0.6078       1.0070e-07
% arkypallidal       -            -             -         2.9175e-07


% mean slope magnitude, RL combined
[mean(rlMag(fp)) mean(rlMag(sp)) mean(rlMag(ak)) mean(rlMag(rp))]
%    0.0667          0.0521          0.0607          0.0649

% RL combined slope magnitude ANOVA, non-RP
grp = [ones(size(fp)) 2*ones(size(sp)) 3*ones(size(ak))];
kruskalwallis([rlMag(fp) rlMag(sp) rlMag(ak)], grp) % p = 1.1415e-27

% RL combined slope magnitude ANOVA, all cell types
grp2 = [ones(size(rp)) 2*ones(size(fp)) 3*ones(size(sp)) 4*ones(size(ak))];
kruskalwallis([rlMag(rp) rlMag(fp) rlMag(sp) rlMag(ak)], grp2) % p = 3.4737e-29

% RL combined slope magnitude, pairwise comparisons
[ranksum(rlMag(fp), rlMag(sp)) ranksum(rlMag(fp), rlMag(ak)) ranksum(rlMag(fp), rlMag(rp))]
[ranksum(rlMag(sp), rlMag(ak)) ranksum(rlMag(sp), rlMag(rp))]
ranksum(rlMag(rp), rlMag(ak))

%               fast proto   slow proto   arkypallidal   slow pacemkr
% fast proto         -       3.1421e-25    1.3083e-04       0.7826
% slow proto         -            -        1.1601e-13     6.9014e-11
% arkypallidal       -            -             -           0.0156




%% Pavlovian - RL Value Coding Correlations

[lia fpPav] = ismember(fp, uPav2); fpPav = fpPav(lia);
[lia spPav] = ismember(sp, uPav2); spPav = spPav(lia);
[lia akPav] = ismember(ak, uPav2); akPav = akPav(lia);
[lia rpPav] = ismember(rp, uPav2); rpPav = rpPav(lia);

fpRL = uPav2(fpPav);
spRL = uPav2(spPav);
akRL = uPav2(akPav);
rpRL = uPav2(rpPav);

figure
scatter(pavTotDur(fpPav), rlTotDur(fpRL))
figure
scatter(pavPreDur(rpPav), rlPreDur(rpRL))

% nominal significance criterion: 0.05
% if inlcuded tests are duration pre-rwd slope, and post-rwd slope, there
% are 9 tests (assumes RP excluded) or 12 test (all cell types included
% This gives Bonferroni-corrected criteria of 0.0056 or 0.0042;
% Bonferroni-corrected criterion: 0.0028 (assumes 18 tests);
% Bonferroni-corrected criterion: 0.0125 (assumes 4 tests);

% FP, correlations in coding duration, all cells
[r p] = corr(pavDur(fpPav)', rlDur(fpRL)')              % r = 0.1391, p = 0.0339
[r p] = corr(pavPreDur(fpPav)', rlPreDur(fpRL)')        % r = 0.1095, p = 0.0954
[r p] = corr(pavPostDurR(fpPav)', rlPostDurR(fpRL)')    % r = 0.1536, p = 0.0190
[r p] = corr(pavPostDurN(fpPav)', rlPostDurN(fpRL)')    % r = -0.0774, p = 0.2394

% FP, correlations in regression slope, all cells
pav = pavSlp(fpPav)'; rl = rlSlp(fpRL)';                        
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0447, p = 0.4972
pav = pavPreSlp(fpPav)'; rl = rlPreSlp(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0228, p = 0.7300
pav = pavPostSlpR(fpPav)'; rl = rlPostSlpR(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0146, p = 0.8331
pav = pavPostSlpN(fpPav)'; rl = rlPostSlpN(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0798, p = 0.2748

% FP, correlations in slope magnitude, all cells
pav = pavMag(fpPav)'; rl = rlMag(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0333, p = 0.6132
pav = pavPreMag(fpPav)'; rl = rlPreMag(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0282, p = 0.6696
pav = pavPostMagR(fpPav)'; rl = rlPostMagR(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.1548, p = 0.0249
pav = pavPostMagN(fpPav)'; rl = rlPostMagN(fpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0308, p = 0.6739


% SP, correlations in coding duration, all cells
[r p] = corr(pavDur(spPav)', rlDur(spRL)')              % r = 0.1701, p = 0.0023
[r p] = corr(pavPreDur(spPav)', rlPreDur(spRL)')        % r = 0.0758, p = 0.1777
[r p] = corr(pavPostDurR(spPav)', rlPostDurR(spRL)')    % r = 0.0523, p = 0.3523
[r p] = corr(pavPostDurN(spPav)', rlPostDurN(spRL)')    % r = -0.0146, p = 0.7950

% SP, correlations in regression slope, all cells
pav = pavSlp(spPav)'; rl = rlSlp(spRL)';                        
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0574, p = 0.3073
pav = pavPreSlp(spPav)'; rl = rlPreSlp(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0458, p = 0.4214
pav = pavPostSlpR(spPav)'; rl = rlPostSlpR(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.2257, p = 2.5079e-04
pav = pavPostSlpN(spPav)'; rl = rlPostSlpN(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0692, p = 0.2758

% SP, correlations in slope magnitude, all cells
pav = pavMag(spPav)'; rl = rlMag(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.2318, p = 2.9936e-05
pav = pavPreMag(spPav)'; rl = rlPreMag(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.1528, p = 0.0069
pav = pavPostMagR(spPav)'; rl = rlPostMagR(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.2808, p = 4.4223e-06
pav = pavPostMagN(spPav)'; rl = rlPostMagN(spRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.2748, p = 1.0425e-05


% AK, correlations in coding duration, all cells
[r p] = corr(pavDur(akPav)', rlDur(akRL)')              % r = 0.2364, p = 5.3432e-04
[r p] = corr(pavPreDur(akPav)', rlPreDur(akRL)')        % r = 0.2084, p = 0.0024
[r p] = corr(pavPostDurR(akPav)', rlPostDurR(akRL)')    % r = -0.0138, p = 0.8417
[r p] = corr(pavPostDurN(akPav)', rlPostDurN(akRL)')    % r = -0.0227, p = 0.7427

% AK, correlations in regression slope, all cells
pav = pavSlp(akPav)'; rl = rlSlp(akRL)';                        
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.0277, p = 0.6888
pav = pavPreSlp(akPav)'; rl = rlPreSlp(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0117, p = 0.8668
pav = pavPostSlpR(akPav)'; rl = rlPostSlpR(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0775, p = 0.2942
pav = pavPostSlpN(akPav)'; rl = rlPostSlpN(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.1116, p = 0.1436

% AK, correlations in slope magnitude, all cells
pav = pavMag(akPav)'; rl = rlMag(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.1923, p = 0.0051
pav = pavPreMag(akPav)'; rl = rlPreMag(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.0731, p = 0.2939
pav = pavPostMagR(akPav)'; rl = rlPostMagR(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.2314, p = 0.0015
pav = pavPostMagN(akPav)'; rl = rlPostMagN(akRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.1085, p = 0.1552


% RP, correlations in coding duration, all cells
[r p] = corr(pavDur(rpPav)', rlDur(rpRL)')              % r = 0.3542, p = 0.0021
[r p] = corr(pavPreDur(rpPav)', rlPreDur(rpRL)')        % r = 0.0619, p = 0.6028
[r p] = corr(pavPostDurR(rpPav)', rlPostDurR(rpRL)')    % r = 0.0523, p = 2.2621e-04
[r p] = corr(pavPostDurN(rpPav)', rlPostDurN(rpRL)')    % r = -0.1604, p = 0.1752

% RP, correlations in regression slope, all cells
pav = pavSlp(rpPav)'; rl = rlSlp(rpRL)';                        
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.1704, p = 0.1495
pav = pavPreSlp(rpPav)'; rl = rlPreSlp(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = -0.1862, p = 0.1148
pav = pavPostSlpR(rpPav)'; rl = rlPostSlpR(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.4134, p = 4.1490e-04
pav = pavPostSlpN(rpPav)'; rl = rlPostSlpN(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.1971, p = 0.1247

% RP, correlations in slope magnitude, all cells
pav = pavMag(rpPav)'; rl = rlMag(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % all
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.6407, p = 1.0276e-09
pav = pavPreMag(rpPav)'; rl = rlPreMag(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % pre-outcome only
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.4966, p = 7.8664e-06
pav = pavPostMagR(rpPav)'; rl = rlPostMagR(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, rewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.5577, p = 6.4377e-07
pav = pavPostMagN(rpPav)'; rl = rlPostMagN(rpRL)';
nN = ~isnan(pav) & ~isnan(rl);                                  % post-outcome, unrewarded
[r p] = corr(pav(nN), rl(nN))                                   % r = 0.2050, p = 0.1100


% Extra correlation stuff
% FP, correlations in coding duration, consistent coders only
sel = pavPreCon(fpPav)' > 0.9 & rlPreCon(fpRL)' > 0.9; length(find(sel))
[r p] = corr(pavPreDur(fpPav(sel))', rlPreDur(fpRL(sel))')      % NS, p = 0.07
[r p] = corr(pavPostDurR(fpPav(sel))', rlPostDurR(fpRL(sel))')  % *, p = 0.0117, r = 0.27
[r p] = corr(pavPostDurN(fpPav(sel))', rlPostDurN(fpRL(sel))')  % *, p = 0.0490, r = -0.21
sel = pavPostConR(fpPav)' > 0.9 & rlPostConR(fpRL)' > 0.9; length(find(sel))
[r p] = corr(pavPreDur(fpPav(sel))', rlPreDur(fpRL(sel))')      % NS, p = 0.93
[r p] = corr(pavPostDurR(fpPav(sel))', rlPostDurR(fpRL(sel))')  % *, p = 0.0342, r = 0.22
[r p] = corr(pavPostDurN(fpPav(sel))', rlPostDurN(fpRL(sel))')  % NS, p = 0.22

% FP, correlations in coding duration, big coders only
sel = pavPreMag(fpPav)' > nanmedian(pavPreMag(fpPav)) & rlPreMag(fpRL)' > nanmedian(rlPreMag(fpPav)); length(find(sel))
[r p] = corr(pavPreDur(fpPav(sel))', rlPreDur(fpRL(sel))')      % NS, p = 0.57
[r p] = corr(pavPostDurR(fpPav(sel))', rlPostDurR(fpRL(sel))')  % *, p < 0.001, r = 0.4
[r p] = corr(pavPostDurN(fpPav(sel))', rlPostDurN(fpRL(sel))')  % NS, p = 0.35
sel = pavPostMagR(fpPav)' > nanmedian(pavPostMagR(fpPav)) & rlPostMagR(fpRL)' > nanmedian(rlPostMagR(fpPav)); length(find(sel))
[r p] = corr(pavPreDur(fpPav(sel))', rlPreDur(fpRL(sel))')      % NS, p = 0.36
[r p] = corr(pavPostDurR(fpPav(sel))', rlPostDurR(fpRL(sel))')  % NS, p = 0.09
[r p] = corr(pavPostDurN(fpPav(sel))', rlPostDurN(fpRL(sel))')  % NS, p = 0.15

% FP, correlations in regression slope, consistent coders only
sel = pavPreCon(fpPav)' > 0.9 & rlPreCon(fpRL)' > 0.9; length(find(sel))
[r p] = corr(pavPreSlp(fpPav(sel))', rlPreSlp(fpRL(sel))')      % NS, p = 0.32
[r p] = corr(pavPostSlpR(fpPav(sel))', rlPostSlpR(fpRL(sel))')  % NaN
[r p] = corr(pavPostSlpN(fpPav(sel))', rlPostSlpN(fpRL(sel))')  % NaN
sel = pavPostConR(fpPav)' > 0.9 & rlPostConR(fpRL)' > 0.9; length(find(sel))
[r p] = corr(pavPreSlp(fpPav(sel))', rlPreSlp(fpRL(sel))')      % NaN
[r p] = corr(pavPostSlpR(fpPav(sel))', rlPostSlpR(fpRL(sel))')  % NS, p = 0.72
[r p] = corr(pavPostSlpN(fpPav(sel))', rlPostSlpN(fpRL(sel))')  % NaN

% FP, correlations in regression slope, big coders only
sel = pavPreMag(fpPav)' > nanmedian(pavPreMag(fpPav)) & rlPreMag(fpRL)' > nanmedian(rlPreMag(fpPav)); length(find(sel))
[r p] = corr(pavPreSlp(fpPav(sel))', rlPreSlp(fpRL(sel))')      % NS, p = 0.94
[r p] = corr(pavPostSlpR(fpPav(sel))', rlPostSlpR(fpRL(sel))')  % NaN
[r p] = corr(pavPostSlpN(fpPav(sel))', rlPostSlpN(fpRL(sel))')  % NaN
sel = pavPostMagR(fpPav)' > nanmedian(pavPostMagR(fpPav)) & rlPostMagR(fpRL)' > nanmedian(rlPostMagR(fpPav)); length(find(sel))
[r p] = corr(pavPreSlp(fpPav(sel))', rlPreSlp(fpRL(sel))')      % NS, p = 0.50
[r p] = corr(pavPostSlpR(fpPav(sel))', rlPostSlpR(fpRL(sel))')  % NS, p = 0.40
[r p] = corr(pavPostSlpN(fpPav(sel))', rlPostSlpN(fpRL(sel))')  % NaN

% FP, correlations in slope magnitude, consistent coders only
sel = pavPreCon(fpPav)' > 0.9 & rlPreCon(fpRL)' > 0.9; length(find(sel))
[r p] = corr(pavPreMag(fpPav(sel))', rlPreMag(fpRL(sel))')      % *, p = 0.0347, r = 0.2280
[r p] = corr(pavPostMagR(fpPav(sel))', rlPostMagR(fpRL(sel))')  % NaN
[r p] = corr(pavPostMagN(fpPav(sel))', rlPostMagN(fpRL(sel))')  % NaN
sel = pavPostConR(fpPav)' > 0.9 & rlPostConR(fpRL)' > 0.9; length(find(sel))
[r p] = corr(pavPreMag(fpPav(sel))', rlPreMag(fpRL(sel))')      % NaN
[r p] = corr(pavPostMagR(fpPav(sel))', rlPostMagR(fpRL(sel))')  % NS, p = 0.09
[r p] = corr(pavPostMagN(fpPav(sel))', rlPostMagN(fpRL(sel))')  % NaN

% FP, correlations in slope magnitude, big coders only
sel = pavPreMag(fpPav)' > nanmedian(pavPreMag(fpPav)) & rlPreMag(fpRL)' > nanmedian(rlPreMag(fpPav)); length(find(sel))
[r p] = corr(pavPreMag(fpPav(sel))', rlPreMag(fpRL(sel))')      % NS, p = 0.12
[r p] = corr(pavPostMagR(fpPav(sel))', rlPostMagR(fpRL(sel))')  % NaN
[r p] = corr(pavPostMagN(fpPav(sel))', rlPostMagN(fpRL(sel))')  % NaN
sel = pavPostMagR(fpPav)' > nanmedian(pavPostMagR(fpPav)) & rlPostMagR(fpRL)' > nanmedian(rlPostMagR(fpPav)); length(find(sel))
[r p] = corr(pavPreMag(fpPav(sel))', rlPreMag(fpRL(sel))')      % NS, p = 0.70
[r p] = corr(pavPostMagR(fpPav(sel))', rlPostMagR(fpRL(sel))')  % NS, p = 0.83
[r p] = corr(pavPostMagN(fpPav(sel))', rlPostMagN(fpRL(sel))')  % NaN



%% Figure 5b: Coding before Rwd

% coding duration, Pavlovian
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
stairs([min(pavTotDur(rpPav)) sort(pavTotDur(rpPav))], (0:length(rpPav)) / length(rpPav), 'color', rpColor, 'linewidth', 3)
stairs([min(pavTotDur(fpPav)) sort(pavTotDur(fpPav))], (0:length(fpPav)) / length(fpPav), 'color', fpColor, 'linewidth', 3)
stairs([min(pavTotDur(spPav)) sort(pavTotDur(spPav))], (0:length(spPav)) / length(spPav), 'color', 'b', 'linewidth', 3)
stairs([min(pavTotDur(akPav)) sort(pavTotDur(akPav))], (0:length(akPav)) / length(akPav), 'color', 'c', 'linewidth', 3)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';


% coding duration, RL
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
stairs([min(rlPreDur(rp)) sort(rlPreDur(rp))], (0:length(rp)) / length(rp), 'color', rpColor, 'linewidth', 3)
stairs([min(rlPreDur(fp)) sort(rlPreDur(fp))], (0:length(fp)) / length(fp), 'color', fpColor, 'linewidth', 3)
stairs([min(rlPreDur(sp)) sort(rlPreDur(sp))], (0:length(sp)) / length(sp), 'color', 'b', 'linewidth', 3)
stairs([min(rlPreDur(ak)) sort(rlPreDur(ak))], (0:length(ak)) / length(ak), 'color', 'c', 'linewidth', 3)
xlim([0 1])
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
ax = gca;
ax.YTick = [0.25 0.5 0.75]; ax.XTick = [0.25 0.5 0.75];
ax.YTickLabels = []; ax.XTickLabels = [];
ax.Box = 'on';
grp = [ones(size(fp)) 2*ones(size(sp)) 3*ones(size(ak))];
kruskalwallis([rlPreDur(fp) rlPreDur(sp) rlPreDur(ak)], grp) % p = 1.1186e-15
[mean(rlPreDur(fp)) mean(rlPreDur(sp)) mean(rlPreDur(ak))]
%     0.4083              0.2527            0.2497
[ranksum(rlPreDur(fp), rlPreDur(sp)) ranksum(rlPreDur(fp), rlPreDur(ak))]
%               1.8238e-14                          5.1987e-11

% coding magnitude, Pavlovian
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
sFP = pavPreMag(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPreMag(spPav); sSP(isnan(sSP)) = [];
sAK = pavPreMag(akPav); sAK(isnan(sAK)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 3)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 3)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 3)
plot([0 0.025], [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 0.023])
ax = gca; ax.Box = 'on';
ax.XTick = [0.01 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];
grp = [ones(size(sFP)) 2*ones(size(sSP)) 3*ones(size(sAK))];
kruskalwallis([sFP sSP sAK], grp) % p = 2.2808e-9
100*[mean(sFP) mean(sSP) mean(sAK)]
%      0.9454   0.8690     0.8572
[ranksum(sFP, sSP) ranksum(sFP, sAK)]
%    2.6766e-8        5.7510e-8

% coding magnitude, Pavlovian (before and after rwd combined)
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
sRP = pavMag(rpPav); sRP(isnan(sRP)) = [];
sFP = pavMag(fpPav); sFP(isnan(sFP)) = [];
sSP = pavMag(spPav); sSP(isnan(sSP)) = [];
sAK = pavMag(akPav); sAK(isnan(sAK)) = [];
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 3)
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 3)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 3)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 3)
plot([0 0.025], [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 0.023])
ax = gca; ax.Box = 'on';
ax.XTick = [0.01 0.02]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];
grp = [ones(size(sFP)) 2*ones(size(sSP)) 3*ones(size(sAK))];
kruskalwallis([sFP sSP sAK], grp) % p = 2.2808e-9
100*[mean(sFP) mean(sSP) mean(sAK)]
%      0.9454   0.8690     0.8572
[ranksum(sFP, sSP) ranksum(sFP, sAK)]
%    2.6766e-8        5.7510e-8

% coding magnitude, RL
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
sFP = rlPreMag(fp); sFP(isnan(sFP)) = [];
sSP = rlPreMag(sp); sSP(isnan(sSP)) = [];
sAK = rlPreMag(ak); sAK(isnan(sAK)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 3)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 3)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 3)
plot([0 0.3], [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 0.23])
ax = gca; ax.Box = 'on';
ax.XTick = [0.1 0.2]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];
grp = [ones(size(sFP)) 2*ones(size(sSP)) 3*ones(size(sAK))];
kruskalwallis([sFP sSP sAK], grp) % p = 2.8087e-31
[mean(sFP) mean(sSP) mean(sAK)]
%  0.0936   0.0685     0.0823
[ranksum(sFP, sSP) ranksum(sFP, sAK)]
%    3.1360e-28        5.7920e-5

% coding magnitude, RL (pre and post rwd combined
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
sRP = rlMag(rp); sRP(isnan(sRP)) = [];
sFP = rlMag(fp); sFP(isnan(sFP)) = [];
sSP = rlMag(sp); sSP(isnan(sSP)) = [];
sAK = rlMag(ak); sAK(isnan(sAK)) = [];
stairs([min(sRP) sort(sRP)], (0:length(sRP)) / length(sRP), 'color', rpColor, 'linewidth', 3)
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 3)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 3)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 3)
plot([0 0.3], [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 0.23])
ax = gca; ax.Box = 'on';
ax.XTick = [0.1 0.2]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];
grp = [ones(size(sFP)) 2*ones(size(sSP)) 3*ones(size(sAK))];
kruskalwallis([sFP sSP sAK], grp) % p = 2.8087e-31
[mean(sFP) mean(sSP) mean(sAK)]
%  0.0936   0.0685     0.0823
[ranksum(sFP, sSP) ranksum(sFP, sAK)]
%    3.1360e-28        5.7920e-5


% coding consistency, Pavlovian
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
sFP = pavPreCon(fpPav); sFP(isnan(sFP)) = [];
sSP = pavPreCon(spPav); sSP(isnan(sSP)) = [];
sAK = pavPreCon(akPav); sAK(isnan(sAK)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 3)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 3)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 3)
plot(xlim, [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 1])
ax = gca; ax.Box = 'on';
ax.XTick = [0.25 0.5 0.75]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];
grp = [ones(size(sFP)) 2*ones(size(sSP)) 3*ones(size(sAK))];
kruskalwallis([sFP sSP sAK], grp) % p = 0.0113
[mean(sFP) mean(sSP) mean(sAK)]
%  0.8025   0.7337     0.7436
[ranksum(sFP, sSP) ranksum(sFP, sAK)]
%       0.005          0.0166

% coding consistency, RL
figure('Position', [10 100 440 440])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
sFP = rlPreCon(fp); sFP(isnan(sFP)) = [];
sSP = rlPreCon(sp); sSP(isnan(sSP)) = [];
sAK = rlPreCon(ak); sAK(isnan(sAK)) = [];
stairs([min(sFP) sort(sFP)], (0:length(sFP)) / length(sFP), 'color', fpColor, 'linewidth', 3)
stairs([min(sSP) sort(sSP)], (0:length(sSP)) / length(sSP), 'color', 'b', 'linewidth', 3)
stairs([min(sAK) sort(sAK)], (0:length(sAK)) / length(sAK), 'color', 'c', 'linewidth', 3)
plot([0 1], [0.5 0.5], '--k', 'linewidth', 1)
xlim([0 1])
ax = gca; ax.Box = 'on';
ax.XTick = [0.25 0.5 0.75]; ax.YTick = [0.25 0.5 0.75];
ax.XTickLabels = []; ax.YTickLabels = [];
grp = [ones(size(sFP)) 2*ones(size(sSP)) 3*ones(size(sAK))];
kruskalwallis([sFP sSP sAK], grp) % p = 1.2413e-8
[mean(sFP) mean(sSP) mean(sAK)]
%  0.8183   0.8166     0.7091
[ranksum(sFP, sSP) ranksum(sFP, sAK)]
%       0.5845          7.6e-7




%% Figure 5C: Response to Laser
% use "GPe-RPE laser response" if this doesn't work properly

% remove WT units that don't have laser data
uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
ratList = {'IM1153', 'IM1261'};
pvCre = ismember(uRat, ratList);
unit = unit(pvCre);
uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)

sesList = unique(uSes);

problemSes = 14:19 % sessions where Tom apparently didn't break up files by laser power
tomPower = [0.5 1 2 5 10];
tomDur = [0.5 1 10 100];
tomPulseNum = [100 100 50 50];

pulseDur = 1;
powerWin = [0 Inf];
maxFreq = 10;

win = [-0.05 0.35];
binWidth = 0.002;
bE = win(1):binWidth:win(2);
bC = bE(2:end) - diff(bE)/2;
psth = nan(length(unit), length(bC));

for s = 1:length(sesList)
    sesUnits = find(ismember(uSes, sesList{s}));
    rat = uRat{sesUnits(1)};
    sesDir = [datRoot rat filesep sesList{s} filesep];
    tmp = load([sesDir 'laserDat.mat']);
    lR = tmp.laserResponse(1).block;
    lR = lR(cellfun(@(l) ~isempty(l), lR));
    if ismember(s, problemSes)
        lRold = lR;
        lR = cell(1, length(tomPower));
        N = length(tomDur);
        taskIdx = find(strcmp('laser', unit(sesUnits(1)).taskList));
        for p = 1:length(tomPower)
            lR{p} = lRold{1}((p-1)*N+(1:N));
            for k = 1:N
                lR{p}(k).taskIdx = taskIdx;
                lR{p}(k).taskName = 'laser';
                lR{p}(k).laserPower = tomPower(p);   
            end
        end
    end
    clear pulseInfo
    targetPulse = cell(1,length(lR));
    for i = 1:length(lR)
        pulseInfo(i).power = lR{i}(1).laserPower;
        pulseInfo(i).freq = arrayfun(@(l) l.pulseFrequency, lR{i});
        pulseInfo(i).dur = arrayfun(@(l) round(l.pulseDur(1)), lR{i});
        pulseInfo(i).n = arrayfun(@(l) length(l.pulseOnset), lR{i});
        targetPulse{i} = find(pulseInfo(i).freq <= maxFreq & pulseInfo(i).dur == pulseDur);
    end
    lR = lR(cellfun(@(tp) ~isempty(tp), targetPulse));
    pulseInfo = pulseInfo(cellfun(@(tp) ~isempty(tp), targetPulse));
    targetPulse = targetPulse(cellfun(@(tp) ~isempty(tp), targetPulse));
    power = arrayfun(@(pi) pi.power, pulseInfo);
    sel = power >= powerWin(1) & power <= powerWin(2);
    lR = lR(sel);
    targetPulse = targetPulse(sel);
    taskIdx = [];
    pulseOnset = {};
    for blk = 1:length(lR)
        for bout = targetPulse{blk}
            [lia locB] = ismember(lR{blk}(bout).taskIdx, taskIdx);
            if lia
                pulseOnset{locB} = [pulseOnset{locB}; lR{blk}(bout).pulseOnset];
            else
                taskIdx = [taskIdx lR{blk}(bout).taskIdx];
                pulseOnset{length(taskIdx)} = lR{blk}(bout).pulseOnset;
            end
        end
    end
    nTr = sum(cellfun(@(p) length(p), pulseOnset));
    for u = sesUnits
        psth(u,:) = zeros(1,length(bC));
        for t = 1:length(taskIdx)
            ti = taskIdx(t);
            spk = unit(u).spkTimes;
            spk = spk(spk>unit(u).taskStart(ti) & spk<unit(u).taskEnd(ti)) - unit(u).taskStart(ti);
            for p = pulseOnset{t}'
                psth(u,:) = psth(u,:) + histcounts(spk-p, bE);
            end
        end
        psth(u,:) = psth(u,:) / (binWidth * nTr);
    end
    
end

% cell counts by type
nFP = length(find(~isnan(psth(fp,1)))) % 64
nSP = length(find(~isnan(psth(sp,1)))) % 173
nAK = length(find(~isnan(psth(ak,1)))) % 85
nRP = length(find(~isnan(psth(rp,1)))) % 38

% z-score PSTH
psth = psth - mean(psth(:,bC<0),2);
psth = psth ./ std(psth,[],2);

fpM = nanmean(psth(fp,:));
fpL = fpM - nanstd(psth(fp,:)) / sqrt(nFP);
fpH = fpM + nanstd(psth(fp,:)) / sqrt(nFP);
spM = nanmean(psth(sp,:));
spL = spM - nanstd(psth(sp,:)) / sqrt(nSP);
spH = spM + nanstd(psth(sp,:)) / sqrt(nSP);
akM = nanmean(psth(ak,:));
akL = akM - nanstd(psth(ak,:)) / sqrt(nAK);
akH = akM + nanstd(psth(ak,:)) / sqrt(nAK);
rpM = nanmean(psth(rp,:));
rpL = rpM - nanstd(psth(rp,:)) / sqrt(nRP);
rpH = rpM + nanstd(psth(rp,:)) / sqrt(nRP);

t = bC*1000;

figure('Position', [10 100 1200 500])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
shade(t, akH, t, akL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t, akM, 'linewidth', 2, 'color', 'c')
shade(t, fpH, t, fpL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t, fpM, 'linewidth', 2, 'color', fpColor)
shade(t, spH, t, spL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t, spM, 'linewidth', 2, 'color', 'b')
shade(t, rpH, t, rpL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t, rpM, 'linewidth', 2, 'color', rpColor)
plot(t([1 end]), [0 0], '--k', 'linewidth', 1)
yR = [-1.15 2.65];
ylim(yR)
plot([0 0], yR, 'color', [1 0.2 0.2], 'linewidth', 1)
plot([pulseDur pulseDur], yR, 'color', [1 0.2 0.2], 'linewidth', 1)
plot([0 pulseDur], [yR(1) yR(1)], 'color', [1 0.2 0.2], 'linewidth', 4)
plot([0 pulseDur], [yR(2) yR(2)], 'color', [1 0.2 0.2], 'linewidth', 4)
plot([-35 -35], [1 2], 'k', 'linewidth', 5)
plot([200 250], [1.5 1.5], 'k', 'linewidth', 5)
ylim(yR + [-0.05 0.05])
ax = gca; ax.YTick = -1:2; ax.XTick = 0:100:300;
ax.YTickLabels = []; ax.XTickLabels = [];

% 1-ms pulses
pulseDur = 1;
powerWin = [0 Inf];
maxFreq = 2;

win = [-0.01 0.05];
binWidth = 0.0005;
bE = win(1):binWidth:win(2);
bC = bE(2:end) - diff(bE)/2;
psth = nan(length(unit), length(bC));

for s = 1:length(sesList)
    sesUnits = find(ismember(uSes, sesList{s}));
    rat = uRat{sesUnits(1)};
    sesDir = [datRoot rat filesep sesList{s} filesep];
    tmp = load([sesDir 'laserDat.mat']);
    lR = tmp.laserResponse(1).block;
    lR = lR(cellfun(@(l) ~isempty(l), lR));
    if ismember(s, problemSes)
        lRold = lR;
        lR = cell(1, length(tomPower));
        N = length(tomDur);
        taskIdx = find(strcmp('laser', unit(sesUnits(1)).taskList));
        for p = 1:length(tomPower)
            lR{p} = lRold{1}((p-1)*N+(1:N));
            for k = 1:N
                lR{p}(k).taskIdx = taskIdx;
                lR{p}(k).taskName = 'laser';
                lR{p}(k).laserPower = tomPower(p);   
            end
        end
    end
    clear pulseInfo
    targetPulse = cell(1,length(lR));
    for i = 1:length(lR)
        pulseInfo(i).power = lR{i}(1).laserPower;
        pulseInfo(i).freq = arrayfun(@(l) l.pulseFrequency, lR{i});
        pulseInfo(i).dur = arrayfun(@(l) round(l.pulseDur(1)), lR{i});
        pulseInfo(i).n = arrayfun(@(l) length(l.pulseOnset), lR{i});
        targetPulse{i} = find(pulseInfo(i).freq <= maxFreq & pulseInfo(i).dur == pulseDur);
    end
    lR = lR(cellfun(@(tp) ~isempty(tp), targetPulse));
    pulseInfo = pulseInfo(cellfun(@(tp) ~isempty(tp), targetPulse));
    targetPulse = targetPulse(cellfun(@(tp) ~isempty(tp), targetPulse));
    power = arrayfun(@(pi) pi.power, pulseInfo);
    sel = power >= powerWin(1) & power <= powerWin(2);
    lR = lR(sel);
    targetPulse = targetPulse(sel);
    taskIdx = [];
    pulseOnset = {};
    for blk = 1:length(lR)
        for bout = targetPulse{blk}
            [lia locB] = ismember(lR{blk}(bout).taskIdx, taskIdx);
            if lia
                pulseOnset{locB} = [pulseOnset{locB}; lR{blk}(bout).pulseOnset];
            else
                taskIdx = [taskIdx lR{blk}(bout).taskIdx];
                pulseOnset{length(taskIdx)} = lR{blk}(bout).pulseOnset;
            end
        end
    end
    nTr = sum(cellfun(@(p) length(p), pulseOnset));
    for u = sesUnits
        psth(u,:) = zeros(1,length(bC));
        for t = 1:length(taskIdx)
            ti = taskIdx(t);
            spk = unit(u).spkTimes;
            spk = spk(spk>unit(u).taskStart(ti) & spk<unit(u).taskEnd(ti)) - unit(u).taskStart(ti);
            for p = pulseOnset{t}'
                psth(u,:) = psth(u,:) + histcounts(spk-p, bE);
            end
        end
        psth(u,:) = psth(u,:) / (binWidth * nTr);
    end
    
end

% cell counts by type
nFP = length(find(~isnan(psth(fp,1)))) % 67
nSP = length(find(~isnan(psth(sp,1)))) % 193
nAK = length(find(~isnan(psth(ak,1)))) % 97
nRP = length(find(~isnan(psth(rp,1)))) % 41

% z-score PSTH
psth = psth - mean(psth(:,bC<0),2);
psth = psth ./ std(psth,[],2);

smWd = 3;
fpM = smoothdata(nanmean(psth(fp,:)), 'gaussian', smWd);
fpL = fpM - smoothdata(nanstd(psth(fp,:)), 'gaussian', smWd) / sqrt(nFP);
fpH = fpM + smoothdata(nanstd(psth(fp,:)), 'gaussian', smWd) / sqrt(nFP);
spM = smoothdata(nanmean(psth(sp,:)), 'gaussian', smWd);
spL = spM - smoothdata(nanstd(psth(sp,:)), 'gaussian', smWd) / sqrt(nSP);
spH = spM + smoothdata(nanstd(psth(sp,:)), 'gaussian', smWd) / sqrt(nSP);
akM = smoothdata(nanmean(psth(ak,:)), 'gaussian', smWd);
akL = akM - smoothdata(nanstd(psth(ak,:)), 'gaussian', smWd) / sqrt(nAK);
akH = akM + smoothdata(nanstd(psth(ak,:)), 'gaussian', smWd) / sqrt(nAK);
rpM = smoothdata(nanmean(psth(rp,:)), 'gaussian', smWd);
rpL = rpM - smoothdata(nanstd(psth(rp,:)), 'gaussian', smWd) / sqrt(nRP);
rpH = rpM + smoothdata(nanstd(psth(rp,:)), 'gaussian', smWd) / sqrt(nRP);

t = bC*1000;

figure('Position', [10 100 1200 500])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
shade(t, akH, t, akL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t, akM, 'linewidth', 2, 'color', 'c')
shade(t, fpH, t, fpL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t, fpM, 'linewidth', 2, 'color', fpColor)
shade(t, spH, t, spL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t, spM, 'linewidth', 2, 'color', 'b')
shade(t, rpH, t, rpL, 'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t, rpM, 'linewidth', 2, 'color', rpColor)
plot(t([1 end]), [0 0], '--k', 'linewidth', 1)
yR = [-1.65 2.15];
ylim(yR)
plot([0 0], yR+[0.1 -0.1], 'color', [1 0.2 0.2], 'linewidth', 1)
plot([pulseDur pulseDur], yR+[0.1 -0.1], 'color', [1 0.2 0.2], 'linewidth', 1)
plot([0 pulseDur], [yR(1) yR(1)]+0.1, 'color', [1 0.2 0.2], 'linewidth', 4)
plot([0 pulseDur], [yR(2) yR(2)]-0.1, 'color', [1 0.2 0.2], 'linewidth', 4)
plot([-7 -7], [1 2], 'k', 'linewidth', 5)
plot([7.5 12.5], [1 1], 'k', 'linewidth', 5)
ylim(yR + [-0.05 0.05])
ax = gca; ax.YTick = -1:2; ax.XTick = 0:10:40;
ax.YTickLabels = []; ax.XTickLabels = [];