%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)

rpColor = [0.7 0 0];
fpColor = [1 0.5 0];



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end      
end



%% Analyze RPE coding at Phasic Peaks

% specs for response measurement
sigma = 20;
win = [-0.1 0.3];
pol = 0;

% 1) RL (after side in, rewarded trials)
mRL = zeros(1, length(unit));
for u = 1:length(unit)
    
    uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', sigma);
    [~, rlIdx] = ismember('rl', lower(unit(u).taskList));
    [~, iSes] = ismember(uSes{u}, sesList);
    ts = unit(u).behav_ts{rlIdx};
    rwd = TrialFilter(ts, 'x1', unit(u).side);
    eTime = ts.Side_NI;
    rr = rwdRate{iSes};
    fr = PeakResponse(uTraj, eTime(rwd), win, pol);
    sel = find(rwd > 10);
    lm = fitlm(rr(rwd(sel)), fr(sel));
    mRL(u) = lm.Coefficients.Estimate(2);
    
end

% 2) Pav (after US, rewarded trials)
mPav = nan(1, length(unit));
for u = 1:length(unit)
    
    [~, pavIdx] = ismember('Pav', unit(u).taskList);
    if pavIdx ~= 0
        ts = unit(u).behav_ts{pavIdx};
    else
        continue
    end
    uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', sigma);
    dt = uTraj.times(2) - uTraj.times(1);
    lg = unit(u).behav_log{pavIdx};
    cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
    cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);
    tr25 = find(lg.toneFreq == cue25);
    tr75 = find(lg.toneFreq == cue75);
    rwd = find(lg.outcome);
    rwdTime = dt*round(nanmean(ts.rwdTime - ts.csTime)/dt);
    eTime = ts.csTime + rwdTime;

    % US prob 25 rewarded
    tr = intersect(tr25, rwd);
    fr25 = PeakResponse(uTraj, eTime(tr), win, pol);
    
    % US prob 75 rewarded
    tr = intersect(tr75, rwd);
    fr75 = PeakResponse(uTraj, eTime(tr), win, pol);
    
    probRwd = [0.25*ones(size(fr25)); 0.75*ones(size(fr75))];
    lm = fitlm(probRwd, [fr25; fr75]);
    mPav(u) = lm.Coefficients.Estimate(2);
    
end



%% Fraction of Time Coding Value

% 1) RL
load([datRoot 'rlLR3.mat']);

% RL times
winRL = [-1 1];
winPre = [winRL(1) 0];
winPost = [0 winRL(2)];
dtLR = 0.005;
tLR = winRL(1):dtLR:winRL(2);
pt0 = find(abs(tLR) == min(abs(tLR))); 
tPre = winRL(1):dtLR:0;
tPost = 0:dtLR:winRL(2);

% significance criteria
pCrit = 0.05;

% time windows (in seconds)
postCiWin = 0.5; postCiPt = find(abs(tLR-postCiWin) == min(abs(tLR-postCiWin)));
preGoWin = 0.5; preGoPt = find(abs(tLR+preGoWin) == min(abs(tLR+preGoWin)));
postGoWin = 0.1; postGoPt = find(abs(tLR-postGoWin) == min(abs(tLR-postGoWin)));
preSiWin = 0.2; preSiPt = find(abs(tLR+preSiWin) == min(abs(tLR+preSiWin)));

rlDur = nan(1, length(unit));

for u = 1:length(unit)
    
    sig1 = pR{2}(u,pt0+1:postCiPt) < pCrit;  % post CI sig
    sig2 = pR{3}(u,preGoPt:pt0) < pCrit;     % pre GO sig
    sig3 = pR{3}(u,pt0+1:postGoPt) < pCrit;  % post GO sig
    sig4 = pR{4}(u,preSiPt:pt0) < pCrit;     % pre SI sig
    sig5 = pRr{1}(u,:) < pCrit;              % post SI sig (rewarded)
    
    sig = [sig1 sig2 sig3 sig4 sig5];
    rlDur(u) = length(find(sig)) / length(sig); 
    
end

% 2) Pav
load([datRoot 'pavLR3.mat']);

rwdTime = 3.1356;
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
pt0 = find(abs(t1) == min(abs(t1)));

% significance criteria
pCrit = 0.05;

% time windows (in seconds)
postCsWin = rwdTime;
csPt = min([round(postCsWin / dtLR) + pt0, size(pRR,2)]);
postUsWin = 1;
usPt = round(postUsWin / dtLR);

pavDur = nan(1, length(uPav2));
for u = 1:length(uPav2)
    
    sig1 = pRR(u,pt0:csPt) < pCrit;
    sig2 = pRRr(u,1:usPt) < pCrit;
    sig = [sig1 sig2];
    pavDur(u) = length(find(sig)) / length(sig);

end



%% Load Unit and Cell Location Data

% load saved location data if already processed
load('/Users/michaelfarries/Documents/GPe-RPE paper/Fig 7/manuscript cell loc 3-27.mat')
unit = unit(keepCells);
% variables loaded:  ml, dv, ap, apRel, keepCells

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)



%% Cell Location from Scratch (load unit data first)

% keep only data from wildtype rats (remove PV-Cre rats)
ratList = {'IM1130', 'IM1137', 'IM1178'};
keepCells = find(ismember(uRat, ratList));
unit = unit(keepCells);
uRat = uRat(keepCells);

% load cell locations
locRoot = '/Users/michaelfarries/Documents/data/'
ratLocDir = {'IM1130/histology/coordinates (final)/','IM1137/histology/coordinates (edited)/','IM1178/coordinates (final)/'};
uAP = zeros(1, length(unit));
uDV = zeros(1, length(unit));
uML = zeros(1, length(unit));
unitDateNum = cellfun(@(x) strsplit(x(6:end), '-'), uSes, 'UniformOutput', false);
unitDateNum = cellfun(@(x) str2num(x{1})*100 + str2num(x{2}), unitDateNum);
for r = 1:length(ratList)
    uR = find(strcmp(uRat, ratList{r}));
    fList = dir([locRoot ratLocDir{r} '*.mat']);
    fList = arrayfun(@(f) f.name, fList, 'UniformOutput', false);
    trodeList = cellfun(@(x) x(1:end-4), fList, 'UniformOutput', false);
    for t = 1:length(trodeList)
        load([locRoot ratLocDir{r} fList{t}]);
        uIdx = intersect(find(strcmp(trodeList{t}, uTrode)), uR);
        if r == 2
            trodeDateNum = cellfun(@(x) strsplit(x(6:end), '-'), recDate, 'UniformOutput', false);
        else
            trodeDateNum = cellfun(@(x) strsplit(x, '/'), recDate, 'UniformOutput', false);
        end
        trodeDateNum = cellfun(@(x) str2num(x{1})*100 + str2num(x{2}), trodeDateNum);
        for u = uIdx
            locIdx = find(unitDateNum(u) == trodeDateNum);
            uAP(u) = ap(locIdx);
            uDV(u) = dv(locIdx);
            uML(u) = ml(locIdx);
        end
    end
end

% remove the few cells that have no location logged
nullLoc = find(uML == 0);
keepCells(nullLoc) = [];
unit(nullLoc) = [];
uRat(nullLoc) = [];
uAP(nullLoc) = [];
uDV(nullLoc) = [];
uML(nullLoc) = [];

uName = uName(keepCells);
uSes = uSes(keepCells);
uTrode = uTrode(keepCells);
uNum = uNum(keepCells);
uType = uType(keepCells);

fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)

% unit lists by rat
u1178 = find(strcmp(uRat, ratList{3}));
u1137 = find(strcmp(uRat, ratList{2}));
u1130 = find(strcmp(uRat, ratList{1}));

% plot locations by rat
figure
scatter3(uML(u1178), uAP(u1178), uDV(u1178), 50, 'g')
xlabel('ML'); ylabel('AP'); zlabel('DV')
hold on
scatter3(uML(u1137), uAP(u1137), uDV(u1137), 50, 'r')
scatter3(uML(u1130), uAP(u1130), uDV(u1130), 50, 'b')

figure('NumberTitle', 'off', 'Name', 'horizontal projection')
hold on
scatter(uML(u1178), uAP(u1178), 50, 'g')
scatter(uML(u1137), uAP(u1137), 50, 'r')
scatter(uML(u1130), uAP(u1130), 50, 'b')
xlabel('ML'); ylabel('AP');
ax = gca;
ax.YGrid = 'on'; ax.YMinorGrid = 'on';
ax.XGrid = 'on'; ax.XMinorGrid = 'on';

figure('NumberTitle', 'off', 'Name', 'coronal projection')
hold on
scatter(uML(u1178), uDV(u1178), 50, 'g')
scatter(uML(u1137), uDV(u1137), 50, 'r')
scatter(uML(u1130), uDV(u1130), 50, 'b')
xlabel('ML'); ylabel('DV');
ax = gca;
ax.YGrid = 'on'; ax.YMinorGrid = 'on';
ax.XGrid = 'on'; ax.XMinorGrid = 'on';

figure('NumberTitle', 'off', 'Name', 'sagittal projection')
hold on
scatter(uAP(u1178), uDV(u1178), 50, 'g')
scatter(uAP(u1137), uDV(u1137), 50, 'r')
scatter(uAP(u1130), uDV(u1130), 50, 'b')
xlabel('AP'); ylabel('DV');
ax = gca;
ax.YGrid = 'on'; ax.YMinorGrid = 'on';
ax.XGrid = 'on'; ax.XMinorGrid = 'on';

% adjustments to harmonize across rats
dML78 = 0;
dAP78 = 0.25;
dDV78 = 0;

dML37 = -0.25;
dAP37 = 0;
dDV37 = 0;

dML30 = -0.25;
dAP30 = -0.25;
dDV30 = 0;

figure
scatter3(uML(u1178)+dML78, uAP(u1178)+dAP78, uDV(u1178)+dDV78, 50, 'g')
hold on
scatter3(uML(u1137)+dML37, uAP(u1137)+dAP37, uDV(u1137)+dDV37, 50, 'r')
scatter3(uML(u1130)+dML30, uAP(u1130)+dAP30, uDV(u1130)+dDV30, 50, 'b')
xlabel('ML'); ylabel('AP'); zlabel('DV')

% define caudal edge of GPe in AP-ML plane
figure('NumberTitle', 'off', 'Name', 'horizontal projection')
hold on
scatter(uML(u1178)+dML78, uAP(u1178)+dAP78, 50, 'g')
scatter(uML(u1137)+dML37, uAP(u1137)+dAP37, 50, 'r')
scatter(uML(u1130)+dML30, uAP(u1130)+dAP30, 50, 'b')
xlabel('ML'); ylabel('AP');
ax = gca;
ax.YGrid = 'on'; ax.YMinorGrid = 'on';
ax.XGrid = 'on'; ax.XMinorGrid = 'on';

mlCaudalPts = [ 2.3  2.8  3.0  3.2  3.5  4.0  4.3];
apCaudalPts = [-1.9 -2.0 -2.1 -2.2 -2.4 -3.0 -3.5];
scatter(mlCaudalPts, apCaudalPts, 20, 'k', 'filled')
plot(mlCaudalPts, apCaudalPts, 'k')

% add jitter to locations to avoid overlap
ap = uAP + 0.04*randn(size(uAP));
dv = uDV + 0.04*randn(size(uDV));
ml = uML + 0.04*randn(size(uML));

% incorporate "harmonization" shifts
ap(u1130) = ap(u1130) + dAP30;
ap(u1137) = ap(u1137) + dAP37;
ap(u1178) = ap(u1178) + dAP78;

dv(u1130) = dv(u1130) + dDV30;
dv(u1137) = dv(u1137) + dDV37;
dv(u1178) = dv(u1178) + dDV78;

ml(u1130) = ml(u1130) + dML30;
ml(u1137) = ml(u1137) + dML37;
ml(u1178) = ml(u1178) + dML78;

figure
scatter3(ml(u1178), ap(u1178), dv(u1178), 50, 'g')
hold on
scatter3(ml(u1137), ap(u1137), dv(u1137), 50, 'r')
scatter3(ml(u1130), ap(u1130), dv(u1130), 50, 'b')
xlabel('ML'); ylabel('AP'); zlabel('DV')

% define AP location relative to caudal GPe border
apRel = ap - interp1(mlCaudalPts, apCaudalPts, ml, 'linear', 'extrap');

figure
scatter3(ml(u1178), apRel(u1178), dv(u1178), 50, 'g')
hold on
scatter3(ml(u1137), apRel(u1137), dv(u1137), 50, 'r')
scatter3(ml(u1130), apRel(u1130), dv(u1130), 50, 'b')
xlabel('ML'); ylabel('AP'); zlabel('DV')

save('/Users/michaelfarries/Documents/GPe-RPE paper/Fig 7/manuscript cell loc 3-27.mat', 'ml', 'dv', 'ap', 'apRel', 'keepCells')



%% Figure 7a (WT Cell Location Plot)

% cell types in the location database
[lia fpWT] = ismember(fp, keepCells);
fpWT = fpWT(lia);
[lia spWT] = ismember(sp, keepCells);
spWT = spWT(lia);
[lia akWT] = ismember(ak, keepCells);
akWT = akWT(lia);
[lia rpWT] = ismember(rp, keepCells);
rpWT = rpWT(lia);

% make sagittal sections for location plots
secThick = 0.4;
secCenters = 2.4:secThick:4.0;
secEdges = secCenters(1:end-1) + secThick/2;

% medialmost section (RP)
sel = find(ml < secEdges(1) & ~ismember(1:length(unit), rpWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml < secEdges(1) & ismember(1:length(unit), rpWT));
scatter(ap(sel2), dv(sel2), 160, rpColor, 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% intermediate sections (RP)
i=3;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(unit), rpWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(unit), rpWT));
scatter(ap(sel2), dv(sel2), 160, rpColor, 'filled')
scatter(-1, -6, 50, 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% lateralmost section (RP)
sel = find(ml >= secEdges(end) & ~ismember(1:length(unit), rpWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml >= secEdges(end) & ismember(1:length(unit), rpWT));
scatter(ap(sel2), dv(sel2), 160, rpColor, 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% medialmost section (FP)
sel = find(ml < secEdges(1) & ~ismember(1:length(unit), fpWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml < secEdges(1) & ismember(1:length(unit), fpWT));
scatter(ap(sel2), dv(sel2), 160, fpColor, 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% intermediate sections (FP)
i=3;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(unit), fpWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(unit), fpWT));
scatter(ap(sel2), dv(sel2), 160, fpColor, 'filled')
scatter(-1, -6, 50, 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% lateralmost section (FP)
sel = find(ml >= secEdges(end) & ~ismember(1:length(unit), fpWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml >= secEdges(end) & ismember(1:length(unit), fpWT));
scatter(ap(sel2), dv(sel2), 160, fpColor, 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% medialmost section (SP)
sel = find(ml < secEdges(1) & ~ismember(1:length(unit), spWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml < secEdges(1) & ismember(1:length(unit), spWT));
scatter(ap(sel2), dv(sel2), 160, 'b', 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% intermediate sections (SP)
i=3;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(unit), spWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(unit), spWT));
scatter(ap(sel2), dv(sel2), 160, 'b', 'filled')
scatter(-1, -6, 50, 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% lateralmost section (SP)
sel = find(ml >= secEdges(end) & ~ismember(1:length(unit), spWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml >= secEdges(end) & ismember(1:length(unit), spWT));
scatter(ap(sel2), dv(sel2), 160, 'b', 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% medialmost section (AK)
sel = find(ml < secEdges(1) & ~ismember(1:length(unit), akWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml < secEdges(1) & ismember(1:length(unit), akWT));
scatter(ap(sel2), dv(sel2), 160, 'c', 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% intermediate sections (AK)
i=3;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(unit), akWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(unit), akWT));
scatter(ap(sel2), dv(sel2), 160, 'c', 'filled')
scatter(-1, -6, 50, 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';

% lateralmost section (AK)
sel = find(ml >= secEdges(end) & ~ismember(1:length(unit), akWT));
figure('Position', [440 378 620 620] )
subplot('Position', [0.001 0.001 0.999 0.999])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml >= secEdges(end) & ismember(1:length(unit), akWT));
scatter(ap(sel2), dv(sel2), 160, 'c', 'filled')
scatter(-1, -6, 50, 'r')
plot([-2 -1], [-7.45 -7.45], 'r')
xlim([-3.5 -0.5])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';



%% Location Histograms, Coding Properties By Location

mRL2 = mRL(keepCells);
mPav2 = mPav(keepCells);
rlDur2 = rlDur(keepCells);

[lia uPav3] = ismember(uPav2, keepCells); 
uPav3 = uPav3(lia);                         % uPav3 locations of Pav cells within keepCells
pavDur2 = pavDur(lia);                      % pavDur2: subset of pavDur located within keepCells

minDV = -8;
maxDV = -5;
nBins = 3;
binW = (maxDV-minDV) / nBins;
binEdges = minDV:binW:maxDV;
binCenters = binEdges(2:end) - binW/2;
[nAll, ~, bin] = histcounts(dv, binEdges);
nRP = histcounts(dv(rpWT), binEdges);
nFP = histcounts(dv(fpWT), binEdges);
nSP = histcounts(dv(spWT), binEdges);
nAK = histcounts(dv(akWT), binEdges);

fracFP = nFP ./ nAll;
fracSP = nSP ./ nAll;
fracAK = nAK ./ nAll;

% Bonferroni-corrected significance criterion: p < 0.0063
% (0.05 / 8)

% RP, RL RPE slope
rpRL = arrayfun(@(b) mean(mRL2(intersect(find(bin==b), rpWT))), 1:nBins)
kruskalwallis(mRL2(rpWT), bin(rpWT)) % NS, p = 0.7011

% FP, RL coding duration
fpRL = arrayfun(@(b) mean(rlDur2(intersect(find(bin==b), fpWT))), 1:nBins)
kruskalwallis(rlDur2(fpWT), bin(fpWT)) % *, p = 6.3457e-4

% SP, RL coding duration
spRL = arrayfun(@(b) mean(rlDur2(intersect(find(bin==b), spWT))), 1:nBins)
kruskalwallis(rlDur2(spWT), bin(spWT)) % NS, p = 0.0230

% AK, RL coding duration
akRL = arrayfun(@(b) mean(rlDur2(intersect(find(bin==b), akWT))), 1:nBins)
kruskalwallis(rlDur2(akWT), bin(akWT)) % NS, p = 0.1119


% RP, Pav RPE slope
tpBin = arrayfun(@(b) intersect(find(bin==b), rpWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    tpBin{b} = tpBin{b}(~isnan(mPav2(tpBin{b})));
    dat = [dat mPav2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
rpPav = arrayfun(@(b) nanmean(mPav2(intersect(find(bin==b), rpWT))), 1:nBins)
kruskalwallis(dat, cat) % *, p = 0.3328

% FP, Pav coding duration
tpBin = arrayfun(@(b) intersect(find(bin==b), fpWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    [lia tpBin{b}] = ismember(tpBin{b}, uPav3);
    tpBin{b} = tpBin{b}(lia);
    dat = [dat pavDur2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
fpPav = arrayfun(@(b) mean(pavDur2(tpBin{b})), 1:nBins)
kruskalwallis(dat, cat) % *, p = 0.0063

% SP, Pav coding duration
tpBin = arrayfun(@(b) intersect(find(bin==b), spWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    [lia tpBin{b}] = ismember(tpBin{b}, uPav3);
    tpBin{b} = tpBin{b}(lia);
    dat = [dat pavDur2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
spPav = arrayfun(@(b) mean(pavDur2(tpBin{b})), 1:nBins)
kruskalwallis(dat, cat) % NS, p = 0.9063

% AK, Pav coding duration
tpBin = arrayfun(@(b) intersect(find(bin==b), akWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    [lia tpBin{b}] = ismember(tpBin{b}, uPav3);
    tpBin{b} = tpBin{b}(lia);
    dat = [dat pavDur2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
akPav = arrayfun(@(b) mean(pavDur2(tpBin{b})), 1:nBins)
kruskalwallis(dat, cat) % NS, p = 0.2295


% Figure 6B location distribution - DV
lm = 0.005; rm = 0.005; xg = 0.06; bm = 0.05; w = (1-lm-rm-3*xg)/4; h = 1-2*bm;
l = lm + (0:3)*(xg+w);
figure('Position', [10 378 1440 200] )
subplot('Position', [l(1) bm w h])
fracRP = (nRP ./ nAll) * 100;
b = bar(fracRP);
b.FaceColor = rpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = 4:4:12; ylim([0 14])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';
subplot('Position', [l(2) bm w h])
fracFP = (nFP ./ nAll) * 100;
b = bar(fracFP);
b.FaceColor = fpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = 12:12:36; ylim([0 40])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';
subplot('Position', [l(3) bm w h])
fracSP = (nSP ./ nAll) * 100;
b = bar(fracSP);
b.FaceColor = 'b'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = 10:10:30; ylim([0 34])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';
subplot('Position', [l(4) bm w h])
fracAK = (nAK ./ nAll) * 100;
b = bar(fracAK);
b.FaceColor = 'c'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = 10:10:30; ylim([0 34])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

% DV, +RPE (RP), durRL (FP, SP, AK)
lm = 0.045; rm = 0.005; xg1 = 0.12; xg2 = 0.01; bm = 0.05; w = (1-lm-rm-xg1-2*xg2)/4; h = 1-2*bm;
l = [lm lm+xg1+w lm+xg1+w+xg2+w lm+xg1+w+2*(xg2+w)];
figure('Position', [10 378 1440 200] )
subplot('Position', [l(1) bm w h])
b = bar(rpRL);
b.FaceColor = rpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = -2:-1; ylim([-2.5 0])
ax.YDir = 'reverse'; ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(2) bm w h])
b = bar(fpRL);
b.FaceColor = fpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [0.2 0.4]; ylim([0 0.5])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(3) bm w h])
b = bar(spRL);
b.FaceColor = 'b'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [0.2 0.4]; ylim([0 0.5])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(4) bm w h])
b = bar(akRL);
b.FaceColor = 'c'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [0.2 0.4]; ylim([0 0.5])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';


% DV, +RPE Pav (RP), durPav (FP, SP, AK)
lm = 0.045; rm = 0.005; xg1 = 0.12; xg2 = 0.01; bm = 0.05; w = (1-lm-rm-xg1-2*xg2)/4; h = 1-2*bm;
l = [lm lm+xg1+w lm+xg1+w+xg2+w lm+xg1+w+2*(xg2+w)];
figure('Position', [10 378 1440 200] )
subplot('Position', [l(1) bm w h])
b = bar(rpPav);
b.FaceColor = rpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [-20 -10]; ylim([-25 0])
ax.YDir = 'reverse'; ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(2) bm w h])
b = bar(fpPav);
b.FaceColor = fpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [0.1 0.2]; ylim([0 0.26]);
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(3) bm w h])
b = bar(spPav);
b.FaceColor = 'b'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [0.1 0.2]; ylim([0 0.26]);
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(4) bm w h])
b = bar(akPav);
b.FaceColor = 'c'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([-8.05 -4.95]); ax = gca; ax.XTick = -8:-5; ax.YTick = [0.1 0.2]; ylim([0 0.26]);
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';


minML = 2.2;
maxML = 4.4;
nBins = 3;
binW = (maxML-minML) / nBins;
binEdges = minML:binW:maxML;
binCenters = binEdges(2:end) - binW/2;
[nAll, ~, bin] = histcounts(ml, binEdges);
nRP = histcounts(dv(rpWT), binEdges);
nFP = histcounts(dv(fpWT), binEdges);
nSP = histcounts(dv(spWT), binEdges);
nAK = histcounts(dv(akWT), binEdges);
fracRP = nRP ./ nAll;
fracFP = nFP ./ nAll;
fracSP = nSP ./ nAll;
fracAK = nAK ./ nAll;

% RP, RL RPE slope
rpRL = arrayfun(@(b) mean(mRL2(intersect(find(bin==b), rpWT))), 1:nBins)
kruskalwallis(mRL2(rpWT), bin(rpWT)) % NS, p = 0.1606

% FP, RL coding duration
fpRL = arrayfun(@(b) mean(rlDur2(intersect(find(bin==b), fpWT))), 1:nBins)
kruskalwallis(rlDur2(fpWT), bin(fpWT)) % NS, p = 0.0962

% SP, RL coding duration
spRL = arrayfun(@(b) mean(rlDur2(intersect(find(bin==b), spWT))), 1:nBins)
kruskalwallis(rlDur2(spWT), bin(spWT)) % NS, p = 0.2476

% AK, RL coding duration
akRL = arrayfun(@(b) mean(rlDur2(intersect(find(bin==b), akWT))), 1:nBins)
kruskalwallis(rlDur2(akWT), bin(akWT)) % NS, p = 0.0095


% RP, Pav RPE slope
tpBin = arrayfun(@(b) intersect(find(bin==b), rpWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    tpBin{b} = tpBin{b}(~isnan(mPav2(tpBin{b})));
    dat = [dat mPav2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
rpPav = arrayfun(@(b) nanmean(mPav2(intersect(find(bin==b), rpWT))), 1:nBins)
kruskalwallis(dat, cat) % NS, p = 0.1588

% FP, Pav coding duration
tpBin = arrayfun(@(b) intersect(find(bin==b), fpWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    [lia tpBin{b}] = ismember(tpBin{b}, uPav3);
    tpBin{b} = tpBin{b}(lia);
    dat = [dat pavDur2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
fpPav = arrayfun(@(b) mean(pavDur2(tpBin{b})), 1:nBins)
kruskalwallis(dat, cat) % NS, p = 0.0803

% SP, Pav coding duration
tpBin = arrayfun(@(b) intersect(find(bin==b), spWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    [lia tpBin{b}] = ismember(tpBin{b}, uPav3);
    tpBin{b} = tpBin{b}(lia);
    dat = [dat pavDur2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
spPav = arrayfun(@(b) mean(pavDur2(tpBin{b})), 1:nBins)
kruskalwallis(dat, cat) % NS, p = 0.1413

% AK, Pav coding duration
tpBin = arrayfun(@(b) intersect(find(bin==b), akWT), 1:nBins, 'UniformOutput', false);
dat = []; cat = [];
for b = 1:nBins
    [lia tpBin{b}] = ismember(tpBin{b}, uPav3);
    tpBin{b} = tpBin{b}(lia);
    dat = [dat pavDur2(tpBin{b})];
    cat = [cat b*ones(size(tpBin{b}))];
end
akPav = arrayfun(@(b) mean(pavDur2(tpBin{b})), 1:nBins)
kruskalwallis(dat, cat) % NS, p = 0.0236

% location distribution - ML
lm = 0.005; rm = 0.005; xg = 0.06; bm = 0.05; w = (1-lm-rm-3*xg)/4; h = 1-2*bm;
l = lm + (0:3)*(xg+w);
figure('Position', [10 378 1440 200] )
subplot('Position', [l(1) bm w h])
fracRP = (nRP ./ nAll) * 100;
b = bar(fracRP);
b.FaceColor = rpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 3:3:9; ylim([0 10])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';
subplot('Position', [l(2) bm w h])
fracFP = (nFP ./ nAll) * 100;
b = bar(fracFP);
b.FaceColor = fpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 12:12:36; ylim([0 40])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';
subplot('Position', [l(3) bm w h])
fracSP = (nSP ./ nAll) * 100;
b = bar(fracSP);
b.FaceColor = 'b'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 12:12:36; ylim([0 40])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';
subplot('Position', [l(4) bm w h])
fracAK = (nAK ./ nAll) * 100;
b = bar(fracAK);
b.FaceColor = 'c'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick =binEdges; ax.YTick = 8:8:24; ylim([0 28])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

% ML, +RPE (RP), durRL (FP, SP, AK)
lm = 0.045; rm = 0.005; xg1 = 0.12; xg2 = 0.01; bm = 0.05; w = (1-lm-rm-xg1-2*xg2)/4; h = 1-2*bm;
l = [lm lm+xg1+w lm+xg1+w+xg2+w lm+xg1+w+2*(xg2+w)];
figure('Position', [10 378 1440 200] )
subplot('Position', [l(1) bm w h])
b = bar(rpPosRpeML);
b.FaceColor = rpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = -0.27:0.09:-0.09; ylim([-0.3 0])
ax.YDir = 'reverse'; ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(2) bm w h])
b = bar(fpDurRlML);
b.FaceColor = fpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 0.12:0.12:0.36; ylim([0 0.41])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(3) bm w h])
b = bar(spDurRlML);
b.FaceColor = 'b'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 0.12:0.12:0.36; ylim([0 0.41])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(4) bm w h])
b = bar(akDurRlML);
b.FaceColor = 'c'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 0.12:0.12:0.36; ylim([0 0.41])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

% ML, GO peak (RP), durPav (FP, SP, AK)
lm = 0.045; rm = 0.005; xg1 = 0.12; xg2 = 0.01; bm = 0.05; w = (1-lm-rm-xg1-2*xg2)/4; h = 1-2*bm;
l = [lm lm+xg1+w lm+xg1+w+xg2+w lm+xg1+w+2*(xg2+w)];
figure('Position', [10 378 1440 200] )
subplot('Position', [l(1) bm w h])
b = bar(rpGoPkML);
b.FaceColor = rpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 1:3; ylim([0 3.3])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(2) bm w h])
b = bar(fpDurPavML);
b.FaceColor = fpColor; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 0.09:0.09:0.27; ylim([0 0.3])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(3) bm w h])
b = bar(spDurPavML);
b.FaceColor = 'b'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 0.09:0.09:0.27; ylim([0 0.3])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';

subplot('Position', [l(4) bm w h])
b = bar(akDurPavML);
b.FaceColor = 'c'; b.BarWidth = 0.95; b.EdgeColor = 'none'; b.XData = binCenters;
xlim([2.15 4.45]); ax = gca; ax.XTick = binEdges; ax.YTick = 0.09:0.09:0.27; ylim([0 0.3])
ax.XTickLabels = []; ax.YTickLabels = []; ax.Box = 'off';



%% Figure 7C: RPE Coding (RL and Pav)

