datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);

% see earlier versions of GPe-RPE Fig 1 to for raw data load


%% Load Full ISI Stats

ratList = unique(uRat);

% loop through rats
swsRate = nan(size(unit));
swsMean = nan(size(unit));
swsSd = nan(size(unit));
swsSkew = nan(size(unit));
swsKurt = nan(size(unit));
swsNumIsi = zeros(size(unit));
swsDur = zeros(size(unit));
wakeMean = nan(size(unit));
wakeSd = nan(size(unit));
wakeSkew = nan(size(unit));
wakeKurt = nan(size(unit));
swsCv = nan(size(unit));
swsCv2 = nan(size(unit));
wakeRate = nan(size(unit));
wakeCv = nan(size(unit));
wakeCv2 = nan(size(unit));
wakeNumIsi = zeros(size(unit));
wakeDur = zeros(size(unit));
rat = cellfun(@(r) str2num(r(3:end)), uRat);
for r = 1:length(ratList)
    
    disp(['rat ' ratList{r}])
    
    uIdx = find(strcmp(ratList{r}, uRat));
    sesList = unique(uSes(uIdx));
    
    % loop through recording sessions
    for iSes = 1:length(sesList)
        
        disp(['   session ' num2str(iSes)])
    
        % load sleep log data
        clear sleepLog
        datDir = [datRoot ratList{r} filesep sesList{iSes} filesep];
        load([datDir 'sleepLog.mat']);
        
        % identify GPe cells recorded in this session, get behavior data
        uIdx = find(strcmp(sesList{iSes}, uSes));
            
        % identify periods of disengaged wakefulness, log SWS times across tasks
        [wake, sws] = WakeTimes(sleepLog, unit(uIdx(1)));
        wakeDur(uIdx) = sum(arrayfun(@(i) diff(wake(i,:)), 1:size(wake,1)));
        swsDur(uIdx) = sum(arrayfun(@(i) diff(sws(i,:)), 1:size(sws,1)));
          
        % extract rate-regularity parameters
        for u = uIdx
            wakeIsi = [];
            for k = 1:size(wake, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > wake(k,1) & unit(u).spkTimes <= wake(k,2));
                wakeIsi = [wakeIsi diff(spk)];
            end
            swsIsi = [];
            for k = 1:size(sws, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > sws(k,1) & unit(u).spkTimes <= sws(k,2));
                swsIsi = [swsIsi diff(spk)];
            end
            wakeNumIsi(u) = length(wakeIsi);
            wakeMean(u) = mean(wakeIsi);
            wakeRate(u) = 1 / wakeMean(u);
            wakeSd(u) = std(wakeIsi);
            wakeCv(u) = wakeSd(u) / wakeMean(u);
            wakeCv2(u) = sqrt(2) * mean(abs(wakeIsi(2:end) - wakeIsi(1:end-1)) ./ (wakeIsi(2:end) + wakeIsi(1:end-1)));
            wakeSkew(u) = skewness(wakeIsi);
            wakeKurt(u) = kurtosis(wakeIsi);
            swsNumIsi(u) = length(swsIsi);
            swsMean(u) = mean(swsIsi);
            swsRate(u) = 1 / swsMean(u);
            swsSd(u) = std(swsIsi);
            swsCv(u) = swsSd(u) / swsMean(u);
            swsCv2(u) = sqrt(2) * mean(abs(swsIsi(2:end) - swsIsi(1:end-1)) ./ (swsIsi(2:end) + swsIsi(1:end-1)));
            swsSkew(u) = skewness(swsIsi);
            swsKurt(u) = kurtosis(swsIsi);
        end
    end
end

% log transform for classification (base e)
w1e = log(wakeMean);
w2e = log(wakeSd);
w3e = log(wakeSkew);
s1e = log(swsMean);
s2e = log(swsSd);
s3e = log(swsSkew);

% log transform for plotting (base 10)
w1 = log10(wakeMean);
w2 = log10(wakeSd);
w3 = log10(wakeSkew);
s1 = log10(swsMean);
s2 = log10(swsSd);
s3 = log10(swsSkew);



%% Figure S1a: Exclusion of Outliers

T = dbscan([w1e' s1e' s2e'], 0.5, 5);
delX3 = find(T == -1);
length(delX3)
in = 1:length(unit);
in(delX3) = [];
out = setdiff(1:length(unit), in);

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(s2(in), s1(in), 60,'k')
scatter(s2(out), s1(out), 100, 'r', 'linewidth', 2)
xlim([-2.35 2.1])
ylim([-2.15 2.1])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1(in), s1(in), 60,'k')
scatter(w1(out), s1(out), 100, 'r', 'linewidth', 2)
xlim([-2.35 2.1])
ylim([-2.15 2.1])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];



%% Figure S1b: Identify RPE Cells and Arky Cells

% define RPE cells
xRP = s2e(in); y = s1e(in);
x1 = -3.2; y1 = -2.8; 
x2 = -0.38; y2 = -0.385;
m = (y2 - y1)/(x2 - x1);
b = y1 - m * x1;
xWinRP = [-3.2 0];
yWinRP = m * xWinRP + b;
rp = find(y > m*xRP + b & xRP > xWinRP(1)  & xRP < xWinRP(2));
xWinRP = log10(exp(xWinRP));
yWinRP = log10(exp(yWinRP));

% define arky cells
xAk = w1e(in); y = s1e(in);
x1 = -3.59; y1 = -2.8;
x2 = -2.70; y2 = -1.6;
m = (y2 - y1)/(x2 - x1);
b = y1 - m * x1;
xWinAk = [-3.9 -2.0];
yWinAk = m * xWinAk + b;
ak = find(y > m*xAk + b & xAk > xWinAk(1)  & xAk < xWinAk(2));
xWinAk = log10(exp(xWinAk));
yWinAk = log10(exp(yWinAk));

uc = setdiff(1:length(in), union(rp, ak));

s1in = s1(in); s2in = s2(in); w1in = w1(in);

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(s2in(ak), s1in(ak), 60, 'c', 'filled')
scatter(s2in(uc), s1in(uc), 60, 'k')
plot(xWinRP, yWinRP, '--', 'color', rpColor, 'linewidth', 1)
scatter(s2in(rpe), s1in(rpe), 60, rpColor, 'filled')
xlim([-2.3 0.7])
ylim([-2.1 0.75])
ax = gca;
ax.YTick = -2:0;
ax.XTick = -2:0;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1in(rp), s1in(rp), 60, rpColor, 'filled')
scatter(w1in(uc), s1in(uc), 60, 'k')
plot(xWinAk, yWinAk, '--', 'color', 'c', 'linewidth', 1)
scatter(w1in(ak), s1in(ak), 60, 'c', 'filled')
xlim([-2.3 0.7])
ylim([-2.1 0.75])
ax = gca;
ax.YTick = -2:0;
ax.XTick = -2:0;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];



%% Figure S1c: Identify Protoypical GPe Classes

% define protos
proto = uc;
w1e = w1e(in); s1e = s1e(in); s2e = s2e(in);

% define fast protos
x = w1e(proto); y = s1e(proto);
fp = find(y < -3 | x < -3.9);

% define slow protos
x1 = -3; y1 = -1.4;
x2 = -2.1; y2 = -2.7;
m = (y2 - y1)/(x2 - x1);
b = y1 - m * x1;
sp = find(y > m*x + b);

% define intermediate protos
uc = setdiff(1:length(proto), union(fp, sp));

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(s2in(proto(uc)), s1in(proto(uc)), 60, 'k')
scatter(s2in(proto(fp)), s1in(proto(fp)), 60, fpColor, 'filled')
scatter(s2in(proto(sp)), s1in(proto(sp)), 60, 'b', 'filled')
xlim([-2.3 0.7])
ylim([-2.1 0.75])
ax = gca;
ax.YTick = -2:0;
ax.XTick = -2:0;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1in(proto(uc)), s1in(proto(uc)), 60, 'k')
scatter(w1in(proto(fp)), s1in(proto(fp)), 60, fpColor, 'filled')
scatter(w1in(proto(sp)), s1in(proto(sp)), 60, 'b', 'filled')
xlim([-2.3 0.7])
ylim([-2.1 0.75])
ax = gca;
ax.YTick = -2:0;
ax.XTick = -2:0;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];
yWinSP = [-1 -3];
xWinSP = (yWinSP - b) / m;
yWinSP = log10(exp(yWinSP));
xWinSP = log10(exp(xWinSP));
plot(xWinSP, yWinSP, '--', 'color', 'b', 'linewidth', 2)
plot([-1.7 xWinSP(2)], log10(exp([-3 -3])), '--', 'color', fpColor, 'linewidth', 2)
plot(log10(exp([-3.9 -3.9])), [log10(exp(-3)) -1.1], '--', 'color', fpColor, 'linewidth', 2)



%% Figure S1d: Final Classification in ISI Space

uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
uc = union(ip, out);
tg = find(arrayfun(@(u) u.tagged, unit));
nonTg = find(arrayfun(@(u) ~u.tagged, unit));
fpNT = intersect(nonTg, fp);
spNT = intersect(nonTg, sp);
akNT = intersect(nonTg, ak);
rpNT = intersect(nonTg, rp);
ucNT = intersect(nonTg, uc);

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(s2(ucNT), s1(ucNT), 60, 'k')
scatter(s2(akNT), s1(akNT), 60, 'c', 'filled')
scatter(s2(spNT), s1(spNT), 60, 'b', 'filled')
scatter(s2(fpNT), s1(fpNT), 60, fpColor, 'filled')
scatter(s2(rpNT), s1(rpNT), 60, rpColor, 'filled')
scatter(s2(tg), s1(tg), 150, 'p', 'filled', 'MarkerFaceColor', 'y', 'MarkerEdgeColor', 'k', 'lineWidth', 0.75)
xlim([-2.35 2.1])
ylim([-2.15 2.1])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1(uc), s1(uc), 60, 'k')
scatter(w1(rp), s1(rp), 60, rpColor, 'filled')
scatter(w1(sp), s1(sp), 60, 'b', 'filled')
scatter(w1(fp), s1(fp), 60, fpColor, 'filled')
scatter(w1(ak), s1(ak), 60, 'c', 'filled')
scatter(w1(tg), s1(tg), 150, 'p', 'filled', 'MarkerFaceColor', 'y', 'MarkerEdgeColor', 'k', 'lineWidth', 0.75)
xlim([-2.35 2.1])
ylim([-2.15 2.1])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];




%% Figure S1e: Histograms of ISI moments

bE = linspace(-2.5, 2.1, 50);
bC = bE(2:end) - diff(bE)/2;

yGap = 0.08;
xGap = 0.01;
w = (1 - 3*xGap)/2;
h = (1 - 0.02 - 2*yGap)/3;
xLoc = xGap + (0:1)*(w+xGap);
yLoc = 1 - 0.01 - (1:3)*h - (0:2)*yGap;

figure('Position', [440 90 480 480])

f = histcounts(w1(fp),bE)';
s = histcounts(w1(sp),bE)';
r = histcounts(w1(rp),bE)';
a = histcounts(w1(ak),bE)';
u = histcounts(w1(uc),bE)';
histMatrix = [f a s r u];
subplot('Position', [xLoc(1) yLoc(1) w h])
b = bar(bC, histMatrix, 'stacked');
b(1).BarWidth = 1;
b(1).FaceColor = fpColor;
b(2).FaceColor = 'c';
b(3).FaceColor = 'b';
b(4).FaceColor = rpColor;
b(5).FaceColor = [0.5 0.5 0.5];
ax = gca;
ax.TickDir = 'out'; ax.Box = 'off';
ax.XTick = [-2:2];
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YTick = [];
ax.XTickLabels = [];
ax.YColor = [1 1 1];
xlim([-2.5 2.1])

f = histcounts(s1(fp),bE)';
s = histcounts(s1(sp),bE)';
r = histcounts(s1(rp),bE)';
a = histcounts(s1(ak),bE)';
u = histcounts(s1(uc),bE)';
histMatrix = [f a s r u];
subplot('Position', [xLoc(2) yLoc(1) w h])
b = bar(bC, histMatrix, 'stacked');
b(1).BarWidth = 1;
b(1).FaceColor = fpColor;
b(2).FaceColor = 'c';
b(3).FaceColor = 'b';
b(4).FaceColor = rpColor;
b(5).FaceColor = [0.5 0.5 0.5];
ax = gca;
ax.TickDir = 'out'; ax.Box = 'off';
ax.XTick = [-2:2];
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YTick = [];
ax.XTickLabels = [];
ax.YColor = [1 1 1];
xlim([-2.5 2.1])

f = histcounts(w2(fp),bE)';
s = histcounts(w2(sp),bE)';
r = histcounts(w2(rp),bE)';
a = histcounts(w2(ak),bE)';
u = histcounts(w2(uc),bE)';
histMatrix = [f a s r u];
subplot('Position', [xLoc(1) yLoc(2) w h])
b = bar(bC, histMatrix, 'stacked');
b(1).BarWidth = 1;
b(1).FaceColor = fpColor;
b(2).FaceColor = 'c';
b(3).FaceColor = 'b';
b(4).FaceColor = rpColor;
b(5).FaceColor = [0.5 0.5 0.5];
ax = gca;
ax.TickDir = 'out'; ax.Box = 'off';
ax.XTick = [-2:2];
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YTick = [];
ax.XTickLabels = [];
ax.YColor = [1 1 1];
xlim([-2.5 2.1])

f = histcounts(s2(fp),bE)';
s = histcounts(s2(sp),bE)';
r = histcounts(s2(rp),bE)';
a = histcounts(s2(ak),bE)';
u = histcounts(s2(uc),bE)';
histMatrix = [f a s r u];
subplot('Position', [xLoc(2) yLoc(2) w h])
b = bar(bC, histMatrix, 'stacked');
b(1).BarWidth = 1;
b(1).FaceColor = fpColor;
b(2).FaceColor = 'c';
b(3).FaceColor = 'b';
b(4).FaceColor = rpColor;
b(5).FaceColor = [0.5 0.5 0.5];
ax = gca;
ax.TickDir = 'out'; ax.Box = 'off';
ax.XTick = [-2:2];
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YTick = [];
ax.XTickLabels = [];
ax.YColor = [1 1 1];
xlim([-2.5 2.1])


bE = linspace(-0.67, 2.1, 50);
bC = bE(2:end) - diff(bE)/2;

f = histcounts(w3(fp),bE)';
s = histcounts(w3(sp),bE)';
r = histcounts(w3(rp),bE)';
a = histcounts(w3(ak),bE)';
u = histcounts(w3(uc),bE)';
histMatrix = [r f a s u];
subplot('Position', [xLoc(1) yLoc(3) w h])
b = bar(bC, histMatrix, 'stacked');
b(1).BarWidth = 1;
b(1).FaceColor = rpColor;
b(2).FaceColor = fpColor;
b(3).FaceColor = 'c';
b(4).FaceColor = 'b';
b(5).FaceColor = [0.5 0.5 0.5];
ax = gca;
ax.TickDir = 'out'; ax.Box = 'off';
ax.XTick = [-2:2];
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YTick = [];
ax.XTickLabels = [];
ax.YColor = [1 1 1];
xlim([-0.67 2.1])

f = histcounts(s3(fp),bE)';
s = histcounts(s3(sp),bE)';
r = histcounts(s3(rp),bE)';
a = histcounts(s3(ak),bE)';
u = histcounts(s3(uc),bE)';
histMatrix = [r f a s u];
subplot('Position', [xLoc(2) yLoc(3) w h])
b = bar(bC, histMatrix, 'stacked');
b(1).BarWidth = 1;
b(1).FaceColor = rpColor;
b(2).FaceColor = fpColor;
b(3).FaceColor = 'c';
b(4).FaceColor = 'b';
b(5).FaceColor = [0.5 0.5 0.5];
ax = gca;
ax.TickDir = 'out'; ax.Box = 'off';
ax.XTick = [-2:2];
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YTick = [];
ax.XTickLabels = [];
ax.YColor = [1 1 1];
xlim([-0.67 2.1])
