%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];
daColor = [0 0.7 0];



%% Supplemental Figure 2a: Encoding of Port Occupancy by the GPe

load([datRoot 'pavLR4.mat'])
[lia,rpPav] = ismember(rp, uPav2);
rpPav = rpPav(lia);
[lia,fpPav] = ismember(fp, uPav2);
fpPav = fpPav(lia);
[lia,spPav] = ismember(sp, uPav2);
spPav = spPav(lia);
[lia,akPav] = ismember(ak, uPav2);
akPav = akPav(lia);

rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);

% fraction encoding
fOfp = smoothdata(FracSignificant2(pO(fpPav,:), 0.05), 'gaussian', 10);
fOsp = smoothdata(FracSignificant2(pO(spPav,:), 0.05), 'gaussian', 10);
fOak = smoothdata(FracSignificant2(pO(akPav,:), 0.05), 'gaussian', 10);
fOrp = smoothdata(FracSignificant2(pO(rpPav,:), 0.05), 'gaussian', 10);

fOfpR = smoothdata(FracSignificant2(pOr(fpPav,:), 0.05), 'gaussian', 10);
fOspR = smoothdata(FracSignificant2(pOr(spPav,:), 0.05), 'gaussian', 10);
fOakR = smoothdata(FracSignificant2(pOr(akPav,:), 0.05), 'gaussian', 10);
fOrpR = smoothdata(FracSignificant2(pOr(rpPav,:), 0.05), 'gaussian', 10);

fOfpN = smoothdata(FracSignificant2(pOn(fpPav,:), 0.05), 'gaussian', 10);
fOspN = smoothdata(FracSignificant2(pOn(spPav,:), 0.05), 'gaussian', 10);
fOakN = smoothdata(FracSignificant2(pOn(akPav,:), 0.05), 'gaussian', 10);
fOrpN = smoothdata(FracSignificant2(pOn(rpPav,:), 0.05), 'gaussian', 10);

figure('Position', [1 85 1440 550])
w1 = 0.7620; g = 0.01; w2 = 0.98 - w1 - g
subplot('Position', [0.01 0.01 w1 0.98])
hold on
plot(t1, fOsp, 'b', 'linewidth', 3)
plot(t1, fOak, 'c', 'linewidth', 3)
plot(t1, fOfp, 'color', fpColor, 'linewidth', 3)
plot(t1, fOrp, 'color', rpColor, 'linewidth', 3)

plot(t2, fOspR, 'b', 'linewidth', 3)
plot(t2, fOakR, 'c', 'linewidth', 3)
plot(t2, fOfpR, 'color', fpColor, 'linewidth', 3)
plot(t2, fOrpR, 'color', rpColor, 'linewidth', 3)
yR = [0 0.65]; yT = [0.2 0.4 0.6];
plot([0 0], yR, '--k', 'linewidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2)
plot(win, [0.1 0.1], '--k', 'linewidth', 2)
ylim(yR)
xlim(win)
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';

subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
plot(t2, fOspN, 'b', 'linewidth', 3)
plot(t2, fOakN, 'c', 'linewidth', 3)
plot(t2, fOfpN, 'color', fpColor, 'linewidth', 3)
plot(t2, fOrpN, 'color', rpColor, 'linewidth', 3)
plot([rwdTime 4.5], [0.1 0.1], '--k', 'linewidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;


% regression slope
sMrp = smoothdata(mean(sO(rpPav,:)), 'gaussian', 10);
sLrp = sMrp - smoothdata(std(sO(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHrp = sMrp + smoothdata(std(sO(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMfp = smoothdata(mean(sO(fpPav,:)), 'gaussian', 10);
sLfp = sMfp - smoothdata(std(sO(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sHfp = sMfp + smoothdata(std(sO(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sMsp = smoothdata(mean(sO(spPav,:)), 'gaussian', 10);
sLsp = sMsp - smoothdata(std(sO(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sHsp = sMsp + smoothdata(std(sO(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sMak = smoothdata(mean(sO(akPav,:)), 'gaussian', 10);
sLak = sMak - smoothdata(std(sO(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);
sHak = sMak + smoothdata(std(sO(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);

sMRrp = smoothdata(mean(sOr(rpPav,:)), 'gaussian', 10);
sLRrp = sMRrp - smoothdata(std(sOr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHRrp = sMRrp + smoothdata(std(sOr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMRfp = smoothdata(mean(sOr(fpPav,:)), 'gaussian', 10);
sLRfp = sMRfp - smoothdata(std(sOr(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sHRfp = sMRfp + smoothdata(std(sOr(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sMRsp = smoothdata(mean(sOr(spPav,:)), 'gaussian', 10);
sLRsp = sMRsp - smoothdata(std(sOr(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sHRsp = sMRsp + smoothdata(std(sOr(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sMRak = smoothdata(mean(sOr(akPav,:)), 'gaussian', 10);
sLRak = sMRak - smoothdata(std(sOr(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);
sHRak = sMRak + smoothdata(std(sOr(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);

sMNrp = smoothdata(mean(sOn(rpPav,:)), 'gaussian', 10);
sLNrp = sMNrp - smoothdata(std(sOn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHNrp = sMNrp + smoothdata(std(sOn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMNfp = smoothdata(mean(sOn(fpPav,:)), 'gaussian', 10);
sLNfp = sMNfp - smoothdata(std(sOn(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sHNfp = sMNfp + smoothdata(std(sOn(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sMNsp = smoothdata(mean(sOn(spPav,:)), 'gaussian', 10);
sLNsp = sMNsp - smoothdata(std(sOn(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sHNsp = sMNsp + smoothdata(std(sOn(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sMNak = smoothdata(mean(sOn(akPav,:)), 'gaussian', 10);
sLNak = sMNak - smoothdata(std(sOn(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);
sHNak = sMNak + smoothdata(std(sOn(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);

figure('Position', [1 378 1440 550])
subplot('Position', [0.01 0.01 w1 0.98])
hold on
shade(t1, sHsp, t1, sLsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t1, sMsp, 'color', 'b', 'lineWidth', 2)
shade(t1, sHak, t1, sLak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t1, sMak, 'color', 'c', 'lineWidth', 2)
shade(t1, sHfp, t1, sLfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t1, sMfp, 'color', fpColor, 'lineWidth', 2)
shade(t1, sHrp, t1, sLrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t1, sMrp, 'color', rpColor, 'lineWidth', 2)

shade(t2, sHRsp, t2, sLRsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t2, sMRsp, 'color', 'b', 'lineWidth', 2)
shade(t2, sHRak, t2, sLRak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t2, sMRak, 'color', 'c', 'lineWidth', 2)
shade(t2, sHRfp, t2, sLRfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t2, sMRfp, 'color', fpColor, 'lineWidth', 2)
shade(t2, sHRrp, t2, sLRrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMRrp, 'color', rpColor, 'lineWidth', 2)
plot(win, [0 0], '--k', 'lineWidth', 2)
yR = [-2 2];
plot([0 0], yR, '--k', 'lineWidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'lineWidth', 2)
ylim(yR)
yT = -1.6:0.8:1.6;
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';

subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
shade(t2, sHNsp, t2, sLNsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t2, sMNsp, 'color', 'b', 'lineWidth', 2)
shade(t2, sHNak, t2, sLNak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t2, sMNak, 'color', 'c', 'lineWidth', 2)
shade(t2, sHNfp, t2, sLNfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t2, sMNfp, 'color', fpColor, 'lineWidth', 2)
shade(t2, sHNrp, t2, sLNrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMNrp, 'color', rpColor, 'lineWidth', 2)
plot([rwdTime 4.5], [0 0], '--k', 'lineWidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;



%% Supplemental Figure 2b: Encoding of Movement by the GPe

% fraction encoding
fMfp = smoothdata(FracSignificant2(pM(fpPav,:), 0.05), 'gaussian', 10);
fMsp = smoothdata(FracSignificant2(pM(spPav,:), 0.05), 'gaussian', 10);
fMak = smoothdata(FracSignificant2(pM(akPav,:), 0.05), 'gaussian', 10);
fMrp = smoothdata(FracSignificant2(pM(rpPav,:), 0.05), 'gaussian', 10);

fMfpR = smoothdata(FracSignificant2(pMr(fpPav,:), 0.05), 'gaussian', 10);
fMspR = smoothdata(FracSignificant2(pMr(spPav,:), 0.05), 'gaussian', 10);
fMakR = smoothdata(FracSignificant2(pMr(akPav,:), 0.05), 'gaussian', 10);
fMrpR = smoothdata(FracSignificant2(pMr(rpPav,:), 0.05), 'gaussian', 10);

fMfpN = smoothdata(FracSignificant2(pMn(fpPav,:), 0.05), 'gaussian', 10);
fMspN = smoothdata(FracSignificant2(pMn(spPav,:), 0.05), 'gaussian', 10);
fMakN = smoothdata(FracSignificant2(pMn(akPav,:), 0.05), 'gaussian', 10);
fMrpN = smoothdata(FracSignificant2(pMn(rpPav,:), 0.05), 'gaussian', 10);

figure('Position', [1 85 1440 550])
w1 = 0.7620; g = 0.01; w2 = 0.98 - w1 - g
subplot('Position', [0.01 0.01 w1 0.98])
hold on
plot(t1, fMsp, 'b', 'linewidth', 3)
plot(t1, fMak, 'c', 'linewidth', 3)
plot(t1, fMfp, 'color', fpColor, 'linewidth', 3)
plot(t1, fMrp, 'color', rpColor, 'linewidth', 3)

plot(t2, fMspR, 'b', 'linewidth', 3)
plot(t2, fMakR, 'c', 'linewidth', 3)
plot(t2, fMfpR, 'color', fpColor, 'linewidth', 3)
plot(t2, fMrpR, 'color', rpColor, 'linewidth', 3)
yR = [0 0.65]; yT = [0.2 0.4 0.6];
plot([0 0], yR, '--k', 'linewidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2)
plot(win, [0.1 0.1], '--k', 'linewidth', 2)
ylim(yR)
xlim(win)
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';

subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
plot(t2, fMspN, 'b', 'linewidth', 3)
plot(t2, fMakN, 'c', 'linewidth', 3)
plot(t2, fMfpN, 'color', fpColor, 'linewidth', 3)
plot(t2, fMrpN, 'color', rpColor, 'linewidth', 3)
plot([rwdTime 4.5], [0.1 0.1], '--k', 'linewidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;


% regression slope
sMrp = smoothdata(mean(sM(rpPav,:)), 'gaussian', 10);
sLrp = sMrp - smoothdata(std(sM(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHrp = sMrp + smoothdata(std(sM(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMfp = smoothdata(mean(sM(fpPav,:)), 'gaussian', 10);
sLfp = sMfp - smoothdata(std(sM(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sHfp = sMfp + smoothdata(std(sM(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sMsp = smoothdata(mean(sM(spPav,:)), 'gaussian', 10);
sLsp = sMsp - smoothdata(std(sM(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sHsp = sMsp + smoothdata(std(sM(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sMak = smoothdata(mean(sM(akPav,:)), 'gaussian', 10);
sLak = sMak - smoothdata(std(sM(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);
sHak = sMak + smoothdata(std(sM(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);

sMRrp = smoothdata(mean(sMr(rpPav,:)), 'gaussian', 10);
sLRrp = sMRrp - smoothdata(std(sMr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHRrp = sMRrp + smoothdata(std(sMr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMRfp = smoothdata(mean(sMr(fpPav,:)), 'gaussian', 10);
sLRfp = sMRfp - smoothdata(std(sMr(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sHRfp = sMRfp + smoothdata(std(sMr(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sMRsp = smoothdata(mean(sMr(spPav,:)), 'gaussian', 10);
sLRsp = sMRsp - smoothdata(std(sMr(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sHRsp = sMRsp + smoothdata(std(sMr(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sMRak = smoothdata(mean(sMr(akPav,:)), 'gaussian', 10);
sLRak = sMRak - smoothdata(std(sMr(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);
sHRak = sMRak + smoothdata(std(sMr(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);

sMNrp = smoothdata(mean(sMn(rpPav,:)), 'gaussian', 10);
sLNrp = sMNrp - smoothdata(std(sMn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHNrp = sMNrp + smoothdata(std(sMn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMNfp = smoothdata(mean(sMn(fpPav,:)), 'gaussian', 10);
sLNfp = sMNfp - smoothdata(std(sMn(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sHNfp = sMNfp + smoothdata(std(sMn(fpPav,:))/sqrt(length(fpPav)), 'gaussian', 10);
sMNsp = smoothdata(mean(sMn(spPav,:)), 'gaussian', 10);
sLNsp = sMNsp - smoothdata(std(sMn(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sHNsp = sMNsp + smoothdata(std(sMn(spPav,:))/sqrt(length(spPav)), 'gaussian', 10);
sMNak = smoothdata(mean(sMn(akPav,:)), 'gaussian', 10);
sLNak = sMNak - smoothdata(std(sMn(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);
sHNak = sMNak + smoothdata(std(sMn(akPav,:))/sqrt(length(akPav)), 'gaussian', 10);

figure('Position', [1 378 1440 550])
subplot('Position', [0.01 0.01 w1 0.98])
hold on
shade(t1, sHsp, t1, sLsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t1, sMsp, 'color', 'b', 'lineWidth', 2)
shade(t1, sHak, t1, sLak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t1, sMak, 'color', 'c', 'lineWidth', 2)
shade(t1, sHfp, t1, sLfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t1, sMfp, 'color', fpColor, 'lineWidth', 2)
shade(t1, sHrp, t1, sLrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t1, sMrp, 'color', rpColor, 'lineWidth', 2)

shade(t2, sHRsp, t2, sLRsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t2, sMRsp, 'color', 'b', 'lineWidth', 2)
shade(t2, sHRak, t2, sLRak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t2, sMRak, 'color', 'c', 'lineWidth', 2)
shade(t2, sHRfp, t2, sLRfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t2, sMRfp, 'color', fpColor, 'lineWidth', 2)
shade(t2, sHRrp, t2, sLRrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMRrp, 'color', rpColor, 'lineWidth', 2)
plot(win, [0 0], '--k', 'lineWidth', 2)
yR = [-0.0015 0.0015];
plot([0 0], yR, '--k', 'lineWidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'lineWidth', 2)
ylim(yR)
yT = [-0.001 0 0.001];
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';

subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
shade(t2, sHNsp, t2, sLNsp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(t2, sMNsp, 'color', 'b', 'lineWidth', 2)
shade(t2, sHNak, t2, sLNak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(t2, sMNak, 'color', 'c', 'lineWidth', 2)
shade(t2, sHNfp, t2, sLNfp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(t2, sMNfp, 'color', fpColor, 'lineWidth', 2)
shade(t2, sHNrp, t2, sLNrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMNrp, 'color', rpColor, 'lineWidth', 2)
plot([rwdTime 4.5], [0 0], '--k', 'lineWidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;



%% LR Model of VTA Dopamine Cell Data

load([datRoot 'pavLR_DA.mat']) % load LR if already computed

% load reformatted DA cell data
load([datRoot 'unitDa.mat'])
keep = false(1, length(unitDA));
for u = 1:length(unitDA)
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    lg = unitDA(u).behav_log{pavIdx};
    keep(u) = ~isempty(lg);
    if keep(u)
        keep(u) = ~isempty(lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1));
    end
end
unitDA = unitDA(keep);

% load original DA cell data to get food port data
tmp = load('/Users/michaelfarries/Documents/MATLAB/Ali DA dat/Units_forMichael.mat');
aliUnit = tmp.Unit;
clear tmp
daNames = arrayfun(@(u) u.name, aliUnit, 'UniformOutput', false);
aliWin = aliUnit(1).segments(2).ratexperience.portStatus.Win;
dtAli = 1/30000;
tAli = aliWin(1):dtAli:(aliWin(2) - dtAli);
% aliUnit(1).segments(2).ratexperience.portStatus.value [trial num, sample num] [.Win]

% linear regression window
dt = 0.005;
win = [-0.5 4.5];
times = win(1):dt:win(2);
nSamp = length(times);

% extract port occupancy data for dopamine cells
portOcpDA = cell(1, length(unitDA));
for u = 1:length(unitDA)
    [~,i] = ismember(unitDA(u).name, daNames);
    segNames = arrayfun(@(s) s.Type, aliUnit(i).segments, 'UniformOutput', false);
    [~,pavSeg] = ismember('Pav', segNames);
    portDat = single(aliUnit(i).segments(pavSeg).ratexperience.portStatus.value);
    nTr = size(portDat,1);
    portOcpDA{u} = zeros(nTr, nSamp);
    for k = 1:nTr
        portOcpDA{u}(k,:) = interp1(tAli, portDat(k,:), times);
    end
end

rwdTime = 3.1356;
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR_DA = zeros(length(unitDA), length(t1));
sO_DA = zeros(length(unitDA), length(t1));
sRRr_DA = zeros(length(unitDA), length(t2));
sOr_DA = zeros(length(unitDA), length(t2));
sRRn_DA = zeros(length(unitDA), length(t2));
sOn_DA = zeros(length(unitDA), length(t2));
pRR_DA = zeros(length(unitDA), length(t1));
pO_DA = zeros(length(unitDA), length(t1));
pRRr_DA = zeros(length(unitDA), length(t2));
pOr_DA = zeros(length(unitDA), length(t2));
pRRn_DA = zeros(length(unitDA), length(t2));
pOn_DA = zeros(length(unitDA), length(t2));
r2Ord_DA = zeros(length(unitDA), length(t1));
r2OrdR_DA = zeros(length(unitDA), length(t2));
r2OrdN_DA = zeros(length(unitDA), length(t2));
r2Adj_DA = zeros(length(unitDA), length(t1));
r2AdjR_DA = zeros(length(unitDA), length(t2));
r2AdjN_DA = zeros(length(unitDA), length(t2));

% DA Pavlovian behavior check
p25ocp = zeros(length(unitDA), length(t1)+length(t2));
p75ocp = zeros(length(unitDA), length(t1)+length(t2));
p25Nocp = zeros(length(unitDA), length(t2));
p75Nocp = zeros(length(unitDA), length(t2));
for u = 1:length(unitDA)
    
    % extract behavior data
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    ts = unitDA(u).behav_ts{pavIdx};
    logPav = unitDA(u).behav_log{pavIdx};
    probRwd = logPav.toneFreq;
    probRwd(probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for j = 1:size(logPav.cueRwdTable, 1)
        probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
    end
    
    % p25
    sel = find(probRwd == 25);
    p25ocp(u, 1:length(t1)) = mean(portOcpDA{u}(sel, 1:length(t1)));
    selR = intersect(sel, find(logPav.outcome));
    p25ocp(u, (length(t1)+1):end) = mean(portOcpDA{u}(selR, (length(t1)+1):end));
    selN = intersect(sel, find(~logPav.outcome));
    p25Nocp(u, :) = mean(portOcpDA{u}(selN, (length(t1)+1):end));
    
    % p75
    sel = find(probRwd == 75);
    p75ocp(u, 1:length(t1)) = mean(portOcpDA{u}(sel, 1:length(t1)));
    selR = intersect(sel, find(logPav.outcome));
    p75ocp(u, (length(t1)+1):end) = mean(portOcpDA{u}(selR, (length(t1)+1):end));
    selN = intersect(sel, find(~logPav.outcome));
    p75Nocp(u, :) = mean(portOcpDA{u}(selN, (length(t1)+1):end));
    
end

figure
hold on
plot(union(t1,t2), mean(p25ocp), 'b', 'linewidth', 1)
plot(union(t1,t2), mean(p75ocp), 'r', 'linewidth', 1)

figure
hold on
plot(t2, mean(p25Nocp), 'b', 'linewidth', 1)
plot(t2, mean(p75Nocp), 'r', 'linewidth', 1)

% rate smoothing parameters
sigma = 0.02;
dtRate = sigma / 10;

% compute linear regression
for u = 1:length(unitDA)
    disp(u)
    
    % generate smooth rate function
    uTraj = UnitTraj(unitDA(u), sigma, dtRate, 'Pav');
    uTraj.name = unitDA(u).name;
    
    % extract behavior data
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    ts = unitDA(u).behav_ts{pavIdx};
    logPav = unitDA(u).behav_log{pavIdx};
    probRwd = logPav.toneFreq;
    probRwd(probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for j = 1:size(logPav.cueRwdTable, 1)
        probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
    end
    m = mean(uTraj.rate);
    sd = std(uTraj.rate);
    uTraj.rate = (uTraj.rate - m)/sd;
    dt = uTraj(1).times(2) - uTraj(1).times(1);
    traj = TrajSplit(uTraj, ts, win);
    
    % regression before outcome, unpredicted (coded as 0%), 25% and 75%
    sel = find(probRwd > 0);
    pR = probRwd(sel);
    pR(pR == 100) = 0;
    nTr = length(sel);
    nSamp = length(t1);
    rate = zeros(nTr, nSamp);
    portOcp = portOcpDA{u}(sel, 1:nSamp);
    for k = 1:nTr
        rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
    end
    for j = 1:nSamp
        lm = fitlm([pR, portOcp(:,j)],rate(:,j));
        sRR_DA(u,j) = lm.Coefficients.Estimate(2);
        sO_DA(u,j) = lm.Coefficients.Estimate(3); 
        pRR_DA(u,j) = lm.Coefficients.pValue(2);
        pO_DA(u,j) = lm.Coefficients.pValue(3);
        r2Adj_DA(u,j) = lm.Rsquared.Adjusted;
        r2Ord_DA(u,j) = lm.Rsquared.Ordinary;
    end
    
    % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
    sel = find(probRwd > 0 & logPav.outcome);
    pR = probRwd(sel);
    pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
    nTr = length(sel);
    nSamp = length(t2);
    rate = zeros(nTr, nSamp);
    portOcp = portOcpDA{u}(sel, (length(t1)+1):end);
    for k = 1:nTr
        rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
    end    
    for j = 1:nSamp
        lm = fitlm([pR, portOcp(:,j)], rate(:,j));
        sRRr_DA(u,j) = lm.Coefficients.Estimate(2);
        sOr_DA(u,j) = lm.Coefficients.Estimate(3);
        pRRr_DA(u,j) = lm.Coefficients.pValue(2);
        pOr_DA(u,j) = lm.Coefficients.pValue(3);
        r2AdjR_DA(u,j) = lm.Rsquared.Adjusted;
        r2OrdR_DA(u,j) = lm.Rsquared.Ordinary;
    end
    
    % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
    sel = find(probRwd > 0 & ~logPav.outcome);
    pR = probRwd(sel);
    pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
    nTr = length(sel);
    nSamp = length(t2);
    rate = zeros(nTr, nSamp);
    portOcp = portOcpDA{u}(sel, (length(t1)+1):end);
    for k = 1:nTr
        rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
    end    
    for j = 1:nSamp
        lm = fitlm([pR, portOcp(:,j)], rate(:,j));
        sRRn_DA(u,j) = lm.Coefficients.Estimate(2);
        sOn_DA(u,j) = lm.Coefficients.Estimate(3);
        pRRn_DA(u,j) = lm.Coefficients.pValue(2);
        pOn_DA(u,j) = lm.Coefficients.pValue(3);
        r2AdjN_DA(u,j) = lm.Rsquared.Adjusted;
        r2OrdN_DA(u,j) = lm.Rsquared.Ordinary;
    end
    
end

save([datRoot 'pavLR_DA.mat'], 'sRR_DA', 'sO_DA', 'sRRr_DA', 'sOr_DA', 'sRRn_DA', 'sOn_DA', 'pRR_DA', 'pO_DA',...
    'pRRr_DA', 'pOr_DA', 'pRRn_DA', 'pOn_DA', 'r2Ord_DA', 'r2Adj_DA', 'r2OrdR_DA', 'r2AdjR_DA', 'r2OrdN_DA', 'r2AdjN_DA')



%% Supplemental Figure 2x: Port Occupancy in Ali's Rats

portOcpDA{u}(k,:);
avgOcp = zeros(10,1001);
for u = 1:10
    avgOcp(u,:) = mean(portOcpDA{u});
end
[~,sesIdx,~] = unique(avgOcp(:,800), 'stable'); % identify unique sessions

% collect Pavlovian behavioral data for DA cells
pavDat = [];
rwdTime = [];
dt = 0.005;
win = [-0.5 4.5];
times = win(1):dt:win(2);
nSamp = length(times);
for s = 1:length(sesIdx)
    clear x
    u = sesIdx(s);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unitDA(u).taskList));
    ts = unitDA(u).behav_ts{pavIdx};
    logPav = unitDA(u).behav_log{pavIdx};
    
    x.csTime = ts.csTime;
    x.outcome = logPav.outcome;
    x.probRwd = logPav.toneFreq;
    x.probRwd(x.probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for i = 1:size(logPav.cueRwdTable, 1)
        x.probRwd(x.probRwd == logPav.cueRwdTable(i,1)) = logPav.cueRwdTable(i,2);
    end

    x.portOcp = portOcpDA{u};
    
    x.t = times;
    pavDat = [pavDat x];
    rT = ts.rwdTime' - ts.csTime';
    rwdTime = [rwdTime rT(~isnan(rT))];
end
rwdTime = mean(rwdTime)

% average reward port occupancy
tPoke = pavDat(1).t;
p0 = zeros(length(sesIdx), length(tPoke));
p25 = zeros(length(sesIdx), length(tPoke));
p75 = zeros(length(sesIdx), length(tPoke));
p25r = zeros(length(sesIdx), length(tPoke));
p75r = zeros(length(sesIdx), length(tPoke));
p25nr = zeros(length(sesIdx), length(tPoke));
p75nr = zeros(length(sesIdx), length(tPoke));
unpred = zeros(length(sesIdx), length(tPoke));
for s = 1:length(pavDat)
    nTr = length(pavDat(s).csTime);
    sel0 = pavDat(s).probRwd == 0;
    sel25 = pavDat(s).probRwd == 25;
    sel75 = pavDat(s).probRwd == 75;
    selUnp = pavDat(s).probRwd == 100;
    p0(s,:) = mean(pavDat(s).portOcp(sel0,:));
    unpred(s,:) = mean(pavDat(s).portOcp(selUnp,:));
    p25(s,:) = mean(pavDat(s).portOcp(sel25,:));
    p25r(s,:) = mean(pavDat(s).portOcp(sel25 & pavDat(s).outcome,:));
    p25nr(s,:) = mean(pavDat(s).portOcp(sel25 & ~pavDat(s).outcome,:));
    p75(s,:) = mean(pavDat(s).portOcp(sel75,:));
    p75r(s,:) = mean(pavDat(s).portOcp(sel75 & pavDat(s).outcome,:));
    p75nr(s,:) = mean(pavDat(s).portOcp(sel75 & ~pavDat(s).outcome,:));
end

rwdBin = find(tPoke > rwdTime);
rwdBin = rwdBin(1);

tPre = tPoke(1:rwdBin);
tPost = tPoke(rwdBin+1:end);
p25M = smoothdata(mean(p25), 'gaussian', 10);
p25L = p25M - smoothdata(std(p25)/sqrt(size(p25,1)), 'gaussian', 10);
p25H = p25M + smoothdata(std(p25)/sqrt(size(p25,1)), 'gaussian', 10);
p75M = smoothdata(mean(p75), 'gaussian', 10);
p75L = p75M - smoothdata(std(p75)/sqrt(size(p25,1)), 'gaussian', 10);
p75H = p75M + smoothdata(std(p75)/sqrt(size(p25,1)), 'gaussian', 10);
p25RM = smoothdata(mean(p25r), 'gaussian', 10);
p25RL = p25RM - smoothdata(std(p25r)/sqrt(size(p25r,1)), 'gaussian', 10);
p25RH = p25RM + smoothdata(std(p25r)/sqrt(size(p25r,1)), 'gaussian', 10);
p25NM = smoothdata(mean(p25nr), 'gaussian', 10);
p25NL = p25NM - smoothdata(std(p25nr)/sqrt(size(p25nr,1)), 'gaussian', 10);
p25NH = p25NM + smoothdata(std(p25nr)/sqrt(size(p25nr,1)), 'gaussian', 10);
p75RM = smoothdata(mean(p75r), 'gaussian', 10);
p75RL = p75RM - smoothdata(std(p75r)/sqrt(size(p75r,1)), 'gaussian', 10);
p75RH = p75RM + smoothdata(std(p75r)/sqrt(size(p75r,1)), 'gaussian', 10);
p75NM = smoothdata(mean(p75nr), 'gaussian', 10);
p75NL = p75NM - smoothdata(std(p75nr)/sqrt(size(p75nr,1)), 'gaussian', 10);
p75NH = p75NM + smoothdata(std(p75nr)/sqrt(size(p75nr,1)), 'gaussian', 10);
p0M = smoothdata(mean(p0), 'gaussian', 10);
p0L = p0M - smoothdata(std(p0)/sqrt(size(p0,1)), 'gaussian', 10);
p0H = p0M + smoothdata(std(p0)/sqrt(size(p0,1)), 'gaussian', 10);
unM = smoothdata(mean(unpred), 'gaussian', 10);
unL = unM - smoothdata(std(unpred)/sqrt(size(unpred,1)), 'gaussian', 10);
unH = unM + smoothdata(std(unpred)/sqrt(size(unpred,1)), 'gaussian', 10);

figure('Position', [10 100 695 450])
subplot('Position', [0.005 0.005 0.994 0.99])
hold on
shade(tPre, p75H(1:rwdBin),tPre, p75L(1:rwdBin),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.7 0.7 0.7], 'FillAlpha', 0.25)
plot(tPre, p75M(1:rwdBin), 'color', [0.7 0.7 0.7], 'lineWidth', 2)
shade(tPre, p25H(1:rwdBin),tPre, p25L(1:rwdBin),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.3 0.3 0.3], 'FillAlpha', 0.25)
plot(tPre, p25M(1:rwdBin), 'color', [0.3 0.3 0.3], 'lineWidth', 2)
shade(tPost, p25NH(rwdBin+1:end),tPost, p25NL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0 0 0.6], 'FillAlpha', 0.25)
plot(tPost, p25NM(rwdBin+1:end), 'color', [0 0 0.6], 'lineWidth', 2)
shade(tPost, p25RH(rwdBin+1:end),tPost, p25RL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.6 0 0], 'FillAlpha', 0.25)
plot(tPost, p25RM(rwdBin+1:end), 'color', [0.6 0 0], 'lineWidth', 2)
shade(tPost, p75NH(rwdBin+1:end),tPost, p75NL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [0.4 0.4 1], 'FillAlpha', 0.25)
plot(tPost, p75NM(rwdBin+1:end), 'color', [0.4 0.4 1], 'lineWidth', 2)
shade(tPost, p75RH(rwdBin+1:end),tPost, p75RL(rwdBin+1:end),'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', [1 0.4 0.4], 'FillAlpha', 0.25)
plot(tPost, p75RM(rwdBin+1:end), 'color', [1 0.4 0.4], 'lineWidth', 2)
yR = [0 0.9];
plot([0 0], yR, '--k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;

figure('Position', [10 100 695 450])
subplot('Position', [0.005 0.005 0.994 0.99])
hold on
shade(tPoke, p0H,tPoke, p0L,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tPoke, p0M, 'color', 'b', 'lineWidth', 2)
shade(tPoke, unH,tPoke, unL,'color', [1,1,1], 'lineWidth', 0.1,...
    'FillType',[1 2], 'FillColor', 'r', 'FillAlpha', 0.25)
plot(tPoke, unM, 'color', 'r', 'lineWidth', 2)
yR = [0 0.9];
plot([0 0], yR, '--k', 'linewidth', 1);
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', [0.25 0.5 0.75])
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 3;




%% Supplemental Figure 2x: VTA-DA GPe-RPE comparison

fRrp = smoothdata(FracSignificant2(pRR(rpPav,:), 0.05), 'gaussian', 10);
fRda = smoothdata(FracSignificant2(pRR_DA, 0.05), 'gaussian', 10);
fRrpR = smoothdata(FracSignificant2(pRRr(rpPav,:), 0.05), 'gaussian', 10);
fRdaR = smoothdata(FracSignificant2(pRRr_DA, 0.05), 'gaussian', 10);
fRrpN = smoothdata(FracSignificant2(pRRn(rpPav,:), 0.05), 'gaussian', 10);
fRdaN = smoothdata(FracSignificant2(pRRn_DA, 0.05), 'gaussian', 10);

fOda = smoothdata(FracSignificant2(pO_DA, 0.05), 'gaussian', 10);
fOrp = smoothdata(FracSignificant2(pO(rpPav,:), 0.05), 'gaussian', 10);
fOdaR = smoothdata(FracSignificant2(pOr_DA, 0.05), 'gaussian', 10);
fOrpR = smoothdata(FracSignificant2(pOr(rpPav,:), 0.05), 'gaussian', 10);
fOdaN = smoothdata(FracSignificant2(pOn_DA, 0.05), 'gaussian', 10);
fOrpN = smoothdata(FracSignificant2(pOn(rpPav,:), 0.05), 'gaussian', 10);

% fraction encoding, p[rwd]
figure('Position', [1 85 1440 550])
w1 = 0.7620; g = 0.01; w2 = 0.98 - w1 - g
subplot('Position', [0.01 0.01 w1 0.98])
hold on
plot(t1, fRrp, 'color', rpColor, 'linewidth', 3)
plot(t1, fRda, 'color', daColor, 'linewidth', 3)
plot(t2, fRrpR, 'color', rpColor, 'linewidth', 3)
plot(t2, fRdaR, 'color', daColor, 'linewidth', 3)
yR = [0 0.9]; yT = 0.2:0.2:0.8;
plot([0 0], yR, '--k', 'linewidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2)
plot(win, [0.1 0.1], '--k', 'linewidth', 2)
ylim(yR)
xlim(win)
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
plot(t2, fRrpN, 'color', rpColor, 'linewidth', 3)
plot(t2, fRdaN, 'color', daColor, 'linewidth', 3)
plot([rwdTime 4.5], [0.1 0.1], '--k', 'linewidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;

% fraction encoding, port occupancy
figure('Position', [1 85 1440 550])
w1 = 0.7620; g = 0.01; w2 = 0.98 - w1 - g
subplot('Position', [0.01 0.01 w1 0.98])
hold on
plot(t1, fOrp, 'color', rpColor, 'linewidth', 3)
plot(t1, fOda, 'color', daColor, 'linewidth', 3)
plot(t2, fOrpR, 'color', rpColor, 'linewidth', 3)
plot(t2, fOdaR, 'color', daColor, 'linewidth', 3)
% yR = [0 0.7]; yT = 0.2:0.2:0.6;
plot([0 0], yR, '--k', 'linewidth', 2)
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2)
plot(win, [0.1 0.1], '--k', 'linewidth', 2)
ylim(yR)
xlim(win)
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
plot(t2, fOrpN, 'color', rpColor, 'linewidth', 3)
plot(t2, fOdaN, 'color', daColor, 'linewidth', 3)
plot([rwdTime 4.5], [0.1 0.1], '--k', 'linewidth', 2)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;


% regression slope, p[rwd]
sRR = sRR*100; sRR_DA = sRR_DA*100; sRRr = sRRr*100; sRRr_DA = sRRr_DA*100; sRRn = sRRn*100; sRRn_DA = sRRn_DA*100;
sMrp = smoothdata(mean(sRR(rpPav,:)), 'gaussian', 10);
sLrp = sMrp - smoothdata(std(sRR(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHrp = sMrp + smoothdata(std(sRR(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMda = smoothdata(mean(sRR_DA), 'gaussian', 10);
sLda = sMda - smoothdata(std(sRR_DA)/sqrt(length(unitDA)), 'gaussian', 10);
sHda = sMda + smoothdata(std(sRR_DA)/sqrt(length(unitDA)), 'gaussian', 10);

sMRrp = smoothdata(mean(sRRr(rpPav,:)), 'gaussian', 10);
sLRrp = sMRrp - smoothdata(std(sRRr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHRrp = sMRrp + smoothdata(std(sRRr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMRda = smoothdata(mean(sRRr_DA), 'gaussian', 10);
sLRda = sMRda - smoothdata(std(sRRr_DA)/sqrt(length(unitDA)), 'gaussian', 10);
sHRda = sMRda + smoothdata(std(sRRr_DA)/sqrt(length(unitDA)), 'gaussian', 10);

sMNrp = smoothdata(mean(sRRn(rpPav,:)), 'gaussian', 10);
sLNrp = sMNrp - smoothdata(std(sRRn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHNrp = sMNrp + smoothdata(std(sRRn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMNda = smoothdata(mean(sRRn_DA), 'gaussian', 10);
sLNda = sMNda - smoothdata(std(sRRn_DA)/sqrt(length(unitDA)), 'gaussian', 10);
sHNda = sMNda + smoothdata(std(sRRn_DA)/sqrt(length(unitDA)), 'gaussian', 10);

figure('Position', [1 378 1440 550])
subplot('Position', [0.01 0.01 w1 0.98])
hold on
shade(t1, sHda, t1, sLda,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(t1, sMda, 'color', daColor, 'lineWidth', 2)
shade(t1, sHrp, t1, sLrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t1, sMrp, 'color', rpColor, 'lineWidth', 2)
shade(t2, sHRda, t2, sLRda,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(t2, sMRda, 'color', daColor, 'lineWidth', 2)
shade(t2, sHRrp, t2, sLRrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMRrp, 'color', rpColor, 'lineWidth', 2)
plot(win, [0 0], 'k', 'lineWidth', 1)
yR = [-3.1 3.1];
plot([0 0], yR, 'k', 'lineWidth', 1)
plot([rwdTime rwdTime], yR, 'k', 'lineWidth', 1)
ylim(yR)
yT = -2:2:2;
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
shade(t2, sHNda, t2, sLNda,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(t2, sMNda, 'color', daColor, 'lineWidth', 2)
shade(t2, sHNrp, t2, sLNrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMNrp, 'color', rpColor, 'lineWidth', 2)
plot([rwdTime 4.5], [0 0], 'k', 'lineWidth', 1)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;

% regression slope, port occupancy
sMrp = smoothdata(mean(sO(rpPav,:)), 'gaussian', 10);
sLrp = sMrp - smoothdata(std(sO(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHrp = sMrp + smoothdata(std(sO(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMda = smoothdata(mean(sO_DA), 'gaussian', 10);
sLda = sMda - smoothdata(std(sO_DA)/sqrt(length(unitDA)), 'gaussian', 10);
sHda = sMda + smoothdata(std(sO_DA)/sqrt(length(unitDA)), 'gaussian', 10);

sMRrp = smoothdata(mean(sOr(rpPav,:)), 'gaussian', 10);
sLRrp = sMRrp - smoothdata(std(sOr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHRrp = sMRrp + smoothdata(std(sOr(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMRda = smoothdata(mean(sOr_DA), 'gaussian', 10);
sLRda = sMRda - smoothdata(std(sOr_DA)/sqrt(length(unitDA)), 'gaussian', 10);
sHRda = sMRda + smoothdata(std(sOr_DA)/sqrt(length(unitDA)), 'gaussian', 10);

sMNrp = smoothdata(mean(sOn(rpPav,:)), 'gaussian', 10);
sLNrp = sMNrp - smoothdata(std(sOn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sHNrp = sMNrp + smoothdata(std(sOn(rpPav,:))/sqrt(length(rpPav)), 'gaussian', 10);
sMNda = smoothdata(mean(sOn_DA), 'gaussian', 10);
sLNda = sMNda - smoothdata(std(sOn_DA)/sqrt(length(unitDA)), 'gaussian', 10);
sHNda = sMNda + smoothdata(std(sOn_DA)/sqrt(length(unitDA)), 'gaussian', 10);

figure('Position', [1 378 1440 550])
subplot('Position', [0.01 0.01 w1 0.98])
hold on
shade(t1, sHda, t1, sLda,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(t1, sMda, 'color', daColor, 'lineWidth', 2)
shade(t1, sHrp, t1, sLrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t1, sMrp, 'color', rpColor, 'lineWidth', 2)
shade(t2, sHRda, t2, sLRda,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(t2, sMRda, 'color', daColor, 'lineWidth', 2)
shade(t2, sHRrp, t2, sLRrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMRrp, 'color', rpColor, 'lineWidth', 2)
plot(win, [0 0], 'k', 'lineWidth', 1)
%yR = [-0.5 1.8];
plot([0 0], yR, 'k', 'lineWidth', 1)
plot([rwdTime rwdTime], yR, 'k', 'lineWidth', 1)
ylim(yR)
%yT = -0.5:0.5:1.5;
ax = gca;
ax.XTick = -0.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
subplot('Position', [0.01+w1+g 0.01 w2 0.98])
hold on
shade(t2, sHNda, t2, sLNda,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(t2, sMNda, 'color', daColor, 'lineWidth', 2)
shade(t2, sHNrp, t2, sLNrp,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(t2, sMNrp, 'color', rpColor, 'lineWidth', 2)
plot([rwdTime 4.5], [0 0], 'k', 'lineWidth', 1)
xlim([rwdTime 4.5])
ylim(yR)
ax = gca;
ax.XTick = 3.5:0.5:4.5;
ax.YTick = yT;
ax.XTickLabels = [];
ax.YTickLabels = [];
ax.Box = 'on';
ax.TickLength(1) = 0.02;
