%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];
daColor = [0 0.7 0];

load([datRoot 'rlLR7.mat']) % load LR if already computed

% variables for rlLR3 stored in cell arrays: 1=LO, 2=CI, 3=GO, 4=pre-SI (all trials together)
% 1=post-SI, 2=FP (broken into separate rewarded and unrewarded cases)



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
tau = 89; % median time constant, calculated elsewhere
rwdRate = cell(1, length(sesList));
slope3 = 1:length(sesList);
pVal3 = 1:length(sesList);
rSq3 = 1:length(sesList);
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end
    lm = fitlm(rwdRate{s}', logLat);
    slope3(s) = lm.Coefficients.Estimate(2);
    pVal3(s) = lm.Coefficients.pValue(2);
    rSq3(s) = lm.Rsquared.Ordinary;
end 



%% Compute Plottable Output from Linear Regression (Choice)

smWd = 10;

fracLOrp = smoothdata(FracSignificant2(pC{1}(rp,:), 0.05), 'gaussian', smWd);
fracLOfp = smoothdata(FracSignificant2(pC{1}(fp,:), 0.05), 'gaussian', smWd);
fracLOip = smoothdata(FracSignificant2(pC{1}(ip,:), 0.05), 'gaussian', smWd);
fracLOsp = smoothdata(FracSignificant2(pC{1}(sp,:), 0.05), 'gaussian', smWd);
fracLOak = smoothdata(FracSignificant2(pC{1}(ak,:), 0.05), 'gaussian', smWd);

fracCIrp = smoothdata(FracSignificant2(pC{2}(rp,:), 0.05), 'gaussian', smWd);
fracCIfp = smoothdata(FracSignificant2(pC{2}(fp,:), 0.05), 'gaussian', smWd);
fracCIip = smoothdata(FracSignificant2(pC{2}(ip,:), 0.05), 'gaussian', smWd);
fracCIsp = smoothdata(FracSignificant2(pC{2}(sp,:), 0.05), 'gaussian', smWd);
fracCIak = smoothdata(FracSignificant2(pC{2}(ak,:), 0.05), 'gaussian', smWd);

fracGOrp = smoothdata(FracSignificant2(pC{3}(rp,:), 0.05), 'gaussian', smWd);
fracGOfp = smoothdata(FracSignificant2(pC{3}(fp,:), 0.05), 'gaussian', smWd);
fracGOip = smoothdata(FracSignificant2(pC{3}(ip,:), 0.05), 'gaussian', smWd);
fracGOsp = smoothdata(FracSignificant2(pC{3}(sp,:), 0.05), 'gaussian', smWd);
fracGOak = smoothdata(FracSignificant2(pC{3}(ak,:), 0.05), 'gaussian', smWd);

fracSIprp = smoothdata(FracSignificant2(pC{5}(rp,:), 0.05), 'gaussian', smWd);
fracSIpfp = smoothdata(FracSignificant2(pC{5}(fp,:), 0.05), 'gaussian', smWd);
fracSIpip = smoothdata(FracSignificant2(pC{5}(ip,:), 0.05), 'gaussian', smWd);
fracSIpsp = smoothdata(FracSignificant2(pC{5}(sp,:), 0.05), 'gaussian', smWd);
fracSIpak = smoothdata(FracSignificant2(pC{5}(ak,:), 0.05), 'gaussian', smWd);

fracSIrrp = smoothdata(FracSignificant2(pCr{1}(rp,:), 0.05), 'gaussian', smWd);
fracSIrfp = smoothdata(FracSignificant2(pCr{1}(fp,:), 0.05), 'gaussian', smWd);
fracSIrip = smoothdata(FracSignificant2(pCr{1}(ip,:), 0.05), 'gaussian', smWd);
fracSIrsp = smoothdata(FracSignificant2(pCr{1}(sp,:), 0.05), 'gaussian', smWd);
fracSIrak = smoothdata(FracSignificant2(pCr{1}(ak,:), 0.05), 'gaussian', smWd);

fracSInrp = smoothdata(FracSignificant2(pCn{1}(rp,:), 0.05), 'gaussian', smWd);
fracSInfp = smoothdata(FracSignificant2(pCn{1}(fp,:), 0.05), 'gaussian', smWd);
fracSInip = smoothdata(FracSignificant2(pCn{1}(ip,:), 0.05), 'gaussian', smWd);
fracSInsp = smoothdata(FracSignificant2(pCn{1}(sp,:), 0.05), 'gaussian', smWd);
fracSInak = smoothdata(FracSignificant2(pCn{1}(ak,:), 0.05), 'gaussian', smWd);

fracFPrrp = smoothdata(FracSignificant2(pCr{2}(rp,:), 0.05), 'gaussian', smWd);
fracFPrfp = smoothdata(FracSignificant2(pCr{2}(fp,:), 0.05), 'gaussian', smWd);
fracFPrip = smoothdata(FracSignificant2(pCr{2}(ip,:), 0.05), 'gaussian', smWd);
fracFPrsp = smoothdata(FracSignificant2(pCr{2}(sp,:), 0.05), 'gaussian', smWd);
fracFPrak = smoothdata(FracSignificant2(pCr{2}(ak,:), 0.05), 'gaussian', smWd);

sLO_Mrp = smoothdata(mean(sC{1}(rp,:)), 'gaussian', smWd);
sLO_Lrp = sLO_Mrp - smoothdata(std(sC{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Hrp = sLO_Mrp + smoothdata(std(sC{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Mfp = smoothdata(mean(sC{1}(fp,:)), 'gaussian', smWd);
sLO_Lfp = sLO_Mfp - smoothdata(std(sC{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sLO_Hfp = sLO_Mfp + smoothdata(std(sC{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sLO_Mip = smoothdata(mean(sC{1}(ip,:)), 'gaussian', smWd);
sLO_Lip = sLO_Mip - smoothdata(std(sC{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sLO_Hip = sLO_Mip + smoothdata(std(sC{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sLO_Msp = smoothdata(mean(sC{1}(sp,:)), 'gaussian', smWd);
sLO_Lsp = sLO_Msp - smoothdata(std(sC{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sLO_Hsp = sLO_Msp + smoothdata(std(sC{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sLO_Mak = smoothdata(mean(sC{1}(ak,:)), 'gaussian', smWd);
sLO_Lak = sLO_Mak - smoothdata(std(sC{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sLO_Hak = sLO_Mak + smoothdata(std(sC{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sCI_Mrp = smoothdata(mean(sC{2}(rp,:)), 'gaussian', smWd);
sCI_Lrp = sCI_Mrp - smoothdata(std(sC{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Hrp = sCI_Mrp + smoothdata(std(sC{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Mfp = smoothdata(mean(sC{2}(fp,:)), 'gaussian', smWd);
sCI_Lfp = sCI_Mfp - smoothdata(std(sC{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sCI_Hfp = sCI_Mfp + smoothdata(std(sC{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sCI_Mip = smoothdata(mean(sC{2}(ip,:)), 'gaussian', smWd);
sCI_Lip = sCI_Mip - smoothdata(std(sC{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sCI_Hip = sCI_Mip + smoothdata(std(sC{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sCI_Msp = smoothdata(mean(sC{2}(sp,:)), 'gaussian', smWd);
sCI_Lsp = sCI_Msp - smoothdata(std(sC{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sCI_Hsp = sCI_Msp + smoothdata(std(sC{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sCI_Mak = smoothdata(mean(sC{2}(ak,:)), 'gaussian', smWd);
sCI_Lak = sCI_Mak - smoothdata(std(sC{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sCI_Hak = sCI_Mak + smoothdata(std(sC{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sGO_Mrp = smoothdata(mean(sC{3}(rp,:)), 'gaussian', smWd);
sGO_Lrp = sGO_Mrp - smoothdata(std(sC{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Hrp = sGO_Mrp + smoothdata(std(sC{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Mfp = smoothdata(mean(sC{3}(fp,:)), 'gaussian', smWd);
sGO_Lfp = sGO_Mfp - smoothdata(std(sC{3}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sGO_Hfp = sGO_Mfp + smoothdata(std(sC{3}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sGO_Mip = smoothdata(mean(sC{3}(ip,:)), 'gaussian', smWd);
sGO_Lip = sGO_Mip - smoothdata(std(sC{3}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sGO_Hip = sGO_Mip + smoothdata(std(sC{3}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sGO_Msp = smoothdata(mean(sC{3}(sp,:)), 'gaussian', smWd);
sGO_Lsp = sGO_Msp - smoothdata(std(sC{3}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sGO_Hsp = sGO_Msp + smoothdata(std(sC{3}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sGO_Mak = smoothdata(mean(sC{3}(ak,:)), 'gaussian', smWd);
sGO_Lak = sGO_Mak - smoothdata(std(sC{3}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sGO_Hak = sGO_Mak + smoothdata(std(sC{3}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIp_Mrp = smoothdata(mean(sC{4}(rp,:)), 'gaussian', smWd);
sSIp_Lrp = sSIp_Mrp - smoothdata(std(sC{4}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Hrp = sSIp_Mrp + smoothdata(std(sC{4}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Mfp = smoothdata(mean(sC{4}(fp,:)), 'gaussian', smWd);
sSIp_Lfp = sSIp_Mfp - smoothdata(std(sC{4}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIp_Hfp = sSIp_Mfp + smoothdata(std(sC{4}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIp_Mip = smoothdata(mean(sC{4}(ip,:)), 'gaussian', smWd);
sSIp_Lip = sSIp_Mip - smoothdata(std(sC{4}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIp_Hip = sSIp_Mip + smoothdata(std(sC{4}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIp_Msp = smoothdata(mean(sC{4}(sp,:)), 'gaussian', smWd);
sSIp_Lsp = sSIp_Msp - smoothdata(std(sC{4}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIp_Hsp = sSIp_Msp + smoothdata(std(sC{4}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIp_Mak = smoothdata(mean(sC{4}(ak,:)), 'gaussian', smWd);
sSIp_Lak = sSIp_Mak - smoothdata(std(sC{4}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIp_Hak = sSIp_Mak + smoothdata(std(sC{4}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIr_Mrp = smoothdata(mean(sCr{1}(rp,:)), 'gaussian', smWd);
sSIr_Lrp = sSIr_Mrp - smoothdata(std(sCr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Hrp = sSIr_Mrp + smoothdata(std(sCr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Mfp = smoothdata(mean(sCr{1}(fp,:)), 'gaussian', smWd);
sSIr_Lfp = sSIr_Mfp - smoothdata(std(sCr{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIr_Hfp = sSIr_Mfp + smoothdata(std(sCr{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIr_Mip = smoothdata(mean(sCr{1}(ip,:)), 'gaussian', smWd);
sSIr_Lip = sSIr_Mip - smoothdata(std(sCr{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIr_Hip = sSIr_Mip + smoothdata(std(sCr{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIr_Msp = smoothdata(mean(sCr{1}(sp,:)), 'gaussian', smWd);
sSIr_Lsp = sSIr_Msp - smoothdata(std(sCr{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIr_Hsp = sSIr_Msp + smoothdata(std(sCr{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIr_Mak = smoothdata(mean(sCr{1}(ak,:)), 'gaussian', smWd);
sSIr_Lak = sSIr_Mak - smoothdata(std(sCr{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIr_Hak = sSIr_Mak + smoothdata(std(sCr{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIn_Mrp = smoothdata(mean(sCn{1}(rp,:)), 'gaussian', smWd);
sSIn_Lrp = sSIn_Mrp - smoothdata(std(sCn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Hrp = sSIn_Mrp + smoothdata(std(sCn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Mfp = smoothdata(mean(sCn{1}(fp,:)), 'gaussian', smWd);
sSIn_Lfp = sSIn_Mfp - smoothdata(std(sCn{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIn_Hfp = sSIn_Mfp + smoothdata(std(sCn{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIn_Mip = smoothdata(mean(sCn{1}(ip,:)), 'gaussian', smWd);
sSIn_Lip = sSIn_Mip - smoothdata(std(sCn{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIn_Hip = sSIn_Mip + smoothdata(std(sCn{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIn_Msp = smoothdata(mean(sCn{1}(sp,:)), 'gaussian', smWd);
sSIn_Lsp = sSIn_Msp - smoothdata(std(sCn{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIn_Hsp = sSIn_Msp + smoothdata(std(sCn{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIn_Mak = smoothdata(mean(sCn{1}(ak,:)), 'gaussian', smWd);
sSIn_Lak = sSIn_Mak - smoothdata(std(sCn{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIn_Hak = sSIn_Mak + smoothdata(std(sCn{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sFPr_Mrp = smoothdata(nanmean(sCr{2}(rp,:)), 'gaussian', smWd);
sFPr_Lrp = sFPr_Mrp - smoothdata(nanstd(sCr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Hrp = sFPr_Mrp + smoothdata(nanstd(sCr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Mfp = smoothdata(nanmean(sCr{2}(fp,:)), 'gaussian', smWd);
sFPr_Lfp = sFPr_Mfp - smoothdata(nanstd(sCr{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sFPr_Hfp = sFPr_Mfp + smoothdata(nanstd(sCr{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sFPr_Mip = smoothdata(nanmean(sCr{2}(ip,:)), 'gaussian', smWd);
sFPr_Lip = sFPr_Mip - smoothdata(nanstd(sCr{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sFPr_Hip = sFPr_Mip + smoothdata(nanstd(sCr{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sFPr_Msp = smoothdata(nanmean(sCr{2}(sp,:)), 'gaussian', smWd);
sFPr_Lsp = sFPr_Msp - smoothdata(nanstd(sCr{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sFPr_Hsp = sFPr_Msp + smoothdata(nanstd(sCr{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sFPr_Mak = smoothdata(nanmean(sCr{2}(ak,:)), 'gaussian', smWd);
sFPr_Lak = sFPr_Mak - smoothdata(nanstd(sCr{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sFPr_Hak = sFPr_Mak + smoothdata(nanstd(sCr{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);



%% Figure S3a: Fraction Encoding (Choice)

dtLR = 0.005;
winLO = [-1 1];
winCI = [-1 1];
winGO = [-1 1];
winSIpre = [-1 1];
winSIpost = [0 1];
winFP = [-1 1];
tFP = tLO;

plotDur = [range(winLO) range(winCI) range(winGO) winSIpost(2)-winSIpre(1) range(winSIpost) range(winFP)];
plotFrac = plotDur / sum(plotDur);
m = 0.0025; g = 0.005; plotSpace = (1-3*m-4*g);
w = plotFrac * plotSpace; wg = w + [g g g m g m];
l = m + [0 arrayfun(@(i) sum(wg(1:i)), 1:5)];
 
b = 0.005; h = 0.99
f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
plot(tLO, fracLOak, 'c', 'linewidth', 3)
plot(tLO, fracLOsp, 'b', 'linewidth', 3)
plot(tLO, fracLOfp, 'color', fpColor, 'linewidth', 3)
plot(tLO, fracLOrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
yR = [0 0.75];
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winLO)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
plot(tCI, fracCIak, 'c', 'linewidth', 3)
plot(tCI, fracCIsp, 'b', 'linewidth', 3)
plot(tCI, fracCIfp, 'color', fpColor, 'linewidth', 3)
plot(tCI, fracCIrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winCI)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
plot(tGO, fracGOak, 'c', 'linewidth', 3)
plot(tGO, fracGOsp, 'b', 'linewidth', 3)
plot(tGO, fracGOfp, 'color', fpColor, 'linewidth', 3)
plot(tGO, fracGOrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winGO)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
plot(tSIpre, fracSIpak, 'c', 'linewidth', 3)
plot(tSIpre, fracSIpsp, 'b', 'linewidth', 3)
plot(tSIpre, fracSIpfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpre, fracSIprp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSIrak, 'c', 'linewidth', 3)
plot(tSIpost, fracSIrsp, 'b', 'linewidth', 3)
plot(tSIpost, fracSIrfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpost, fracSIrrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim([winSIpre(1) winSIpost(2)])
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
plot(tSIpost, fracSInak, 'c', 'linewidth', 3)
plot(tSIpost, fracSInsp, 'b', 'linewidth', 3)
plot(tSIpost, fracSInfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpost, fracSInrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
xlim(winSIpost)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
plot(tFP, fracFPrak, 'c', 'linewidth', 3)
plot(tFP, fracFPrsp, 'b', 'linewidth', 3)
plot(tFP, fracFPrfp, 'color', fpColor, 'linewidth', 3)
plot(tFP, fracFPrrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winFP)
ylim(yR)
ax = gca;
ax.YTick = [-0.4:0.2:0.4];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Figure S3a: Regression Slope (Choice)

f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
shade(tLO, sLO_Hak, tLO, sLO_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tLO, sLO_Mak, 'color', 'c', 'lineWidth', 2)
shade(tLO, sLO_Hsp, tLO, sLO_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tLO, sLO_Msp, 'color', 'b', 'lineWidth', 2)
shade(tLO, sLO_Hfp, tLO, sLO_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tLO, sLO_Hrp, tLO, sLO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
yR = [-0.15 0.15];
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
shade(tCI, sCI_Hak, tCI, sCI_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tCI, sCI_Mak, 'color', 'c', 'lineWidth', 2)
shade(tCI, sCI_Hsp, tCI, sCI_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tCI, sCI_Msp, 'color', 'b', 'lineWidth', 2)
shade(tCI, sCI_Hfp, tCI, sCI_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tCI, sCI_Hrp, tCI, sCI_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
shade(tGO, sGO_Hak, tGO, sGO_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tGO, sGO_Mak, 'color', 'c', 'lineWidth', 2)
shade(tGO, sGO_Hsp, tGO, sGO_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tGO, sGO_Msp, 'color', 'b', 'lineWidth', 2)
shade(tGO, sGO_Hfp, tGO, sGO_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tGO, sGO_Hrp, tGO, sGO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
shade(tSIpre, sSIp_Hak(1:201), tSIpre, sSIp_Lak(1:201),'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mak(1:201), 'color', 'c', 'lineWidth', 2)
shade(tSIpre, sSIp_Hsp(1:201), tSIpre, sSIp_Lsp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Msp(1:201), 'color', 'b', 'lineWidth', 2)
shade(tSIpre, sSIp_Hfp(1:201), tSIpre, sSIp_Lfp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mfp(1:201), 'color', fpColor, 'lineWidth', 2)
shade(tSIpre, sSIp_Hrp(1:201), tSIpre, sSIp_Lrp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mrp(1:201), 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hak, tSIpost, sSIr_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mak, 'color', 'c', 'lineWidth', 2)
shade(tSIpost, sSIr_Hsp, tSIpost, sSIr_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Msp, 'color', 'b', 'lineWidth', 2)
shade(tSIpost, sSIr_Hfp, tSIpost, sSIr_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hrp, tSIpost, sSIr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
shade(tSIpost, sSIn_Hak, tSIpost, sSIn_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mak, 'color', 'c', 'lineWidth', 2)
shade(tSIpost, sSIn_Hsp, tSIpost, sSIn_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Msp, 'color', 'b', 'lineWidth', 2)
shade(tSIpost, sSIn_Hfp, tSIpost, sSIn_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tSIpost, sSIn_Hrp, tSIpost, sSIn_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([0 1], [0 0], '--k', 'linewidth', 2)
ylim(yR)
xlim([0 1])
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
shade(tFP, sFPr_Hak, tFP, sFPr_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tFP, sFPr_Mak, 'color', 'c', 'lineWidth', 2)
shade(tFP, sFPr_Hsp, tFP, sFPr_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tFP, sFPr_Msp, 'color', 'b', 'lineWidth', 2)
shade(tFP, sFPr_Hfp, tFP, sFPr_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tFP, sFPr_Hrp, tFP, sFPr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = [-0.2 -0.1 0];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Compute Plottable Output from Linear Regression (Movement)

smWd = 10;

fracLOrp = smoothdata(FracSignificant2(pM{1}(rp,:), 0.05), 'gaussian', smWd);
fracLOfp = smoothdata(FracSignificant2(pM{1}(fp,:), 0.05), 'gaussian', smWd);
fracLOip = smoothdata(FracSignificant2(pM{1}(ip,:), 0.05), 'gaussian', smWd);
fracLOsp = smoothdata(FracSignificant2(pM{1}(sp,:), 0.05), 'gaussian', smWd);
fracLOak = smoothdata(FracSignificant2(pM{1}(ak,:), 0.05), 'gaussian', smWd);

fracCIrp = smoothdata(FracSignificant2(pM{2}(rp,:), 0.05), 'gaussian', smWd);
fracCIfp = smoothdata(FracSignificant2(pM{2}(fp,:), 0.05), 'gaussian', smWd);
fracCIip = smoothdata(FracSignificant2(pM{2}(ip,:), 0.05), 'gaussian', smWd);
fracCIsp = smoothdata(FracSignificant2(pM{2}(sp,:), 0.05), 'gaussian', smWd);
fracCIak = smoothdata(FracSignificant2(pM{2}(ak,:), 0.05), 'gaussian', smWd);

fracGOrp = smoothdata(FracSignificant2(pM{3}(rp,:), 0.05), 'gaussian', smWd);
fracGOfp = smoothdata(FracSignificant2(pM{3}(fp,:), 0.05), 'gaussian', smWd);
fracGOip = smoothdata(FracSignificant2(pM{3}(ip,:), 0.05), 'gaussian', smWd);
fracGOsp = smoothdata(FracSignificant2(pM{3}(sp,:), 0.05), 'gaussian', smWd);
fracGOak = smoothdata(FracSignificant2(pM{3}(ak,:), 0.05), 'gaussian', smWd);

fracSIprp = smoothdata(FracSignificant2(pM{5}(rp,:), 0.05), 'gaussian', smWd);
fracSIpfp = smoothdata(FracSignificant2(pM{5}(fp,:), 0.05), 'gaussian', smWd);
fracSIpip = smoothdata(FracSignificant2(pM{5}(ip,:), 0.05), 'gaussian', smWd);
fracSIpsp = smoothdata(FracSignificant2(pM{5}(sp,:), 0.05), 'gaussian', smWd);
fracSIpak = smoothdata(FracSignificant2(pM{5}(ak,:), 0.05), 'gaussian', smWd);

fracSIrrp = smoothdata(FracSignificant2(pMr{1}(rp,:), 0.05), 'gaussian', smWd);
fracSIrfp = smoothdata(FracSignificant2(pMr{1}(fp,:), 0.05), 'gaussian', smWd);
fracSIrip = smoothdata(FracSignificant2(pMr{1}(ip,:), 0.05), 'gaussian', smWd);
fracSIrsp = smoothdata(FracSignificant2(pMr{1}(sp,:), 0.05), 'gaussian', smWd);
fracSIrak = smoothdata(FracSignificant2(pMr{1}(ak,:), 0.05), 'gaussian', smWd);

fracSInrp = smoothdata(FracSignificant2(pMn{1}(rp,:), 0.05), 'gaussian', smWd);
fracSInfp = smoothdata(FracSignificant2(pMn{1}(fp,:), 0.05), 'gaussian', smWd);
fracSInip = smoothdata(FracSignificant2(pMn{1}(ip,:), 0.05), 'gaussian', smWd);
fracSInsp = smoothdata(FracSignificant2(pMn{1}(sp,:), 0.05), 'gaussian', smWd);
fracSInak = smoothdata(FracSignificant2(pMn{1}(ak,:), 0.05), 'gaussian', smWd);

fracFPrrp = smoothdata(FracSignificant2(pMr{2}(rp,:), 0.05), 'gaussian', smWd);
fracFPrfp = smoothdata(FracSignificant2(pMr{2}(fp,:), 0.05), 'gaussian', smWd);
fracFPrip = smoothdata(FracSignificant2(pMr{2}(ip,:), 0.05), 'gaussian', smWd);
fracFPrsp = smoothdata(FracSignificant2(pMr{2}(sp,:), 0.05), 'gaussian', smWd);
fracFPrak = smoothdata(FracSignificant2(pMr{2}(ak,:), 0.05), 'gaussian', smWd);

sLO_Mrp = smoothdata(mean(sM{1}(rp,:)), 'gaussian', smWd);
sLO_Lrp = sLO_Mrp - smoothdata(std(sM{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Hrp = sLO_Mrp + smoothdata(std(sM{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Mfp = smoothdata(mean(sM{1}(fp,:)), 'gaussian', smWd);
sLO_Lfp = sLO_Mfp - smoothdata(std(sM{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sLO_Hfp = sLO_Mfp + smoothdata(std(sM{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sLO_Mip = smoothdata(mean(sM{1}(ip,:)), 'gaussian', smWd);
sLO_Lip = sLO_Mip - smoothdata(std(sM{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sLO_Hip = sLO_Mip + smoothdata(std(sM{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sLO_Msp = smoothdata(mean(sM{1}(sp,:)), 'gaussian', smWd);
sLO_Lsp = sLO_Msp - smoothdata(std(sM{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sLO_Hsp = sLO_Msp + smoothdata(std(sM{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sLO_Mak = smoothdata(mean(sM{1}(ak,:)), 'gaussian', smWd);
sLO_Lak = sLO_Mak - smoothdata(std(sM{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sLO_Hak = sLO_Mak + smoothdata(std(sM{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sCI_Mrp = smoothdata(mean(sM{2}(rp,:)), 'gaussian', smWd);
sCI_Lrp = sCI_Mrp - smoothdata(std(sM{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Hrp = sCI_Mrp + smoothdata(std(sM{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Mfp = smoothdata(mean(sM{2}(fp,:)), 'gaussian', smWd);
sCI_Lfp = sCI_Mfp - smoothdata(std(sM{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sCI_Hfp = sCI_Mfp + smoothdata(std(sM{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sCI_Mip = smoothdata(mean(sM{2}(ip,:)), 'gaussian', smWd);
sCI_Lip = sCI_Mip - smoothdata(std(sM{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sCI_Hip = sCI_Mip + smoothdata(std(sM{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sCI_Msp = smoothdata(mean(sM{2}(sp,:)), 'gaussian', smWd);
sCI_Lsp = sCI_Msp - smoothdata(std(sM{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sCI_Hsp = sCI_Msp + smoothdata(std(sM{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sCI_Mak = smoothdata(mean(sM{2}(ak,:)), 'gaussian', smWd);
sCI_Lak = sCI_Mak - smoothdata(std(sM{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sCI_Hak = sCI_Mak + smoothdata(std(sM{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sGO_Mrp = smoothdata(mean(sM{3}(rp,:)), 'gaussian', smWd);
sGO_Lrp = sGO_Mrp - smoothdata(std(sM{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Hrp = sGO_Mrp + smoothdata(std(sM{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Mfp = smoothdata(mean(sM{3}(fp,:)), 'gaussian', smWd);
sGO_Lfp = sGO_Mfp - smoothdata(std(sM{3}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sGO_Hfp = sGO_Mfp + smoothdata(std(sM{3}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sGO_Mip = smoothdata(mean(sM{3}(ip,:)), 'gaussian', smWd);
sGO_Lip = sGO_Mip - smoothdata(std(sM{3}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sGO_Hip = sGO_Mip + smoothdata(std(sM{3}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sGO_Msp = smoothdata(mean(sM{3}(sp,:)), 'gaussian', smWd);
sGO_Lsp = sGO_Msp - smoothdata(std(sM{3}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sGO_Hsp = sGO_Msp + smoothdata(std(sM{3}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sGO_Mak = smoothdata(mean(sM{3}(ak,:)), 'gaussian', smWd);
sGO_Lak = sGO_Mak - smoothdata(std(sM{3}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sGO_Hak = sGO_Mak + smoothdata(std(sM{3}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIp_Mrp = smoothdata(mean(sM{4}(rp,:)), 'gaussian', smWd);
sSIp_Lrp = sSIp_Mrp - smoothdata(std(sM{4}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Hrp = sSIp_Mrp + smoothdata(std(sM{4}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Mfp = smoothdata(mean(sM{4}(fp,:)), 'gaussian', smWd);
sSIp_Lfp = sSIp_Mfp - smoothdata(std(sM{4}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIp_Hfp = sSIp_Mfp + smoothdata(std(sM{4}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIp_Mip = smoothdata(mean(sM{4}(ip,:)), 'gaussian', smWd);
sSIp_Lip = sSIp_Mip - smoothdata(std(sM{4}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIp_Hip = sSIp_Mip + smoothdata(std(sM{4}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIp_Msp = smoothdata(mean(sM{4}(sp,:)), 'gaussian', smWd);
sSIp_Lsp = sSIp_Msp - smoothdata(std(sM{4}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIp_Hsp = sSIp_Msp + smoothdata(std(sM{4}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIp_Mak = smoothdata(mean(sM{4}(ak,:)), 'gaussian', smWd);
sSIp_Lak = sSIp_Mak - smoothdata(std(sM{4}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIp_Hak = sSIp_Mak + smoothdata(std(sM{4}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIr_Mrp = smoothdata(mean(sMr{1}(rp,:)), 'gaussian', smWd);
sSIr_Lrp = sSIr_Mrp - smoothdata(std(sMr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Hrp = sSIr_Mrp + smoothdata(std(sMr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Mfp = smoothdata(mean(sMr{1}(fp,:)), 'gaussian', smWd);
sSIr_Lfp = sSIr_Mfp - smoothdata(std(sMr{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIr_Hfp = sSIr_Mfp + smoothdata(std(sMr{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIr_Mip = smoothdata(mean(sMr{1}(ip,:)), 'gaussian', smWd);
sSIr_Lip = sSIr_Mip - smoothdata(std(sMr{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIr_Hip = sSIr_Mip + smoothdata(std(sMr{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIr_Msp = smoothdata(mean(sMr{1}(sp,:)), 'gaussian', smWd);
sSIr_Lsp = sSIr_Msp - smoothdata(std(sMr{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIr_Hsp = sSIr_Msp + smoothdata(std(sMr{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIr_Mak = smoothdata(mean(sMr{1}(ak,:)), 'gaussian', smWd);
sSIr_Lak = sSIr_Mak - smoothdata(std(sMr{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIr_Hak = sSIr_Mak + smoothdata(std(sMr{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sSIn_Mrp = smoothdata(mean(sMn{1}(rp,:)), 'gaussian', smWd);
sSIn_Lrp = sSIn_Mrp - smoothdata(std(sMn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Hrp = sSIn_Mrp + smoothdata(std(sMn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Mfp = smoothdata(mean(sMn{1}(fp,:)), 'gaussian', smWd);
sSIn_Lfp = sSIn_Mfp - smoothdata(std(sMn{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIn_Hfp = sSIn_Mfp + smoothdata(std(sMn{1}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sSIn_Mip = smoothdata(mean(sMn{1}(ip,:)), 'gaussian', smWd);
sSIn_Lip = sSIn_Mip - smoothdata(std(sMn{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIn_Hip = sSIn_Mip + smoothdata(std(sMn{1}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sSIn_Msp = smoothdata(mean(sMn{1}(sp,:)), 'gaussian', smWd);
sSIn_Lsp = sSIn_Msp - smoothdata(std(sMn{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIn_Hsp = sSIn_Msp + smoothdata(std(sMn{1}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sSIn_Mak = smoothdata(mean(sMn{1}(ak,:)), 'gaussian', smWd);
sSIn_Lak = sSIn_Mak - smoothdata(std(sMn{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sSIn_Hak = sSIn_Mak + smoothdata(std(sMn{1}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);

sFPr_Mrp = smoothdata(nanmean(sMr{2}(rp,:)), 'gaussian', smWd);
sFPr_Lrp = sFPr_Mrp - smoothdata(nanstd(sMr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Hrp = sFPr_Mrp + smoothdata(nanstd(sMr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Mfp = smoothdata(nanmean(sMr{2}(fp,:)), 'gaussian', smWd);
sFPr_Lfp = sFPr_Mfp - smoothdata(nanstd(sMr{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sFPr_Hfp = sFPr_Mfp + smoothdata(nanstd(sMr{2}(fp,:))/sqrt(length(fp)), 'gaussian', smWd);
sFPr_Mip = smoothdata(nanmean(sMr{2}(ip,:)), 'gaussian', smWd);
sFPr_Lip = sFPr_Mip - smoothdata(nanstd(sMr{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sFPr_Hip = sFPr_Mip + smoothdata(nanstd(sMr{2}(ip,:))/sqrt(length(ip)), 'gaussian', smWd);
sFPr_Msp = smoothdata(nanmean(sMr{2}(sp,:)), 'gaussian', smWd);
sFPr_Lsp = sFPr_Msp - smoothdata(nanstd(sMr{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sFPr_Hsp = sFPr_Msp + smoothdata(nanstd(sMr{2}(sp,:))/sqrt(length(sp)), 'gaussian', smWd);
sFPr_Mak = smoothdata(nanmean(sMr{2}(ak,:)), 'gaussian', smWd);
sFPr_Lak = sFPr_Mak - smoothdata(nanstd(sMr{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);
sFPr_Hak = sFPr_Mak + smoothdata(nanstd(sMr{2}(ak,:))/sqrt(length(ak)), 'gaussian', smWd);



%% Figure S3a: Fraction Encoding (Movement)

dtLR = 0.005;
winLO = [-1 1];
winCI = [-1 1];
winGO = [-1 1];
winSIpre = [-1 1];
winSIpost = [0 1];
winFP = [-1 1];
tFP = tLO;

plotDur = [range(winLO) range(winCI) range(winGO) winSIpost(2)-winSIpre(1) range(winSIpost) range(winFP)];
plotFrac = plotDur / sum(plotDur);
m = 0.0025; g = 0.005; plotSpace = (1-3*m-4*g);
w = plotFrac * plotSpace; wg = w + [g g g m g m];
l = m + [0 arrayfun(@(i) sum(wg(1:i)), 1:5)];
 
b = 0.005; h = 0.99
f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
plot(tLO, fracLOak, 'c', 'linewidth', 3)
plot(tLO, fracLOsp, 'b', 'linewidth', 3)
plot(tLO, fracLOfp, 'color', fpColor, 'linewidth', 3)
plot(tLO, fracLOrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
yR = [0 0.75];
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winLO)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
plot(tCI, fracCIak, 'c', 'linewidth', 3)
plot(tCI, fracCIsp, 'b', 'linewidth', 3)
plot(tCI, fracCIfp, 'color', fpColor, 'linewidth', 3)
plot(tCI, fracCIrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winCI)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
plot(tGO, fracGOak, 'c', 'linewidth', 3)
plot(tGO, fracGOsp, 'b', 'linewidth', 3)
plot(tGO, fracGOfp, 'color', fpColor, 'linewidth', 3)
plot(tGO, fracGOrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winGO)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
plot(tSIpre, fracSIpak, 'c', 'linewidth', 3)
plot(tSIpre, fracSIpsp, 'b', 'linewidth', 3)
plot(tSIpre, fracSIpfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpre, fracSIprp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSIrak, 'c', 'linewidth', 3)
plot(tSIpost, fracSIrsp, 'b', 'linewidth', 3)
plot(tSIpost, fracSIrfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpost, fracSIrrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim([winSIpre(1) winSIpost(2)])
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
plot(tSIpost, fracSInak, 'c', 'linewidth', 3)
plot(tSIpost, fracSInsp, 'b', 'linewidth', 3)
plot(tSIpost, fracSInfp, 'color', fpColor, 'linewidth', 3)
plot(tSIpost, fracSInrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
xlim(winSIpost)
ylim(yR)
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
plot(tFP, fracFPrak, 'c', 'linewidth', 3)
plot(tFP, fracFPrsp, 'b', 'linewidth', 3)
plot(tFP, fracFPrfp, 'color', fpColor, 'linewidth', 3)
plot(tFP, fracFPrrp, 'color', rpColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winFP)
ylim(yR)
ax = gca;
ax.YTick = [-0.4:0.2:0.4];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Figure S3a: Regression Slope (Movement)

f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
shade(tLO, sLO_Hak, tLO, sLO_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tLO, sLO_Mak, 'color', 'c', 'lineWidth', 2)
shade(tLO, sLO_Hsp, tLO, sLO_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tLO, sLO_Msp, 'color', 'b', 'lineWidth', 2)
shade(tLO, sLO_Hfp, tLO, sLO_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tLO, sLO_Hrp, tLO, sLO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
yR = [-0.0012 0.0012];
yT = [-0.001 0.001];
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
shade(tCI, sCI_Hak, tCI, sCI_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tCI, sCI_Mak, 'color', 'c', 'lineWidth', 2)
shade(tCI, sCI_Hsp, tCI, sCI_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tCI, sCI_Msp, 'color', 'b', 'lineWidth', 2)
shade(tCI, sCI_Hfp, tCI, sCI_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tCI, sCI_Hrp, tCI, sCI_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
shade(tGO, sGO_Hak, tGO, sGO_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tGO, sGO_Mak, 'color', 'c', 'lineWidth', 2)
shade(tGO, sGO_Hsp, tGO, sGO_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tGO, sGO_Msp, 'color', 'b', 'lineWidth', 2)
shade(tGO, sGO_Hfp, tGO, sGO_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tGO, sGO_Hrp, tGO, sGO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
shade(tSIpre, sSIp_Hak(1:201), tSIpre, sSIp_Lak(1:201),'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mak(1:201), 'color', 'c', 'lineWidth', 2)
shade(tSIpre, sSIp_Hsp(1:201), tSIpre, sSIp_Lsp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Msp(1:201), 'color', 'b', 'lineWidth', 2)
shade(tSIpre, sSIp_Hfp(1:201), tSIpre, sSIp_Lfp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mfp(1:201), 'color', fpColor, 'lineWidth', 2)
shade(tSIpre, sSIp_Hrp(1:201), tSIpre, sSIp_Lrp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mrp(1:201), 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hak, tSIpost, sSIr_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mak, 'color', 'c', 'lineWidth', 2)
shade(tSIpost, sSIr_Hsp, tSIpost, sSIr_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Msp, 'color', 'b', 'lineWidth', 2)
shade(tSIpost, sSIr_Hfp, tSIpost, sSIr_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hrp, tSIpost, sSIr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
shade(tSIpost, sSIn_Hak, tSIpost, sSIn_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mak, 'color', 'c', 'lineWidth', 2)
shade(tSIpost, sSIn_Hsp, tSIpost, sSIn_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Msp, 'color', 'b', 'lineWidth', 2)
shade(tSIpost, sSIn_Hfp, tSIpost, sSIn_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tSIpost, sSIn_Hrp, tSIpost, sSIn_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([0 1], [0 0], '--k', 'linewidth', 2)
ylim(yR)
xlim([0 1])
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
shade(tFP, sFPr_Hak, tFP, sFPr_Lak,'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'c', 'FillAlpha', 0.25)
plot(tFP, sFPr_Mak, 'color', 'c', 'lineWidth', 2)
shade(tFP, sFPr_Hsp, tFP, sFPr_Lsp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', 'b', 'FillAlpha', 0.25)
plot(tFP, sFPr_Msp, 'color', 'b', 'lineWidth', 2)
shade(tFP, sFPr_Hfp, tFP, sFPr_Lfp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', fpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mfp, 'color', fpColor, 'lineWidth', 2)
shade(tFP, sFPr_Hrp, tFP, sFPr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mrp, 'color', rpColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% GP-RPE - VTA-DA comparison [load linear regerssion data]

lrDA = load([datRoot 'rlLRda3.mat'])
lrGP = load([datRoot 'rlLR3a.mat'])



%% Compute Plottable Output from Linear Regression (Reward Rate)

smWd = 10;

fracLOrp = smoothdata(FracSignificant2(lrGP.pR{1}(rp,:), 0.05), 'gaussian', smWd);
fracLOda = smoothdata(FracSignificant2(lrDA.pRda{1}, 0.05), 'gaussian', smWd);
fracCIrp = smoothdata(FracSignificant2(lrGP.pR{2}(rp,:), 0.05), 'gaussian', smWd);
fracCIda = smoothdata(FracSignificant2(lrDA.pRda{2}, 0.05), 'gaussian', smWd);
fracGOrp = smoothdata(FracSignificant2(lrGP.pR{3}(rp,:), 0.05), 'gaussian', smWd);
fracGOda = smoothdata(FracSignificant2(lrDA.pRda{3}, 0.05), 'gaussian', smWd);
fracSIprp = smoothdata(FracSignificant2(lrGP.pR{5}(rp,:), 0.05), 'gaussian', smWd);
fracSIpda = smoothdata(FracSignificant2(lrDA.pRda{4}, 0.05), 'gaussian', smWd);
fracSIrrp = smoothdata(FracSignificant2(lrGP.pRr{1}(rp,:), 0.05), 'gaussian', smWd);
fracSIrda = smoothdata(FracSignificant2(lrDA.pRdaR{1}, 0.05), 'gaussian', smWd);
fracSInrp = smoothdata(FracSignificant2(lrGP.pRn{1}(rp,:), 0.05), 'gaussian', smWd);
fracSInda = smoothdata(FracSignificant2(lrDA.pRdaN{1}, 0.05), 'gaussian', smWd);
fracFPrrp = smoothdata(FracSignificant2(lrGP.pRr{2}(rp,:), 0.05), 'gaussian', smWd);
fracFPrda = smoothdata(FracSignificant2(lrDA.pRdaR{2}, 0.05), 'gaussian', smWd);

sLO_Mrp = smoothdata(mean(lrGP.sR{1}(rp,:)), 'gaussian', smWd);
sLO_Lrp = sLO_Mrp - smoothdata(std(lrGP.sR{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Hrp = sLO_Mrp + smoothdata(std(lrGP.sR{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Mda = smoothdata(mean(lrDA.sRda{1}), 'gaussian', smWd);
sLO_Lda = sLO_Mda - smoothdata(std(lrDA.sRda{1})/sqrt(29), 'gaussian', smWd);
sLO_Hda = sLO_Mda + smoothdata(std(lrDA.sRda{1})/sqrt(29), 'gaussian', smWd);

sCI_Mrp = smoothdata(mean(lrGP.sR{2}(rp,:)), 'gaussian', smWd);
sCI_Lrp = sCI_Mrp - smoothdata(std(lrGP.sR{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Hrp = sCI_Mrp + smoothdata(std(lrGP.sR{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Mda = smoothdata(mean(lrDA.sRda{2}), 'gaussian', smWd);
sCI_Lda = sCI_Mda - smoothdata(std(lrDA.sRda{2})/sqrt(29), 'gaussian', smWd);
sCI_Hda = sCI_Mda + smoothdata(std(lrDA.sRda{2})/sqrt(29), 'gaussian', smWd);

sGO_Mrp = smoothdata(mean(lrGP.sR{3}(rp,:)), 'gaussian', smWd);
sGO_Lrp = sGO_Mrp - smoothdata(std(lrGP.sR{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Hrp = sGO_Mrp + smoothdata(std(lrGP.sR{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Mda = smoothdata(mean(lrDA.sRda{3}), 'gaussian', smWd);
sGO_Lda = sGO_Mda - smoothdata(std(lrDA.sRda{3})/sqrt(29), 'gaussian', smWd);
sGO_Hda = sGO_Mda + smoothdata(std(lrDA.sRda{3})/sqrt(29), 'gaussian', smWd);

sSIp_Mrp = smoothdata(mean(lrGP.sR{5}(rp,:)), 'gaussian', smWd);
sSIp_Lrp = sSIp_Mrp - smoothdata(std(lrGP.sR{5}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Hrp = sSIp_Mrp + smoothdata(std(lrGP.sR{5}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Mda = smoothdata(mean(lrDA.sRda{4}), 'gaussian', smWd);
sSIp_Lda = sSIp_Mda - smoothdata(std(lrDA.sRda{4})/sqrt(29), 'gaussian', smWd);
sSIp_Hda = sSIp_Mda + smoothdata(std(lrDA.sRda{4})/sqrt(29), 'gaussian', smWd);

sSIr_Mrp = smoothdata(mean(lrGP.sRr{1}(rp,:)), 'gaussian', smWd);
sSIr_Lrp = sSIr_Mrp - smoothdata(std(lrGP.sRr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Hrp = sSIr_Mrp + smoothdata(std(lrGP.sRr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Mda = smoothdata(mean(lrDA.sRdaR{1}), 'gaussian', smWd);
sSIr_Lda = sSIr_Mda - smoothdata(std(lrDA.sRdaR{1})/sqrt(29), 'gaussian', smWd);
sSIr_Hda = sSIr_Mda + smoothdata(std(lrDA.sRdaR{1})/sqrt(29), 'gaussian', smWd);

sSIn_Mrp = smoothdata(mean(lrGP.sRn{1}(rp,:)), 'gaussian', smWd);
sSIn_Lrp = sSIn_Mrp - smoothdata(std(lrGP.sRn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Hrp = sSIn_Mrp + smoothdata(std(lrGP.sRn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Mda = smoothdata(mean(lrDA.sRdaN{1}), 'gaussian', smWd);
sSIn_Lda = sSIn_Mda - smoothdata(std(lrDA.sRdaN{1})/sqrt(29), 'gaussian', smWd);
sSIn_Hda = sSIn_Mda + smoothdata(std(lrDA.sRdaN{1})/sqrt(29), 'gaussian', smWd);

sFPr_Mrp = smoothdata(nanmean(lrGP.sRr{2}(rp,:)), 'gaussian', smWd);
sFPr_Lrp = sFPr_Mrp - smoothdata(nanstd(lrGP.sRr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Hrp = sFPr_Mrp + smoothdata(nanstd(lrGP.sRr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Mda = smoothdata(mean(lrDA.sRdaR{2}), 'gaussian', smWd);
sFPr_Lda = sFPr_Mda - smoothdata(std(lrDA.sRdaR{2})/sqrt(29), 'gaussian', smWd);
sFPr_Hda = sFPr_Mda + smoothdata(std(lrDA.sRdaR{2})/sqrt(29), 'gaussian', smWd);



%% Figure S3x: Fraction Encoding (Reward Rate)

dtLR = 0.005;
winLO = [-1 1];
winCI = [-1 1];
winGO = [-1 1];
winSIpre = [-1 1];
winSIpost = [0 1];
winFP = [-1 1];
tFP = tLO;

plotDur = [range(winLO) range(winCI) range(winGO) winSIpost(2)-winSIpre(1) range(winSIpost) range(winFP)];
plotFrac = plotDur / sum(plotDur);
m = 0.0025; g = 0.005; plotSpace = (1-3*m-4*g);
w = plotFrac * plotSpace; wg = w + [g g g m g m];
l = m + [0 arrayfun(@(i) sum(wg(1:i)), 1:5)];
 
b = 0.005; h = 0.99
f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
plot(tLO, fracLOrp, 'color', rpColor, 'linewidth', 3)
plot(tLO, fracLOda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
yR = [0 0.85];
yT = [0.2 0.4 0.6 0.8];
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winLO)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
plot(tCI, fracCIrp, 'color', rpColor, 'linewidth', 3)
plot(tCI, fracCIda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winCI)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
plot(tGO, fracGOrp, 'color', rpColor, 'linewidth', 3)
plot(tGO, fracGOda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winGO)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
plot(tSIpre, fracSIprp, 'color', rpColor, 'linewidth', 3)
plot(tSIpre, fracSIpda, 'color', daColor, 'linewidth', 3)
plot(tSIpost, fracSIrrp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSIrda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim([winSIpre(1) winSIpost(2)])
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
plot(tSIpost, fracSInrp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSInda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
xlim(winSIpost)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
plot(tFP, fracFPrrp, 'color', rpColor, 'linewidth', 3)
plot(tFP, fracFPrda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winFP)
ylim(yR)
ax = gca;
ax.YTick = [-0.4:0.2:0.4];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Figure S3x: GPe-RPE - VTA-DA comparison: Regression Slope (Reward Rate)

f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
shade(tLO, sLO_Hrp, tLO, sLO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tLO, sLO_Hda, tLO, sLO_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
yR = [-0.37 0.12];
yT = [-0.3 -0.2 -0.1 0.1];
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
shade(tCI, sCI_Hrp, tCI, sCI_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tCI, sCI_Hda, tCI, sCI_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
shade(tGO, sGO_Hrp, tGO, sGO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tGO, sGO_Hda, tGO, sGO_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
shade(tSIpre, sSIp_Hrp(1:201), tSIpre, sSIp_Lrp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mrp(1:201), 'color', rpColor, 'lineWidth', 2)
shade(tSIpre, sSIp_Hda(1:201), tSIpre, sSIp_Lda(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mda(1:201), 'color', daColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hrp, tSIpost, sSIr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hda, tSIpost, sSIr_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
shade(tSIpost, sSIn_Hrp, tSIpost, sSIn_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIn_Hda, tSIpost, sSIn_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mda, 'color', daColor, 'lineWidth', 2)
plot([0 1], [0 0], '--k', 'linewidth', 2)
ylim(yR)
xlim([0 1])
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
shade(tFP, sFPr_Hrp, tFP, sFPr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tFP, sFPr_Hda, tFP, sFPr_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Compute Plottable Output from Linear Regression (Choice)

smWd = 10;

fracLOrp = smoothdata(FracSignificant2(lrGP.pC{1}(rp,:), 0.05), 'gaussian', smWd);
fracLOda = smoothdata(FracSignificant2(lrDA.pCda{1}, 0.05), 'gaussian', smWd);
fracCIrp = smoothdata(FracSignificant2(lrGP.pC{2}(rp,:), 0.05), 'gaussian', smWd);
fracCIda = smoothdata(FracSignificant2(lrDA.pCda{2}, 0.05), 'gaussian', smWd);
fracGOrp = smoothdata(FracSignificant2(lrGP.pC{3}(rp,:), 0.05), 'gaussian', smWd);
fracGOda = smoothdata(FracSignificant2(lrDA.pCda{3}, 0.05), 'gaussian', smWd);
fracSIprp = smoothdata(FracSignificant2(lrGP.pC{5}(rp,:), 0.05), 'gaussian', smWd);
fracSIpda = smoothdata(FracSignificant2(lrDA.pCda{4}, 0.05), 'gaussian', smWd);
fracSIrrp = smoothdata(FracSignificant2(lrGP.pCr{1}(rp,:), 0.05), 'gaussian', smWd);
fracSIrda = smoothdata(FracSignificant2(lrDA.pCdaR{1}, 0.05), 'gaussian', smWd);
fracSInrp = smoothdata(FracSignificant2(lrGP.pCn{1}(rp,:), 0.05), 'gaussian', smWd);
fracSInda = smoothdata(FracSignificant2(lrDA.pCdaN{1}, 0.05), 'gaussian', smWd);
fracFPrrp = smoothdata(FracSignificant2(lrGP.pCr{2}(rp,:), 0.05), 'gaussian', smWd);
fracFPrda = smoothdata(FracSignificant2(lrDA.pCdaR{2}, 0.05), 'gaussian', smWd);

sLO_Mrp = smoothdata(mean(lrGP.sC{1}(rp,:)), 'gaussian', smWd);
sLO_Lrp = sLO_Mrp - smoothdata(std(lrGP.sC{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Hrp = sLO_Mrp + smoothdata(std(lrGP.sC{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sLO_Mda = smoothdata(mean(lrDA.sCda{1}), 'gaussian', smWd);
sLO_Lda = sLO_Mda - smoothdata(std(lrDA.sCda{1})/sqrt(29), 'gaussian', smWd);
sLO_Hda = sLO_Mda + smoothdata(std(lrDA.sCda{1})/sqrt(29), 'gaussian', smWd);

sCI_Mrp = smoothdata(mean(lrGP.sC{2}(rp,:)), 'gaussian', smWd);
sCI_Lrp = sCI_Mrp - smoothdata(std(lrGP.sC{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Hrp = sCI_Mrp + smoothdata(std(lrGP.sC{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sCI_Mda = smoothdata(mean(lrDA.sCda{2}), 'gaussian', smWd);
sCI_Lda = sCI_Mda - smoothdata(std(lrDA.sCda{2})/sqrt(29), 'gaussian', smWd);
sCI_Hda = sCI_Mda + smoothdata(std(lrDA.sCda{2})/sqrt(29), 'gaussian', smWd);

sGO_Mrp = smoothdata(mean(lrGP.sC{3}(rp,:)), 'gaussian', smWd);
sGO_Lrp = sGO_Mrp - smoothdata(std(lrGP.sC{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Hrp = sGO_Mrp + smoothdata(std(lrGP.sC{3}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sGO_Mda = smoothdata(mean(lrDA.sCda{3}), 'gaussian', smWd);
sGO_Lda = sGO_Mda - smoothdata(std(lrDA.sCda{3})/sqrt(29), 'gaussian', smWd);
sGO_Hda = sGO_Mda + smoothdata(std(lrDA.sCda{3})/sqrt(29), 'gaussian', smWd);

sSIp_Mrp = smoothdata(mean(lrGP.sC{5}(rp,:)), 'gaussian', smWd);
sSIp_Lrp = sSIp_Mrp - smoothdata(std(lrGP.sC{5}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Hrp = sSIp_Mrp + smoothdata(std(lrGP.sC{5}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIp_Mda = smoothdata(mean(lrDA.sCda{4}), 'gaussian', smWd);
sSIp_Lda = sSIp_Mda - smoothdata(std(lrDA.sCda{4})/sqrt(29), 'gaussian', smWd);
sSIp_Hda = sSIp_Mda + smoothdata(std(lrDA.sCda{4})/sqrt(29), 'gaussian', smWd);

sSIr_Mrp = smoothdata(mean(lrGP.sCr{1}(rp,:)), 'gaussian', smWd);
sSIr_Lrp = sSIr_Mrp - smoothdata(std(lrGP.sCr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Hrp = sSIr_Mrp + smoothdata(std(lrGP.sCr{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIr_Mda = smoothdata(mean(lrDA.sCdaR{1}), 'gaussian', smWd);
sSIr_Lda = sSIr_Mda - smoothdata(std(lrDA.sCdaR{1})/sqrt(29), 'gaussian', smWd);
sSIr_Hda = sSIr_Mda + smoothdata(std(lrDA.sCdaR{1})/sqrt(29), 'gaussian', smWd);

sSIn_Mrp = smoothdata(mean(lrGP.sCn{1}(rp,:)), 'gaussian', smWd);
sSIn_Lrp = sSIn_Mrp - smoothdata(std(lrGP.sCn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Hrp = sSIn_Mrp + smoothdata(std(lrGP.sCn{1}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sSIn_Mda = smoothdata(mean(lrDA.sCdaN{1}), 'gaussian', smWd);
sSIn_Lda = sSIn_Mda - smoothdata(std(lrDA.sCdaN{1})/sqrt(29), 'gaussian', smWd);
sSIn_Hda = sSIn_Mda + smoothdata(std(lrDA.sCdaN{1})/sqrt(29), 'gaussian', smWd);

sFPr_Mrp = smoothdata(nanmean(lrGP.sCr{2}(rp,:)), 'gaussian', smWd);
sFPr_Lrp = sFPr_Mrp - smoothdata(nanstd(lrGP.sCr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Hrp = sFPr_Mrp + smoothdata(nanstd(lrGP.sCr{2}(rp,:))/sqrt(length(rp)), 'gaussian', smWd);
sFPr_Mda = smoothdata(mean(lrDA.sCdaR{2}), 'gaussian', smWd);
sFPr_Lda = sFPr_Mda - smoothdata(std(lrDA.sCdaR{2})/sqrt(29), 'gaussian', smWd);
sFPr_Hda = sFPr_Mda + smoothdata(std(lrDA.sCdaR{2})/sqrt(29), 'gaussian', smWd);




%% Figure S3x: Fraction Encoding (Choice)

dtLR = 0.005;
winLO = [-1 1];
winCI = [-1 1];
winGO = [-1 1];
winSIpre = [-1 1];
winSIpost = [0 1];
winFP = [-1 1];
tFP = tLO;

plotDur = [range(winLO) range(winCI) range(winGO) winSIpost(2)-winSIpre(1) range(winSIpost) range(winFP)];
plotFrac = plotDur / sum(plotDur);
m = 0.0025; g = 0.005; plotSpace = (1-3*m-4*g);
w = plotFrac * plotSpace; wg = w + [g g g m g m];
l = m + [0 arrayfun(@(i) sum(wg(1:i)), 1:5)];
 
b = 0.005; h = 0.99
f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
plot(tLO, fracLOrp, 'color', rpColor, 'linewidth', 3)
plot(tLO, fracLOda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
yR = [0 0.85];
yT = [0.2 0.4 0.6 0.8];
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winLO)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
plot(tCI, fracCIrp, 'color', rpColor, 'linewidth', 3)
plot(tCI, fracCIda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winCI)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
plot(tGO, fracGOrp, 'color', rpColor, 'linewidth', 3)
plot(tGO, fracGOda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winGO)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
plot(tSIpre, fracSIprp, 'color', rpColor, 'linewidth', 3)
plot(tSIpre, fracSIpda, 'color', daColor, 'linewidth', 3)
plot(tSIpost, fracSIrrp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSIrda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim([winSIpre(1) winSIpost(2)])
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
plot(tSIpost, fracSInrp, 'color', rpColor, 'linewidth', 3)
plot(tSIpost, fracSInda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
xlim(winSIpost)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
plot(tFP, fracFPrrp, 'color', rpColor, 'linewidth', 3)
plot(tFP, fracFPrda, 'color', daColor, 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
xlim(winFP)
ylim(yR)
ax = gca;
ax.YTick = [-0.4:0.2:0.4];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';



%% Figure S3x: GPe-RPE - VTA-DA comparison: Regression Slope (Reward Rate)

f = figure('Position', [1 100 1440 400])
subplot('Position', [l(1) b w(1) h])
hold on
shade(tLO, sLO_Hrp, tLO, sLO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tLO, sLO_Hda, tLO, sLO_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tLO, sLO_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
yR = [-0.6 0.6];
yT = [-0.5 0.5];
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(2) b w(2) h])
hold on
shade(tCI, sCI_Hrp, tCI, sCI_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tCI, sCI_Hda, tCI, sCI_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tCI, sCI_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(3) b w(3) h])
hold on
shade(tGO, sGO_Hrp, tGO, sGO_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tGO, sGO_Hda, tGO, sGO_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tGO, sGO_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(4) b w(4) h])
hold on
shade(tSIpre, sSIp_Hrp(1:201), tSIpre, sSIp_Lrp(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mrp(1:201), 'color', rpColor, 'lineWidth', 2)
shade(tSIpre, sSIp_Hda(1:201), tSIpre, sSIp_Lda(1:201), 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tSIpre, sSIp_Mda(1:201), 'color', daColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hrp, tSIpost, sSIr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIr_Hda, tSIpost, sSIr_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIr_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(5) b w(5) h])
hold on
shade(tSIpost, sSIn_Hrp, tSIpost, sSIn_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tSIpost, sSIn_Hda, tSIpost, sSIn_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tSIpost, sSIn_Mda, 'color', daColor, 'lineWidth', 2)
plot([0 1], [0 0], '--k', 'linewidth', 2)
ylim(yR)
xlim([0 1])
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [l(6) b w(6) h])
hold on
shade(tFP, sFPr_Hrp, tFP, sFPr_Lrp, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', rpColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mrp, 'color', rpColor, 'lineWidth', 2)
shade(tFP, sFPr_Hda, tFP, sFPr_Lda, 'color', [1 1 1], 'lineWidth', 0.1, 'FillType',[1 2], 'FillColor', daColor, 'FillAlpha', 0.25)
plot(tFP, sFPr_Mda, 'color', daColor, 'lineWidth', 2)
plot([-1 1], [0 0], '--k', 'linewidth', 2)
plot([0 0], yR, '--k', 'linewidth', 2)
ylim(yR)
ax = gca;
ax.YTick = yT;
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';


