%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end      
end 



%% Parameters for Response Assessment and Peak Measurement

latCrit = 1;
sigma = 20;

% specs for response detection
pR.bslnWin = [-0.1 0];        % baseline window
pR.responseWin = [0 0.3];     % response window
pR.binWidth = 0.05;           % response bin width
pR.responsePolarity = 1;      % response polarity

% specs for response detection after GO cue (narrower window)
pG.bslnWin = [-0.1 0];        % baseline window
pG.responseWin = [0 0.1]; % response window
pG.binWidth = 0.05;           % response bin width
pG.responsePolarity = 0;      % response polarity

nBins = length([pR.responseWin(1):pR.binWidth:pR.responseWin(2)]) - 1;
nGoBins = length([pG.responseWin(1):pG.binWidth:pG.responseWin(2)]) - 1;
win = [pR.bslnWin(1) pR.responseWin(2)];
winGo = [pG.bslnWin(1) pG.responseWin(2)];

% alt "baseline" used to identify phasic responses
pR2 = pR;
pR2.bslnWin = [0.3 0.5];



%% Assess Responsivness, Measure Peak Response (RL, GPe)

goPval = ones(length(unit), nGoBins);
goBsln = zeros(length(unit), 1);
goRate = zeros(length(unit), nGoBins);
siRwdPval = ones(length(unit), nBins);
siRwdBsln = zeros(length(unit), 1);
siRwdRate = zeros(length(unit), nBins);
siPostPval = ones(length(unit), nBins);

goPk = cell(1, length(unit));
goPkt = zeros(1, length(unit));
siRwdPk = cell(1, length(unit));
siRwdPkt = zeros(1, length(unit));

pol = 1;
for u = 1:length(unit)
    
    disp(u)
    [~, rlIdx] = ismember('RL', unit(u).taskList);
    t1 = unit(u).taskStart(rlIdx);
    t2 = unit(u).taskEnd(rlIdx);
    ts = unit(u).behav_ts{rlIdx};
    spk = unit(u).spkTimes(unit(u).spkTimes>t1 & unit(u).spkTimes<t2) - t1;
    uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', sigma);
        
    % go
    eTime = ts.go;
    [goPval(u,:) goRate(u,:) goBsln(u)] = ResponseAssess(spk, eTime, pG);
    [goPk{u} goPkt(u)] = PeakResponse(uTraj, eTime, winGo, pol);
    
    % side in: rewarded
    rwd = TrialFilter(ts, 'x1', 'R');
    eTime = ts.Side_NI;
    [siRwdPval(u,:) siRwdRate(u,:) siRwdBsln(u)] = ResponseAssess(spk, eTime(rwd), pR);
    [siRwdPk{u} siRwdPkt(u)] = PeakResponse(uTraj, eTime(rwd), win, pol);
    
    % side in: post response (phasic response check)
    siPostPval(u,:) = ResponseAssess(spk, eTime(rwd), pR2);
    
end



%% Assess Responsivness, Measure Peak Response (Pav, GPe)

cs0Pval = nan(length(unit), nBins);
cs0Rate = ones(length(unit), nBins);
cs0Bsln = ones(length(unit), 1);
cs25Pval = nan(length(unit), nBins);
cs25Rate = ones(length(unit), nBins);
cs25Bsln = ones(length(unit), 1);
cs75Pval = nan(length(unit), nBins);
cs75Rate = ones(length(unit), nBins);
cs75Bsln = ones(length(unit), 1);
csAllPval = nan(length(unit), nBins);
csAllRate = ones(length(unit), nBins);
csAllBsln = ones(length(unit), 1);
us0Pval = nan(length(unit), nBins);
us0Rate = ones(length(unit), nBins);
us0Bsln = ones(length(unit), 1);
us25rPval = nan(length(unit), nBins);
us25rRate = ones(length(unit), nBins);
us25rBsln = ones(length(unit), 1);
us25nrPval = nan(length(unit), nBins);
us25nrRate = ones(length(unit), nBins);
us25nrBsln = ones(length(unit), 1);
us75rPval = nan(length(unit), nBins);
us75rRate = ones(length(unit), nBins);
us75rBsln = ones(length(unit), 1);
us75nrPval = nan(length(unit), nBins);
us75nrRate = ones(length(unit), nBins);
us75nrBsln = ones(length(unit), 1);
us100Pval = nan(length(unit), nBins);
us100Rate = ones(length(unit), nBins);
us100Bsln = ones(length(unit), 1);
usAllPval = nan(length(unit), nBins);
usAllRate = ones(length(unit), nBins);
usAllBsln = ones(length(unit), 1);
cs0Pk = cell(1, length(unit));
cs0Pkt = nan(1, length(unit));
cs25Pk = cell(1, length(unit));
cs25Pkt = nan(1, length(unit));
cs75Pk = cell(1, length(unit));
cs75Pkt = nan(1, length(unit));
csAllPk = cell(1, length(unit));
csAllPkt = nan(1, length(unit));
us0Pk = cell(1, length(unit));
us0Pkt = nan(1, length(unit));
us25rPk = cell(1, length(unit));
us25rPkt = nan(1, length(unit));
us25nrPk = cell(1, length(unit));
us25nrPkt = nan(1, length(unit));
us75rPk = cell(1, length(unit));
us75rPkt = nan(1, length(unit));
us75nrPk = cell(1, length(unit));
us75nrPkt = nan(1, length(unit));
us100Pk = cell(1, length(unit));
us100Pkt = nan(1, length(unit));
usAllPk = cell(1, length(unit));
usAllPkt = nan(1, length(unit));

for u = 1:length(unit)
    
    [~, pavIdx] = ismember('Pav', unit(u).taskList);
    if pavIdx ~= 0
        ts = unit(u).behav_ts{pavIdx};
    else
        continue
    end
    lg = unit(u).behav_log{pavIdx};
    cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
    cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
    cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);
    tr0 = find(lg.toneFreq == cue0);
    tr25 = find(lg.toneFreq == cue25);
    tr75 = find(lg.toneFreq == cue75);
    tr100 = find(lg.toneFreq == 0);
    rwd = find(lg.outcome);
    noRwd = find(~lg.outcome);
    t1 = unit(u).taskStart(pavIdx);
    t2 = unit(u).taskEnd(pavIdx);
    spk = unit(u).spkTimes(unit(u).spkTimes>t1 & unit(u).spkTimes<t2) - t1;
    
    uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', sigma);

    % CS prob 0
    eTime = ts.csTime;
    [cs0Pval(u,:) cs0Rate(u,:) cs0Bsln(u)] = ResponseAssess(spk, eTime(tr0), pR);
    [cs0Pk{u} cs0Pkt(u)] = PeakResponse(uTraj, eTime(tr0), win, pol);
    
    % CS prob 25
    [cs25Pval(u,:) cs25Rate(u,:) cs25Bsln(u)] = ResponseAssess(spk, eTime(tr25), pR);
    [cs25Pk{u} cs25Pkt(u)] = PeakResponse(uTraj, eTime(tr25), win, pol);
    
    % CS prob 75
    [cs75Pval(u,:) cs75Rate(u,:) cs75Bsln(u)] = ResponseAssess(spk, eTime(tr75), pR);
    [cs75Pk{u} cs75Pkt(u)] = PeakResponse(uTraj, eTime(tr75), win, pol);
    
    % CS All
    tr = unique([tr0; tr25; tr75]);
    [csAllPval(u,:) csAllRate(u,:) csAllBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [csAllPk{u} csAllPkt(u)] = PeakResponse(uTraj, eTime(tr), win, pol);
    
    % US prob 0
    rwdTime = dt*round(nanmean(ts.rwdTime - ts.csTime)/dt);
    eTime = ts.csTime + rwdTime;
    [us0Pval(u,:) us0Rate(u,:) us0Bsln(u)] = ResponseAssess(spk, eTime(tr0), pR);
    [us0Pk{u} us0Pkt(u)] = PeakResponse(uTraj, eTime(tr0), win, pol);
    
    % US prob 100 (unpredicted reward)
    [us100Pval(u,:) us100Rate(u,:) us100Bsln(u)] = ResponseAssess(spk, eTime(tr100), pR);
    [us100Pk{u} us100Pkt(u)] = PeakResponse(uTraj, eTime(tr100), win, pol);
    
    % US prob 25 rewarded
    tr = intersect(tr25, rwd);
    [us25rPval(u,:) us25rRate(u,:) us25rBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us25rPk{u} us25rPkt(u)] = PeakResponse(uTraj, eTime(tr), win, pol);
    
    % US prob 25 unrewarded
    tr = intersect(tr25, noRwd);
    [us25nrPval(u,:) us25nrRate(u,:) us25nrBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us25nrPk{u} us25nrPkt(u)] = PeakResponse(uTraj, eTime(tr), win, pol);
    
    % US prob 75 rewarded
    tr = intersect(tr75, rwd);
    [us75rPval(u,:) us75rRate(u,:) us75rBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us75rPk{u} us75rPkt(u)] = PeakResponse(uTraj, eTime(tr), win, pol);
    
    % US prob 75 unrewarded
    tr = intersect(tr75, noRwd);
    [us75nrPval(u,:) us75nrRate(u,:) us75nrBsln(u)] = ResponseAssess(spk, eTime(tr), pR);
    [us75nrPk{u} us75nrPkt(u)] = PeakResponse(uTraj, eTime(tr), win, pol);
    
    % US all (rewarded only)
    [usAllPval(u,:) usAllRate(u,:) usAllBsln(u)] = ResponseAssess(spk, eTime(rwd), pR);
    [usAllPk{u} usAllPkt(u)] = PeakResponse(uTraj, eTime(rwd), win, pol);
    
end



%% Figure 4b: RPE Coding (RL and Pav)

mPosRpeGP = zeros(1, length(unit));
pPosRpeGP = zeros(1, length(unit));
rPosRpeGP = zeros(1, length(unit));
mNegRpeGP = zeros(1, length(unit));
pNegRpeGP = zeros(1, length(unit));
rNegRpeGP = zeros(1, length(unit));
for u = 1:length(unit)
    [~, rlIdx] = ismember('RL', unit(u).taskList);
    ts = unit(u).behav_ts{rlIdx};
    [~, iSes] = ismember(uSes{u}, sesList);
    rr = rwdRate{iSes};
    fr = siRwdPk{u};
    rwd = TrialFilter(ts, 'x1', unit(u).side);
    sel = find(rwd > 10);
    lm = fitlm(rr(rwd(sel)), fr(sel));
    mPosRpeGP(u) = lm.Coefficients.Estimate(2);
    pPosRpeGP(u) = lm.Coefficients.pValue(2);
    rPosRpeGP(u) = lm.Rsquared.Ordinary;
    
    noRwd = TrialFilter(ts, 'x0', unit(u).side);
    fr = siNoRwdPk{u};
    sel = find(noRwd > 10);
    lm = fitlm(rr(noRwd(sel)), fr(sel));
    mNegRpeGP(u) = lm.Coefficients.Estimate(2);
    pNegRpeGP(u) = lm.Coefficients.pValue(2);
    rNegRpeGP(u) = lm.Rsquared.Ordinary;
    
end



%% Load Full ISI Stats

ratList = unique(uRat);

% loop through rats
swsRate = nan(size(unit));
swsMean = nan(size(unit));
swsSd = nan(size(unit));
swsSkew = nan(size(unit));
swsKurt = nan(size(unit));
swsNumIsi = zeros(size(unit));
swsDur = zeros(size(unit));
wakeMean = nan(size(unit));
wakeSd = nan(size(unit));
wakeSkew = nan(size(unit));
wakeKurt = nan(size(unit));
swsCv = nan(size(unit));
swsCv2 = nan(size(unit));
wakeRate = nan(size(unit));
wakeCv = nan(size(unit));
wakeCv2 = nan(size(unit));
wakeNumIsi = zeros(size(unit));
wakeDur = zeros(size(unit));
rat = cellfun(@(r) str2num(r(3:end)), uRat);
for r = 1:length(ratList)
    
    disp(['rat ' ratList{r}])
    
    uIdx = find(strcmp(ratList{r}, uRat));
    sesList = unique(uSes(uIdx));
    
    % loop through recording sessions
    for iSes = 1:length(sesList)
        
        disp(['   session ' num2str(iSes)])
    
        % load sleep log data
        clear sleepLog
        datDir = [datRoot ratList{r} filesep sesList{iSes} filesep];
        load([datDir 'sleepLog.mat']);
        
        % identify GPe cells recorded in this session, get behavior data
        uIdx = find(strcmp(sesList{iSes}, uSes));
            
        % identify periods of disengaged wakefulness, log SWS times across tasks
        [wake, sws] = WakeTimes(sleepLog, unit(uIdx(1)));
        wakeDur(uIdx) = sum(arrayfun(@(i) diff(wake(i,:)), 1:size(wake,1)));
        swsDur(uIdx) = sum(arrayfun(@(i) diff(sws(i,:)), 1:size(sws,1)));
          
        % extract rate-regularity parameters
        for u = uIdx
            wakeIsi = [];
            for k = 1:size(wake, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > wake(k,1) & unit(u).spkTimes <= wake(k,2));
                wakeIsi = [wakeIsi diff(spk)];
            end
            swsIsi = [];
            for k = 1:size(sws, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > sws(k,1) & unit(u).spkTimes <= sws(k,2));
                swsIsi = [swsIsi diff(spk)];
            end
            wakeNumIsi(u) = length(wakeIsi);
            wakeMean(u) = mean(wakeIsi);
            wakeRate(u) = 1 / wakeMean(u);
            wakeSd(u) = std(wakeIsi);
            wakeCv(u) = wakeSd(u) / wakeMean(u);
            wakeCv2(u) = sqrt(2) * mean(abs(wakeIsi(2:end) - wakeIsi(1:end-1)) ./ (wakeIsi(2:end) + wakeIsi(1:end-1)));
            wakeSkew(u) = skewness(wakeIsi);
            wakeKurt(u) = kurtosis(wakeIsi);
            swsNumIsi(u) = length(swsIsi);
            swsMean(u) = mean(swsIsi);
            swsRate(u) = 1 / swsMean(u);
            swsSd(u) = std(swsIsi);
            swsCv(u) = swsSd(u) / swsMean(u);
            swsCv2(u) = sqrt(2) * mean(abs(swsIsi(2:end) - swsIsi(1:end-1)) ./ (swsIsi(2:end) + swsIsi(1:end-1)));
            swsSkew(u) = skewness(swsIsi);
            swsKurt(u) = kurtosis(swsIsi);
        end
    end
end

% log transform
w1 = log10(wakeMean); % negative sign converts log(mean ISI) to log(mean rate)
w2 = log10(wakeSd);
w3 = log10(wakeSkew);

s1 = log10(swsMean); % negative sign converts log(mean ISI) to log(mean rate)
s2 = log10(swsSd);
s3 = log10(swsSkew);



%% Identify RPE-Encoding Neurons (RL)

pCrit = 0.01;

siRwd = find(arrayfun(@(u) ~isempty(HolmBonferroni(siRwdPval(u,:), 'criterion', pCrit)), 1:length(unit)));
length(siRwd)

siPost = find(arrayfun(@(u) ~isempty(HolmBonferroni(siPostPval(u,:), 'criterion', pCrit)), 1:length(unit)));
length(siPost)

siPhasic  = intersect(siRwd, siPost);
length(siPhasic)

length(intersect(siPhasic, rp)) / length(rp)
length(intersect(siPhasic, fp)) / length(fp)
length(intersect(siPhasic, sp)) / length(sp)
length(intersect(siPhasic, ak)) / length(ak)

siRpe = intersect(find(mPosRpeGP < 0 & pPosRpeGP < 0.01), siPhasic);
length(intersect(siRpe, rp)) / length(rp)
length(intersect(siRpe, fp)) / length(fp)
length(intersect(siRpe, sp)) / length(sp)
length(intersect(siRpe, ak)) / length(ak)



%% Fig. S4B: Examples of RPE Coding Outside of Slow Pacemakers

% fast proto RPE (weak): 1132
% slow proto RPE: 45, 324, 1317
% slow proto RPE (weak): 102 270 345 917 990 1274
% arky RPE (weak): 97, 743
% intermediate proto RPE (weak): 312
% unclassified RPE: 1047 (ACh candidate)

%% Review RL data
close all
ii=ii+1;
u = candidateList(ii)
%[~, uP] = ismember(u, uPav2)

s = find(strcmp(uSes{u}, sesList));
rr = rwdRate{s}(11:end);
uTrajRL = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
ts = unit(u).behav_ts{rlIdx};
pt = find(timesRL == 0) + 1;

loTr = find(rr <= quantile(rr, lo(2))) + 10;
medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
hiTr = find(rr >= quantile(rr, hi(1))) + 10;

% light on
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 1);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
loL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
loM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
loH = mean(r);

% center in
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 2);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
ciL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
ciM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
ciH = mean(r);

% go
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 3);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
goL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
goM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
goH = mean(r);

% side in (pre)
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 5);
rwd = TrialFilter(ts, 'x1', unit(u).side);
noRwd = TrialFilter(ts, 'x0', unit(u).side);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
siL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
siM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
siH = mean(r);

% side in (post)
sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLR = mean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMR = mean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHR = mean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLN = mean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMN = mean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHN = mean(r,1);

% food port
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 6);
sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpLR = nanmean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpMR = nanmean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpHR = nanmean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpLN = nanmean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpMN = nanmean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpHN = nanmean(r);

% make figure
lm = 0.005; xg = 0.005; w = 0.194;
bm = 0.0005; yg = 0.025; hb = 0.34; ht = 0.99; bt = 0.005;

nm = [unit(u).cellType ' (' num2str(u) ')'];
figure('Position', [10 100 1400 300], 'NumberTitle', 'off', 'name', nm)
maxRate = max([loL loM loH ciL ciM ciH goL goM goH siL siM siH]);
maxRate = max([maxRate siLR siMR siHR siLN siMN siHN fpLR fpMR fpHR fpLN fpMN fpHN]);
yR = [0 1.25*maxRate];
yT = [50 100];

% light on
subplot('Position', [lm 0.005 w 0.99])
hold on
plot(timesRL, loH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, loM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, loL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
ylim(yR)
plot([0 0], yR, 'k', 'linewidth', 1);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% center in
subplot('Position', [lm+w+xg bt w ht])
hold on
plot(timesRL, ciH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, ciM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, ciL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% GO
subplot('Position', [lm+2*(w+xg) bt w ht])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% side in
subplot('Position', [lm+3*(w+xg) bt w ht])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR)
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% food port
subplot('Position', [lm+4*(w+xg) bt w ht])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL, fpLN, 'color', cList{6}, 'linewidth', 3)
plot(timesRL, fpMN, 'color', cList{5}, 'linewidth', 3)
plot(timesRL, fpHN, 'color', cList{4}, 'linewidth', 3)
plot(timesRL, fpLR, 'color', cList{3}, 'linewidth', 3)
plot(timesRL, fpMR, 'color', cList{2}, 'linewidth', 3)
plot(timesRL, fpHR, 'color', cList{1}, 'linewidth', 3)
plot([0 0], yR, 'k', 'linewidth', 1);
ylim(yR);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

disp(ii/length(candidateList))