%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];

sesList = unique(uSes);



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end      
end 

 

%% Load Pavlovian and RL LR

load([datRoot 'pavLR4.mat'])
load([datRoot 'rlLR7.mat'])

% RL times
winRL = [-1 1];
winPre = [winRL(1) 0];
winPost = [0 winRL(2)];
dtLR = 0.005;
tFP = tLO;

% Pav times
rwdTime = 3.1356;
winPav = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [winPav(1) rT];
winLR2 = [rT+dtLR winPav(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
pt0 = find(abs(t1) == min(abs(t1)));

% significance criteria
pCrit = 0.05;



%% Example Cell: RL Panel


lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 1;
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

% ak examples: 220(RPE) 520 (alt)
% ak examples (suppl): 186 809 525 644 196
% sp examples: 1278 
% sp examples (suppl): 207 229 363 1003 1279
% fp example: 404
% fp examples (suppl): 393 537 1263 325 380 [alt: 716]

u = 1263;
[~, uP] = ismember(u, uPav2)

s = find(strcmp(uSes{u}, sesList));
rr = rwdRate{s}(11:end);
uTrajRL = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
ts = unit(u).behav_ts{rlIdx};
pt = find(timesRL == 0) + 1;

loTr = find(rr <= quantile(rr, lo(2))) + 10;
medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
hiTr = find(rr >= quantile(rr, hi(1))) + 10;

% light on
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 1);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
loL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
loM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
loH = mean(r);

% center in
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 2);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
ciL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
ciM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
ciH = mean(r);

% go
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 3);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
goL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
goM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
goH = mean(r);

% side in (pre)
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 5);
rwd = TrialFilter(ts, 'x1', unit(u).side);
noRwd = TrialFilter(ts, 'x0', unit(u).side);
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
siL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
siM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
siH = mean(r);

% side in (post)
sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLR = mean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMR = mean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHR = mean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLN = mean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMN = mean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHN = mean(r,1);

% food port
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 6);
sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpLR = nanmean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpMR = nanmean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpHR = nanmean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpLN = nanmean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpMN = nanmean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpHN = nanmean(r);

% figure panel parameters
lm = 0.005; xg = 0.005; w = 0.194;
bm = 0.01; yg = 0.025; hb = 0.34; ht = 0.62; bt = bm+yg+hb;

% raster plots
tkW = 1;
tkH = 2;
f = figure('Position', [10 100 1400 300])
subplot('Position', [lm 0.005 w 0.99])   % light on
RasterPlot(unit(u), 1, [-1 1], 'trials', {loTr, medTr, hiTr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors',...
    {[0.1 0.1 0.1], [0.4 0.4 0.4], [0.7 0.7 0.7]})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';

subplot('Position', [lm+w+xg 0.005 w 0.99]) % center in
RasterPlot(unit(u), 2, [-1 1], 'trials', {loTr, medTr, hiTr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors',...
    {[0.1 0.1 0.1], [0.4 0.4 0.4], [0.7 0.7 0.7]})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';

subplot('Position', [lm+2*(w+xg) 0.005 w 0.99]) % GO
RasterPlot(unit(u), 3, [-1 1], 'trials', {loTr, medTr, hiTr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors',...
    {[0.1 0.1 0.1], [0.4 0.4 0.4], [0.7 0.7 0.7]})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';

subplot('Position', [lm+3*(w+xg) 0.005 w 0.99]) % side in
cList = {[0.4 0 0], [1 0 0], [1 0.6 0.6], [0 0 0.4], [0 0 1], [0.6 0.6 1]};
trList = {intersect(loTr, rwd), intersect(medTr, rwd), intersect(hiTr, rwd), ...
    intersect(loTr, noRwd), intersect(medTr, noRwd), intersect(hiTr, noRwd)};
RasterPlot(unit(u), 5, [-1 1], 'trials', trList, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off'
ax.XTick = [];
ax.Visible = 'off';

subplot('Position', [lm+4*(w+xg) 0.005 w 0.99]) % food port
RasterPlot(unit(u), 7, [-1 1], 'trials', {rwd, noRwd}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', {'r', 'b'})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off'
ax.XTick = [];
ax.Visible = 'off';


% rate plots
nm = [unit(u).cellType ' (' num2str(u) ')'];
figure('Position', [10 100 1400 400], 'NumberTitle', 'off', 'name', nm)
maxRate = max([loL loM loH ciL ciM ciH goL goM goH siL siM siH]);
maxRate = max([maxRate siLR siMR siHR siLN siMN siHN fpLR fpMR fpHR fpLN fpMN fpHN]);
yR = [0 1.25*maxRate];
yT = [40 80];

tLR = -1:dtLR:1;
durCrit = 0.05;
tPre = -1:dtLR:0;
tPost = 0:dtLR:1;
sMin = min([sR{1}(u,:) sR{2}(u,:) sR{3}(u,:) sR{4}(u,:) sRr{1}(u,:) sRn{1}(u,:) sRr{2}(u,:) sRn{2}(u,:)]);
sMax = max([sR{1}(u,:) sR{2}(u,:) sR{3}(u,:) sR{4}(u,:) sRr{1}(u,:) sRn{1}(u,:) sRr{2}(u,:) sRn{2}(u,:)]);
ySR = [sMin sMax] *1.1;
ySR = [-0.22 0.24];
yST = [ -0.2 0.2];

ns = [1 1 1]*0.65;
nsR = [1 0.6 0.6];
nsN = [0.6 0.6 1];

smWd = 10;

% light on
subplot('Position', [lm bt w ht])
hold on
plot(timesRL, loH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, loM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, loL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
ylim(yR)
sigPts = AnnotateSig(gcf, tLR, pR{1}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
plot([0 0], yR, '--k', 'linewidth', 2);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{1}(u,:), 'gaussian', smWd);
subplot('Position', [lm bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tLR(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% center in
subplot('Position', [lm+w+xg bt w ht])
hold on
plot(timesRL, ciH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, ciM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, ciL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
sigPts = AnnotateSig(gcf, tLR, pR{2}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{2}(u,:), 'gaussian', smWd);
subplot('Position', [lm+w+xg bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tLR(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% GO
subplot('Position', [lm+2*(w+xg) bt w ht])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
sigPts = AnnotateSig(gcf, tLR, pR{3}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{3}(u,:), 'gaussian', smWd);
subplot('Position', [lm+2*(w+xg) bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tLR(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% side in
subplot('Position', [lm+3*(w+xg) bt w ht])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
sigPts = AnnotateSig(gcf, tPre, pR{5}(u,:), pCrit, durCrit, 'k', 'returnPts', true);
sigPtsR = AnnotateSig(gcf, tPost, pRr{1}(u,:), pCrit, durCrit, 'r', 'bardrop', 0.03, 'returnPts', true);
sigPtsN = AnnotateSig(gcf, tPost, pRn{1}(u,:), pCrit, durCrit, 'b', 'bardrop', 0.08, 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sR{5}(u,:), 'gaussian', smWd);
subplot('Position', [lm+3*(w+xg) bm w hb])
hold on
plot(tPre, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(tPre(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
slp = smoothdata(sRn{1}(u,:), 'gaussian', smWd);
plot(tPost, slp, 'linewidth', 3, 'color', nsN)
for i = 1:length(sigPtsN)
    plot(tPost(sigPtsN{i}), slp(sigPtsN{i}), 'linewidth', 3, 'color', [0 0 0.75])
end
slp = smoothdata(sRr{1}(u,:), 'gaussian', smWd);
plot(tPost, slp, 'linewidth', 3, 'color', nsR)
for i = 1:length(sigPtsR)
    plot(tPost(sigPtsR{i}), slp(sigPtsR{i}), 'linewidth', 3, 'color', [0.75 0 0])
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

% food port
subplot('Position', [lm+4*(w+xg) bt w ht])
hold on
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL, fpLN, 'color', cList{6}, 'linewidth', 3)
plot(timesRL, fpMN, 'color', cList{5}, 'linewidth', 3)
plot(timesRL, fpHN, 'color', cList{4}, 'linewidth', 3)
plot(timesRL, fpLR, 'color', cList{3}, 'linewidth', 3)
plot(timesRL, fpMR, 'color', cList{2}, 'linewidth', 3)
plot(timesRL, fpHR, 'color', cList{1}, 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR);
sigPtsR = AnnotateSig(gcf, tLR, pRr{2}(u,:), pCrit, durCrit, 'r', 'bardrop', 0.03, 'returnPts', true);
sigPtsN = AnnotateSig(gcf, tLR, pRn{2}(u,:), pCrit, durCrit, 'b', 'bardrop', 0.08, 'returnPts', true);
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')

slp = smoothdata(sRn{2}(u,:), 'gaussian', smWd);
subplot('Position', [lm+4*(w+xg) bm w hb])
hold on
plot(tLR, slp, 'linewidth', 3, 'color', nsN)
for i = 1:length(sigPtsN)
    plot(tLR(sigPtsN{i}), slp(sigPtsN{i}), 'linewidth', 3, 'color', [0 0 0.75])
end
slp = smoothdata(sRr{2}(u,:), 'gaussian', smWd);
plot(tLR, slp, 'linewidth', 3, 'color', nsR)
for i = 1:length(sigPtsR)
    plot(tLR(sigPtsR{i}), slp(sigPtsR{i}), 'linewidth', 3, 'color', [0.75 0 0])
end
plot([0 0], ySR, '--k', 'linewidth', 2);
plot([tLR(1) tLR(end)], [0,0], '--k', 'linewidth', 2);
ylim(ySR)
set(gca, 'YTick', yST)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')



%% Figure 5a: Example Cell (Pav panel)

winPav = [-0.5 4.5];
cListPav = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

% ak examples: 220(RPE) 520 (alt)
% ak examples (suppl): 186 809 525 644 196
% sp examples: 1278 
% sp examples (suppl): 207 229 363 1003 1279
% fp example: 404
% fp examples (suppl): 393 537 1263 325 380 [alt: 716]

[~, uP] = ismember(u, uPav2)

uTrajPav = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
dt = uTrajPav(1).times(2) - uTrajPav(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
pavIdx = find(strcmp(lower(unit(u).taskList), 'pav'));
lg = unit(u).behav_log{pavIdx};
ts = unit(u).behav_ts{pavIdx};

cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

rwdTime = nanmean(ts.rwdTime - ts.csTime);
traj = TrajSplit(uTrajPav, ts, winPav);

% average rate: prob 25 cue
tr25 = find(lg.toneFreq == cue25);
tr25r = intersect(tr25, find(lg.outcome));
r = zeros(length(tr25r), nPtsPav);
for k = 1:length(tr25r)
    r(k,:) = traj(tr25r(k)).rate;
end
p25r = mean(r);
tr25nr = intersect(tr25, find(~lg.outcome));
r = zeros(length(tr25nr), nPtsPav);
for k = 1:length(tr25nr)
    r(k,:) = traj(tr25nr(k)).rate;
end
p25nr = mean(r);
r = zeros(length(tr25), nPtsPav);
for k = 1:length(tr25)
    r(k,:) = traj(tr25(k)).rate;
end
p25 = mean(r);

% average rate: prob 75 cue
tr75 = find(lg.toneFreq == cue75);
tr75r = intersect(tr75, find(lg.outcome));
r = zeros(length(tr75r), nPtsPav);
for k = 1:length(tr75r)
    r(k,:) = traj(tr75r(k)).rate;
end
p75r = mean(r);
tr75nr = intersect(tr75, find(~lg.outcome));
r = zeros(length(tr75nr), nPtsPav);
for k = 1:length(tr75nr)
    r(k,:) = traj(tr75nr(k)).rate;
end
p75nr = mean(r);
r = zeros(length(tr75), nPtsPav);
for k = 1:length(tr75)
    r(k,:) = traj(tr75(k)).rate;
end
p75 = mean(r);

% raster plots
tkW = 1;
tkH = 2;
f = figure('Position', [10 100 930 300])
subplot('Position', [lm 0.005 0.99 0.99])
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};
RasterPlot(unit(u), 1, winPav, 'trials', {tr75r, tr25r, tr75nr, tr25nr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH,...
    'colors', cList, 'task', 'Pav')
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
plot([rwdTime rwdTime], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';



%maxRate = max([p25 p75 p25r p25nr p75r p75nr]);
%maxRate = 5*ceil(maxRate/5);
% yR = [0 maxRate];     Use limits from RL panels
% yticks = [25 50 75];  Use ticks from RL panels

maxSlope = max([sRR(uP,:) sRRr(uP,:) sRRn(uP,:)])
minSlope = min([sRR(uP,:) sRRr(uP,:) sRRn(uP,:)])
yS = [-0.032 0.028];
ySt = [-0.02 0.02];

% Pav example, 25% and 75% pRwd rate plot
fig = figure('Position', [10 100 930 400])
subplot('Position', [lm bt 0.99 ht])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cListPav{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cListPav{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cListPav{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cListPav{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', [0.3 0.3 0.3], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'YTick', yT)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;
sigPts = AnnotateSig(gcf, t1, pRR(uP,:), pCrit, durCrit, 'k', 'returnPts', true);
sigPtsR = AnnotateSig(gcf, t2, pRRr(uP,:), pCrit, durCrit, 'r', 'bardrop', 0.03, 'returnPts', true);
sigPtsN = AnnotateSig(gcf, t2, pRRn(uP,:), pCrit, durCrit, 'b', 'bardrop', 0.08, 'returnPts', true);

slp = smoothdata(sRR(uP,:), 'gaussian', smWd);
subplot('Position', [lm bm 0.99 hb])
hold on
plot(t1, slp, 'linewidth', 3, 'color', ns)
for i = 1:length(sigPts)
    plot(t1(sigPts{i}), slp(sigPts{i}), 'linewidth', 3, 'color', 'k')
end
slp = smoothdata(sRRn(uP,:), 'gaussian', smWd);
plot(t2, slp, 'linewidth', 3, 'color', nsN)
for i = 1:length(sigPtsN)
    plot(t2(sigPtsN{i}), slp(sigPtsN{i}), 'linewidth', 3, 'color', [0 0 0.75])
end
slp = smoothdata(sRRr(uP,:), 'gaussian', smWd);
plot(t2, slp, 'linewidth', 3, 'color', nsR)
for i = 1:length(sigPtsR)
    plot(t2(sigPtsR{i}), slp(sigPtsR{i}), 'linewidth', 3, 'color', [0.75 0 0])
end
plot([0 0], yS, '--k', 'linewidth', 2);
plot([rwdTime rwdTime], yS, '--k', 'linewidth', 2);
plot([t1(1) t2(end)], [0,0], '--k', 'linewidth', 2);
ylim(yS)
set(gca, 'YTick', ySt)
set(gca, 'XTick', [-0.5:0.5:4]);
set(gca, 'YTickLabels', [])
set(gca, 'XTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;



