%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)

fpColor = [1 0.5 0];
rpColor = [0.7 0 0];
chColor = [0.3 0.3 0.3];


%% Load Full ISI Stats and Identify Candidate Cholinergic Cells

ratList = unique(uRat);

% loop through rats
swsRate = nan(size(unit));
swsMean = nan(size(unit));
swsSd = nan(size(unit));
swsSkew = nan(size(unit));
swsKurt = nan(size(unit));
swsNumIsi = zeros(size(unit));
swsDur = zeros(size(unit));
wakeMean = nan(size(unit));
wakeSd = nan(size(unit));
wakeSkew = nan(size(unit));
wakeKurt = nan(size(unit));
swsCv = nan(size(unit));
swsCv2 = nan(size(unit));
wakeRate = nan(size(unit));
wakeCv = nan(size(unit));
wakeCv2 = nan(size(unit));
wakeNumIsi = zeros(size(unit));
wakeDur = zeros(size(unit));
rat = cellfun(@(r) str2num(r(3:end)), uRat);
for r = 1:length(ratList)
    
    disp(['rat ' ratList{r}])
    
    uIdx = find(strcmp(ratList{r}, uRat));
    sesList = unique(uSes(uIdx));
    
    % loop through recording sessions
    for iSes = 1:length(sesList)
        
        disp(['   session ' num2str(iSes)])
    
        % load sleep log data
        clear sleepLog
        datDir = [datRoot ratList{r} filesep sesList{iSes} filesep];
        load([datDir 'sleepLog.mat']);
        
        % identify GPe cells recorded in this session, get behavior data
        uIdx = find(strcmp(sesList{iSes}, uSes));
            
        % identify periods of disengaged wakefulness, log SWS times across tasks
        [wake, sws] = WakeTimes(sleepLog, unit(uIdx(1)));
        wakeDur(uIdx) = sum(arrayfun(@(i) diff(wake(i,:)), 1:size(wake,1)));
        swsDur(uIdx) = sum(arrayfun(@(i) diff(sws(i,:)), 1:size(sws,1)));
          
        % extract rate-regularity parameters
        for u = uIdx
            wakeIsi = [];
            for k = 1:size(wake, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > wake(k,1) & unit(u).spkTimes <= wake(k,2));
                wakeIsi = [wakeIsi diff(spk)];
            end
            swsIsi = [];
            for k = 1:size(sws, 1)
                spk = unit(u).spkTimes(unit(u).spkTimes > sws(k,1) & unit(u).spkTimes <= sws(k,2));
                swsIsi = [swsIsi diff(spk)];
            end
            wakeNumIsi(u) = length(wakeIsi);
            wakeMean(u) = mean(wakeIsi);
            wakeRate(u) = 1 / wakeMean(u);
            wakeSd(u) = std(wakeIsi);
            wakeCv(u) = wakeSd(u) / wakeMean(u);
            wakeCv2(u) = sqrt(2) * mean(abs(wakeIsi(2:end) - wakeIsi(1:end-1)) ./ (wakeIsi(2:end) + wakeIsi(1:end-1)));
            wakeSkew(u) = skewness(wakeIsi);
            wakeKurt(u) = kurtosis(wakeIsi);
            swsNumIsi(u) = length(swsIsi);
            swsMean(u) = mean(swsIsi);
            swsRate(u) = 1 / swsMean(u);
            swsSd(u) = std(swsIsi);
            swsCv(u) = swsSd(u) / swsMean(u);
            swsCv2(u) = sqrt(2) * mean(abs(swsIsi(2:end) - swsIsi(1:end-1)) ./ (swsIsi(2:end) + swsIsi(1:end-1)));
            swsSkew(u) = skewness(swsIsi);
            swsKurt(u) = kurtosis(swsIsi);
        end
    end
end

% log transform
w1 = log10(wakeMean);
w2 = log10(wakeSd);
w3 = log10(wakeSkew);

s1 = log10(swsMean);
s2 = log10(swsSd);
s3 = log10(swsSkew);

figure('Position', [440 378 720 620])
subplot('Position', [0.01 0.01 0.98 0.98])
hold on
scatter(w1, s1, 60,'k')
xlim([-2.1 1.6])
ylim([-2.1 1.9])
ax = gca;
ax.YTick = -2:2;
ax.XTick = -2:2;
ax.XMinorTick = 'on';
xm = [0.02 0.04 0.06 0.08 0.2 0.4 0.6 0.8 2 4 6 8 20 40 60 80];
ax.XAxis.MinorTickValues = log10(xm);
ax.YMinorTick = 'on';
ax.YAxis.MinorTickValues = log10(xm);
ax.XTickLabels = [];
ax.YTickLabels = [];
%ax.XTickLabels = {'0.01', '0.1', '1', '10', '100'};
%ax.YTickLabels = {'0.01', '0.1', '1', '10', '100'};
scatter(w1(rp), s1(rp), 60, rpColor, 'filled')

minY = 0.5;
maxX = -0.35;
ch = find(w1 < maxX & s1 > minY);
hold on
scatter(w1(ch), s1(ch), 80, chColor, 'filled')
xlabel('log(mean ISI), wake')
ylabel('log(mean ISI), SWS')
title('cholinergic candiate 1')

figure('Position', [440 378 300 620])
subplot('Position', [0.01 0.51 0.48 0.48])
hold on
avg = [mean(wakeRate(ch)) mean(swsRate(ch))];
err = [std(wakeRate(ch)) std(swsRate(ch))];
b = bar(avg); 
b.FaceColor = chColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = chColor; e.LineStyle = 'none'; e.LineWidth = 2;
ylim([0 8])
ax = gca; ax.YTick = [2 4 6 8]; ax.XTick = []; ax.YTickLabels = [];

subplot('Position', [0.51 0.51 0.48 0.48])
hold on
avg = [mean(wakeRate(rp)) mean(swsRate(rp))];
err = [std(wakeRate(rp)) std(swsRate(rp))];
b = bar(avg); 
b.FaceColor = rpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = rpColor; e.LineStyle = 'none'; e.LineWidth = 2;
ylim([0 8])
ax = gca; ax.YTick = []; ax.XTick = []; ax.YTickLabels = [];

subplot('Position', [0.01 0.01 0.48 0.48])
hold on
avg = [mean(wakeCv(ch)) mean(swsCv(ch))];
err = [std(wakeCv(ch)) std(swsCv(ch))];
b = bar(avg); 
b.FaceColor = chColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = chColor; e.LineStyle = 'none'; e.LineWidth = 2;
ylim([0 2])
ax = gca; ax.YTick = [1 2]; ax.XTick = []; ax.YTickLabels = [];

subplot('Position', [0.51 0.01 0.48 0.48])
hold on
avg = [mean(wakeCv(rp)) mean(swsCv(rp))];
err = [std(wakeCv(rp)) std(swsCv(rp))];
b = bar(avg); 
b.FaceColor = rpColor; b.EdgeColor = 'none'; xlim([0.4 2.6]); b.BarWidth = 0.9;
e = errorbar([1 2], avg, [0 0], err);
e.Color = rpColor; e.LineStyle = 'none'; e.LineWidth = 2;
ylim([0 2])
ax = gca; ax.YTick = []; ax.XTick = []; ax.YTickLabels = [];



%% Calculate Reward Rate Using Median Time Constant for All Sessions

sesList = unique(uSes);
% tau = median(rwdTau);
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end      
end 

 


%% Example Cholinergic Candidates (RL)

i=i-1
u = ch(i); % choice

winRL = [-1 1];
lo = [0 0.33]; med = [0.33 0.66]; hi = [0.66 1];
latCrit = 1;
sesList = unique(uSes);
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

uTrajRL = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
dt = uTrajRL(1).times(2) - uTrajRL(1).times(1);
timesRL = winRL(1):dt:winRL(2);
nPtsRL = round(diff(winRL)/dt) + 1;
rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
ts = unit(u).behav_ts{rlIdx};

% average rate: light on
lat = BehaviorTimes(ts);
sL = find(lat < latCrit);
lL = find(lat >= latCrit);
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 1);
r = zeros(length(sL), nPtsRL);
for k = 1:length(sL)
    r(k,:) = traj(sL(k)).rate;
end
ltShortLat = mean(r); 
r = zeros(length(lL), nPtsRL);
for k = 1:length(lL)
    r(k,:) = traj(lL(k)).rate;
end
ltLongLat = mean(r);

% average rate: center in
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 2);
r = zeros(length(sL), nPtsRL);
for k = 1:length(sL)
    r(k,:) = traj(sL(k)).rate;
end
ciShortLat = mean(r); 
r = zeros(length(lL), nPtsRL);
for k = 1:length(lL)
    r(k,:) = traj(lL(k)).rate;
end
ciLongLat = mean(r);

% average rate: go
traj = TrajSplit(uTrajRL,  ts, winRL, 'event', 3);
s = find(strcmp(uSes{u}, sesList));
rr = rwdRate{s}(11:end);
loTr = find(rr <= quantile(rr, lo(2))) + 10;
medTr = find(rr >= quantile(rr,med(1)) & rr <= quantile(rr, med(2))) + 10;
hiTr = find(rr >= quantile(rr, hi(1))) + 10;
r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
goL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
goM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
goH = mean(r);

% average rate: side in
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 5);
rwd = TrialFilter(ts, 'x1', unit(u).side);
noRwd = TrialFilter(ts, 'x0', unit(u).side);

r = zeros(length(loTr), nPtsRL);
for k = 1:length(loTr)
    r(k,:) = traj(loTr(k)).rate;
end
siL = mean(r);
r = zeros(length(medTr), nPtsRL);
for k = 1:length(medTr)
    r(k,:) = traj(medTr(k)).rate;
end
siM = mean(r);
r = zeros(length(hiTr), nPtsRL);
for k = 1:length(hiTr)
    r(k,:) = traj(hiTr(k)).rate;
end
siH = mean(r);

sel = intersect(loTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLR = mean(r);
sel = intersect(medTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMR = mean(r);
sel = intersect(hiTr, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHR = mean(r);
sel = intersect(loTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siLN = mean(r);
sel = intersect(medTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siMN = mean(r);
sel = intersect(hiTr, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
siHN = mean(r);

% average rate: food port
traj = TrajSplit(uTrajRL, ts, winRL, 'event', 6);
s = find(strcmp(uSes{u}, sesList));
valid = find(~isnan(ts.firstFoodPoke));
sel = intersect(valid, rwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpR = mean(r);
sel = intersect(valid, noRwd);
r = zeros(length(sel), nPtsRL);
for k = 1:length(sel)
    r(k,:) = traj(sel(k)).rate;
end
fpN = mean(r);

maxRate = max([ltLongLat ltShortLat ciLongLat ciShortLat goL goM goH siLR siMR siHR siLN siMN siHN]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate]
yT = [25 50 75];

tkW = 2;
tkH = 4;

lm = 0.02; bm = 0.05; xg = 0.005; yg = 0.01; 
w = (0.99-lm-4*xg)/5; h = (0.995-bm-yg)/2;
l = lm+(0:4)*(w+xg); b = bm + (0:1)*(h+yg);

f = figure('Position', [1 100 1440 600])
subplot('Position', [l(1) b(2) w h])
cList = {[0.1 1 0.1], [0 0.4 0]};
[~, oS] = sort(lat(sL));
[~, oL] = sort(lat(lL));
odr = {oS, oL};
RasterPlot(unit(u), 1, [-1 1], 'trials', {sL, lL}, 'order', odr, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [l(2) b(2) w h])
RasterPlot(unit(u), 2, [-1 1], 'trials', {sL, lL}, 'order', odr, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [l(3) b(2) w h])
RasterPlot(unit(u), 3, [-1 1], 'trials', {loTr, medTr, hiTr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors',...
    {[0.1 0.1 0.1], [0.4 0.4 0.4], [0.7 0.7 0.7]})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [l(4) b(2) w h])
cList = {[0.4 0 0], [1 0 0], [1 0.6 0.6], [0 0 0.4], [0 0 1], [0.6 0.6 1]};
trList = {intersect(loTr, rwd), intersect(medTr, rwd), intersect(hiTr, rwd), ...
    intersect(loTr, noRwd), intersect(medTr, noRwd), intersect(hiTr, noRwd)};
RasterPlot(unit(u), 5, [-1 1], 'trials', trList, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', cList)
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off'
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [l(5) b(2) w h])
RasterPlot(unit(u), 7, [-1 1], 'trials', {rwd, noRwd}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH, 'colors', {'r', 'b'})
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off'
ax.XTick = [];
ax.YAxis.Visible = 'off';

subplot('Position', [l(1) b(1) w h])
hold on
cList = {[0.1 1 0.1], [0 0.4 0]};
plot(timesRL, ltShortLat, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ltLongLat, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTick', yT)
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [l(2) b(1) w h])
hold on
plot(timesRL, ciShortLat, 'color', cList{1}, 'linewidth', 3)
plot(timesRL, ciLongLat, 'color', cList{2}, 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTick', yT)
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [l(3) b(1) w h])
hold on
plot(timesRL, goH, 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL, goM, 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL, goL, 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTick', yT)
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [l(4) b(1) w h])
hold on
pt = find(timesRL == 0) + 1;
cList = {[1 0.6 0.6], [1 0 0], [0.4 0 0], [0.6 0.6 1], [0 0 1], [0 0 0.4]};
plot(timesRL(pt+1:end), siLR(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMR(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHR(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesRL(pt+1:end), siLN(pt+1:end), 'color', cList{6}, 'linewidth', 3)
plot(timesRL(pt+1:end), siMN(pt+1:end), 'color', cList{5}, 'linewidth', 3)
plot(timesRL(pt+1:end), siHN(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesRL(1:pt), siH(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesRL(1:pt), siM(1:pt), 'color', [0.4 0.4 0.4], 'linewidth', 3)
plot(timesRL(1:pt), siL(1:pt), 'color', [0.1 0.1 0.1], 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTick', yT)
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')

subplot('Position', [l(5) b(1) w h])
hold on
plot(timesRL, fpN, 'color', 'b', 'linewidth', 3)
plot(timesRL, fpR, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5 0 0.5])
set(gca, 'YTick', yT)
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')



%% Pavlovian Behavior

% identfiy sessions with Pavlovian behavior
uPav = find(arrayfun(@(u) any(strcmp('pav', lower(u.taskList))), unit));

chPav = intersect(uPav,ch)
u = ch(i); [lia locB] = ismember(u, chPav)

winPav = [-0.5 4.5];
sesList = unique(uSes);
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};

uTrajPav = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
dt = uTrajPav(1).times(2) - uTrajPav(1).times(1);
timesPav = winPav(1):dt:winPav(2);
nPtsPav = round(diff(winPav)/dt) + 1;
pavIdx = find(strcmp(lower(unit(u).taskList), 'pav'));
lg = unit(u).behav_log{pavIdx};
ts = unit(u).behav_ts{pavIdx};

cue0 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 0, 1);
cue25 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 25, 1);
cue75 = lg.cueRwdTable(lg.cueRwdTable(:,2) == 75, 1);

rwdTime = nanmean(ts.rwdTime - ts.csTime);
traj = TrajSplit(uTrajPav, ts, winPav);

% average rate: prob 0 cue
tr0 = find(lg.toneFreq == cue0);
r = zeros(length(tr0), nPtsPav);
for k = 1:length(tr0)
    r(k,:) = traj(tr0(k)).rate;
end
p0 = mean(r); 

% average rate: unpredicted reward
tr100 = find(lg.toneFreq == 0);
r = zeros(length(tr100), nPtsPav);
for k = 1:length(tr100)
    r(k,:) = traj(tr100(k)).rate;
end
p100 = mean(r);

% average rate: prob 25 cue
tr25 = find(lg.toneFreq == cue25);
tr25r = intersect(tr25, find(lg.outcome));
r = zeros(length(tr25r), nPtsPav);
for k = 1:length(tr25r)
    r(k,:) = traj(tr25r(k)).rate;
end
p25r = mean(r);
tr25nr = intersect(tr25, find(~lg.outcome));
r = zeros(length(tr25nr), nPtsPav);
for k = 1:length(tr25nr)
    r(k,:) = traj(tr25nr(k)).rate;
end
p25nr = mean(r);
r = zeros(length(tr25), nPtsPav);
for k = 1:length(tr25)
    r(k,:) = traj(tr25(k)).rate;
end
p25 = mean(r);

% average rate: prob 75 cue
tr75 = find(lg.toneFreq == cue75);
tr75r = intersect(tr75, find(lg.outcome));
r = zeros(length(tr75r), nPtsPav);
for k = 1:length(tr75r)
    r(k,:) = traj(tr75r(k)).rate;
end
p75r = mean(r);
tr75nr = intersect(tr75, find(~lg.outcome));
r = zeros(length(tr75nr), nPtsPav);
for k = 1:length(tr75nr)
    r(k,:) = traj(tr75nr(k)).rate;
end
p75nr = mean(r);
r = zeros(length(tr75), nPtsPav);
for k = 1:length(tr75)
    r(k,:) = traj(tr75(k)).rate;
end
p75 = mean(r);

maxRate = max([p0 p100 p25r p25nr p75r p75nr]);
maxRate = 5*ceil(maxRate/5);
yR = [0 maxRate];
yT = [40 80 120];

% Pav example, 25% and 75% pRwd raster
lm = 0.02; bm = 0.05; xg = 0.005; yg = 0.01; 
w = (0.99-lm-xg)/2; h = (0.995-bm-yg)/2;
l = lm+(0:1)*(w+xg); b = bm + (0:1)*(h+yg);

tkH = 2;

f = figure('Position', [1 100 1400 600])
subplot('Position', [l(1) b(2) w h])
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};
RasterPlot(unit(u), 1, winPav, 'trials', {tr75r, tr25r, tr75nr, tr25nr}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH,...
    'colors', cList, 'task', 'Pav')
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
plot([rwdTime rwdTime], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';

% Pav example, 0% and 100% raster
subplot('Position', [l(2) b(2) w h])       
cList = {[1 0.4 0.4], [0.6 0 0], [0.4 0.4 1], [0 0 0.6]};
RasterPlot(unit(u), 1, winPav, 'trials', {tr100, tr0}, 'fig', f, 'tickWidth', tkW, 'tickSpread', tkH,...
    'colors', {'r', 'b'}, 'task', 'Pav')
yRas = ylim;
plot([0 0], yRas, 'k', 'linewidth', 1)
plot([rwdTime rwdTime], yRas, 'k', 'linewidth', 1)
ax = gca;
ax.Box = 'off';
ax.XTick = [];
ax.Visible = 'off';

% Pav example, 25% and 75% pRwd rate plot
subplot('Position', [l(1) b(1) w h])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav(pt+1:end), p25nr(pt+1:end), 'color', cList{4}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75nr(pt+1:end), 'color', cList{3}, 'linewidth', 3)
plot(timesPav(pt+1:end), p75r(pt+1:end), 'color', cList{1}, 'linewidth', 3)
plot(timesPav(pt+1:end), p25r(pt+1:end), 'color', cList{2}, 'linewidth', 3)
plot(timesPav(1:pt), p75(1:pt), 'color', [0.7 0.7 0.7], 'linewidth', 3)
plot(timesPav(1:pt), p25(1:pt), 'color', chColor, 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTick', yT)
set(gca, 'XTickLabels', [])
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;

% Pav example, 0% and 100% rate plot
subplot('Position', [l(2) b(1) w h])
pt = find(abs(timesPav-rwdTime) == min(abs(timesPav-rwdTime))) + 1;
hold on
plot(timesPav, p0, 'color', 'b', 'linewidth', 3)
plot(timesPav, p100, 'color', 'r', 'linewidth', 3)
plot([0 0], yR, '--k', 'linewidth', 2);
plot([rwdTime rwdTime], yR, '--k', 'linewidth', 2);
ylim(yR)
set(gca, 'XTick', [-0.5:0.5:4])
set(gca, 'YTick', yT)
set(gca, 'XTickLabels', [])
set(gca, 'YTickLabels', [])
set(gca, 'Box', 'on')
ax = gca;
ax.TickLength = ax.TickLength / 2;



%% Location of Cholinergic Candidates

% load cell location data
load('/Users/michaelfarries/Documents/GPe-RPE paper/Fig 7/manuscript cell loc 3-27.mat')
% contains 'ml', 'dv', 'ap', 'apRel', 'keepCells'

[lia locB] = ismember(ch, keepCells);
chLoc = locB(lia);

[lia locB] = ismember(rp, keepCells);
rpLoc = locB(lia);

% location plot, horizontal projection
figure('Position', [10 110 500 500])
subplot('Position', [0.01 0.01 0.98 0.98])
scatter(ml, ap, 100, 'k')
hold on
scatter(ml(rpLoc), ap(rpLoc), 100, rpColor, 'filled')
scatter(ml(chLoc), ap(chLoc), 100, chColor, 'filled')
xlim([1.75 4.75])

% make sagittal sections for location plots
secThick = 0.4;
secCenters = 2.4:secThick:4.0;
secEdges = secCenters(1:end-1) + secThick/2;

lm = 0.001; bm = 0.001; xg = 0.001; 
w = (0.998-lm-4*xg)/5; h = 0.998;
l = lm+(0:4)*(w+xg);
figure('Position', [10 110 1400 500])

% medialmost section
sel = find(ml < secEdges(1) & ~ismember(1:length(keepCells), chLoc));
subplot('Position', [l(1) bm w h])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml < secEdges(1) & ismember(1:length(keepCells), chLoc));
scatter(ap(sel2), dv(sel2), 160, 'k', 'filled')
xlim([-2.5 -0.9])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';
plot([-2.45 -2.45], [-7.9 -4.8], 'k', 'linewidth', 2)


% section 2
i=1;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(keepCells), chLoc));
subplot('Position', [l(2) bm w h])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(keepCells), chLoc));
scatter(ap(sel2), dv(sel2), 160, 'k', 'filled')
xlim([-2.3 -0.7])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';
plot([-2.25 -2.25], [-7.9 -4.8], 'k', 'linewidth', 2)

% section 3
i=2;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(keepCells), chLoc));
subplot('Position', [l(3) bm w h])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(keepCells), chLoc));
scatter(ap(sel2), dv(sel2), 160, 'k', 'filled')
xlim([-2.4 -0.8])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';
plot([-2.35 -2.35], [-7.9 -4.8], 'k', 'linewidth', 2)

% section 4
i=3;
sel = find(ml>=secEdges(i) & ml<secEdges(i+1) & ~ismember(1:length(keepCells), chLoc));
subplot('Position', [l(4) bm w h])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml>=secEdges(i) & ml<secEdges(i+1) & ismember(1:length(keepCells), chLoc));
scatter(ap(sel2), dv(sel2), 160, 'k', 'filled')
xlim([-2.65 -1.05])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';
plot([-2.6 -2.6], [-7.9 -4.8], 'k', 'linewidth', 2)

% lateralmost section
sel = find(ml >= secEdges(end) & ~ismember(1:length(keepCells), chLoc));
subplot('Position', [l(5) bm w h])
hold on
scatter(ap(sel), dv(sel), 120, 'k')
sel2 = find(ml >= secEdges(end) & ismember(1:length(keepCells), chLoc));
scatter(ap(sel2), dv(sel2), 160, 'k', 'filled')
xlim([-3.4 -1.8])
ylim([-8 -4.5])
ax = gca;
ax.XDir = 'reverse';
ax.Visible = 'off';



%% Extras

fracLOch = smoothdata(FracSignificant2(pR{1}(ch,:), 0.05), 'gaussian', 10);
fracCIch = smoothdata(FracSignificant2(pR{2}(ch,:), 0.05), 'gaussian', 10);
fracGOch = smoothdata(FracSignificant2(pR{3}(ch,:), 0.05), 'gaussian', 10);
fracSIpch = smoothdata(FracSignificant2(pR{4}(ch,:), 0.05), 'gaussian', 10);
fracSIrch = smoothdata(FracSignificant2(pRr{1}(ch,:), 0.05), 'gaussian', 10);
fracSInch = smoothdata(FracSignificant2(pRn{1}(ch,:), 0.05), 'gaussian', 10);
fracFPrch = smoothdata(FracSignificant2(pRr{2}(ch,:), 0.05), 'gaussian', 10);

sLO_Mch = smoothdata(mean(sR{1}(ch,:)), 'gaussian', 10);
sCI_Mch = smoothdata(mean(sR{2}(ch,:)), 'gaussian', 10);
sGO_Mch = smoothdata(mean(sR{3}(ch,:)), 'gaussian', 10);
sSIp_Mch = smoothdata(mean(sR{4}(ch,:)), 'gaussian', 10);
sSIr_Mch = smoothdata(mean(sRr{1}(ch,:)), 'gaussian', 10);
sSIn_Mch = smoothdata(mean(sRn{1}(ch,:)), 'gaussian', 10);
sFPr_Mch = smoothdata(nanmean(sRr{2}(ch,:)), 'gaussian', 10);

m = 0.0025; g = 0.005; w = (1-3*m-4*g)/5.5;
b = 0.005; h = 0.99
f = figure('Position', [1 100 1440 400])
subplot('Position', [m b w h])
hold on
plot(t, fracLOch, 'color', 'k', 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
plot([0 0], [0 0.7], 'k', 'linewidth', 1)
ylim([0 0.7])
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [m+g+w b w h])
hold on
plot(t, fracCIch, 'color', 'k', 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
plot([0 0], [0 0.7], 'k', 'linewidth', 1)
ylim([0 0.7])
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [m+2*(g+w) b w h])
hold on
plot(t, fracGOch, 'color', 'k', 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
plot([0 0], [0 0.7], 'k', 'linewidth', 1)
ylim([0 0.7])
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [m+3*(w+g) b w h])
hold on
plot(tPre, fracSIpch, 'color', 'k', 'linewidth', 3)
plot(tPost, fracSIrch, 'color', 'k', 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
plot([0 0], [0 0.7], 'k', 'linewidth', 1)
ylim([0 0.7])
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [2*m+3*(w+g)+w b w/2 h])
hold on
plot(tPost, fracSInch, 'color', 'k', 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
ylim([0 0.7])
xlim([0 1])
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';

subplot('Position', [2*m+4*(w+g)+w/2 b w h])
hold on
plot(t, fracFPrch, 'color', 'k', 'linewidth', 3)
plot([-1 1], [0.1 0.1], '--k', 'linewidth', 1)
plot([0 0], [0 0.7], 'k', 'linewidth', 1)
ylim([0 0.7])
ax = gca;
ax.YTick = [0.2 0.4 0.6];
ax.XTick = [-0.5 0 0.5];
ax.YTickLabels = [];
ax.XTickLabels = [];
ax.Box = 'on';


