%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];



%% Pavlovian Behavior

% identfiy sessions with Pavlovian behavior
uPav = find(arrayfun(@(u) any(strcmp('pav', lower(u.taskList))), unit));
pavSes = unique(uSes(uPav));

% remove sessions in which the reward port was non-functional
rwdPort = true(1, length(pavSes));
for s = 1:length(pavSes)
    uIdx= find(strcmp(pavSes{s}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    rwdPort(s) = ~all(cellfun(@(r) isempty(r), ts.rwdPokeIn));
end
pavSes = pavSes(rwdPort);

% collect Pavlovian behavioral data
pavDat = [];
rwdTime = [];
dt = 0.005;
win = [-0.5 4.5];
times = win(1):dt:win(2);
nSamp = length(times);
for s = 1:length(pavSes)
    clear x
    uIdx = find(strcmp(pavSes{s}, uSes));
    u = uIdx(1);
    x.rat = uRat{u};
    x.date = uSes{u};
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    logPav = unit(u).behav_log{pavIdx};
    
    % collect trial rwd port pokes together into 1 list for whole session
    nTr = length(ts.csTime);
    pokeIn = [];
    pokeOut = [];
    for k = 1:nTr
        pokeIn = [pokeIn ts.rwdPokeIn{k}'];
        pokeOut = [pokeOut ts.rwdPokeOut{k}'];
    end
    
    % create rwd port occupancy trajectory for entire session
    clear ocpTraj
    ocpTraj.times = 0:dt:ceil(ts.csTime(end) + 16);
    ocpTraj.rate = zeros(size(ocpTraj.times));
    for i = 1:length(pokeIn)
        [~,~,bin1] = histcounts(pokeIn(i), ocpTraj.times);
        [~,~,bin2] = histcounts(pokeOut(i), ocpTraj.times);
        ocpTraj.rate(bin1:bin2) = 1;
    end
    ocpTraj = TrajSplit(ocpTraj, ts, win);
    x.csTime = ts.csTime;
    x.outcome = logPav.outcome;
    x.probRwd = logPav.toneFreq;
    x.probRwd(x.probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for i = 1:size(logPav.cueRwdTable, 1)
        x.probRwd(x.probRwd == logPav.cueRwdTable(i,1)) = logPav.cueRwdTable(i,2);
    end
    x.firstRwdPoke = nan(1,nTr);
    x.rwdPokeIn = cell(1,nTr);
    x.rwdPokeOut = cell(1,nTr);
    x.portOcp = zeros(nTr, nSamp);
    for k = 1:nTr
        if k > 1
            x.rwdPokeIn{k} = [ts.rwdPokeIn{k-1}; ts.rwdPokeIn{k}] - ts.csTime(k);
            x.rwdPokeOut{k} = [ts.rwdPokeOut{k-1}; ts.rwdPokeOut{k}] - ts.csTime(k);
        else
            x.rwdPokeIn{k} = ts.rwdPokeIn{k} - ts.csTime(k);
            x.rwdPokeOut{k} = ts.rwdPokeOut{k} - ts.csTime(k);
        end
        if ~isempty(ts.rwdPokeIn{k}) 
            x.firstRwdPoke(k) = x.rwdPokeIn{k}(1);
        end
        
        % reward port occupancy
        x.portOcp(k,:) = ocpTraj(k).rate;
        
    end
    x.t = times;
    pavDat = [pavDat x];
    rT = ts.rwdTime' - ts.csTime';
    rwdTime = [rwdTime rT(~isnan(rT))];
end
rwdTime = mean(rwdTime);



%% Linear Regression on Prob[rwd], Port Occupancy, and Movement (accelerometer)

load([datRoot 'pavLR4.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

% rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = zeros(length(uPav2), length(t1));
sO = zeros(length(uPav2), length(t1));
sM = zeros(length(uPav2), length(t1));
sRRr = zeros(length(uPav2), length(t2));
sOr = zeros(length(uPav2), length(t2));
sMr = zeros(length(uPav2), length(t2));
sRRn = zeros(length(uPav2), length(t2));
sOn = zeros(length(uPav2), length(t2));
sMn = zeros(length(uPav2), length(t2));
pRR = zeros(length(uPav2), length(t1));
pO = zeros(length(uPav2), length(t1));
pM = zeros(length(uPav2), length(t1));
pRRr = zeros(length(uPav2), length(t2));
pOr = zeros(length(uPav2), length(t2));
pMr = zeros(length(uPav2), length(t2));
pRRn = zeros(length(uPav2), length(t2));
pOn = zeros(length(uPav2), length(t2));
pMn = zeros(length(uPav2), length(t2));
r2Ord = zeros(length(uPav2), length(t1));
r2OrdR = zeros(length(uPav2), length(t2));
r2OrdN = zeros(length(uPav2), length(t2));
r2Adj = zeros(length(uPav2), length(t1));
r2AdjR = zeros(length(uPav2), length(t2));
r2AdjN = zeros(length(uPav2), length(t2));

cal = Calibrate([datRoot 'IM1178 accel calibration']);
accWin = win + [-0.1 0.1];

for ses = 1:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    rat = uRat{uIdx(1)};
    
    % load accelerometer data
    accDir = dir([datRoot rat filesep pavSes{ses} filesep rat '-Pav*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accPre = zeros(length(pavDat(ses).csTime), length(t1));
    accPost = zeros(length(pavDat(ses).csTime), length(t2));
    for k = 1:size(accPre,1)
        dat = LoadAuxData(accDir, 'timeRange', pavDat(ses).csTime(k) + accWin);
        tmp = zeros(size(dat.a));
        tmp(1,:) = (dat.a(3,:) - cal.v0x1) * cal.mx1;
        tmp(2,:) = (dat.a(6,:) - cal.v0x2) * cal.mx2;
        tmp(3,:) = (dat.a(2,:) - cal.v0y1) * cal.my1;
        tmp(4,:) = (dat.a(5,:) - cal.v0y2) * cal.my2;
        tmp(5,:) = (dat.a(1,:) - cal.v0z1) * cal.mz1;
        tmp(6,:) = (dat.a(4,:) - cal.v0z2) * cal.mz2;
        tmp = mean(abs(tmp));
        t = dat.t - pavDat(ses).csTime(k);
        accPre(k,:) = interp1(t, tmp, t1);
        accPost(k,:) = interp1(t, tmp, t2);
    end
    
    % loop through session units
    for u = uIdx
        
        [~,i] = ismember(u, uPav2);
        disp(['    unit ' num2str(i)])
        pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
        ts = unit(u).behav_ts{pavIdx};
        logPav = unit(u).behav_log{pavIdx};
        probRwd = logPav.toneFreq;
        probRwd(probRwd == 0) = -1;
        logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
        for j = 1:size(logPav.cueRwdTable, 1)
            probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
        end
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        dt = uTraj(1).times(2) - uTraj(1).times(1);
        traj = TrajSplit(uTraj, ts, win);
        
        % regression before outcome, unpredicted (coded as 0%), 25% and 75%
        sel = find(probRwd > 0);
        pR = probRwd(sel);
        pR(pR == 100) = 0;
        nTr = length(sel);
        nSamp = length(t1);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t1);
        end
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j), accPre(sel,j)], rate(:,j));
            sRR(i,j) = lm.Coefficients.Estimate(2);
            sO(i,j) = lm.Coefficients.Estimate(3);
            sM(i,j) = lm.Coefficients.Estimate(4);
            pRR(i,j) = lm.Coefficients.pValue(2);
            pO(i,j) = lm.Coefficients.pValue(3);
            pM(i,j) = lm.Coefficients.pValue(4);
            r2Adj(i,j) = lm.Rsquared.Adjusted;
            r2Ord(i,j) = lm.Rsquared.Ordinary;
        end
    
        % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j), accPost(sel,j)], rate(:,j));
            sRRr(i,j) = lm.Coefficients.Estimate(2);
            sOr(i,j) = lm.Coefficients.Estimate(3);
            sMr(i,j) = lm.Coefficients.Estimate(4);
            pRRr(i,j) = lm.Coefficients.pValue(2);
            pOr(i,j) = lm.Coefficients.pValue(3);
            pMr(i,j) = lm.Coefficients.pValue(4);
            r2AdjR(i,j) = lm.Rsquared.Adjusted;
            r2OrdR(i,j) = lm.Rsquared.Ordinary;
        end
        
        % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & ~logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j), accPost(sel,j)], rate(:,j));
            sRRn(i,j) = lm.Coefficients.Estimate(2);
            sOn(i,j) = lm.Coefficients.Estimate(3);
            sMn(i,j) = lm.Coefficients.Estimate(4);
            pRRn(i,j) = lm.Coefficients.pValue(2);
            pOn(i,j) = lm.Coefficients.pValue(3);
            pMn(i,j) = lm.Coefficients.pValue(4);
            r2AdjN(i,j) = lm.Rsquared.Adjusted;
            r2OrdN(i,j) = lm.Rsquared.Ordinary;
        end
        
    end
    
end

save([datRoot 'pavLR4.mat'], 'sRR', 'sO', 'sM', 'sRRr', 'sOr', 'sMr', 'sRRn', 'sOn', 'sMn',...
    'pRR', 'pO', 'pM', 'pRRr', 'pOr', 'pMr', 'pRRn', 'pOn', 'pMn',...
    'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')



%% Linear Regression on Prob[rwd], Port Occupancy, and Movement (accelerometer) at Different Lags

load([datRoot 'pavLR4a.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

lag = [0.025 0.05 0.075 0.1];
nLag = length(lag);

% rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = cell(1, nLag); for i = 1:nLag sRR{i} = zeros(length(uPav2), length(t1)); end
sO = cell(1, nLag); for i = 1:nLag sO{i} = zeros(length(uPav2), length(t1)); end
sM = cell(1, nLag); for i = 1:nLag sM{i} = zeros(length(uPav2), length(t1)); end
sRRr = cell(1, nLag); for i = 1:nLag sRRr{i} = zeros(length(uPav2), length(t2)); end
sOr = cell(1, nLag); for i = 1:nLag sOr{i} = zeros(length(uPav2), length(t2)); end
sMr = cell(1, nLag); for i = 1:nLag sMr{i} = zeros(length(uPav2), length(t2)); end
sRRn = cell(1, nLag); for i = 1:nLag sRRn{i} = zeros(length(uPav2), length(t2)); end
sOn = cell(1, nLag); for i = 1:nLag sOn{i} = zeros(length(uPav2), length(t2)); end
sMn = cell(1, nLag); for i = 1:nLag sMn{i} = zeros(length(uPav2), length(t2)); end
pRR = cell(1, nLag); for i = 1:nLag pRR{i} = zeros(length(uPav2), length(t1)); end
pO = cell(1, nLag); for i = 1:nLag pO{i} = zeros(length(uPav2), length(t1)); end
pM = cell(1, nLag); for i = 1:nLag pM{i} = zeros(length(uPav2), length(t1)); end
pRRr = cell(1, nLag); for i = 1:nLag pRRr{i} = zeros(length(uPav2), length(t2)); end
pOr = cell(1, nLag); for i = 1:nLag pOr{i} = zeros(length(uPav2), length(t2)); end
pMr = cell(1, nLag); for i = 1:nLag pMr{i} = zeros(length(uPav2), length(t2)); end
pRRn = cell(1, nLag); for i = 1:nLag pRRn{i} = zeros(length(uPav2), length(t2)); end
pOn = cell(1, nLag); for i = 1:nLag pOn{i} = zeros(length(uPav2), length(t2)); end
pMn = cell(1, nLag); for i = 1:nLag pMn{i} = zeros(length(uPav2), length(t2)); end
r2Ord = cell(1, nLag); for i = 1:nLag r2Ord{i} = zeros(length(uPav2), length(t1)); end
r2OrdR = cell(1, nLag); for i = 1:nLag r2OrdR{i} = zeros(length(uPav2), length(t2)); end
r2OrdN = cell(1, nLag); for i = 1:nLag r2OrdN{i} = zeros(length(uPav2), length(t2)); end
r2Adj = cell(1, nLag); for i = 1:nLag r2Adj{i} = zeros(length(uPav2), length(t1)); end
r2AdjR = cell(1, nLag); for i = 1:nLag r2AdjR{i} = zeros(length(uPav2), length(t2)); end
r2AdjN = cell(1, nLag); for i = 1:nLag r2AdjN{i} = zeros(length(uPav2), length(t2)); end

cal = Calibrate([datRoot 'IM1178 accel calibration']);
accWin = win + [-0.1 0.2];

for ses = 1:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    rat = uRat{uIdx(1)};
    
    % load accelerometer data
    accDir = dir([datRoot rat filesep pavSes{ses} filesep rat '-Pav*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accPre = cell(1, nLag); for i = 1:nLag accPre{i} = zeros(length(pavDat(ses).csTime), length(t1)); end
    accPost = cell(1, nLag); for i = 1:nLag accPost{i} = zeros(length(pavDat(ses).csTime), length(t2)); end
    for k = 1:length(pavDat(ses).csTime)
        dat = LoadAuxData(accDir, 'timeRange', pavDat(ses).csTime(k) + accWin);
        tmp = zeros(size(dat.a));
        tmp(1,:) = (dat.a(3,:) - cal.v0x1) * cal.mx1;
        tmp(2,:) = (dat.a(6,:) - cal.v0x2) * cal.mx2;
        tmp(3,:) = (dat.a(2,:) - cal.v0y1) * cal.my1;
        tmp(4,:) = (dat.a(5,:) - cal.v0y2) * cal.my2;
        tmp(5,:) = (dat.a(1,:) - cal.v0z1) * cal.mz1;
        tmp(6,:) = (dat.a(4,:) - cal.v0z2) * cal.mz2;
        tmp = mean(abs(tmp));
        t = dat.t - pavDat(ses).csTime(k);
        for n = 1:nLag
            accPre{n}(k,:) = interp1(t-lag(n), tmp, t1);
            accPost{n}(k,:) = interp1(t-lag(n), tmp, t2);
        end
    end
    
    % loop through session units
    for u = uIdx
        
        [~,i] = ismember(u, uPav2);
        disp(['    unit ' num2str(i)])
        pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
        ts = unit(u).behav_ts{pavIdx};
        logPav = unit(u).behav_log{pavIdx};
        probRwd = logPav.toneFreq;
        probRwd(probRwd == 0) = -1;
        logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
        for j = 1:size(logPav.cueRwdTable, 1)
            probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
        end
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        dt = uTraj(1).times(2) - uTraj(1).times(1);
        traj = TrajSplit(uTraj, ts, win);
        
        % regression before outcome, unpredicted (coded as 0%), 25% and 75%
        sel = find(probRwd > 0);
        pR = probRwd(sel);
        pR(pR == 100) = 0;
        nTr = length(sel);
        nSamp = length(t1);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t1);
        end
        for n = 1:nLag
           for j = 1:nSamp
               lm = fitlm([pR, portOcp(:,j), accPre{n}(sel,j)], rate(:,j));
               sRR{n}(i,j) = lm.Coefficients.Estimate(2);
               sO{n}(i,j) = lm.Coefficients.Estimate(3);
               sM{n}(i,j) = lm.Coefficients.Estimate(4);
               pRR{n}(i,j) = lm.Coefficients.pValue(2);
               pO{n}(i,j) = lm.Coefficients.pValue(3);
               pM{n}(i,j) = lm.Coefficients.pValue(4);
               r2Adj{n}(i,j) = lm.Rsquared.Adjusted;
               r2Ord{n}(i,j) = lm.Rsquared.Ordinary;
           end
        end
    
        % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end
        for n = 1:nLag
            for j = 1:nSamp
                lm = fitlm([pR, portOcp(:,j), accPost{n}(sel,j)], rate(:,j));
                sRRr{n}(i,j) = lm.Coefficients.Estimate(2);
                sOr{n}(i,j) = lm.Coefficients.Estimate(3);
                sMr{n}(i,j) = lm.Coefficients.Estimate(4);
                pRRr{n}(i,j) = lm.Coefficients.pValue(2);
                pOr{n}(i,j) = lm.Coefficients.pValue(3);
                pMr{n}(i,j) = lm.Coefficients.pValue(4);
                r2AdjR{n}(i,j) = lm.Rsquared.Adjusted;
                r2OrdR{n}(i,j) = lm.Rsquared.Ordinary;
            end
        end
        
        % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & ~logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end
        for n = 1:nLag
            for j = 1:nSamp
                lm = fitlm([pR, portOcp(:,j), accPost{n}(sel,j)], rate(:,j));
                sRRn{n}(i,j) = lm.Coefficients.Estimate(2);
                sOn{n}(i,j) = lm.Coefficients.Estimate(3);
                sMn{n}(i,j) = lm.Coefficients.Estimate(4);
                pRRn{n}(i,j) = lm.Coefficients.pValue(2);
                pOn{n}(i,j) = lm.Coefficients.pValue(3);
                pMn{n}(i,j) = lm.Coefficients.pValue(4);
                r2AdjN{n}(i,j) = lm.Rsquared.Adjusted;
                r2OrdN{n}(i,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'pavLR4a.mat'], 'sRR', 'sO', 'sM', 'sRRr', 'sOr', 'sMr', 'sRRn', 'sOn', 'sMn',...
    'pRR', 'pO', 'pM', 'pRRr', 'pOr', 'pMr', 'pRRn', 'pOn', 'pMn',...
    'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')



%% Linear Regression on Prob[rwd], Port Occupancy, and Movement (more detailed)

load([datRoot 'pavLR5.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

% rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = zeros(length(uPav2), length(t1));
sO = zeros(length(uPav2), length(t1));
sX = zeros(length(uPav2), length(t1));
sY = zeros(length(uPav2), length(t1));
sZ = zeros(length(uPav2), length(t1));
sRRr = zeros(length(uPav2), length(t2));
sOr = zeros(length(uPav2), length(t2));
sXr = zeros(length(uPav2), length(t2));
sYr = zeros(length(uPav2), length(t2));
sZr = zeros(length(uPav2), length(t2));
sRRn = zeros(length(uPav2), length(t2));
sOn = zeros(length(uPav2), length(t2));
sMn = zeros(length(uPav2), length(t2));
sXn = zeros(length(uPav2), length(t2));
sYn = zeros(length(uPav2), length(t2));
sZn = zeros(length(uPav2), length(t2));
pRR = zeros(length(uPav2), length(t1));
pO = zeros(length(uPav2), length(t1));
pX = zeros(length(uPav2), length(t1));
pY = zeros(length(uPav2), length(t1));
pZ = zeros(length(uPav2), length(t1));
pRRr = zeros(length(uPav2), length(t2));
pOr = zeros(length(uPav2), length(t2));
pXr = zeros(length(uPav2), length(t2));
pYr = zeros(length(uPav2), length(t2));
pZr = zeros(length(uPav2), length(t2));
pRRn = zeros(length(uPav2), length(t2));
pOn = zeros(length(uPav2), length(t2));
pXn = zeros(length(uPav2), length(t2));
pYn = zeros(length(uPav2), length(t2));
pZn = zeros(length(uPav2), length(t2));
r2Ord = zeros(length(uPav2), length(t1));
r2OrdR = zeros(length(uPav2), length(t2));
r2OrdN = zeros(length(uPav2), length(t2));
r2Adj = zeros(length(uPav2), length(t1));
r2AdjR = zeros(length(uPav2), length(t2));
r2AdjN = zeros(length(uPav2), length(t2));

cal = Calibrate([datRoot 'IM1178 accel calibration']);
accWin = win + [-0.1 0.1];

for ses = 1:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    rat = uRat{uIdx(1)};
    
    % load accelerometer data
    accDir = dir([datRoot rat filesep pavSes{ses} filesep rat '-Pav*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    xPre = zeros(length(pavDat(ses).csTime), length(t1));
    xPost = zeros(length(pavDat(ses).csTime), length(t2));
    yPre = zeros(length(pavDat(ses).csTime), length(t1));
    yPost = zeros(length(pavDat(ses).csTime), length(t2));
    zPre = zeros(length(pavDat(ses).csTime), length(t1));
    zPost = zeros(length(pavDat(ses).csTime), length(t2));
    for k = 1:size(xPre,1)
        dat = LoadAuxData(accDir, 'timeRange', pavDat(ses).csTime(k) + accWin);
        tmp = zeros(size(dat.a));
        tmp(1,:) = (dat.a(3,:) - cal.v0x1) * cal.mx1;
        tmp(2,:) = (dat.a(6,:) - cal.v0x2) * cal.mx2;
        tmp(3,:) = (dat.a(2,:) - cal.v0y1) * cal.my1;
        tmp(4,:) = (dat.a(5,:) - cal.v0y2) * cal.my2;
        tmp(5,:) = (dat.a(1,:) - cal.v0z1) * cal.mz1;
        tmp(6,:) = (dat.a(4,:) - cal.v0z2) * cal.mz2;
        t = dat.t - pavDat(ses).csTime(k);
        xPre(k,:) = interp1(t, mean(tmp(1:2,:)), t1);
        yPre(k,:) = interp1(t, mean(tmp(3:4,:)), t1);
        zPre(k,:) = interp1(t, mean(tmp(5:6,:)), t1);
        xPost(k,:) = interp1(t, mean(tmp(1:2,:)), t2);
        yPost(k,:) = interp1(t, mean(tmp(3:4,:)), t2);
        zPost(k,:) = interp1(t, mean(tmp(5:6,:)), t2);
    end
    
    % loop through session units
    for u = uIdx
        
        [~,i] = ismember(u, uPav2);
        disp(['    unit ' num2str(i)])
        pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
        ts = unit(u).behav_ts{pavIdx};
        logPav = unit(u).behav_log{pavIdx};
        probRwd = logPav.toneFreq;
        probRwd(probRwd == 0) = -1;
        logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
        for j = 1:size(logPav.cueRwdTable, 1)
            probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
        end
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        dt = uTraj(1).times(2) - uTraj(1).times(1);
        traj = TrajSplit(uTraj, ts, win);
        
        % regression before outcome, unpredicted (coded as 0%), 25% and 75%
        sel = find(probRwd > 0);
        pR = probRwd(sel);
        pR(pR == 100) = 0;
        nTr = length(sel);
        nSamp = length(t1);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t1);
        end
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j), xPre(sel,j), yPre(sel,j), zPre(sel,j)], rate(:,j));
            sRR(i,j) = lm.Coefficients.Estimate(2);
            sO(i,j) = lm.Coefficients.Estimate(3);
            sX(i,j) = lm.Coefficients.Estimate(4);
            sY(i,j) = lm.Coefficients.Estimate(5);
            sZ(i,j) = lm.Coefficients.Estimate(6);
            pRR(i,j) = lm.Coefficients.pValue(2);
            pO(i,j) = lm.Coefficients.pValue(3);
            pX(i,j) = lm.Coefficients.pValue(4);
            pY(i,j) = lm.Coefficients.pValue(5);
            pZ(i,j) = lm.Coefficients.pValue(6);
            r2Adj(i,j) = lm.Rsquared.Adjusted;
            r2Ord(i,j) = lm.Rsquared.Ordinary;
        end
    
        % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j), xPost(sel,j), yPost(sel,j), zPost(sel,j)], rate(:,j));
            sRRr(i,j) = lm.Coefficients.Estimate(2);
            sOr(i,j) = lm.Coefficients.Estimate(3);
            sXr(i,j) = lm.Coefficients.Estimate(4);
            sYr(i,j) = lm.Coefficients.Estimate(5);
            sZr(i,j) = lm.Coefficients.Estimate(6);
            pRRr(i,j) = lm.Coefficients.pValue(2);
            pOr(i,j) = lm.Coefficients.pValue(3);
            pXr(i,j) = lm.Coefficients.pValue(4);
            pYr(i,j) = lm.Coefficients.pValue(5);
            pZr(i,j) = lm.Coefficients.pValue(6);
            r2AdjR(i,j) = lm.Rsquared.Adjusted;
            r2OrdR(i,j) = lm.Rsquared.Ordinary;
        end
        
        % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & ~logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j), xPost(sel,j), yPost(sel,j), zPost(sel,j)], rate(:,j));
            sRRn(i,j) = lm.Coefficients.Estimate(2);
            sOn(i,j) = lm.Coefficients.Estimate(3);
            sXn(i,j) = lm.Coefficients.Estimate(4);
            sYn(i,j) = lm.Coefficients.Estimate(5);
            sZn(i,j) = lm.Coefficients.Estimate(6);
            pRRn(i,j) = lm.Coefficients.pValue(2);
            pOn(i,j) = lm.Coefficients.pValue(3);
            pXn(i,j) = lm.Coefficients.pValue(4);
            pYn(i,j) = lm.Coefficients.pValue(5);
            pZn(i,j) = lm.Coefficients.pValue(6);
            r2AdjN(i,j) = lm.Rsquared.Adjusted;
            r2OrdN(i,j) = lm.Rsquared.Ordinary;
        end
        
    end
    
end

save([datRoot 'pavLR5.mat'], 'sRR', 'sO', 'sX', 'sY', 'sZ', 'sRRr', 'sOr', 'sXr', 'sYr', 'sZr',...
    'sRRn', 'sOn', 'sXn', 'sYn', 'sZn', 'pRR', 'pO', 'pX', 'pY', 'pZ',... 
    'pRRr', 'pOr', 'pXr', 'pYr', 'pZr', 'pRRn', 'pOn', 'pXn', 'pYn', 'pZn',...
    'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')



%% Accererometer Autocorrelation

lags = -200:2:200;  % ms
dt = 2              % ms

for ses = 1:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    rat = uRat{uIdx(1)};
    
    % load accelerometer data
    accDir = dir([datRoot rat filesep pavSes{ses} filesep rat '-Pav*']);
    accDir = [accDir(1).folder filesep accDir(1).name];
    for k = 1:size(xPre,1)
        dat = LoadAuxData(accDir, 'timeRange', pavDat(ses).csTime(k) + accWin);
        tmp = zeros(size(dat.a));
        tmp(1,:) = (dat.a(3,:) - cal.v0x1) * cal.mx1;
        tmp(2,:) = (dat.a(6,:) - cal.v0x2) * cal.mx2;
        tmp(3,:) = (dat.a(2,:) - cal.v0y1) * cal.my1;
        tmp(4,:) = (dat.a(5,:) - cal.v0y2) * cal.my2;
        tmp(5,:) = (dat.a(1,:) - cal.v0z1) * cal.mz1;
        tmp(6,:) = (dat.a(4,:) - cal.v0z2) * cal.mz2;
        tmp = mean(abs(tmp));
        t = dat.t - pavDat(ses).csTime(k);
    end
end

lags = 0:2:400;
[ac t] = Crosscorr(tmp, tmp, 2, lags);
figure
plot(t,ac)



%% Linear Regression on Prob[rwd] and Port Occupancy

load([datRoot 'pavLR3.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = zeros(length(uPav2), length(t1));
sO = zeros(length(uPav2), length(t1));
sRRr = zeros(length(uPav2), length(t2));
sOr = zeros(length(uPav2), length(t2));
sRRn = zeros(length(uPav2), length(t2));
sOn = zeros(length(uPav2), length(t2));
pRR = zeros(length(uPav2), length(t1));
pO = zeros(length(uPav2), length(t1));
pRRr = zeros(length(uPav2), length(t2));
pOr = zeros(length(uPav2), length(t2));
pRRn = zeros(length(uPav2), length(t2));
pOn = zeros(length(uPav2), length(t2));
r2Ord = zeros(length(uPav2), length(t1));
r2OrdR = zeros(length(uPav2), length(t2));
r2OrdN = zeros(length(uPav2), length(t2));
r2Adj = zeros(length(uPav2), length(t1));
r2AdjR = zeros(length(uPav2), length(t2));
r2AdjN = zeros(length(uPav2), length(t2));

for i = 1:length(uPav2)
    disp(i)
    % load unit data
    u = uPav2(i);
    ses = find(strcmp(uSes{u}, pavSes));
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    logPav = unit(u).behav_log{pavIdx};
    probRwd = logPav.toneFreq;
    probRwd(probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for j = 1:size(logPav.cueRwdTable, 1)
        probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
    end
    uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
    m = mean(uTraj.rate);
    sd = std(uTraj.rate);
    uTraj.rate = (uTraj.rate - m)/sd;
    dt = uTraj(1).times(2) - uTraj(1).times(1);
    traj = TrajSplit(uTraj, ts, win);
    
    % regression before outcome, unpredicted (coded as 0%), 25% and 75%
    sel = find(probRwd > 0);
    pR = probRwd(sel);
    pR(pR == 100) = 0;
    nTr = length(sel);
    nSamp = length(t1);
    rate = zeros(nTr, nSamp);
    portOcp = zeros(nTr, nSamp);
    for k = 1:nTr
        rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
        portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t1);
    end
    for j = 1:nSamp
        lm = fitlm([pR, portOcp(:,j)],rate(:,j));
        sRR(i,j) = lm.Coefficients.Estimate(2);
        sO(i,j) = lm.Coefficients.Estimate(3); 
        pRR(i,j) = lm.Coefficients.pValue(2);
        pO(i,j) = lm.Coefficients.pValue(3);
        r2Adj(i,j) = lm.Rsquared.Adjusted;
        r2Ord(i,j) = lm.Rsquared.Ordinary;
    end
    
    % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
    sel = find(probRwd > 0 & logPav.outcome);
    pR = probRwd(sel);
    pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
    nTr = length(sel);
    nSamp = length(t2);
    rate = zeros(nTr, nSamp);
    portOcp = zeros(nTr, nSamp);
    for k = 1:nTr
        rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
        portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
    end    
    for j = 1:nSamp
        lm = fitlm([pR, portOcp(:,j)], rate(:,j));
        sRRr(i,j) = lm.Coefficients.Estimate(2);
        sOr(i,j) = lm.Coefficients.Estimate(3);
        pRRr(i,j) = lm.Coefficients.pValue(2);
        pOr(i,j) = lm.Coefficients.pValue(3);
        r2AdjR(i,j) = lm.Rsquared.Adjusted;
        r2OrdR(i,j) = lm.Rsquared.Ordinary;
    end
    
    % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
    sel = find(probRwd > 0 & ~logPav.outcome);
    pR = probRwd(sel);
    pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
    nTr = length(sel);
    nSamp = length(t2);
    rate = zeros(nTr, nSamp);
    portOcp = zeros(nTr, nSamp);
    for k = 1:nTr
        rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
        portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
    end    
    for j = 1:nSamp
        lm = fitlm([pR, portOcp(:,j)], rate(:,j));
        sRRn(i,j) = lm.Coefficients.Estimate(2);
        sOn(i,j) = lm.Coefficients.Estimate(3);
        pRRn(i,j) = lm.Coefficients.pValue(2);
        pOn(i,j) = lm.Coefficients.pValue(3);
        r2AdjN(i,j) = lm.Rsquared.Adjusted;
        r2OrdN(i,j) = lm.Rsquared.Ordinary;
    end
    
end

save([datRoot 'pavLR3.mat'], 'sRR', 'sO', 'sRRr', 'sOr', 'sRRn', 'sOn', 'pRR', 'pO',...
    'pRRr', 'pOr', 'pRRn', 'pOn', 'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')



%% Linear Regression on Prob[rwd] and Port Occupancy Shuffled

% pair spiking data with behavioral data from a different session

load([datRoot 'pavLR3 shuffle.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

% rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = zeros(length(uPav2), length(t1));
sO = zeros(length(uPav2), length(t1));
sRRr = zeros(length(uPav2), length(t2));
sOr = zeros(length(uPav2), length(t2));
sRRn = zeros(length(uPav2), length(t2));
sOn = zeros(length(uPav2), length(t2));
pRR = zeros(length(uPav2), length(t1));
pO = zeros(length(uPav2), length(t1));
pRRr = zeros(length(uPav2), length(t2));
pOr = zeros(length(uPav2), length(t2));
pRRn = zeros(length(uPav2), length(t2));
pOn = zeros(length(uPav2), length(t2));
r2Ord = zeros(length(uPav2), length(t1));
r2OrdR = zeros(length(uPav2), length(t2));
r2OrdN = zeros(length(uPav2), length(t2));
r2Adj = zeros(length(uPav2), length(t1));
r2AdjR = zeros(length(uPav2), length(t2));
r2AdjN = zeros(length(uPav2), length(t2));

pavSes2 = 1:length(pavSes);
while any(pavSes2 == 1:length(pavSes))
    pavSes2 = randperm(length(pavSes));
end

for ses = 1:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    tEnd = ts.csTime(end)+30;
    
    % load alternate behavior data
    s2 = pavSes2(ses);
    u = find(strcmp(pavSes{s2}, uSes));
    u = u(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    nTr = length(find(ts.csTime < tEnd - 5));
    ts.csTime = ts.csTime(1:nTr);
    logPav = unit(u).behav_log{pavIdx};
    probRwd = logPav.toneFreq;
    probRwd(probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for j = 1:size(logPav.cueRwdTable, 1)
        probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
    end
    probRwd = probRwd(1:nTr);
    logPav.outcome = logPav.outcome(1:nTr);
    
    % loop through session units
    for u = uIdx
        
        [~,i] = ismember(u, uPav2);
        disp(['    unit ' num2str(i)])
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        dt = uTraj(1).times(2) - uTraj(1).times(1);
        traj = TrajSplit(uTraj, ts, win);
        
        % regression before outcome, unpredicted (coded as 0%), 25% and 75%
        sel = find(probRwd > 0);
        pR = probRwd(sel);
        pR(pR == 100) = 0;
        nTr = length(sel);
        nSamp = length(t1);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
            portOcp(k,:) = interp1(pavDat(s2).t, pavDat(s2).portOcp(sel(k),:), t1);
        end
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j)], rate(:,j));
            sRR(i,j) = lm.Coefficients.Estimate(2);
            sO(i,j) = lm.Coefficients.Estimate(3);
            pRR(i,j) = lm.Coefficients.pValue(2);
            pO(i,j) = lm.Coefficients.pValue(3);
            r2Adj(i,j) = lm.Rsquared.Adjusted;
            r2Ord(i,j) = lm.Rsquared.Ordinary;
        end
    
        % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(s2).t, pavDat(s2).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j)], rate(:,j));
            sRRr(i,j) = lm.Coefficients.Estimate(2);
            sOr(i,j) = lm.Coefficients.Estimate(3);
            pRRr(i,j) = lm.Coefficients.pValue(2);
            pOr(i,j) = lm.Coefficients.pValue(3);
            r2AdjR(i,j) = lm.Rsquared.Adjusted;
            r2OrdR(i,j) = lm.Rsquared.Ordinary;
        end
        
        % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & ~logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(s2).t, pavDat(s2).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j)], rate(:,j));
            sRRn(i,j) = lm.Coefficients.Estimate(2);
            sOn(i,j) = lm.Coefficients.Estimate(3);
            pRRn(i,j) = lm.Coefficients.pValue(2);
            pOn(i,j) = lm.Coefficients.pValue(3);
            r2AdjN(i,j) = lm.Rsquared.Adjusted;
            r2OrdN(i,j) = lm.Rsquared.Ordinary;
        end
        
    end
    
end

save([datRoot 'pavLR3 shuffle.mat'], 'sRR', 'sO', 'sRRr', 'sOr', 'sRRn', 'sOn',...
    'pRR', 'pO', 'pRRr', 'pOr', 'pRRn', 'pOn',...
    'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')



%% Linear Regression on Prob[rwd] and Port Occupancy Shuffled Another Way

% neural activity is aligned to data from other sessions, but with
% appropriate timing (correct timing taken from real session, but prob rwd
% and outcome taken from shuffled session)

load([datRoot 'pavLR3 shuffle2.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

% rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = zeros(length(uPav2), length(t1));
sO = zeros(length(uPav2), length(t1));
sRRr = zeros(length(uPav2), length(t2));
sOr = zeros(length(uPav2), length(t2));
sRRn = zeros(length(uPav2), length(t2));
sOn = zeros(length(uPav2), length(t2));
pRR = zeros(length(uPav2), length(t1));
pO = zeros(length(uPav2), length(t1));
pRRr = zeros(length(uPav2), length(t2));
pOr = zeros(length(uPav2), length(t2));
pRRn = zeros(length(uPav2), length(t2));
pOn = zeros(length(uPav2), length(t2));
r2Ord = zeros(length(uPav2), length(t1));
r2OrdR = zeros(length(uPav2), length(t2));
r2OrdN = zeros(length(uPav2), length(t2));
r2Adj = zeros(length(uPav2), length(t1));
r2AdjR = zeros(length(uPav2), length(t2));
r2AdjN = zeros(length(uPav2), length(t2));

pavSes2 = 1:length(pavSes);
while any(pavSes2 == 1:length(pavSes))
    pavSes2 = randperm(length(pavSes));
end

for ses = 31:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    tEnd = ts.csTime(end);
    
    % load alternate behavior data
    s2 = pavSes2(ses);
    u = find(strcmp(pavSes{s2}, uSes));
    u = u(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    tsAlt = unit(u).behav_ts{pavIdx};
    nTr = min(length(find(tsAlt.csTime < tEnd)),length(ts.csTime));
    tsAlt.csTime = tsAlt.csTime(1:nTr);
    ts.csTime = ts.csTime(1:nTr);
    logPav = unit(u).behav_log{pavIdx};
    probRwd = logPav.toneFreq;
    probRwd(probRwd == 0) = -1;
    logPav.cueRwdTable(logPav.cueRwdTable(:,1)==0,1) = -1;
    for j = 1:size(logPav.cueRwdTable, 1)
        probRwd(probRwd == logPav.cueRwdTable(j,1)) = logPav.cueRwdTable(j,2);
    end
    probRwd = probRwd(1:nTr);
    logPav.outcome = logPav.outcome(1:nTr);
    
    % loop through session units
    for u = uIdx
        
        [~,i] = ismember(u, uPav2);
        disp(['    unit ' num2str(i)])
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        dt = uTraj(1).times(2) - uTraj(1).times(1);
        traj = TrajSplit(uTraj, ts, win);
        
        % regression before outcome, unpredicted (coded as 0%), 25% and 75%
        sel = find(probRwd > 0);
        pR = probRwd(sel);
        pR(pR == 100) = 0;
        nTr = length(sel);
        nSamp = length(t1);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t1);
            portOcp(k,:) = interp1(pavDat(s2).t, pavDat(s2).portOcp(sel(k),:), t1);
        end
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j)], rate(:,j));
            sRR(i,j) = lm.Coefficients.Estimate(2);
            sO(i,j) = lm.Coefficients.Estimate(3);
            pRR(i,j) = lm.Coefficients.pValue(2);
            pO(i,j) = lm.Coefficients.pValue(3);
            r2Adj(i,j) = lm.Rsquared.Adjusted;
            r2Ord(i,j) = lm.Rsquared.Ordinary;
        end
    
        % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(s2).t, pavDat(s2).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j)], rate(:,j));
            sRRr(i,j) = lm.Coefficients.Estimate(2);
            sOr(i,j) = lm.Coefficients.Estimate(3);
            pRRr(i,j) = lm.Coefficients.pValue(2);
            pOr(i,j) = lm.Coefficients.pValue(3);
            r2AdjR(i,j) = lm.Rsquared.Adjusted;
            r2OrdR(i,j) = lm.Rsquared.Ordinary;
        end
        
        % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
        sel = find(probRwd > 0 & ~logPav.outcome);
        pR = probRwd(sel);
        pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(s2).t, pavDat(s2).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR, portOcp(:,j)], rate(:,j));
            sRRn(i,j) = lm.Coefficients.Estimate(2);
            sOn(i,j) = lm.Coefficients.Estimate(3);
            pRRn(i,j) = lm.Coefficients.pValue(2);
            pOn(i,j) = lm.Coefficients.pValue(3);
            r2AdjN(i,j) = lm.Rsquared.Adjusted;
            r2OrdN(i,j) = lm.Rsquared.Ordinary;
        end
        
    end
    
end

save([datRoot 'pavLR3 shuffle2.mat'], 'sRR', 'sO', 'sRRr', 'sOr', 'sRRn', 'sOn',...
    'pRR', 'pO', 'pRRr', 'pOr', 'pRRn', 'pOn',...
    'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')


%% Compute Reward Rate for Shuffle Control

% compute reward rate for each session using tau obtained above
tau = 89;
sesList = unique(uSes);
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end
end 




%% Shuffle Control: Port Occupancy and Movement with RL Value

% load([datRoot 'pavLR-RL shuffle.mat']) % load LR if already computed

badSes = setdiff(uSes(uPav), pavSes);
uPav2 = uPav;
uPav2(cellfun(@(s) ismember(s, badSes), uSes(uPav))) = [];

rwdTime = 3.1356
win = [-0.5 4.5];
dtLR = 0.005;
rT = floor(rwdTime/dtLR)*dtLR;
winLR1 = [win(1) rT];
winLR2 = [rT+dtLR win(2)];
t1 = winLR1(1):dtLR:winLR1(2);
t2 = winLR2(1):dtLR:winLR2(2);
sRR = zeros(length(uPav2), length(t1));
sO = zeros(length(uPav2), length(t1));
sM = zeros(length(uPav2), length(t1));
sRRr = zeros(length(uPav2), length(t2));
sOr = zeros(length(uPav2), length(t2));
sMr = zeros(length(uPav2), length(t2));
sRRn = zeros(length(uPav2), length(t2));
sOn = zeros(length(uPav2), length(t2));
sMn = zeros(length(uPav2), length(t2));
pRR = zeros(length(uPav2), length(t1));
pO = zeros(length(uPav2), length(t1));
pM = zeros(length(uPav2), length(t1));
pRRr = zeros(length(uPav2), length(t2));
pOr = zeros(length(uPav2), length(t2));
pMr = zeros(length(uPav2), length(t2));
pRRn = zeros(length(uPav2), length(t2));
pOn = zeros(length(uPav2), length(t2));
pMn = zeros(length(uPav2), length(t2));
r2Ord = zeros(length(uPav2), length(t1));
r2OrdR = zeros(length(uPav2), length(t2));
r2OrdN = zeros(length(uPav2), length(t2));
r2Adj = zeros(length(uPav2), length(t1));
r2AdjR = zeros(length(uPav2), length(t2));
r2AdjN = zeros(length(uPav2), length(t2));

cal = Calibrate([datRoot 'IM1178 accel calibration']);
accWin = win + [-0.1 0.1];

for ses = 5:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    u = uIdx(1);
    rat = uRat{u};
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    ts = unit(u).behav_ts{pavIdx};
    s = find(strcmp(pavSes{ses}, sesList));
    pR = rwdRate{s};
    nTr = min([length(ts.csTime) length(pR)]);
    pR = pR(1:nTr);
    
    % load accelerometer data
    accDir = dir([datRoot rat filesep pavSes{ses} filesep rat '-Pav*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accPre = zeros(nTr, length(t1));
    accPost = zeros(nTr, length(t2));
    for k = 1:nTr
        dat = LoadAuxData(accDir, 'timeRange', pavDat(ses).csTime(k) + accWin);
        tmp = zeros(size(dat.a));
        tmp(1,:) = (dat.a(3,:) - cal.v0x1) * cal.mx1;
        tmp(2,:) = (dat.a(6,:) - cal.v0x2) * cal.mx2;
        tmp(3,:) = (dat.a(2,:) - cal.v0y1) * cal.my1;
        tmp(4,:) = (dat.a(5,:) - cal.v0y2) * cal.my2;
        tmp(5,:) = (dat.a(1,:) - cal.v0z1) * cal.mz1;
        tmp(6,:) = (dat.a(4,:) - cal.v0z2) * cal.mz2;
        tmp = mean(abs(tmp));
        t = dat.t - pavDat(ses).csTime(k);
        accPre(k,:) = interp1(t, tmp, t1);
        accPost(k,:) = interp1(t, tmp, t2);
    end
    
    % loop through session units
    for u = uIdx
        
        [~,i] = ismember(u, uPav2);
        disp(['    unit ' num2str(i)])
             
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        dt = uTraj(1).times(2) - uTraj(1).times(1);
        traj = TrajSplit(uTraj, ts, win);
        traj = traj(1:nTr);
        
        % regression before outcome, unpredicted (coded as 0%), 25% and 75%
        % nTr = length(sel);
        nSamp = length(t1);
        rate = zeros(nTr, nSamp);
        portOcp = zeros(nTr, nSamp);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, t1);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(k,:), t1);
        end
        for j = 1:nSamp
            lm = fitlm([pR', portOcp(:,j), accPre(:,j)], rate(:,j));
            sRR(i,j) = lm.Coefficients.Estimate(2);
            sO(i,j) = lm.Coefficients.Estimate(3);
            sM(i,j) = lm.Coefficients.Estimate(4);
            pRR(i,j) = lm.Coefficients.pValue(2);
            pO(i,j) = lm.Coefficients.pValue(3);
            pM(i,j) = lm.Coefficients.pValue(4);
            r2Adj(i,j) = lm.Rsquared.Adjusted;
            r2Ord(i,j) = lm.Rsquared.Ordinary;
        end
    
        % regression after outcome on rewarded trials, (unpred, 25%, and 75%)
        sel = find(logPav.outcome(1:nTr));
        % pR = probRwd(sel);
        % pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        % nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(length(sel), nSamp);
        portOcp = zeros(length(sel), nSamp);
        for k = 1:length(sel)
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR(sel)', portOcp(:,j), accPost(sel,j)], rate(:,j));
            sRRr(i,j) = lm.Coefficients.Estimate(2);
            sOr(i,j) = lm.Coefficients.Estimate(3);
            sMr(i,j) = lm.Coefficients.Estimate(4);
            pRRr(i,j) = lm.Coefficients.pValue(2);
            pOr(i,j) = lm.Coefficients.pValue(3);
            pMr(i,j) = lm.Coefficients.pValue(4);
            r2AdjR(i,j) = lm.Rsquared.Adjusted;
            r2OrdR(i,j) = lm.Rsquared.Ordinary;
        end
        
        % regression after outcome on unrewarded trials, (unpred, 25%, and 75%)
        sel = find(~logPav.outcome(1:nTr));
        %pR = probRwd(sel);
        %pR(pR == 100) = 0; % treat unpredicted reward as p[rwd] = 0
        %nTr = length(sel);
        nSamp = length(t2);
        rate = zeros(length(sel), nSamp);
        portOcp = zeros(length(sel), nSamp);
        for k = 1:length(sel)
            rate(k,:) = interp1(traj(sel(k)).times, traj(sel(k)).rate, t2);
            portOcp(k,:) = interp1(pavDat(ses).t, pavDat(ses).portOcp(sel(k),:), t2);
        end    
        for j = 1:nSamp
            lm = fitlm([pR(sel)', portOcp(:,j), accPost(sel,j)], rate(:,j));
            sRRn(i,j) = lm.Coefficients.Estimate(2);
            sOn(i,j) = lm.Coefficients.Estimate(3);
            sMn(i,j) = lm.Coefficients.Estimate(4);
            pRRn(i,j) = lm.Coefficients.pValue(2);
            pOn(i,j) = lm.Coefficients.pValue(3);
            pMn(i,j) = lm.Coefficients.pValue(4);
            r2AdjN(i,j) = lm.Rsquared.Adjusted;
            r2OrdN(i,j) = lm.Rsquared.Ordinary;
        end
        
    end
    
end

save([datRoot 'pavLR-RL shuffle.mat'], 'sRR', 'sO', 'sM', 'sRRr', 'sOr', 'sMr', 'sRRn', 'sOn', 'sMn',...
    'pRR', 'pO', 'pM', 'pRRr', 'pOr', 'pMr', 'pRRn', 'pOn', 'pMn',...
    'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN', 'uPav2')



