%% Load Unit Data

datRoot = '/Volumes/LaCie/Farries recordings/';
load([datRoot 'unitDat_final_culled.mat'])

uName = arrayfun(@(u) strsplit(u.name), unit, 'UniformOutput', false);
uRat = cellfun(@(u) u{1}, uName, 'UniformOutput', false);
uSes = cellfun(@(u) u{2}, uName, 'UniformOutput', false);
uTrode = cellfun(@(u) u{3}, uName, 'UniformOutput', false);
uNum = cellfun(@(u) u{4}, uName, 'UniformOutput', false);
uName = arrayfun(@(u) strjoin(u{1}), uName, 'UniformOutput', false);
uType = arrayfun(@(u) strsplit(u.cellType), unit, 'UniformOutput', false);
uType = cellfun(@(u) u{1}, uType, 'UniformOutput', false);
fp = find(strcmp(uType, 'fast'));
sp = find(strcmp(uType, 'slow'));
ip = find(strcmp(uType, 'intermediate'));
rp = find(strcmp(uType, 'RPE'));
ak = find(strcmp(uType, 'arky'));
out = find(strcmp(uType, 'unclassified'));
length(unit)
length(fp)+length(sp)+length(ip)+length(rp)+length(ak)+length(out)
  
rpColor = [0.7 0 0];
fpColor = [1 0.5 0];

sesList = unique(uSes, 'stable');



%% Compute Reward Rate

% compute reward rate for each session using tau obtained above
tau = 89;
rwdRate = cell(1, length(sesList));
for s = 1:length(sesList)
    uIdx = find(strcmp(sesList{s}, uSes));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(uIdx(1)).taskList));
    tsRL = unit(uIdx(1)).behav_ts{rlIdx};
    logLat = log(BehaviorTimes(tsRL));
    t = tsRL.trialbegin;
    nTr = length(t);
    rwdRate{s} = zeros(1, nTr);
    for k = 1:nTr
        if k > 1
            rwdRate{s}(k) = rwdRate{s}(k-1)*exp(-(t(k) - t(k-1))/tau);
        end
        rwdRate{s}(k) = rwdRate{s}(k) + tsRL.outcome(k);
    end
end 




%% Linear Regressionon Reward Rate, Choice, and Movement (accelerometer)

load([datRoot 'rlLR7.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(unit), length(tLO));
sC{2} = nan(length(unit), length(tCI));
sC{3} = nan(length(unit), length(tGO));
sC{4} = nan(length(unit), length(tCO));
sC{5} = nan(length(unit), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(unit), length(tSIpost)); sCr{2} = nan(length(unit), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(unit), length(tSIpost)); sCn{2} = nan(length(unit), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(unit), length(tLO));
pC{2} = nan(length(unit), length(tCI));
pC{3} = nan(length(unit), length(tGO));
pC{4} = nan(length(unit), length(tCO));
pC{5} = nan(length(unit), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(unit), length(tSIpost)); pCr{2} = nan(length(unit), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(unit), length(tSIpost)); pCn{2} = nan(length(unit), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(unit), length(tLO));
sM{2} = nan(length(unit), length(tCI));
sM{3} = nan(length(unit), length(tGO));
sM{4} = nan(length(unit), length(tCO));
sM{5} = nan(length(unit), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(unit), length(tSIpost)); sMr{2} = nan(length(unit), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(unit), length(tSIpost)); sMn{2} = nan(length(unit), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(unit), length(tLO));
pM{2} = nan(length(unit), length(tCI));
pM{3} = nan(length(unit), length(tGO));
pM{4} = nan(length(unit), length(tCO));
pM{5} = nan(length(unit), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(unit), length(tSIpost)); pMr{2} = nan(length(unit), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(unit), length(tSIpost)); pMn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
sOld = 0;
for u = 1:length(unit)
    
    % load unit data
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    choice = ts.choice' ~= unit(u).side;
    nTr = length(choice);
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    s = find(strcmp(uSes{u}, sesList));
    if s > sOld
        accLO = [];
        sOld = s;
    end
    rr = rwdRate{s}';
    nTr = length(rr);
    uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
    m = mean(uTraj.rate);
    sd = std(uTraj.rate);
    uTraj.rate = (uTraj.rate - m)/sd;
    
    % load accelerometer data
    if isempty(accLO)
        disp(['session ' num2str(s)])
        rat = uRat{u};
        accDir = dir([datRoot rat filesep sesList{s} filesep rat '-RL*']);
        if isempty(accDir)
            disp('** ERROR **')
            break
        end
        accDir = [accDir(1).folder filesep accDir(1).name];
        accLO = zeros(nTr, length(tLO));
        accCI = zeros(nTr, length(tCI));
        accGO = zeros(nTr, length(tGO));
        accCO = zeros(nTr, length(tCO));
        accSIpre = zeros(nTr, length(tSIpre));
        accSIpost = zeros(nTr, length(tSIpost));
        accFP = nan(nTr, length(tFP));
        t1 = ts.trialbegin + winLO(1) - 0.1;
        t2 = ts.firstFoodPoke + winFP(2) + 0.1;
        t2(isnan(t2)) = ts.Side_NI(isnan(t2)) + winSIpost(2) + 0.1;
        for k = 1:nTr
            dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
            dat.a = mean(abs((dat.a - cal0) .* calM));
            accLO(k,:) = interp1(dat.t-ts.trialbegin(k), dat.a, tLO);
            accCI(k,:) = interp1(dat.t-ts.Center_NI(k), dat.a, tCI);
            accGO(k,:) = interp1(dat.t-ts.go(k), dat.a, tGO);
            accCO(k,:) = interp1(dat.t-ts.Center_NO(k), dat.a, tGO);
            accSIpre(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpre);
            accSIpost(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpost);
            if ~isnan(ts.firstFoodPoke(k))
                accFP(k,:) = interp1(dat.t-ts.firstFoodPoke(k), dat.a, tFP);
            end
        end
    end
    
    disp(['    unit ' num2str(u)])
    
    % LO
    traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
    rate = zeros(nTr, nSampLO);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
    end
    for j = 1:nSampLO
        lm = fitlm([rr, choice, accLO(:,j)], rate(:,j));
        sR{1}(u,j) = lm.Coefficients.Estimate(2);
        sC{1}(u,j) = lm.Coefficients.Estimate(3);
        sM{1}(u,j) = lm.Coefficients.Estimate(4);
        pR{1}(u,j) = lm.Coefficients.pValue(2);
        pC{1}(u,j) = lm.Coefficients.pValue(3);
        pM{1}(u,j) = lm.Coefficients.pValue(4);
        r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % CI
    traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
    rate = zeros(nTr, nSampCI);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
    end
    for j = 1:nSampCI
        lm = fitlm([rr, choice, accCI(:,j)], rate(:,j));
        sR{2}(u,j) = lm.Coefficients.Estimate(2);
        sC{2}(u,j) = lm.Coefficients.Estimate(3);
        sM{2}(u,j) = lm.Coefficients.Estimate(4);
        pR{2}(u,j) = lm.Coefficients.pValue(2);
        pC{2}(u,j) = lm.Coefficients.pValue(3);
        pM{2}(u,j) = lm.Coefficients.pValue(4);
        r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % GO
    traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
    rate = zeros(nTr, nSampGO);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
    end
    for j = 1:nSampGO
        lm = fitlm([rr, choice, accGO(:,j)], rate(:,j));
        sR{3}(u,j) = lm.Coefficients.Estimate(2);
        sC{3}(u,j) = lm.Coefficients.Estimate(3);
        sM{3}(u,j) = lm.Coefficients.Estimate(4);
        pR{3}(u,j) = lm.Coefficients.pValue(2);
        pC{3}(u,j) = lm.Coefficients.pValue(3);
        pM{3}(u,j) = lm.Coefficients.pValue(4);
        r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % CO
    traj = TrajSplit(uTraj, ts, winCO, 'event', 4);
    rate = zeros(nTr, nSampCO);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tCO);
    end
    for j = 1:nSampCO
        lm = fitlm([rr, choice, accCO(:,j)], rate(:,j));
        sR{4}(u,j) = lm.Coefficients.Estimate(2);
        sC{4}(u,j) = lm.Coefficients.Estimate(3);
        sM{4}(u,j) = lm.Coefficients.Estimate(4);
        pR{4}(u,j) = lm.Coefficients.pValue(2);
        pC{4}(u,j) = lm.Coefficients.pValue(3);
        pM{4}(u,j) = lm.Coefficients.pValue(4);
        r2Adj{4}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{4}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % pre-SI regression at SI
    traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
    rate = zeros(nTr, nSampSIpre);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
    end
    for j = 1:nSampSIpre
        lm = fitlm([rr, choice, accSIpre(:,j)], rate(:,j));
        sR{5}(u,j) = lm.Coefficients.Estimate(2);
        sC{5}(u,j) = lm.Coefficients.Estimate(3);
        sM{5}(u,j) = lm.Coefficients.Estimate(4);
        pR{5}(u,j) = lm.Coefficients.pValue(2);
        pC{5}(u,j) = lm.Coefficients.pValue(3);
        pM{5}(u,j) = lm.Coefficients.pValue(4);
        r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % post-SI regression at SI, rewarded trials
    rate = zeros(nTr, nSampSIpost);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
    end
    for j = 1:nSampSIpost
        lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
        sRr{1}(u,j) = lm.Coefficients.Estimate(2);
        sCr{1}(u,j) = lm.Coefficients.Estimate(3);
        sMr{1}(u,j) = lm.Coefficients.Estimate(4);
        pRr{1}(u,j) = lm.Coefficients.pValue(2);
        pCr{1}(u,j) = lm.Coefficients.pValue(3);
        pMr{1}(u,j) = lm.Coefficients.pValue(4);
        r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
        r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % SI - unrewarded trials
    for j = 1:nSampSIpost
        lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
        sRn{1}(u,j) = lm.Coefficients.Estimate(2);
        sCn{1}(u,j) = lm.Coefficients.Estimate(3);
        sMn{1}(u,j) = lm.Coefficients.Estimate(4);
        pRn{1}(u,j) = lm.Coefficients.pValue(2);
        pCn{1}(u,j) = lm.Coefficients.pValue(3);
        pMn{1}(u,j) = lm.Coefficients.pValue(4);
        r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
        r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % FP - rewarded trials
    traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
    fp = find(~isnan(ts.firstFoodPoke));
    [~,ftr] = ismember(tr, fp);
    [~,ftn] = ismember(tn, fp);
    ftr = ftr(ftr > 0);
    ftn = ftn(ftn > 0);
    if ~isempty(fp)
        rate = zeros(length(fp), nSampFP);
        for k = 1:length(fp)
            rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
        end
        for j = 1:nSampFP
            lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
            sRr{2}(u,j) = lm.Coefficients.Estimate(2);
            sCr{2}(u,j) = lm.Coefficients.Estimate(3);
            sMr{2}(u,j) = lm.Coefficients.Estimate(4);
            pRr{2}(u,j) = lm.Coefficients.pValue(2);
            pCr{2}(u,j) = lm.Coefficients.pValue(3);
            pMr{2}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
        end
    end
    
    % FP - unrewarded trials
    if ~isempty(fp)
        for j = 1:nSampFP
            lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
            sRn{2}(u,j) = lm.Coefficients.Estimate(2);
            sCn{2}(u,j) = lm.Coefficients.Estimate(3);
            sMn{2}(u,j) = lm.Coefficients.Estimate(4);
            pRn{2}(u,j) = lm.Coefficients.pValue(2);
            pCn{2}(u,j) = lm.Coefficients.pValue(3);
            pMn{2}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
        end
    end
    
    
end

save([datRoot 'rlLR7a.mat'], 'sR', 'sC', 'sM', 'sRr', 'sRn', 'sCr', 'sCn', 'sMr', 'sMn',...
    'pR', 'pC', 'pM', 'pRr', 'pRn', 'pCr', 'pCn', 'pMr', 'pMn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')



%% Linear Regressionon Reward Rate and Choice (using longer rwd rate tau)

load([datRoot 'rlLR3a.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(unit), length(tLO));
sC{2} = nan(length(unit), length(tCI));
sC{3} = nan(length(unit), length(tGO));
sC{4} = nan(length(unit), length(tCO));
sC{5} = nan(length(unit), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(unit), length(tSIpost)); sCr{2} = nan(length(unit), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(unit), length(tSIpost)); sCn{2} = nan(length(unit), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(unit), length(tLO));
pC{2} = nan(length(unit), length(tCI));
pC{3} = nan(length(unit), length(tGO));
pC{4} = nan(length(unit), length(tCO));
pC{5} = nan(length(unit), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(unit), length(tSIpost)); pCr{2} = nan(length(unit), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(unit), length(tSIpost)); pCn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

sOld = 0;
for u = 1:length(unit)
    
    % load unit data
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    choice = ts.choice' ~= unit(u).side;
    nTr = length(choice);
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    s = find(strcmp(uSes{u}, sesList));
    if s > sOld
        accLO = [];
        sOld = s;
    end
    rr = rwdRate{s}';
    nTr = length(rr);
    uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
    m = mean(uTraj.rate);
    sd = std(uTraj.rate);
    uTraj.rate = (uTraj.rate - m)/sd;
    
    % load accelerometer data
    if isempty(accLO)
        disp(['session ' num2str(s)])
        rat = uRat{u};
        accDir = dir([datRoot rat filesep sesList{s} filesep rat '-RL*']);
        if isempty(accDir)
            disp('** ERROR **')
            break
        end
        accDir = [accDir(1).folder filesep accDir(1).name];
        accLO = zeros(nTr, length(tLO));
    end
    
    disp(['    unit ' num2str(u)])
    
    % LO
    traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
    rate = zeros(nTr, nSampLO);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
    end
    for j = 1:nSampLO
        lm = fitlm([rr, choice], rate(:,j));
        sR{1}(u,j) = lm.Coefficients.Estimate(2);
        sC{1}(u,j) = lm.Coefficients.Estimate(3);
        pR{1}(u,j) = lm.Coefficients.pValue(2);
        pC{1}(u,j) = lm.Coefficients.pValue(3);
        r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % CI
    traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
    rate = zeros(nTr, nSampCI);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
    end
    for j = 1:nSampCI
        lm = fitlm([rr, choice], rate(:,j));
        sR{2}(u,j) = lm.Coefficients.Estimate(2);
        sC{2}(u,j) = lm.Coefficients.Estimate(3);
        pR{2}(u,j) = lm.Coefficients.pValue(2);
        pC{2}(u,j) = lm.Coefficients.pValue(3);
        r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % GO
    traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
    rate = zeros(nTr, nSampGO);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
    end
    for j = 1:nSampGO
        lm = fitlm([rr, choice], rate(:,j));
        sR{3}(u,j) = lm.Coefficients.Estimate(2);
        sC{3}(u,j) = lm.Coefficients.Estimate(3);
        pR{3}(u,j) = lm.Coefficients.pValue(2);
        pC{3}(u,j) = lm.Coefficients.pValue(3);
        r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % CO
    traj = TrajSplit(uTraj, ts, winCO, 'event', 4);
    rate = zeros(nTr, nSampCO);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tCO);
    end
    for j = 1:nSampCO
        lm = fitlm([rr, choice], rate(:,j));
        sR{4}(u,j) = lm.Coefficients.Estimate(2);
        sC{4}(u,j) = lm.Coefficients.Estimate(3);
        pR{4}(u,j) = lm.Coefficients.pValue(2);
        pC{4}(u,j) = lm.Coefficients.pValue(3);
        r2Adj{4}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{4}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % pre-SI regression at SI
    traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
    rate = zeros(nTr, nSampSIpre);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
    end
    for j = 1:nSampSIpre
        lm = fitlm([rr, choice], rate(:,j));
        sR{5}(u,j) = lm.Coefficients.Estimate(2);
        sC{5}(u,j) = lm.Coefficients.Estimate(3);
        pR{5}(u,j) = lm.Coefficients.pValue(2);
        pC{5}(u,j) = lm.Coefficients.pValue(3);
        r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
        r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % post-SI regression at SI, rewarded trials
    rate = zeros(nTr, nSampSIpost);
    for k = 1:nTr
        rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
    end
    for j = 1:nSampSIpost
        lm = fitlm([rr(tr), choice(tr)], rate(tr,j));
        sRr{1}(u,j) = lm.Coefficients.Estimate(2);
        sCr{1}(u,j) = lm.Coefficients.Estimate(3);
        pRr{1}(u,j) = lm.Coefficients.pValue(2);
        pCr{1}(u,j) = lm.Coefficients.pValue(3);
        r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
        r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % SI - unrewarded trials
    for j = 1:nSampSIpost
        lm = fitlm([rr(tn), choice(tn)], rate(tn,j));
        sRn{1}(u,j) = lm.Coefficients.Estimate(2);
        sCn{1}(u,j) = lm.Coefficients.Estimate(3);
        pRn{1}(u,j) = lm.Coefficients.pValue(2);
        pCn{1}(u,j) = lm.Coefficients.pValue(3);
        r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
        r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
    end
    
    % FP - rewarded trials
    traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
    fp = find(~isnan(ts.firstFoodPoke));
    [~,ftr] = ismember(tr, fp);
    [~,ftn] = ismember(tn, fp);
    ftr = ftr(ftr > 0);
    ftn = ftn(ftn > 0);
    if ~isempty(fp)
        rate = zeros(length(fp), nSampFP);
        for k = 1:length(fp)
            rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
        end
        for j = 1:nSampFP
            lm = fitlm([rr(fp(ftr)), choice(fp(ftr))], rate(ftr,j));
            sRr{2}(u,j) = lm.Coefficients.Estimate(2);
            sCr{2}(u,j) = lm.Coefficients.Estimate(3);
            pRr{2}(u,j) = lm.Coefficients.pValue(2);
            pCr{2}(u,j) = lm.Coefficients.pValue(3);
            r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
        end
    end
    
    % FP - unrewarded trials
    if ~isempty(fp)
        for j = 1:nSampFP
            lm = fitlm([rr(fp(ftn)), choice(fp(ftn))], rate(ftn,j));
            sRn{2}(u,j) = lm.Coefficients.Estimate(2);
            sCn{2}(u,j) = lm.Coefficients.Estimate(3);
            pRn{2}(u,j) = lm.Coefficients.pValue(2);
            pCn{2}(u,j) = lm.Coefficients.pValue(3);
            r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
        end
    end
    
    
end

save([datRoot 'rlLR3a.mat'], 'sR', 'sC', 'sRr', 'sRn', 'sCr', 'sCn', 'pR', 'pC', 'pRr',...
    'pRn', 'pCr', 'pCn', 'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN',...
    'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')



%% Linear Regression on Shuffled Behavior (1a -- all behavior)

% pair spiking data with behavioral data from a different session

% load([datRoot 'rlLR shuffle1a.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(unit), length(tLO));
sC{2} = nan(length(unit), length(tCI));
sC{3} = nan(length(unit), length(tGO));
sC{4} = nan(length(unit), length(tCO));
sC{5} = nan(length(unit), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(unit), length(tSIpost)); sCr{2} = nan(length(unit), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(unit), length(tSIpost)); sCn{2} = nan(length(unit), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(unit), length(tLO));
pC{2} = nan(length(unit), length(tCI));
pC{3} = nan(length(unit), length(tGO));
pC{4} = nan(length(unit), length(tCO));
pC{5} = nan(length(unit), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(unit), length(tSIpost)); pCr{2} = nan(length(unit), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(unit), length(tSIpost)); pCn{2} = nan(length(unit), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(unit), length(tLO));
sM{2} = nan(length(unit), length(tCI));
sM{3} = nan(length(unit), length(tGO));
sM{4} = nan(length(unit), length(tCO));
sM{5} = nan(length(unit), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(unit), length(tSIpost)); sMr{2} = nan(length(unit), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(unit), length(tSIpost)); sMn{2} = nan(length(unit), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(unit), length(tLO));
pM{2} = nan(length(unit), length(tCI));
pM{3} = nan(length(unit), length(tGO));
pM{4} = nan(length(unit), length(tCO));
pM{5} = nan(length(unit), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(unit), length(tSIpost)); pMr{2} = nan(length(unit), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(unit), length(tSIpost)); pMn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

altSes = 1:length(sesList);
while any(altSes == 1:length(sesList))
    altSes = randperm(length(sesList));
end

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
for ses = 43:length(sesList)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(sesList{ses}, uSes));
    u = uIdx(1);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    tEnd = ts.Side_NO(end)+5;
    
    % load alternate behavior data
    s2 = altSes(ses);
    u = find(strcmp(sesList{s2}, uSes));
    u = u(1);
    rlIdx2 = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx2};
    trEnd = ts.firstFoodPoke + 1.1;
    trEnd(isnan(trEnd)) = ts.Side_NO(isnan(trEnd)) + 5;
    trList = find(trEnd - tEnd < 0);
    nTr = length(trList);
    tr1 = 11;
    ts.choice = ts.choice(tr1:nTr);
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    choice = ts.choice' ~= unit(u).side;
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{s2}';
    rr = rr(tr1:nTr);
    nTr = length(ts.trialbegin);
    
    % load accelerometer data
    rat = uRat{u};
    accDir = dir([datRoot rat filesep sesList{s2} filesep rat '-RL*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accLO = randn(nTr, length(tLO));
    accCI = randn(nTr, length(tCI));
    accGO = randn(nTr, length(tGO));
    accCO = randn(nTr, length(tCO));
    accSIpre = randn(nTr, length(tSIpre));
    accSIpost = randn(nTr, length(tSIpost));
    accFP = randn(nTr, length(tFP));
    t1 = ts.trialbegin + winLO(1) - 0.1;
    t2 = ts.firstFoodPoke + winFP(2) + 0.1;
    sni = ts.Side_NI;
    t2(isnan(t2)) = sni(isnan(t2)) + winSIpost(2) + 0.1;
    for k = 1:nTr
        if range([t1(k) t2(k)]) > 20
            continue
        end
        dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
        dat.a = mean(abs((dat.a - cal0) .* calM));
        accLO(k,:) = interp1(dat.t-ts.trialbegin(k), dat.a, tLO);
        accCI(k,:) = interp1(dat.t-ts.Center_NI(k), dat.a, tCI);
        accGO(k,:) = interp1(dat.t-ts.go(k), dat.a, tGO);
        accCO(k,:) = interp1(dat.t-ts.Center_NO(k), dat.a, tGO);
        accSIpre(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpre);
        accSIpost(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpost);
         if ~isnan(ts.firstFoodPoke(k))
             accFP(k,:) = interp1(dat.t-ts.firstFoodPoke(k), dat.a, tFP);
         end
    end
    
    % loop through session units
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accLO(tr1:end,j)], rate((tr1:end),j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            sC{1}(u,j) = lm.Coefficients.Estimate(3);
            sM{1}(u,j) = lm.Coefficients.Estimate(4);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            pC{1}(u,j) = lm.Coefficients.pValue(3);
            pM{1}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm([rr(tr1:end), choice(tr1:end), accCI((tr1:end),j)], rate((tr1:end),j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            sC{2}(u,j) = lm.Coefficients.Estimate(3);
            sM{2}(u,j) = lm.Coefficients.Estimate(4);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            pC{2}(u,j) = lm.Coefficients.pValue(3);
            pM{2}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accGO((tr1:end),j)], rate((tr1:end),j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            sC{3}(u,j) = lm.Coefficients.Estimate(3);
            sM{3}(u,j) = lm.Coefficients.Estimate(4);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            pC{3}(u,j) = lm.Coefficients.pValue(3);
            pM{3}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm([rr(tr1:end), choice(tr1:end), accSIpre(tr1:end,j)], rate((tr1:end),j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            sC{5}(u,j) = lm.Coefficients.Estimate(3);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            pC{5}(u,j) = lm.Coefficients.pValue(3);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            sCr{1}(u,j) = lm.Coefficients.Estimate(3);
            sMr{1}(u,j) = lm.Coefficients.Estimate(4);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            pCr{1}(u,j) = lm.Coefficients.pValue(3);
            pMr{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            sCn{1}(u,j) = lm.Coefficients.Estimate(3);
            sMn{1}(u,j) = lm.Coefficients.Estimate(4);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            pCn{1}(u,j) = lm.Coefficients.pValue(3);
            pMn{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = find(~isnan(ts.firstFoodPoke));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                sCr{2}(u,j) = lm.Coefficients.Estimate(3);
                sMr{2}(u,j) = lm.Coefficients.Estimate(4);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                pCr{2}(u,j) = lm.Coefficients.pValue(3);
                pMr{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                sCn{2}(u,j) = lm.Coefficients.Estimate(3);
                sMn{2}(u,j) = lm.Coefficients.Estimate(4);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                pCn{2}(u,j) = lm.Coefficients.pValue(3);
                pMn{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle1a.mat'], 'sR', 'sC', 'sRr', 'sRn', 'sCr', 'sCn',...
    'pR', 'pC', 'pRr', 'pRn', 'pCr', 'pCn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')




%% Linear Regression on Shuffled Behavior (1b -- reward rate only)

% pair spiking data with reward rate data from a different session

% load([datRoot 'rlLR shuffle1b.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

altSes = 1:length(sesList);
while any(altSes == 1:length(sesList))
    altSes = randperm(length(sesList));
end

for ses = 1:length(sesList)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(sesList{ses}, uSes));
    u = uIdx(1);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    tEnd = ts.Side_NO(end)+5;
    
    % load alternate behavior data
    s2 = altSes(ses);
    u = find(strcmp(sesList{s2}, uSes));
    u = u(1);
    rlIdx2 = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx2};
    trEnd = ts.firstFoodPoke + 1.1;
    trEnd(isnan(trEnd)) = ts.Side_NO(isnan(trEnd)) + 5;
    trList = find(trEnd - tEnd < 0);
    nTr = length(trList);
    tr1 = 11;
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    choice = ts.choice' ~= unit(u).side;
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{s2}';
    rr = rr(tr1:nTr);
    nTr = length(ts.trialbegin);
    
    % loop through session units
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm(rr(tr1:end), rate((tr1:end),j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm(rr(tr1:end), rate((tr1:end),j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm(rr(tr1:end), rate((tr1:end),j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm(rr(tr1:end), rate((tr1:end),j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm(rr(tr), rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm(rr(tn), rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = find(~isnan(ts.firstFoodPoke));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm(rr(fp(ftr)), rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm(rr(fp(ftn)), rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle1b.mat'], 'sR', 'sRr', 'sRn', 'pR', 'pRr', 'pRn',...
     'r2Ord', 'r2Adj', 'r2OrdR', 'r2AdjR', 'r2OrdN', 'r2AdjN',...
     'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')




%% Linear Regression on Shuffled Behavior (1c -- all behavior, but only rwd rate shuffled)

% pair spiking data with behavioral data from a different session

%load([datRoot 'rlLR shuffle1c.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(unit), length(tLO));
sC{2} = nan(length(unit), length(tCI));
sC{3} = nan(length(unit), length(tGO));
sC{4} = nan(length(unit), length(tCO));
sC{5} = nan(length(unit), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(unit), length(tSIpost)); sCr{2} = nan(length(unit), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(unit), length(tSIpost)); sCn{2} = nan(length(unit), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(unit), length(tLO));
pC{2} = nan(length(unit), length(tCI));
pC{3} = nan(length(unit), length(tGO));
pC{4} = nan(length(unit), length(tCO));
pC{5} = nan(length(unit), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(unit), length(tSIpost)); pCr{2} = nan(length(unit), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(unit), length(tSIpost)); pCn{2} = nan(length(unit), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(unit), length(tLO));
sM{2} = nan(length(unit), length(tCI));
sM{3} = nan(length(unit), length(tGO));
sM{4} = nan(length(unit), length(tCO));
sM{5} = nan(length(unit), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(unit), length(tSIpost)); sMr{2} = nan(length(unit), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(unit), length(tSIpost)); sMn{2} = nan(length(unit), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(unit), length(tLO));
pM{2} = nan(length(unit), length(tCI));
pM{3} = nan(length(unit), length(tGO));
pM{4} = nan(length(unit), length(tCO));
pM{5} = nan(length(unit), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(unit), length(tSIpost)); pMr{2} = nan(length(unit), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(unit), length(tSIpost)); pMn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

altSes = 1:length(sesList);
while any(altSes == 1:length(sesList))
    altSes = randperm(length(sesList));
end

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
for ses = 1:length(sesList)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(sesList{ses}, uSes));
    u = uIdx(1);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    tEnd = ts.Side_NO(end)+5;
    uOld = u;
    
    % load alternate behavior data
    s2 = altSes(ses);
    u = find(strcmp(sesList{s2}, uSes));
    u = u(1);
    rlIdx2 = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts2 = unit(u).behav_ts{rlIdx2};
    trEnd = ts2.firstFoodPoke + 1.1;
    trEnd(isnan(trEnd)) = ts2.Side_NO(isnan(trEnd)) + 5;
    trList = find(trEnd - tEnd < 0);
    nTr = min([length(trList) length(ts.trialbegin)]);
    tr1 = 11;
    ts.choice = ts.choice(tr1:nTr);
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    choice = ts.choice' ~= unit(u).side;
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{s2}';
    rr = rr(tr1:nTr);
    nTr = length(ts.trialbegin);
    
    % load accelerometer data
    rat = uRat{uOld};
    accDir = dir([datRoot rat filesep sesList{ses} filesep rat '-RL*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accLO = randn(nTr, length(tLO));
    accCI = randn(nTr, length(tCI));
    accGO = randn(nTr, length(tGO));
    accCO = randn(nTr, length(tCO));
    accSIpre = randn(nTr, length(tSIpre));
    accSIpost = randn(nTr, length(tSIpost));
    accFP = randn(nTr, length(tFP));
    t1 = ts.trialbegin + winLO(1) - 0.1;
    t2 = ts.firstFoodPoke + winFP(2) + 0.1;
    sni = ts.Side_NI;
    t2(isnan(t2)) = sni(isnan(t2)) + winSIpost(2) + 0.1;
    for k = 1:nTr
        if range([t1(k) t2(k)]) > 20
            continue
        end
        dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
        dat.a = mean(abs((dat.a - cal0) .* calM));
        accLO(k,:) = interp1(dat.t-ts.trialbegin(k), dat.a, tLO);
        accCI(k,:) = interp1(dat.t-ts.Center_NI(k), dat.a, tCI);
        accGO(k,:) = interp1(dat.t-ts.go(k), dat.a, tGO);
        accCO(k,:) = interp1(dat.t-ts.Center_NO(k), dat.a, tGO);
        accSIpre(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpre);
        accSIpost(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpost);
         if ~isnan(ts.firstFoodPoke(k))
             accFP(k,:) = interp1(dat.t-ts.firstFoodPoke(k), dat.a, tFP);
         end
    end
    
    % loop through session units
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accLO(tr1:end,j)], rate((tr1:end),j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            sC{1}(u,j) = lm.Coefficients.Estimate(3);
            sM{1}(u,j) = lm.Coefficients.Estimate(4);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            pC{1}(u,j) = lm.Coefficients.pValue(3);
            pM{1}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm([rr(tr1:end), choice(tr1:end), accCI((tr1:end),j)], rate((tr1:end),j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            sC{2}(u,j) = lm.Coefficients.Estimate(3);
            sM{2}(u,j) = lm.Coefficients.Estimate(4);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            pC{2}(u,j) = lm.Coefficients.pValue(3);
            pM{2}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accGO((tr1:end),j)], rate((tr1:end),j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            sC{3}(u,j) = lm.Coefficients.Estimate(3);
            sM{3}(u,j) = lm.Coefficients.Estimate(4);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            pC{3}(u,j) = lm.Coefficients.pValue(3);
            pM{3}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm([rr(tr1:end), choice(tr1:end), accSIpre(tr1:end,j)], rate((tr1:end),j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            sC{5}(u,j) = lm.Coefficients.Estimate(3);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            pC{5}(u,j) = lm.Coefficients.pValue(3);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            sCr{1}(u,j) = lm.Coefficients.Estimate(3);
            sMr{1}(u,j) = lm.Coefficients.Estimate(4);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            pCr{1}(u,j) = lm.Coefficients.pValue(3);
            pMr{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            sCn{1}(u,j) = lm.Coefficients.Estimate(3);
            sMn{1}(u,j) = lm.Coefficients.Estimate(4);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            pCn{1}(u,j) = lm.Coefficients.pValue(3);
            pMn{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = find(~isnan(ts.firstFoodPoke));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                sCr{2}(u,j) = lm.Coefficients.Estimate(3);
                sMr{2}(u,j) = lm.Coefficients.Estimate(4);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                pCr{2}(u,j) = lm.Coefficients.pValue(3);
                pMr{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                sCn{2}(u,j) = lm.Coefficients.Estimate(3);
                sMn{2}(u,j) = lm.Coefficients.Estimate(4);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                pCn{2}(u,j) = lm.Coefficients.pValue(3);
                pMn{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle1c.mat'], 'sR', 'sC', 'sRr', 'sRn', 'sCr', 'sCn',...
    'pR', 'pC', 'pRr', 'pRn', 'pCr', 'pCn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')




%% Linear Regression on Shuffled Behavior (2a -- all behavior)

% neural activity is aligned to data from other sessions, but with
% appropriate timing (correct timing taken from real session, but rwd rate,
% choice, outcome taken from shuffled session)

% load([datRoot 'rlLR shuffle2a.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(unit), length(tLO));
sC{2} = nan(length(unit), length(tCI));
sC{3} = nan(length(unit), length(tGO));
sC{4} = nan(length(unit), length(tCO));
sC{5} = nan(length(unit), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(unit), length(tSIpost)); sCr{2} = nan(length(unit), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(unit), length(tSIpost)); sCn{2} = nan(length(unit), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(unit), length(tLO));
pC{2} = nan(length(unit), length(tCI));
pC{3} = nan(length(unit), length(tGO));
pC{4} = nan(length(unit), length(tCO));
pC{5} = nan(length(unit), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(unit), length(tSIpost)); pCr{2} = nan(length(unit), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(unit), length(tSIpost)); pCn{2} = nan(length(unit), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(unit), length(tLO));
sM{2} = nan(length(unit), length(tCI));
sM{3} = nan(length(unit), length(tGO));
sM{4} = nan(length(unit), length(tCO));
sM{5} = nan(length(unit), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(unit), length(tSIpost)); sMr{2} = nan(length(unit), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(unit), length(tSIpost)); sMn{2} = nan(length(unit), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(unit), length(tLO));
pM{2} = nan(length(unit), length(tCI));
pM{3} = nan(length(unit), length(tGO));
pM{4} = nan(length(unit), length(tCO));
pM{5} = nan(length(unit), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(unit), length(tSIpost)); pMr{2} = nan(length(unit), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(unit), length(tSIpost)); pMn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

altSes = 1:length(sesList);
while any(altSes == 1:length(sesList))
    altSes = randperm(length(sesList));
end

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
tr1 = 11;
for ses = 1:length(sesList)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(sesList{ses}, uSes));
    u = uIdx(1);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    tEnd = ts.Side_NO(end)+5;
    uOld = u;
    
    % load alternate behavior data
    s2 = altSes(ses);
    u = find(strcmp(sesList{s2}, uSes));
    u = u(1);
    rlIdx2 = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    tsAlt = unit(u).behav_ts{rlIdx2};
    nTr = min([length(tsAlt.trialbegin) length(ts.trialbegin)]);
    ts.choice = ts.choice(tr1:nTr);
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    tsAlt.choice = tsAlt.choice(tr1:nTr);
    tsAlt.outcome = tsAlt.outcome(tr1:nTr);
    tsAlt.trialbegin = tsAlt.trialbegin(tr1:nTr);
    tsAlt.Center_NI = tsAlt.Center_NI(tr1:nTr);
    tsAlt.Center_NO = tsAlt.Center_NO(tr1:nTr);
    tsAlt.go = tsAlt.go(tr1:nTr);
    tsAlt.Side_NI = tsAlt.Side_NI(tr1:nTr);
    tsAlt.firstFoodPoke = tsAlt.firstFoodPoke(tr1:nTr);
    choice = tsAlt.choice' ~= unit(u).side;
    tr = TrialFilter(tsAlt, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(tsAlt, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{s2}';
    rr = rr(tr1:nTr);
    nTr = nTr - tr1 + 1;
    
    % load accelerometer data
    rat = uRat{u};
    accDir = dir([datRoot rat filesep sesList{s2} filesep rat '-RL*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accLO = randn(nTr, length(tLO));
    accCI = randn(nTr, length(tCI));
    accGO = randn(nTr, length(tGO));
    accSIpre = randn(nTr, length(tSIpre));
    accSIpost = randn(nTr, length(tSIpost));
    accFP = randn(nTr, length(tFP));
    t1 = tsAlt.trialbegin + winLO(1) - 0.1;
    t2 = tsAlt.firstFoodPoke + winFP(2) + 0.1;
    sni = tsAlt.Side_NI;
    t2(isnan(t2)) = sni(isnan(t2)) + winSIpost(2) + 0.1;
    for k = 1:nTr
        if range([t1(k) t2(k)]) > 20
            continue
        end
        dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
        dat.a = mean(abs((dat.a - cal0) .* calM));
        accLO(k,:) = interp1(dat.t-tsAlt.trialbegin(k), dat.a, tLO);
        accCI(k,:) = interp1(dat.t-tsAlt.Center_NI(k), dat.a, tCI);
        accGO(k,:) = interp1(dat.t-tsAlt.go(k), dat.a, tGO);
        accSIpre(k,:) = interp1(dat.t-tsAlt.Side_NI(k), dat.a, tSIpre);
        accSIpost(k,:) = interp1(dat.t-tsAlt.Side_NI(k), dat.a, tSIpost);
        if ~isnan(tsAlt.firstFoodPoke(k))
            accFP(k,:) = interp1(dat.t-tsAlt.firstFoodPoke(k), dat.a, tFP);
        end
    end
    
    % loop through session units
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm([rr, choice, accLO(:,j)], rate(:,j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            sC{1}(u,j) = lm.Coefficients.Estimate(3);
            sM{1}(u,j) = lm.Coefficients.Estimate(4);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            pC{1}(u,j) = lm.Coefficients.pValue(3);
            pM{1}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm([rr, choice, accCI(:,j)], rate(:,j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            sC{2}(u,j) = lm.Coefficients.Estimate(3);
            sM{2}(u,j) = lm.Coefficients.Estimate(4);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            pC{2}(u,j) = lm.Coefficients.pValue(3);
            pM{2}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm([rr, choice, accGO(:,j)], rate(:,j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            sC{3}(u,j) = lm.Coefficients.Estimate(3);
            sM{3}(u,j) = lm.Coefficients.Estimate(4);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            pC{3}(u,j) = lm.Coefficients.pValue(3);
            pM{3}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm([rr, choice, accSIpre(:,j)], rate(:,j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            sC{5}(u,j) = lm.Coefficients.Estimate(3);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            pC{5}(u,j) = lm.Coefficients.pValue(3);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            sCr{1}(u,j) = lm.Coefficients.Estimate(3);
            sMr{1}(u,j) = lm.Coefficients.Estimate(4);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            pCr{1}(u,j) = lm.Coefficients.pValue(3);
            pMr{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            sCn{1}(u,j) = lm.Coefficients.Estimate(3);
            sMn{1}(u,j) = lm.Coefficients.Estimate(4);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            pCn{1}(u,j) = lm.Coefficients.pValue(3);
            pMn{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = intersect(find(~isnan(ts.firstFoodPoke)), find(~isnan(tsAlt.firstFoodPoke)));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                sCr{2}(u,j) = lm.Coefficients.Estimate(3);
                sMr{2}(u,j) = lm.Coefficients.Estimate(4);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                pCr{2}(u,j) = lm.Coefficients.pValue(3);
                pMr{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                sCn{2}(u,j) = lm.Coefficients.Estimate(3);
                sMn{2}(u,j) = lm.Coefficients.Estimate(4);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                pCn{2}(u,j) = lm.Coefficients.pValue(3);
                pMn{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle2a.mat'], 'sR', 'sC', 'sM', 'sRr', 'sRn', 'sCr', 'sCn', 'sMr', 'sMn',...
    'pR', 'pC', 'pM', 'pRr', 'pRn', 'pCr', 'pCn', 'pMr', 'pMn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')



%% Linear Regression on Shuffled Behavior (2b -- only RR shuffled)

% neural activity is aligned to data from other sessions, but with
% appropriate timing (correct timing taken from real session, but rwd rate,
% choice, outcome taken from shuffled session)

% load([datRoot 'rlLR shuffle2b.mat']) % load LR if already computed

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(unit), length(tLO));
sR{2} = nan(length(unit), length(tCI));
sR{3} = nan(length(unit), length(tGO));
sR{4} = nan(length(unit), length(tCO));
sR{5} = nan(length(unit), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(unit), length(tSIpost)); sRr{2} = nan(length(unit), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(unit), length(tSIpost)); sRn{2} = nan(length(unit), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(unit), length(tLO));
pR{2} = nan(length(unit), length(tCI));
pR{3} = nan(length(unit), length(tGO));
pR{4} = nan(length(unit), length(tCO));
pR{5} = nan(length(unit), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(unit), length(tSIpost)); pRr{2} = nan(length(unit), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(unit), length(tSIpost)); pRn{2} = nan(length(unit), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(unit), length(tLO));
sC{2} = nan(length(unit), length(tCI));
sC{3} = nan(length(unit), length(tGO));
sC{4} = nan(length(unit), length(tCO));
sC{5} = nan(length(unit), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(unit), length(tSIpost)); sCr{2} = nan(length(unit), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(unit), length(tSIpost)); sCn{2} = nan(length(unit), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(unit), length(tLO));
pC{2} = nan(length(unit), length(tCI));
pC{3} = nan(length(unit), length(tGO));
pC{4} = nan(length(unit), length(tCO));
pC{5} = nan(length(unit), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(unit), length(tSIpost)); pCr{2} = nan(length(unit), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(unit), length(tSIpost)); pCn{2} = nan(length(unit), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(unit), length(tLO));
sM{2} = nan(length(unit), length(tCI));
sM{3} = nan(length(unit), length(tGO));
sM{4} = nan(length(unit), length(tCO));
sM{5} = nan(length(unit), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(unit), length(tSIpost)); sMr{2} = nan(length(unit), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(unit), length(tSIpost)); sMn{2} = nan(length(unit), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(unit), length(tLO));
pM{2} = nan(length(unit), length(tCI));
pM{3} = nan(length(unit), length(tGO));
pM{4} = nan(length(unit), length(tCO));
pM{5} = nan(length(unit), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(unit), length(tSIpost)); pMr{2} = nan(length(unit), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(unit), length(tSIpost)); pMn{2} = nan(length(unit), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(unit), length(tLO));
r2Ord{2} = nan(length(unit), length(tCI));
r2Ord{3} = nan(length(unit), length(tGO));
r2Ord{4} = nan(length(unit), length(tCO));
r2Ord{5} = nan(length(unit), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(unit), length(tSIpost)); r2OrdR{2} = nan(length(unit), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(unit), length(tSIpost)); r2OrdN{2} = nan(length(unit), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(unit), length(tLO));
r2Adj{2} = nan(length(unit), length(tCI));
r2Adj{3} = nan(length(unit), length(tGO));
r2Adj{4} = nan(length(unit), length(tCO));
r2Adj{5} = nan(length(unit), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(unit), length(tSIpost)); r2AdjR{2} = nan(length(unit), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(unit), length(tSIpost)); r2AdjN{2} = nan(length(unit), length(tFP));

altSes = 1:length(sesList);
while any(altSes == 1:length(sesList))
    altSes = randperm(length(sesList));
end
shift = 9;
altSes = mod((1:length(sesList)) + shift-1, length(sesList))+1;

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
tr1 = 11;
for ses = 1:length(sesList)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(sesList{ses}, uSes));
    u = uIdx(1);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    tEnd = ts.Side_NO(end)+5;
    uOld = u;
    
    % load alternate behavior data
    s2 = altSes(ses);
    u = find(strcmp(sesList{s2}, uSes));
    u = u(1);
    rlIdx2 = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    tsAlt = unit(u).behav_ts{rlIdx2};
    nTr = min([length(tsAlt.trialbegin) length(ts.trialbegin)]);
    ts.choice = ts.choice(tr1:nTr);
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    choice = ts.choice' ~= unit(u).side;
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{s2}';
    rr = rr(tr1:nTr);
    nTr = nTr - tr1 + 1;
    
    % load accelerometer data
    rat = uRat{uOld};
    accDir = dir([datRoot rat filesep sesList{ses} filesep rat '-RL*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accLO = randn(nTr, length(tLO));
    accCI = randn(nTr, length(tCI));
    accGO = randn(nTr, length(tGO));
    accSIpre = randn(nTr, length(tSIpre));
    accSIpost = randn(nTr, length(tSIpost));
    accFP = randn(nTr, length(tFP));
    t1 = ts.trialbegin + winLO(1) - 0.1;
    t2 = ts.firstFoodPoke + winFP(2) + 0.1;
    sni = ts.Side_NI;
    t2(isnan(t2)) = sni(isnan(t2)) + winSIpost(2) + 0.1;
    for k = 1:nTr
        if range([t1(k) t2(k)]) > 20
            continue
        end
        dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
        dat.a = mean(abs((dat.a - cal0) .* calM));
        accLO(k,:) = interp1(dat.t-ts.trialbegin(k), dat.a, tLO);
        accCI(k,:) = interp1(dat.t-ts.Center_NI(k), dat.a, tCI);
        accGO(k,:) = interp1(dat.t-ts.go(k), dat.a, tGO);
        accSIpre(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpre);
        accSIpost(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpost);
        if ~isnan(ts.firstFoodPoke(k))
            accFP(k,:) = interp1(dat.t-ts.firstFoodPoke(k), dat.a, tFP);
        end
    end
    
    % loop through session units
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'RL', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm([rr, choice, accLO(:,j)], rate(:,j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            sC{1}(u,j) = lm.Coefficients.Estimate(3);
            sM{1}(u,j) = lm.Coefficients.Estimate(4);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            pC{1}(u,j) = lm.Coefficients.pValue(3);
            pM{1}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm([rr, choice, accCI(:,j)], rate(:,j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            sC{2}(u,j) = lm.Coefficients.Estimate(3);
            sM{2}(u,j) = lm.Coefficients.Estimate(4);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            pC{2}(u,j) = lm.Coefficients.pValue(3);
            pM{2}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm([rr, choice, accGO(:,j)], rate(:,j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            sC{3}(u,j) = lm.Coefficients.Estimate(3);
            sM{3}(u,j) = lm.Coefficients.Estimate(4);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            pC{3}(u,j) = lm.Coefficients.pValue(3);
            pM{3}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm([rr, choice, accSIpre(:,j)], rate(:,j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            sC{5}(u,j) = lm.Coefficients.Estimate(3);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            pC{5}(u,j) = lm.Coefficients.pValue(3);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            sCr{1}(u,j) = lm.Coefficients.Estimate(3);
            sMr{1}(u,j) = lm.Coefficients.Estimate(4);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            pCr{1}(u,j) = lm.Coefficients.pValue(3);
            pMr{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            sCn{1}(u,j) = lm.Coefficients.Estimate(3);
            sMn{1}(u,j) = lm.Coefficients.Estimate(4);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            pCn{1}(u,j) = lm.Coefficients.pValue(3);
            pMn{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = intersect(find(~isnan(ts.firstFoodPoke)), find(~isnan(ts.firstFoodPoke)));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                sCr{2}(u,j) = lm.Coefficients.Estimate(3);
                sMr{2}(u,j) = lm.Coefficients.Estimate(4);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                pCr{2}(u,j) = lm.Coefficients.pValue(3);
                pMr{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                sCn{2}(u,j) = lm.Coefficients.Estimate(3);
                sMn{2}(u,j) = lm.Coefficients.Estimate(4);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                pCn{2}(u,j) = lm.Coefficients.pValue(3);
                pMn{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle2b-4.mat'], 'sR', 'sC', 'sM', 'sRr', 'sRn', 'sCr', 'sCn', 'sMr', 'sMn',...
    'pR', 'pC', 'pM', 'pRr', 'pRn', 'pCr', 'pCn', 'pMr', 'pMn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')




%% Linear Regression Shuffle 3: Pavlovian Ephys Paired with RL Behavior (same session)

% pair spiking data with behavioral data from a different session

% load([datRoot 'rlLR shuffle3.mat']) % load LR if already computed

% identfiy sessions with Pavlovian data
uPav = find(arrayfun(@(u) any(strcmp('pav', lower(u.taskList))), unit));
pavSes = unique(uSes(uPav));

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(uPav), length(tLO));
sR{2} = nan(length(uPav), length(tCI));
sR{3} = nan(length(uPav), length(tGO));
sR{4} = nan(length(uPav), length(tCO));
sR{5} = nan(length(uPav), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(uPav), length(tSIpost)); sRr{2} = nan(length(uPav), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(uPav), length(tSIpost)); sRn{2} = nan(length(uPav), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(uPav), length(tLO));
pR{2} = nan(length(uPav), length(tCI));
pR{3} = nan(length(uPav), length(tGO));
pR{4} = nan(length(uPav), length(tCO));
pR{5} = nan(length(uPav), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(uPav), length(tSIpost)); pRr{2} = nan(length(uPav), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(uPav), length(tSIpost)); pRn{2} = nan(length(uPav), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(uPav), length(tLO));
sC{2} = nan(length(uPav), length(tCI));
sC{3} = nan(length(uPav), length(tGO));
sC{4} = nan(length(uPav), length(tCO));
sC{5} = nan(length(uPav), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(uPav), length(tSIpost)); sCr{2} = nan(length(uPav), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(uPav), length(tSIpost)); sCn{2} = nan(length(uPav), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(uPav), length(tLO));
pC{2} = nan(length(uPav), length(tCI));
pC{3} = nan(length(uPav), length(tGO));
pC{4} = nan(length(uPav), length(tCO));
pC{5} = nan(length(uPav), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(uPav), length(tSIpost)); pCr{2} = nan(length(uPav), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(uPav), length(tSIpost)); pCn{2} = nan(length(uPav), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(uPav), length(tLO));
sM{2} = nan(length(uPav), length(tCI));
sM{3} = nan(length(uPav), length(tGO));
sM{4} = nan(length(uPav), length(tCO));
sM{5} = nan(length(uPav), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(uPav), length(tSIpost)); sMr{2} = nan(length(uPav), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(uPav), length(tSIpost)); sMn{2} = nan(length(uPav), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(uPav), length(tLO));
pM{2} = nan(length(uPav), length(tCI));
pM{3} = nan(length(uPav), length(tGO));
pM{4} = nan(length(uPav), length(tCO));
pM{5} = nan(length(uPav), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(uPav), length(tSIpost)); pMr{2} = nan(length(uPav), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(uPav), length(tSIpost)); pMn{2} = nan(length(uPav), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(uPav), length(tLO));
r2Ord{2} = nan(length(uPav), length(tCI));
r2Ord{3} = nan(length(uPav), length(tGO));
r2Ord{4} = nan(length(uPav), length(tCO));
r2Ord{5} = nan(length(uPav), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(uPav), length(tSIpost)); r2OrdR{2} = nan(length(uPav), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(uPav), length(tSIpost)); r2OrdN{2} = nan(length(uPav), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(uPav), length(tLO));
r2Adj{2} = nan(length(uPav), length(tCI));
r2Adj{3} = nan(length(uPav), length(tGO));
r2Adj{4} = nan(length(uPav), length(tCO));
r2Adj{5} = nan(length(uPav), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(uPav), length(tSIpost)); r2AdjR{2} = nan(length(uPav), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(uPav), length(tSIpost)); r2AdjN{2} = nan(length(uPav), length(tFP));

% altSes = 1:length(sesList);
% while any(altSes == 1:length(sesList))
%     altSes = randperm(length(sesList));
% end

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
for ses = 33:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
    tEndPav = uTraj.times(end);
    ts = unit(u).behav_ts{rlIdx};
    trEnd = ts.firstFoodPoke + 1.1;
    trEnd(isnan(trEnd)) = ts.Side_NO(isnan(trEnd)) + 5;
    trList = find(trEnd - tEndPav < 0);
    nTr = length(trList);
    tr1 = 1;
    
    ts.choice = ts.choice(tr1:nTr);
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    choice = ts.choice' ~= unit(u).side;
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{find(strcmp(pavSes{ses}, sesList))}';
    rr = rr(tr1:nTr);
    nTr = length(ts.trialbegin);
    
    % load accelerometer data
    rat = uRat{u};
    accDir = dir([datRoot rat filesep pavSes{ses} filesep rat '-RL*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accLO = randn(nTr, length(tLO));
    accCI = randn(nTr, length(tCI));
    accGO = randn(nTr, length(tGO));
    accCO = randn(nTr, length(tCO));
    accSIpre = randn(nTr, length(tSIpre));
    accSIpost = randn(nTr, length(tSIpost));
    accFP = randn(nTr, length(tFP));
    t1 = ts.trialbegin + winLO(1) - 0.1;
    t2 = ts.firstFoodPoke + winFP(2) + 0.1;
    sni = ts.Side_NI;
    t2(isnan(t2)) = sni(isnan(t2)) + winSIpost(2) + 0.1;
    for k = 1:nTr
        if range([t1(k) t2(k)]) > 20
            continue
        end
        dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
        dat.a = mean(abs((dat.a - cal0) .* calM));
        accLO(k,:) = interp1(dat.t-ts.trialbegin(k), dat.a, tLO);
        accCI(k,:) = interp1(dat.t-ts.Center_NI(k), dat.a, tCI);
        accGO(k,:) = interp1(dat.t-ts.go(k), dat.a, tGO);
        accCO(k,:) = interp1(dat.t-ts.Center_NO(k), dat.a, tGO);
        accSIpre(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpre);
        accSIpost(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpost);
         if ~isnan(ts.firstFoodPoke(k))
             accFP(k,:) = interp1(dat.t-ts.firstFoodPoke(k), dat.a, tFP);
         end
    end
    
    % loop through session units
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accLO(tr1:end,j)], rate((tr1:end),j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            sC{1}(u,j) = lm.Coefficients.Estimate(3);
            sM{1}(u,j) = lm.Coefficients.Estimate(4);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            pC{1}(u,j) = lm.Coefficients.pValue(3);
            pM{1}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm([rr(tr1:end), choice(tr1:end), accCI((tr1:end),j)], rate((tr1:end),j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            sC{2}(u,j) = lm.Coefficients.Estimate(3);
            sM{2}(u,j) = lm.Coefficients.Estimate(4);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            pC{2}(u,j) = lm.Coefficients.pValue(3);
            pM{2}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accGO((tr1:end),j)], rate((tr1:end),j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            sC{3}(u,j) = lm.Coefficients.Estimate(3);
            sM{3}(u,j) = lm.Coefficients.Estimate(4);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            pC{3}(u,j) = lm.Coefficients.pValue(3);
            pM{3}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm([rr(tr1:end), choice(tr1:end), accSIpre(tr1:end,j)], rate((tr1:end),j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            sC{5}(u,j) = lm.Coefficients.Estimate(3);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            pC{5}(u,j) = lm.Coefficients.pValue(3);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            sCr{1}(u,j) = lm.Coefficients.Estimate(3);
            sMr{1}(u,j) = lm.Coefficients.Estimate(4);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            pCr{1}(u,j) = lm.Coefficients.pValue(3);
            pMr{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            sCn{1}(u,j) = lm.Coefficients.Estimate(3);
            sMn{1}(u,j) = lm.Coefficients.Estimate(4);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            pCn{1}(u,j) = lm.Coefficients.pValue(3);
            pMn{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = find(~isnan(ts.firstFoodPoke));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                sCr{2}(u,j) = lm.Coefficients.Estimate(3);
                sMr{2}(u,j) = lm.Coefficients.Estimate(4);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                pCr{2}(u,j) = lm.Coefficients.pValue(3);
                pMr{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                sCn{2}(u,j) = lm.Coefficients.Estimate(3);
                sMn{2}(u,j) = lm.Coefficients.Estimate(4);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                pCn{2}(u,j) = lm.Coefficients.pValue(3);
                pMn{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle3.mat'], 'sR', 'sC', 'sRr', 'sRn', 'sCr', 'sCn',...
    'pR', 'pC', 'pRr', 'pRn', 'pCr', 'pCn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')




%% Linear Regression Shuffle 3b: Pavlovian Ephys Paired with RL Behavior (different session)

% pair spiking data with behavioral data from a different session

% load([datRoot 'rlLR shuffle3.mat']) % load LR if already computed

% identfiy sessions with Pavlovian data
uPav = find(arrayfun(@(u) any(strcmp('pav', lower(u.taskList))), unit));
pavSes = unique(uSes(uPav));

dtLR = 0.005;
winLO = [-1 1]; tLO = winLO(1):dtLR:winLO(2); nSampLO = length(tLO);
winCI = [-1 1]; tCI = winCI(1):dtLR:winCI(2); nSampCI = length(tCI);
winGO = [-1 1]; tGO = winGO(1):dtLR:winGO(2); nSampGO = length(tGO);
winCO = [-1 1]; tCO = winCO(1):dtLR:winCO(2); nSampCO = length(tCO);
winSIpre = [-1 0]; tSIpre = winSIpre(1):dtLR:winSIpre(2); nSampSIpre = length(tSIpre);
winSIpost = [0 1]; tSIpost = winSIpost(1):dtLR:winSIpost(2); nSampSIpost = length(tSIpost);
winFP = [-1 1]; tFP = winFP(1):dtLR:winFP(2); nSampFP = length(tFP);

% reward rate (suffix: r = rewarded trials, n = unrewarded trials)
sR = cell(1,5);
sR{1} = nan(length(uPav), length(tLO));
sR{2} = nan(length(uPav), length(tCI));
sR{3} = nan(length(uPav), length(tGO));
sR{4} = nan(length(uPav), length(tCO));
sR{5} = nan(length(uPav), length(tSIpre));
sRr = cell(1,2);
sRr{1} = nan(length(uPav), length(tSIpost)); sRr{2} = nan(length(uPav), length(tFP));
sRn = cell(1,2);
sRn{1} = nan(length(uPav), length(tSIpost)); sRn{2} = nan(length(uPav), length(tFP));
pR = cell(1,5);
pR{1} = nan(length(uPav), length(tLO));
pR{2} = nan(length(uPav), length(tCI));
pR{3} = nan(length(uPav), length(tGO));
pR{4} = nan(length(uPav), length(tCO));
pR{5} = nan(length(uPav), length(tSIpre));
pRr = cell(1,2);
pRr{1} = nan(length(uPav), length(tSIpost)); pRr{2} = nan(length(uPav), length(tFP));
pRn = cell(1,2);
pRn{1} = nan(length(uPav), length(tSIpost)); pRn{2} = nan(length(uPav), length(tFP));

% choice (suffix: r = rewarded trials, n = unrewarded trials)
sC = cell(1,5);
sC{1} = nan(length(uPav), length(tLO));
sC{2} = nan(length(uPav), length(tCI));
sC{3} = nan(length(uPav), length(tGO));
sC{4} = nan(length(uPav), length(tCO));
sC{5} = nan(length(uPav), length(tSIpre));
sCr = cell(1,2);
sCr{1} = nan(length(uPav), length(tSIpost)); sCr{2} = nan(length(uPav), length(tFP));
sCn = cell(1,2);
sCn{1} = nan(length(uPav), length(tSIpost)); sCn{2} = nan(length(uPav), length(tFP));
pC = cell(1,4);
pC{1} = nan(length(uPav), length(tLO));
pC{2} = nan(length(uPav), length(tCI));
pC{3} = nan(length(uPav), length(tGO));
pC{4} = nan(length(uPav), length(tCO));
pC{5} = nan(length(uPav), length(tSIpre));
pCr = cell(1,2);
pCr{1} = nan(length(uPav), length(tSIpost)); pCr{2} = nan(length(uPav), length(tFP));
pCn = cell(1,2);
pCn{1} = nan(length(uPav), length(tSIpost)); pCn{2} = nan(length(uPav), length(tFP));

% movement (suffix: r = rewarded trials, n = unrewarded trials)
sM = cell(1,5);
sM{1} = nan(length(uPav), length(tLO));
sM{2} = nan(length(uPav), length(tCI));
sM{3} = nan(length(uPav), length(tGO));
sM{4} = nan(length(uPav), length(tCO));
sM{5} = nan(length(uPav), length(tSIpre));
sMr = cell(1,2);
sMr{1} = nan(length(uPav), length(tSIpost)); sMr{2} = nan(length(uPav), length(tFP));
sMn = cell(1,2);
sMn{1} = nan(length(uPav), length(tSIpost)); sMn{2} = nan(length(uPav), length(tFP));
pM = cell(1,4);
pM{1} = nan(length(uPav), length(tLO));
pM{2} = nan(length(uPav), length(tCI));
pM{3} = nan(length(uPav), length(tGO));
pM{4} = nan(length(uPav), length(tCO));
pM{5} = nan(length(uPav), length(tSIpre));
pMr = cell(1,2);
pMr{1} = nan(length(uPav), length(tSIpost)); pMr{2} = nan(length(uPav), length(tFP));
pMn = cell(1,2);
pMn{1} = nan(length(uPav), length(tSIpost)); pMn{2} = nan(length(uPav), length(tFP));

% coefficients of determination (suffix: R = rewarded trials, N = unrewarded trials)
r2Ord = cell(1,5);
r2Ord{1} = nan(length(uPav), length(tLO));
r2Ord{2} = nan(length(uPav), length(tCI));
r2Ord{3} = nan(length(uPav), length(tGO));
r2Ord{4} = nan(length(uPav), length(tCO));
r2Ord{5} = nan(length(uPav), length(tSIpre));
r2OrdR = cell(1,2);
r2OrdR{1} = nan(length(uPav), length(tSIpost)); r2OrdR{2} = nan(length(uPav), length(tFP));
r2OrdN = cell(1,2);
r2OrdN{1} = nan(length(uPav), length(tSIpost)); r2OrdN{2} = nan(length(uPav), length(tFP));
r2Adj = cell(1,5);
r2Adj{1} = nan(length(uPav), length(tLO));
r2Adj{2} = nan(length(uPav), length(tCI));
r2Adj{3} = nan(length(uPav), length(tGO));
r2Adj{4} = nan(length(uPav), length(tCO));
r2Adj{5} = nan(length(uPav), length(tSIpre));
r2AdjR = cell(1,2);
r2AdjR{1} = nan(length(uPav), length(tSIpost)); r2AdjR{2} = nan(length(uPav), length(tFP));
r2AdjN = cell(1,2);
r2AdjN{1} = nan(length(uPav), length(tSIpost)); r2AdjN{2} = nan(length(uPav), length(tFP));

altSes = 1:length(pavSes);
while any(altSes == 1:length(pavSes))
    altSes = randperm(length(pavSes));
end

cal = Calibrate([datRoot 'IM1178 accel calibration']);
cal0 = [cal.v0z1; cal.v0y1; cal.v0x1; cal.v0z2; cal.v0y2; cal.v0x2];
calM = [cal.mz1; cal.my1; cal.mx1; cal.mz2; cal.my2; cal.mx2];
for ses = 1:length(pavSes)
    
    disp(['session ' num2str(ses)])
    uIdx = find(strcmp(pavSes{ses}, uSes));
    u = uIdx(1);
    pavIdx = find(cellfun(@(t) strcmp(lower(t), 'pav'), unit(u).taskList));
    uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
    tEndPav = uTraj.times(end);
    
    % get RL behavior from an different session
    s2 = altSes(ses);
    uIdx = find(strcmp(pavSes{s2}, uSes));
    u = uIdx(1);
    rlIdx = find(cellfun(@(t) strcmp(lower(t), 'rl'), unit(u).taskList));
    ts = unit(u).behav_ts{rlIdx};
    trEnd = ts.firstFoodPoke + 1.1;
    trEnd(isnan(trEnd)) = ts.Side_NO(isnan(trEnd)) + 5;
    trList = find(trEnd - tEndPav < 0);
    nTr = length(trList);
    tr1 = 1;
    ts.choice = ts.choice(tr1:nTr);
    ts.outcome = ts.outcome(tr1:nTr);
    ts.trialbegin = ts.trialbegin(tr1:nTr);
    ts.Center_NI = ts.Center_NI(tr1:nTr);
    ts.Center_NO = ts.Center_NO(tr1:nTr);
    ts.go = ts.go(tr1:nTr);
    ts.Side_NI = ts.Side_NI(tr1:nTr);
    ts.firstFoodPoke = ts.firstFoodPoke(tr1:nTr);
    choice = ts.choice' ~= unit(u).side;
    tr = TrialFilter(ts, 'x1', unit(u).side)'; % rewarded trials
    tn = TrialFilter(ts, 'x0', unit(u).side)'; % unrewarded trials
    rr = rwdRate{find(strcmp(pavSes{s2}, sesList))}';
    rr = rr(tr1:nTr);
    nTr = length(ts.trialbegin);
    
    % load accelerometer data
    rat = uRat{u};
    accDir = dir([datRoot rat filesep pavSes{s2} filesep rat '-RL*']);
    if isempty(accDir)
        disp('** ERROR **')
        break
    end
    accDir = [accDir(1).folder filesep accDir(1).name];
    accLO = randn(nTr, length(tLO));
    accCI = randn(nTr, length(tCI));
    accGO = randn(nTr, length(tGO));
    accCO = randn(nTr, length(tCO));
    accSIpre = randn(nTr, length(tSIpre));
    accSIpost = randn(nTr, length(tSIpost));
    accFP = randn(nTr, length(tFP));
    t1 = ts.trialbegin + winLO(1) - 0.1;
    t2 = ts.firstFoodPoke + winFP(2) + 0.1;
    sni = ts.Side_NI;
    t2(isnan(t2)) = sni(isnan(t2)) + winSIpost(2) + 0.1;
    for k = 1:nTr
        if range([t1(k) t2(k)]) > 20
            continue
        end
        dat = LoadAuxData(accDir, 'timeRange', [t1(k) t2(k)]);
        dat.a = mean(abs((dat.a - cal0) .* calM));
        accLO(k,:) = interp1(dat.t-ts.trialbegin(k), dat.a, tLO);
        accCI(k,:) = interp1(dat.t-ts.Center_NI(k), dat.a, tCI);
        accGO(k,:) = interp1(dat.t-ts.go(k), dat.a, tGO);
        accCO(k,:) = interp1(dat.t-ts.Center_NO(k), dat.a, tGO);
        accSIpre(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpre);
        accSIpost(k,:) = interp1(dat.t-ts.Side_NI(k), dat.a, tSIpost);
         if ~isnan(ts.firstFoodPoke(k))
             accFP(k,:) = interp1(dat.t-ts.firstFoodPoke(k), dat.a, tFP);
         end
    end
    
    % loop through session units
    uIdx = find(strcmp(pavSes{ses}, uSes));
    for u = uIdx
        
        disp(['    unit ' num2str(u)])
        uTraj = LoadUnitTraj(unit(u), 'Pav', datRoot, 'sigma', 20);
        m = mean(uTraj.rate);
        sd = std(uTraj.rate);
        uTraj.rate = (uTraj.rate - m)/sd;
        
        % LO
        traj = TrajSplit(uTraj, ts, winLO, 'event', 1);
        rate = zeros(nTr, nSampLO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tLO);
        end
        for j = 1:nSampLO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accLO(tr1:end,j)], rate((tr1:end),j));
            sR{1}(u,j) = lm.Coefficients.Estimate(2);
            sC{1}(u,j) = lm.Coefficients.Estimate(3);
            sM{1}(u,j) = lm.Coefficients.Estimate(4);
            pR{1}(u,j) = lm.Coefficients.pValue(2);
            pC{1}(u,j) = lm.Coefficients.pValue(3);
            pM{1}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{1}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{1}(u,j) = lm.Rsquared.Ordinary;
        end
        
        % CI
        traj = TrajSplit(uTraj, ts, winCI, 'event', 2);
        rate = zeros(nTr, nSampCI);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tCI);
        end
        for j = 1:nSampCI
            lm = fitlm([rr(tr1:end), choice(tr1:end), accCI((tr1:end),j)], rate((tr1:end),j));
            sR{2}(u,j) = lm.Coefficients.Estimate(2);
            sC{2}(u,j) = lm.Coefficients.Estimate(3);
            sM{2}(u,j) = lm.Coefficients.Estimate(4);
            pR{2}(u,j) = lm.Coefficients.pValue(2);
            pC{2}(u,j) = lm.Coefficients.pValue(3);
            pM{2}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{2}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{2}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % GO
        traj = TrajSplit(uTraj, ts, winGO, 'event', 3);
        rate = zeros(nTr, nSampGO);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tGO);
        end
        for j = 1:nSampGO
            lm = fitlm([rr(tr1:end), choice(tr1:end), accGO((tr1:end),j)], rate((tr1:end),j));
            sR{3}(u,j) = lm.Coefficients.Estimate(2);
            sC{3}(u,j) = lm.Coefficients.Estimate(3);
            sM{3}(u,j) = lm.Coefficients.Estimate(4);
            pR{3}(u,j) = lm.Coefficients.pValue(2);
            pC{3}(u,j) = lm.Coefficients.pValue(3);
            pM{3}(u,j) = lm.Coefficients.pValue(4);
            r2Adj{3}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{3}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % pre-SI regression at SI
        traj = TrajSplit(uTraj, ts, [winSIpre(1) winSIpost(2)], 'event', 5);
        rate = zeros(nTr, nSampSIpre);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpre);
        end
        for j = 1:nSampSIpre
            lm = fitlm([rr(tr1:end), choice(tr1:end), accSIpre(tr1:end,j)], rate((tr1:end),j));
            sR{5}(u,j) = lm.Coefficients.Estimate(2);
            sC{5}(u,j) = lm.Coefficients.Estimate(3);
            pR{5}(u,j) = lm.Coefficients.pValue(2);
            pC{5}(u,j) = lm.Coefficients.pValue(3);
            r2Adj{5}(u,j) = lm.Rsquared.Adjusted;
            r2Ord{5}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % post-SI regression at SI, rewarded trials
        rate = zeros(nTr, nSampSIpost);
        for k = 1:nTr
            rate(k,:) = interp1(traj(k).times, traj(k).rate, tSIpost);
        end
        for j = 1:nSampSIpost
            lm = fitlm([rr(tr), choice(tr), accSIpost(tr,j)], rate(tr,j));
            sRr{1}(u,j) = lm.Coefficients.Estimate(2);
            sCr{1}(u,j) = lm.Coefficients.Estimate(3);
            sMr{1}(u,j) = lm.Coefficients.Estimate(4);
            pRr{1}(u,j) = lm.Coefficients.pValue(2);
            pCr{1}(u,j) = lm.Coefficients.pValue(3);
            pMr{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjR{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdR{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % SI - unrewarded trials
        for j = 1:nSampSIpost
            lm = fitlm([rr(tn), choice(tn), accSIpost(tn,j)], rate(tn,j));
            sRn{1}(u,j) = lm.Coefficients.Estimate(2);
            sCn{1}(u,j) = lm.Coefficients.Estimate(3);
            sMn{1}(u,j) = lm.Coefficients.Estimate(4);
            pRn{1}(u,j) = lm.Coefficients.pValue(2);
            pCn{1}(u,j) = lm.Coefficients.pValue(3);
            pMn{1}(u,j) = lm.Coefficients.pValue(4);
            r2AdjN{1}(u,j) = lm.Rsquared.Adjusted;
            r2OrdN{1}(u,j) = lm.Rsquared.Ordinary;
        end
    
        % FP - rewarded trials
        traj = TrajSplit(uTraj, ts, winFP, 'event', 6);
        fp = find(~isnan(ts.firstFoodPoke));
        [~,ftr] = ismember(tr, fp);
        [~,ftn] = ismember(tn, fp);
        ftr = ftr(ftr > 0);
        ftn = ftn(ftn > 0);
        if ~isempty(fp)
            rate = zeros(length(fp), nSampFP);
            for k = 1:length(fp)
                rate(k,:) = interp1(traj(fp(k)).times, traj(fp(k)).rate, tFP);
            end
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftr)), choice(fp(ftr)), accFP(ftr,j)], rate(ftr,j));
                sRr{2}(u,j) = lm.Coefficients.Estimate(2);
                sCr{2}(u,j) = lm.Coefficients.Estimate(3);
                sMr{2}(u,j) = lm.Coefficients.Estimate(4);
                pRr{2}(u,j) = lm.Coefficients.pValue(2);
                pCr{2}(u,j) = lm.Coefficients.pValue(3);
                pMr{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjR{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdR{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
    
        % FP - unrewarded trials
        if ~isempty(fp)
            for j = 1:nSampFP
                lm = fitlm([rr(fp(ftn)), choice(fp(ftn)), accFP(ftn,j)], rate(ftn,j));
                sRn{2}(u,j) = lm.Coefficients.Estimate(2);
                sCn{2}(u,j) = lm.Coefficients.Estimate(3);
                sMn{2}(u,j) = lm.Coefficients.Estimate(4);
                pRn{2}(u,j) = lm.Coefficients.pValue(2);
                pCn{2}(u,j) = lm.Coefficients.pValue(3);
                pMn{2}(u,j) = lm.Coefficients.pValue(4);
                r2AdjN{2}(u,j) = lm.Rsquared.Adjusted;
                r2OrdN{2}(u,j) = lm.Rsquared.Ordinary;
            end
        end
        
    end
    
end

save([datRoot 'rlLR shuffle3b.mat'], 'sR', 'sC', 'sRr', 'sRn', 'sCr', 'sCn',...
    'pR', 'pC', 'pRr', 'pRn', 'pCr', 'pCn', 'r2Ord', 'r2Adj', 'r2OrdR',...
    'r2AdjR', 'r2OrdN', 'r2AdjN', 'tLO', 'tCI', 'tGO', 'tCO', 'tSIpre', 'tSIpost')



