function Raster(unit, evt, tRange, varargin)

% Optional arguments

% 'fig', figure number for plotting over and existing figure

% default values for optional arguments
fig = [];
task = 'RL';        % only RL works for now
trials = {'xx'};
showEvents = false;
colors = {'r','b', 'g','c','m','y'};
tickWidth = 1.5;
tickSpread = 1.5;
nSamp = Inf;
zeroEvent = [];
order = [];
evtLineWidth = 1;
showEvtNames = false;

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'fig'
            fig = varargin{i+1};
        case 'task'
            task = varargin{i+1};
        case 'trials'
            trials = varargin{i+1};
        case 'tickwidth'
            tickWidth = varargin{i+1};
        case 'tickspread'
            tickSpread = varargin{i+1};
        case 'colors'
            colors = varargin{i+1};
        case 'nsamp'
            nSamp = varargin{i+1};
        case 'zeroevent'
            zeroEvent = varargin{i+1};
        case 'order'
            order = varargin{i+1};
        case 'eventlinewidth'
            evtLineWidth = varargin{i+1};
        case 'showeventnames'
            showEvtNames = varargin{i+1};
        case 'showevents'
            showEvents = varargin{i+1};
    end     
end

nCells = length(unit);
if ~iscell(trials)
    trials = {trials};
end
if ~iscell(colors)
    colors = {colors};
end
if ~isempty(order) & ~iscell(order)
    order = {order};
end
nTrialSpec = length(trials);
taskIdx = arrayfun(@(u) find(arrayfun(@(t) strcmp(lower(task), t), lower(u.taskList))), unit);

if ~isnumeric(evt)
    evt = EventNum(evt);
end

if isempty(zeroEvent)
    zeroEvent = evt;
elseif ~isnumeric(zeroEvent)
    zeroEvent = EventNum(zeroEvent);
end

% select/create figure
if isempty(fig)
    figure
else
    figure(fig)
end
set(gca, 'Box', 'on')
hold on
numColors = length(colors);

trNum = 0;
trNumOld = 0;
tickY = [0.5 -0.5] * tickSpread;
for u = 1:nCells
    
    b = unit(u).behav_ts{taskIdx(u)};
    spkTimes = unit(u).spkTimes;
    tsk = [unit(u).taskStart(taskIdx(u)) unit(u).taskEnd(taskIdx(u))];
    spkTimes = spkTimes(spkTimes >= tsk(1) & spkTimes <= tsk(2)) - tsk(1);
    
    for i = 1:nTrialSpec
        
        c = mod((u-1)*nTrialSpec+i - 1, numColors) + 1;
        if isstr(trials{i})
            tr = TrialFilter(b, trials{i}, unit(u).side);
        else
            tr = trials{i};
        end
        if ~isempty(order)
            tr = tr(order{i});
        else
            tr = randsample(tr, min(nSamp, length(tr)));
        end
        
        if strcmp(task, 'RL')
            eT = [b.trialbegin b.Center_NI b.go b.Center_NO b.Side_NI b.Side_NO b.firstFoodPoke];
        else
            eT = [b.csTime b.rwdTime];
        end
        t0 = eT(tr, zeroEvent);
        if any(isnan(t0))
            [~, iSort] = sort(isnan(t0));
            t0 = t0(iSort);
            tr = tr(iSort);
        end
        
        % plot spike ticks
        for k = 1:length(tr)
            trNum = trNum - 1;
            tSnip = [eT(tr(k), evt(1)) eT(tr(k), evt(end))] + tRange;
            if isnan(t0(k))
                spk = [];  
            else
                spk = spkTimes(spkTimes >=tSnip(1) & spkTimes <= tSnip(2)) - t0(k);
            end
            for s = spk
                line([s s], trNum + 0.5 + tickY, 'color', colors{c}, 'LineWidth', tickWidth); 
            end
        end
        
        % plot events
        if showEvents
            eT = bsxfun(@minus, eT, eT(:, zeroEvent));
            evtStyle = cell(1, size(eT,2));
            for e = 1:size(eT,2)
                if all(eT(1,e) == eT(:,e))
                    evtStyle{e} = '-';
                else
                    evtStyle{e} = '--';
                end
            end
            eT = mean(eT);
            eNames = EventNum(1:7);
            del = eT < tRange(1) | eT > tRange(2);
            eT(del) = [];
            evtStyle(del) = [];
            eNames(del) = [];
            for e = 1:length(eT)
                plot([eT(e) eT(e)], [trNum trNumOld], 'color', 'k', 'lineStyle', evtStyle{e}, 'lineWidth', evtLineWidth)
                if u==1 & i==1 & showEvtNames
                    text(eT(e), 0, eNames{e}, 'VerticalAlignment', 'bottom', 'HorizontalAlignment', 'center', 'BackgroundColor', 'w', 'EdgeColor', 'k')
                end
            end
        end
        
        trNumOld = trNum;
    end
end




% evtDat = [];
% yMin = 0;
% 
% if ~iscell(trialDat)
%     trialDat = {trialDat};
% end
% nGroups = length(trialDat);
% 
% trNum = 0;
% xMin = 0;
% xMax = 0;
% groupEnd = -ones(1,nGroups);
% for j = 1:nGroups
%     
%     c = mod(j - 1, numColors) + 1;
%     nTr = length(trialDat{j});
%     if j > 1
%         groupEnd(j) = groupEnd(j-1) - nTr;
%     else
%         groupEnd(j) = -nTr;
%     end
%     for k = 1:nTr
%         trNum = trNum - 1;
%         spk = trialDat{j}(k).spkTimes;
%         spk = spk(spk > plotRange(1) & spk < plotRange(2));
%         for i = 1:length(spk)
%            line([spk(i) spk(i)],trNum + 0.5 + tickY, 'color', tickColor{c}, 'LineWidth', tickWidth); 
%         end
% 
%     end
%     
% end


axis([tRange trNum 0]);
set(gca,'YTick',[]);

