
function log = ReadBehavLog(logFile, task)

scanRL1 = 'Subject:%s Date:%s Time:%s Attempt:%u16 Trial:%u16 Food:%u16 Block:%u16 Block trial:%u16 Center:%u8 Port poked:%u16 RT:%u16 MT:%u16 PreT:%u16 ResponseLimit:%u16 TrPerBlock:%u16 FalseStart:%u16 WrongStart:%u16 FailureToRespond:%u16 Prob Left:%u16 Prob Right:%u16 Target Poke:%u16 CNI Latency:%u16 ITI:%u16 ';
scanRL2 = 'Subject:%s Date:%s Time:%s Attempt:%u16 Trial:%u16 Food:%u16 Block:%u16 Block trial:%u16 Center:%u8 Port poked:%u16 RT:%u16 MT:%u16 PreT:%u16 ResponseLimit:%u16 TrPerBlock:%u16 FalseStart:%u16 WrongStart:%u16 FailureToRespond:%u16 Prob Left:%u16 Prob Right:%u16 Target Poke:%u16 CNI Latency:%u16 SI Duration:%u16 ITI:%u16 TTR:%u16 Laser stim freq:%u16 Number of pulses:%u16 Pulse width:%u16 Amplitude:%u16 Blue laser LIM:%u16 Laser trail code:%u16';
scanLaser = 'Pulse Width:%f Frequency: %f Count: %f Voltage: %f Current: %f';


switch lower(task)
    
    case 'laser'
        
        % read data from log file
        fid = fopen(logFile);
        tmp = textscan(fid, scanLaser, 'MultipleDelimsAsOne', 1);
        fclose(fid);
        
        % parse logfile data
        nBlockLaser = length(tmp{1});
        for n = 1:nBlockLaser
            log(n).duration = tmp{1}(n);
            log(n).frequency = tmp{2}(n);
            log(n).count = tmp{3}(n);
            log(n).voltage = tmp{4}(n);
            log(n).current = tmp{5}(n);
        end
        
    case 'rl'
        
        % read data from log file
        fid = fopen(logFile);
        tmp = textscan(fid, scanRL1, 'MultipleDelimsAsOne', 1);
        if length(tmp{1}) < 2
            fseek(fid, 0, 'bof');
            tmp = textscan(fid, scanRL2, 'MultipleDelimsAsOne', 1);
        end
        fclose(fid);
        
        % parse logfile data
        time = tmp{3};
        trialNum = double(tmp{5});
        cumRwd = double(tmp{6});
        block = double(tmp{7});
        centerPort = double(tmp{9});
        portPoked = double(tmp{10});
        ReactionTime = double(tmp{11});
        MovementTime = double(tmp{12});
        falseStart = double(tmp{16});
        wrongStart = double(tmp{17});
        failureToRespond = double(tmp{18});
        probLeft = double(tmp{19});
        probRight = double(tmp{20});
        CNIlatency = double(tmp{22});

        % extract time for each attempt, in sec, relative to 1st attempt
        timeDat = zeros(length(time), 3);
        for i = 1:length(time)
            timeDat(i,:) = [3600 60 1] .* cellfun(@(s) str2num(s), strsplit(time{i},':'));
        end
        midnight = find(diff(timeDat(:,1)) < 0);
        timeDat(midnight:end,1) = timeDat(midnight:end,1) + 24*3600;

        % compile info about all attempts (valid trial or not)
        trialLoc = find(diff([0; trialNum]) == 1);
        nBlockAttempts = diff([0; find(diff(block) == 1); length(centerPort)]);
        attemptData.nBlockAttempts = nBlockAttempts;
        attemptData.blockNum = [];
        attemptData.blockAttempt = [];
        for i = 1:length(nBlockAttempts)
            attemptData.blockNum = [attemptData.blockNum; i*ones(nBlockAttempts(i), 1)];
            attemptData.blockAttempt = [attemptData.blockAttempt; (1:nBlockAttempts(i))'];
        end
        attemptData.time = sum(timeDat,2) - sum(timeDat(1,:));
        attemptData.validTrial = trialLoc;
        attemptData.falseStart = find(diff([0; falseStart]) == 1);
        % logged "wrong starts" don't necessarily contain all wrong starts; some
        % pokes in the center port yield invalid trials without being logged as
        % wrong starts. The line below fixs this.
        % ** make new category for this kind of error--'wrongChoice' **
        attemptData.wrongStart = union(find(diff([0; wrongStart]) == 1), find(portPoked == centerPort));
        attemptData.failureToRespond =  find(diff([0; failureToRespond]) == 1);
        attemptData.centerPort = centerPort;
        attemptData.portPoked = portPoked;
        attemptData.ReactionTime = ReactionTime;
        attemptData.MovementTime = MovementTime;
        log.attemptData = attemptData;

        % compile info about valid trials
        log.TrialNumber = trialNum(trialLoc);
        pL = probLeft(trialLoc);
        pR = probRight(trialLoc);
        blockEnds = [find(diff(pL)~=0 | diff(pR)~=0); length(trialLoc)];
        blockStarts = [1; blockEnds(1:end-1) + 1];
        log.nBlockTrials = blockEnds - blockStarts + 1;
        log.blockNum = zeros(length(trialLoc), 1);
        log.blockTrial = zeros(length(trialLoc), 1);
        for i = 1:length(blockStarts)
            log.blockNum(blockStarts(i):blockEnds(i)) = i;
            log.blockTrial(blockStarts(i):blockEnds(i)) = (1:log.nBlockTrials(i))';
        end
        log.centerPort = centerPort(trialLoc);
        log.R_choice = portPoked(trialLoc) > centerPort(trialLoc);
        log.L_choice = portPoked(trialLoc) < centerPort(trialLoc);
        log.outcome = logical(diff([0; cumRwd(trialLoc)]));
        log.block_probabilities = [pL pR] / 100;
        log.ReactionTime = ReactionTime(trialLoc);
        log.MovementTime = MovementTime(trialLoc);
        log.CNIlatency = CNIlatency(trialLoc);
        
    case 'pav'
        
        % read data from log file
        fid = fopen(logFile);
        tmp1 = textscan(fid, 'Tone:%f \\  Prob:%f ','MultipleDelimsAsOne',1);
        tmp2 = textscan(fid, 'Subject:%s Date:%s Time:%s Tone Freq:%f CS duration:%f Rew Foreperiod:%f Food:  %f Latency: %f Trial Length:%f','MultipleDelimsAsOne',1);
        fclose(fid);
        
        % parse logfile data
        log.cueRwdTable(:,1) = tmp1{1};
        log.cueRwdTable(:,2) = tmp1{2};
        time = tmp2{3};
        timeDat = zeros(length(time), 3);
        for i = 1:length(time)
            timeDat(i,:) = [3600 60 1] .* cellfun(@(s) str2num(s), strsplit(time{i},':'));
        end
        midnight = find(diff(timeDat(:,1)) < 0);
        timeDat(midnight:end,1) = timeDat(midnight:end,1) + 24*3600;
        log.time = sum(timeDat,2) - sum(timeDat(1,:));
        log.toneFreq = tmp2{4};
        log.toneDur = tmp2{5} / 1000;
        log.rewForeperiod = tmp2{6} / 1000;
        log.outcome = logical(tmp2{7});
        log.latency = tmp2{8}/1000;
        log.trialDur = tmp2{9};
        
end