function tag = TagCheck(laserResponse, varargin)

altIsi = [];
sampPerSec = 500;
responseWin = 10; % milliseconds
makePlot = false;
ctrlIsi = [];
fig = [];

for i = 1:2:length(varargin)
    switch lower(varargin{i})
        case 'isi'
            altIsi = varargin{i+1};
        case 'responsewin'
            responseWin = varargin{i+1};
        case  'combineisi'
            ctrlIsi = varargin{i+1};
        case  'ctrlisi'
            ctrlIsi = varargin{i+1};
        case  'poolisi'
            ctrlIsi = varargin{i+1};
        case 'makeplot'
            makePlot = varargin{i+1};
        case 'fig'
            fig = varargin{i+1};
    end
end

if ~isfield(laserResponse, 'block')
    lr.block = {laserResponse};
    laserResponse = lr;
end

altLat = [];
if ~isempty(altIsi)
    for i = altIsi
        nSamp = poissrnd(i * sampPerSec);
        altLat = [altLat i * rand(1, nSamp)];
    end
end

if isempty(altLat) & ~isempty(ctrlIsi)
    for i = 1:length(laserResponse.block)
        for j = 1:length(laserResponse.block{i})
            altIsi = [altIsi laserResponse.block{i}(j).preIsi];
            altIsi = [altIsi laserResponse.block{i}(j).postIsi];
        end
    end
    for i = altIsi
        nSamp = poissrnd(i * sampPerSec);
        altLat = [altLat i * rand(1, nSamp)];
    end
end

tag = [];
for i = 1:length(laserResponse.block)
    for j = 1:length(laserResponse.block{i})
        tg.laserPower = laserResponse.block{i}(j).laserPower;
        tg.pulseDur = laserResponse.block{i}(j).pulseDur(1);
        tg.numPulses = length(laserResponse.block{i}(j).pulseOnset);
        if isempty(altLat)
            nullLat = [];
            for s = laserResponse.block{i}(j).preIsi
                nSamp = poissrnd(s * sampPerSec);
                nullLat = [nullLat s * rand(1, nSamp)];
            end
        else
            nullLat = altLat;
        end
        maxLat = 1 / laserResponse.block{i}(j).pulseFrequency;
        nullLat = 1000 * nullLat(nullLat < maxLat);
        lat = laserResponse.block{i}(j).latency;
        tg.truncationFrac = length(find(isnan(lat))) / tg.numPulses;
        lat = 1000 * lat(~isnan(lat));
        tg.latency = lat;
        tg.medianLat = median(lat);
        tg.deltaLat = (median(lat) - median(nullLat));
        tg.nullLat = nullLat;
        tg.responseWin = responseWin;
        tg.reliability = length(find(lat < responseWin)) / tg.numPulses;
        tg.jitter = std(lat);
        if length(lat) > 0 & length(nullLat > 0)
            tg.pVal = ranksum(lat, nullLat);
        else
            tg.pVal = 1;
        end
        nullIsi = zeros(1, tg.numPulses); % estimate of ISI without stim
        if isempty(altIsi)
            isi = laserResponse.block{i}(j).preIsi;
        else
            isi = altIsi;
        end
        for k = 1:tg.numPulses
            nullIsi(k) = mean(isi(isi > laserResponse.block{i}(j).negLat(k)));
        end
        tg.ctrlIsi = 1000*isi;
        mask = cellfun(@(isi) ~isempty(isi), laserResponse.block{i}(j).responseIsi);
        tg.isi1 = 1000*cellfun(@(isi) isi(1), laserResponse.block{i}(j).responseIsi(mask));
        tg.nullIsi = 1000*nullIsi;
        tag = [tag tg];
        if makePlot
            str = [num2str(tg.pulseDur) ' ms pulses,' num2str(tg.laserPower) ' mW'];
            if isempty(fig)
                figure('Name', str)
            else
                figure(fig)
            end
            hold on
            plot(sort(nullLat), (1:length(nullLat)) / length(nullLat), 'color', 'b', 'linewidth', 2)
            plot(sort(lat), (1:length(lat)) / length(lat), 'color', 'r', 'linewidth', 2)
            title(['delta lat: ' num2str(tg.deltaLat) ' ms, p = ' num2str(tg.pVal)])
        end
            
    end    
end