function [wakeTimes swsTimes] = WakeTimes(sleepLog, unit)

% define time intervals (in seconds) between "disenaged wakefulness" and major events
postSni = 10;
preCni = 5;
postUs = 10;
preCs = 0;
postHvs = 10;
preHvs = 10;
postSws = 10;
preSws = 10;

minWake = 30;

% unpack behavior data
taskList = unit.taskList;
tmpList = cellfun(@(t) strsplit(t, '-'), taskList, 'UniformOutput', false);
tmpList = cellfun(@(t) t{1}, tmpList, 'UniformOutput', false);
tsBehav = unit.behav_ts;
taskStart = unit.taskStart;
taskEnd = unit.taskEnd;

% logical array defining wake time
wake = true(1, ceil(max(taskEnd)));

% eliminate artificial time between tasks
for i = 2:length(taskList)
    wake(floor(taskEnd(i-1)):ceil(taskStart(i))) = false;
end

% eliminate any behavior epochs that aren't RL, Pav, or sleep
badTasks = find(~ismember(lower(tmpList), {'rl', 'pav', 'sleep'}));
if iscolumn(badTasks)
    badTasks = badTasks';
end
for i = badTasks
    wake(floor(taskStart(i)):ceil(taskEnd(i))) = false;
end
taskList(badTasks) = [];
tsBehav(badTasks) = [];
taskStart(badTasks) = [];
taskEnd(badTasks) = [];

% eliminate segments too close to a RL event
[~, i] = ismember('rl', lower(taskList));
tSni = ceil(tsBehav{i}.Side_NI + taskStart(i));
tCni = floor(tsBehav{i}.Center_NI + taskStart(i));
for k = 1:length(tSni)
    wake(tCni(k)-preCni:tSni(k)+postSni) = false;
end
j = find(arrayfun(@(s) strcmp(lower(s.task), 'rl'), sleepLog));
hvs = round(sleepLog(j).hvs + taskStart(i));
hvs(hvs(:,1) <= preHvs, 1) = preHvs + 1; 
hvs(hvs(:,2) >= length(wake) - postHvs, 2) = length(wake) - postHvs - 1;
for k = 1:size(hvs,1)
    wake(hvs(k,1)-preHvs:hvs(k,2)+postHvs) = false;
end
sws = round(sleepLog(j).rawSws + taskStart(i));
for k = 1:size(sws,1)
    wake(sws(k,1)-preSws:sws(k,2)+postSws) = false;
end

% eliminate segments too close to a Pav event
[~, i] = ismember('pav', lower(taskList));
if i ~= 0
    tCs = floor(tsBehav{i}.csTime + taskStart(i));
    rwdTime = nanmean(tsBehav{i}.rwdTime - tsBehav{i}.csTime);
    tUs = ceil(tsBehav{i}.csTime + rwdTime);
    for k = 1:length(tCs)
        wake(tCs(k)-preCs:tUs(k)+postUs) = false;
    end
    j = find(arrayfun(@(s) strcmp(lower(s.task), 'pav'), sleepLog));
    hvs = round(sleepLog(j).hvs + taskStart(i));
    for k = 1:size(hvs,1)
        wake(hvs(k,1)-preHvs:hvs(k,2)+postHvs) = false;
    end
    sws = round(sleepLog(j).rawSws + taskStart(i));
    for k = 1:size(sws,1)
        wake(sws(k,1)-preSws:sws(k,2)+postSws) = false;
    end
end

% eliminate segments too close to a sleep event
[~, i] = ismember('sleep', lower(taskList));
if i ~= 0
    j = find(arrayfun(@(s) strcmp(lower(s.task), 'sleep'), sleepLog));
    hvs = round(sleepLog(j).hvs + taskStart(i));
    for k = 1:size(hvs,1)
        wake(hvs(k,1)-preHvs:hvs(k,2)+postHvs) = false;
    end
    sws = round(sleepLog(j).rawSws + taskStart(i));
    for k = 1:size(sws,1)
        wake(sws(k,1)-preSws:sws(k,2)+postSws) = false;
    end
end

% convert wake logical array to list of wake times
deltaWake = diff(wake);
wakeStart = find(deltaWake == 1) + 1;
if wake(1)
    wakeStart = [1 wakeStart];
end
wakeEnd = find(deltaWake == -1) - 1;
if wake(end)
    wakeEnd = [wakeEnd length(wake) - 1];
end
wakeTimes = [wakeStart' wakeEnd'];
wakeDur = arrayfun(@(i) diff(wakeTimes(i,:)), 1:size(wakeTimes,1));
keepLoc = find(wakeDur > minWake);
wakeTimes = wakeTimes(keepLoc, :);

% compile SWS times across tasks
swsTimes = [];
for i = 1:length(taskList)
    j = find(arrayfun(@(s) strcmp(lower(s.task), lower(taskList{i})), sleepLog));
    swsTimes = [swsTimes; round(sleepLog(j).rawSws + taskStart(i))];
end