%% choose session
datRoot = '/Volumes/LaCie/Farries recordings/';
rat = 'IM1055';
sesList = dir([datRoot rat '/20*']);
sesList = arrayfun(@(x) x.name, sesList, 'UniformOutput', false)

iSes = 10;
sesDir = [datRoot rat filesep sesList{iSes} filesep]

% load behavior data
load([sesDir 'behavior - RL.mat'])
nTr = length(tsRL.attemptNumber);
laserAttempt = find(arrayfun(@(a) ~isempty(a.laserOn), tsRL.attempt));
laserValidAttempt = intersect(laserAttempt, tsRL.attemptNumber);
[~, laserTrial] = ismember(laserValidAttempt, tsRL.attemptNumber);
ctrlTrial = setdiff(1:nTr, laserTrial);
laserOn = arrayfun(@(a) a.laserOn, tsRL.attempt(laserValidAttempt));
pulseDur = median(arrayfun(@(a) a.laserOff, tsRL.attempt(laserValidAttempt)) - laserOn);
laserOn = tsRL.trialbegin(laserTrial)' + laserOn;
laserDelay = 0.25;

rwd = TrialFilter(tsRL, 'x1', 'L');
noRwd = TrialFilter(tsRL, 'x0', 'L');
prevRwd = TrialFilter(tsRL, 'x1xx', 'L');
prevNoRwd = TrialFilter(tsRL, 'x0xx', 'L');
prevLaser = setdiff(laserTrial+1, nTr+1);
prevCtrl = setdiff(ctrlTrial+1, nTr+1);
rwdLaser = intersect(prevRwd, prevLaser);
rwdCtrl = intersect(prevRwd, prevCtrl);
noRwdLaser = intersect(prevNoRwd, prevLaser);
noRwdCtrl = intersect(prevNoRwd, prevCtrl);

lat = tsRL.Center_NI - tsRL.trialbegin;
rt = tsRL.Center_NO - tsRL.go;
mt = tsRL.Side_NI - tsRL.Center_NO;
ft = tsRL.firstFoodPoke - tsRL.Side_NO;


%% analysis of latency

latLaser = lat(prevLaser);
latCtrl = lat(prevCtrl);
latRwd = lat(prevRwd);
latNoRwd = lat(prevNoRwd);
latRwdLaser = lat(rwdLaser);
latRwdCtrl = lat(rwdCtrl);
latNoRwdLaser = lat(noRwdLaser);
latNoRwdCtrl = lat(noRwdCtrl);

% overall effect of laser on latency of next trial
tmp = sort(latCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on latency (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(log(tmp), (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(latLaser);
plot(log(tmp), (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(latCtrl)
mean(latLaser)
ranksum(log(latCtrl), log(latLaser))
xlabel('log(latency)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([-4 4])
set(gca, 'XTick', -4:2:4)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% overall effect of reward on latency of next trial
tmp = sort(latNoRwd);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on latency (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(log(tmp), (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(latRwd);
plot(log(tmp), (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(latNoRwd)
mean(latRwd)
ranksum(log(latNoRwd), log(latRwd))

% effect of reward on latency of next trial (no laser)
tmp = sort(latNoRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on latency (control trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(log(tmp), (1:length(tmp))/length(tmp), 'b', 'LineWidth', 3)
hold on
tmp = sort(latRwdCtrl);
plot(log(tmp), (1:length(tmp))/length(tmp), 'r', 'LineWidth', 3)
mean(latNoRwdCtrl)
mean(latRwdCtrl)
ranksum(log(latNoRwdCtrl), log(latRwdCtrl))
xlabel('log(latency)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([-4 4])
set(gca, 'XTick', -4:2:4)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)


% effect of laser on latency following rewarded trials
tmp = sort(latRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on latency (rewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(log(tmp), (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(latRwdLaser);
plot(log(tmp), (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(latRwdCtrl)
mean(latRwdLaser)
ranksum(log(latRwdCtrl), log(latRwdLaser))
xlabel('log(latency)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([-4 4])
set(gca, 'XTick', -4:2:4)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of laser on latency following unrewarded trials
tmp = sort(latNoRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on latency (unrewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(log(tmp), (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(latNoRwdLaser);
plot(log(tmp), (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(latNoRwdCtrl)
mean(latNoRwdLaser)
ranksum(log(latNoRwdCtrl), log(latNoRwdLaser))
xlabel('log(latency)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([-4 4])
set(gca, 'XTick', -4:2:4)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of reward on latency of next trial (with laser)
tmp = sort(latNoRwdLaser);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on latency (laser trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(log(tmp), (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(latRwdLaser);
plot(log(tmp), (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(latNoRwdLaser)
mean(latRwdLaser)
ranksum(log(latNoRwdLaser), log(latRwdLaser))
xlabel('log(latency)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([-4 4])
set(gca, 'XTick', -4:2:4)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

%% analysis of reaction time

rtLaser = rt(prevLaser);
rtCtrl = rt(prevCtrl);
rtRwd = rt(prevRwd);
rtNoRwd = rt(prevNoRwd);
rtRwdLaser = rt(rwdLaser);
rtRwdCtrl = rt(rwdCtrl);
rtNoRwdLaser = rt(noRwdLaser);
rtNoRwdCtrl = rt(noRwdCtrl);

% overall effect of laser on reaction time of next trial
tmp = sort(rtCtrl)*1000;
titleStr = [rat ', ' sesList{iSes} ': effect of laser on reaction time (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(rtLaser)*1000;
plot(tmp, (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(rtCtrl)*1000
mean(rtLaser)*1000
ranksum(rtCtrl, rtLaser)
xlabel('reaction time (ms)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 1000])
set(gca, 'XTick', 0:200:1000)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% overall effect of reward on reaction time of next trial
tmp = sort(rtNoRwd);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on reaction time (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(rtRwd);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(rtNoRwd)*1000
mean(rtRwd)*1000
ranksum(rtNoRwd, rtRwd)

% effect of reward on reaction time of next trial (no laser)
tmp = sort(rtNoRwdCtrl)*1000;
titleStr = [rat ', ' sesList{iSes} ': effect of reward on reaction time (control trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 3)
hold on
tmp = 1000*sort(rtRwdCtrl);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 3)
mean(rtNoRwdCtrl)*1000
mean(rtRwdCtrl)*1000
ranksum(rtNoRwdCtrl, rtRwdCtrl)
xlabel('reaction time (ms)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 1000])
set(gca, 'XTick', 0:200:1000)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of laser on reaction time following rewarded trials
tmp = sort(rtRwdCtrl)*1000;
titleStr = [rat ', ' sesList{iSes} ': effect of laser on reaction time (rewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(rtRwdLaser)*1000;
plot(tmp, (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(rtRwdCtrl)
mean(rtRwdLaser)
ranksum(rtRwdCtrl, rtRwdLaser)
xlabel('reaction time (ms)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 1000])
set(gca, 'XTick', 0:200:1000)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of laser on reaction time following unrewarded trials
tmp = sort(rtNoRwdCtrl)*1000;
titleStr = [rat ', ' sesList{iSes} ': effect of laser on reaction time (unrewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(rtNoRwdLaser)*1000;
plot(tmp, (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(rtNoRwdCtrl)
mean(rtNoRwdLaser)
ranksum(rtNoRwdCtrl, rtNoRwdLaser)
xlabel('reaction time (ms)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 1000])
set(gca, 'XTick', 0:200:1000)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of reward on reaction time of next trial (with laser)
tmp = sort(rtNoRwdLaser);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on reaction time (laser trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(rtRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(rtNoRwdLaser)
mean(rtRwdLaser)
ranksum(rtNoRwdLaser, rtRwdLaser)

%% analysis of movement time

mtLaser = mt(prevLaser);
mtCtrl = mt(prevCtrl);
mtRwd = mt(prevRwd);
mtNoRwd = mt(prevNoRwd);
mtRwdLaser = mt(rwdLaser);
mtRwdCtrl = mt(rwdCtrl);
mtNoRwdLaser = mt(noRwdLaser);
mtNoRwdCtrl = mt(noRwdCtrl);

% overall effect of laser on movement time of next trial
tmp = sort(mtCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on movement time (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(mtLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(mtCtrl)
mean(mtLaser)
ranksum(mtCtrl, mtLaser)

% overall effect of reward on movement time of next trial
tmp = sort(mtNoRwd);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on movement time (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(mtRwd);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(mtNoRwd)
mean(mtRwd)
ranksum(mtNoRwd, mtRwd)

% effect of reward on movement time of next trial (no laser)
tmp = sort(mtNoRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on movement time (control trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(mtRwdCtrl);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(mtNoRwdCtrl)
mean(mtRwdCtrl)
ranksum(mtNoRwdCtrl, mtRwdCtrl)

% effect of laser on movement time following rewarded trials
tmp = sort(mtRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on movement time (rewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(mtRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(mtRwdCtrl)
mean(mtRwdLaser)
ranksum(mtRwdCtrl, mtRwdLaser)

% effect of laser on movement time following unrewarded trials
tmp = sort(mtNoRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on movement time (unrewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(mtNoRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(mtNoRwdCtrl)
mean(mtNoRwdLaser)
ranksum(mtNoRwdCtrl, mtNoRwdLaser)

% effect of reward on movement time of next trial (with laser)
tmp = sort(mtNoRwdLaser);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on movement time (laser trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(mtRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(mtNoRwdLaser)
mean(mtRwdLaser)
ranksum(mtNoRwdLaser, mtRwdLaser)

%% analysis of time to food port

ftLaser = ft(laserTrial);
visit = ~isnan(ftLaser);
visitLaser = length(ftLaser(visit)) / length(ftLaser);
ftLaser = ftLaser(visit);

ftCtrl = ft(ctrlTrial);
visit = ~isnan(ftCtrl);
visitCtrl = length(ftCtrl(visit)) / length(ftCtrl);
ftCtrl = ftCtrl(visit);

ftRwd = ft(rwd);
visit = ~isnan(ftRwd);
visitRwd = length(ftRwd(visit)) / length(ftRwd);
ftRwd = ftRwd(visit);

ftNoRwd = ft(noRwd);
visit = ~isnan(ftNoRwd);
visitNoRwd = length(ftNoRwd(visit)) / length(ftNoRwd);
ftNoRwd = ftNoRwd(visit);

ftRwdLaser = ft(intersect(rwd, laserTrial));
visit = ~isnan(ftRwdLaser);
visitRwdLaser = length(ftRwdLaser(visit)) / length(ftRwdLaser);
ftRwdLaser = ftRwdLaser(visit);

ftRwdCtrl = ft(intersect(rwd, ctrlTrial));
visit = ~isnan(ftRwdCtrl);
visitRwdCtrl = length(ftRwdCtrl(visit)) / length(ftRwdCtrl);
ftRwdCtrl = ftRwdCtrl(visit);

ftNoRwdLaser = ft(intersect(noRwd, laserTrial));
visit = ~isnan(ftNoRwdLaser);
visitNoRwdLaser = length(ftNoRwdLaser(visit)) / length(ftNoRwdLaser);
ftNoRwdLaser = ftNoRwdLaser(visit);

ftNoRwdCtrl = ft(intersect(noRwd, ctrlTrial));
visit = ~isnan(ftNoRwdCtrl);
visitNoRwdCtrl = length(ftNoRwdCtrl(visit)) / length(ftNoRwdCtrl);
ftNoRwdCtrl = ftNoRwdCtrl(visit);

% overall effect of laser on time to food port
tmp = sort(ftCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on food port latency (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(ftLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(ftCtrl)
mean(ftLaser)
ranksum(ftCtrl, ftLaser)

% overall effect of reward on food port latency
tmp = sort(ftNoRwd);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on food port latency (all trials)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(ftRwd);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(ftNoRwd)
mean(ftRwd)
ranksum(ftNoRwd, ftRwd)

% effect of reward on food port latency (no laser)
tmp = sort(ftNoRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on food port latency (control trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 3)
hold on
tmp = sort(ftRwdCtrl);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 3)
mean(ftNoRwdCtrl)
mean(ftRwdCtrl)
ranksum(ftNoRwdCtrl, ftRwdCtrl)
xlabel('time to food port entry (sec)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 6])
set(gca, 'XTick', 0:6)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of laser on food port latency on rewarded trials
tmp = sort(ftRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on food port latency (rewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(ftRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(ftRwdCtrl)
mean(ftRwdLaser)
ranksum(ftRwdCtrl, ftRwdLaser)
xlabel('time to food port entry (sec)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 6])
set(gca, 'XTick', 0:6)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of laser on food port latency on unrewarded trials
tmp = sort(ftNoRwdCtrl);
titleStr = [rat ', ' sesList{iSes} ': effect of laser on food port latency (unrewarded trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'k', 'LineWidth', 3)
hold on
tmp = sort(ftNoRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'color', [0 0.75 0], 'LineWidth', 3)
mean(ftNoRwdCtrl)
mean(ftNoRwdLaser)
ranksum(ftNoRwdCtrl, ftNoRwdLaser)
xlabel('time to food port entry (sec)')
ylabel('fraction < x')
set(gca, 'Box', 'off')
xlim([0 6])
set(gca, 'XTick', 0:6)
set(gca, 'YTick', 0:0.2:1)
set(gca, 'FontSize', 12)

% effect of reward on food port latency (with laser)
tmp = sort(ftNoRwdLaser);
titleStr = [rat ', ' sesList{iSes} ': effect of reward on food port latency (laser trials only)'];
figure('Name', titleStr, 'NumberTitle', 'off');
plot(tmp, (1:length(tmp))/length(tmp), 'b', 'LineWidth', 2)
hold on
tmp = sort(ftRwdLaser);
plot(tmp, (1:length(tmp))/length(tmp), 'r', 'LineWidth', 2)
mean(ftNoRwdLaser)
mean(ftRwdLaser)
ranksum(ftNoRwdLaser, ftRwdLaser)

%% analysis of choice behavior

win = TrialFilter(tsRL, 'x1xx', 'L');
lose = TrialFilter(tsRL, 'x0xx', 'L');
winStayR = TrialFilter(tsRL, 'R1Rx', 'L');
winShiftR = TrialFilter(tsRL, 'R1Lx', 'L');
winStayL = TrialFilter(tsRL, 'L1Lx', 'L');
loseShiftR = TrialFilter(tsRL, 'R0Lx', 'L');
loseShiftL = TrialFilter(tsRL, 'L0Rx', 'L');

pWinStay = (length(winStayR) + length(winStayL)) / length(win);
pLoseShift = (length(loseShiftR) + length(loseShiftL)) / length(lose)

winLaser = intersect(win, prevLaser);
winCtrl = intersect(win, prevCtrl);
loseLaser = intersect(lose, prevLaser);
loseCtrl = intersect(lose, prevCtrl);

pWinStayCtrl = (length(intersect(winStayR, prevCtrl)) + length(intersect(winStayL, prevCtrl)) + 1) / (length(winCtrl) + 2);
stay = length(intersect(winStayR, prevCtrl)) + length(intersect(winStayL, prevCtrl));
shift = length(winCtrl) - stay;
x = 0:0.002:1;
figure
plot(x, betapdf(x, stay+1, shift+1), 'k', 'LineWidth', 3)
hold on
pWinStayLaser = (length(intersect(winStayR, prevLaser)) + length(intersect(winStayL, prevLaser)) + 1) / (length(winLaser) + 2);
stay = length(intersect(winStayR, prevLaser)) + length(intersect(winStayL, prevLaser))
shift = length(winLaser) - stay;
plot(x, betapdf(x, stay+1, shift+1), 'color', [0 0.75 0], 'LineWidth', 3)
y = ylim;
plot([pWinStayCtrl pWinStayCtrl], y, '--', 'color', 'k', 'LineWidth', 2)
plot([pWinStayLaser pWinStayLaser], y, '--', 'color', [0 0.75 0], 'LineWidth', 2)
xlabel('prob(stay|win)')
set(gca, 'Box', 'off')
xlim([0 1])
set(gca, 'XTick', 0:0.2:1)
set(gca, 'YTick', [])
set(gca, 'FontSize', 12)


pLoseShiftCtrl = (length(intersect(loseShiftR, prevCtrl)) + length(intersect(loseShiftL, prevCtrl)) + 1) / (length(loseCtrl) + 2);
shiftC = length(intersect(loseShiftR, prevCtrl)) + length(intersect(loseShiftL, prevCtrl));
stayC = length(loseCtrl) - shiftC;
x = 0:0.002:1;
figure
plot(x, betapdf(x, shiftC+1, stayC+1), 'k', 'LineWidth', 3)
hold on
pLoseShiftLaser = (length(intersect(loseShiftR, prevLaser)) + length(intersect(loseShiftL, prevLaser)) + 1) / (length(loseLaser) + 2);
shiftL = length(intersect(loseShiftR, prevLaser)) + length(intersect(loseShiftL, prevLaser))
stayL = length(loseLaser) - shiftL;
plot(x, betapdf(x, shiftL+1, stayL+1), 'color', [0 0.75 0], 'LineWidth', 3)
y = ylim;
plot([pLoseShiftCtrl pLoseShiftCtrl], y, '--', 'color', 'k', 'LineWidth', 2)
plot([pLoseShiftLaser pLoseShiftLaser], y, '--', 'color', [0 0.75 0], 'LineWidth', 2)
xlabel('prob(shift|lose)')
set(gca, 'Box', 'off')
xlim([0 1])
set(gca, 'XTick', 0:0.2:1)
set(gca, 'YTick', [])
set(gca, 'FontSize', 12)


